/**
 * @Description 任务选择器
 * @Author chenlaichun
 * @Date 2018/5/3 13:46
 */
(function () {
    'use strict';

    angular.module('myApp')
        .directive('taskSelector', taskSelector);

    taskSelector.$inject = ['$ionicModal', '$http'];

    function taskSelector( $ionicModal, $http) {
        return {
            scope: {selectNode: "=", onSelect: "&onSelect"},
            templateUrl: 'scripts/components/taskSelector/taskSelectorTemplate.html',
            link: taskSelectorLink
        };
        function taskSelectorLink( $scope, $element, $attrs) {
            /*1我的工作任务 2每日工作PDCA 3每周工作PDCA 4每月工作PDCA 5每季工作PDCA 6半年工作PDCA 7项目管理 8事务交办 9工作报告*/
            $scope.dataFromMaps = {
                "1": "工作任务","2": "每日工作PDCA","3": "每周工作PDCA","4": "每月工作PDCA",
                "5": "每季工作PDCA","6": "半年工作PDCA","7": "项目协作","8": "事务交办","9": "工作报告"
            };
            //选择任务modal
            $ionicModal.fromTemplateUrl('choice-task-modal.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.choice_task_modal = modal;
            });
            /* 分页信息 */
            var pageable = {
                pageNumber: -1,
                pageSize: 10
            };
            /* 查询条件*/
            $scope.conditions = {
                completeStatus: 2,
                selectType: 1  /*1--本周 2--本月 3--不限*/
            };
            /* 展示数据 集合*/
            $scope.viewDataList = [];
            /* 数据加载方法 */
            var loadDataLing = function ( params, type) {
                var config = {
                    method:"POST",
                    url: basePath + '/third/workreport/findMyTaskDetailByConditions',
                    params: {pageSize: pageable.pageSize, pageNumber: pageable.pageNumber},
                    data: params
                };
                return $http( config).then(function (response) {
                    $scope.isError = false;
                    var data = response.data;
                    $scope.isLastPage = data.lastPage;
                    if ( "footer" === type) {
                        $scope.viewDataList = $scope.viewDataList.concat( data.content);
                        $scope.isLastPage = data.totalElements <= $scope.viewDataList.length;
                    } else {
                        $scope.viewDataList = data.content;
                    }
                }, function () {
                    $scope.isError = true;
                    $scope.viewDataList = [];
                }).finally(function(){
                    if ( type === 'footer') {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    } else {
                        $scope.$broadcast('scroll.refreshComplete');
                    }
                });

            };
            /* 进入指令 默认给一个 点击事件 点击展示选择器*/
            $element.bind( "click", function () {
                pageable.pageNumber = 0;
                loadDataLing( $scope.conditions);
                $scope.choice_task_modal.show();
            });
            /* 顶部取消按钮*/
            $scope.closeChoiceTask = function () {
                $scope.choice_task_modal.hide();
            };
            /* 点击确定按钮 关闭选择框 并且执行回调函数*/
            $scope.sureChoiceTask = function () {
                if ( $scope.selectNode && $scope.selectNode.id) {
                    var config = {
                        method:"POST",
                        url: basePath + '/third/workreport/findMyWorkTaskById',
                        params: {taskId: $scope.selectNode.id}
                    };
                    $http(config).then(function (response) {
                        $scope.onSelect( {item: response.data});
                        $scope.choice_task_modal.hide();
                    });
                } else {
                    $scope.onSelect( {item: {}});
                    $scope.choice_task_modal.hide();
                }
            };
            /* 选择完成状态 进行查询方法 */
            $scope.selectMyTask = function ( type) {
                $scope.conditions.selectType = type;
                pageable.pageNumber = 0;
                loadDataLing( $scope.conditions);
            };
            /* 选择办理截止日期 进行查询方法*/
            $scope.selectCompleteStatus = function ( type) {
                $scope.conditions.completeStatus = type;
                pageable.pageNumber = 0;
                loadDataLing( $scope.conditions);
            };
            /* 选中事件 执行方法*/
            $scope.selectedNode = function (item) {
                $scope.selectNode = angular.copy(item);
            };

            /* 下拉刷新和滑动至底部刷新*/
            $scope.ionRefresher = {
                /* 顶部刷新*/
                topRefresher: function () {
                    pageable.pageNumber = 0;
                    loadDataLing( $scope.conditions);
                },
                /* 下拉加载 */
                footerRefresher: function () {
                    pageable.pageNumber += 1;
                    loadDataLing( $scope.conditions, 'footer');
                }
            };
        }
    }
})();
