(function () {
    window.ynjs = window.ynjs || {};
    window.ynjs.version = '0.8.0';
    var moduleName = 'myApp';

    (function (ynjs) {
        var $callbackAction = {};//回调事件
        var $backAction = {};//cordova物理返回键回调事件,用于取消事件注册

        // 注册事件
        function registerBackAction(priority, callback, backAction) {
            cancelBackAction(priority);
            if (priority === 0) {
                //页面默认的路由返回
                $callbackAction[priority] = callback;
                priority = 101;
            }
            $callbackAction[priority] = callback;
            $backAction[priority] = backAction;
        }

        // 取消事件绑定
        function cancelBackAction(priority) {
            if (priority === undefined) {
                cancelBackAction(0);
                cancelBackAction(101);
                cancelBackAction(201);
            } else {
                if (priority === 0) {
                    delete $callbackAction[priority];
                    priority = 101;
                }
                delete $callbackAction[priority];
                if (ynjs.Util.isFunction($backAction[priority])) {
                    $backAction[priority]();
                }
            }
        }

        // 设置页面标题
        function setNavTitle(name) {
            if (ynjs.Platform.isAndroid()) {
                window.native.setMicroTitle(name);
            } else if (ynjs.Platform.isIOS()) {
                window.webkit.messageHandlers.setMicroTitle.postMessage(name);
            }
        }

        // 默认返回事件
        function defaultAction() {
            if ($callbackAction[0]) {
                //默认路由
                $callbackAction[0]();
            } else {
                //关闭微应用
                try {
                    finish();
                } catch (e) {
                    console.error('plugin: close() not defined');
                }
            }
        }

        // 关闭微应用
        function finish() {
            if (window && window.localStorage) {
                window.localStorage.setItem("microId", null);
            }
            yn.plugin.yncordova.close();
        }

        /**
         * ynjs.Navigator
         * @module ynjs
         * @description 导航事件
         * */
        var self = ynjs.Navigator = {};

        /**
         * @description 关闭微应用
         * */
        self.finish = function () {
            finish();
        };
        /**
         * @description 返回事件
         * @param force boolean ,true则忽略拦截事件
         * */
        self.pop = function (force) {
            if (force) {
                defaultAction();
            } else if ($callbackAction[201]) {
                //模态框
                $callbackAction[201]();
            } else if ($callbackAction[101]) {
                //路由
                $callbackAction[101]();
            } else {
                defaultAction();
            }
        };
        /**
         * @description 注册返回事件
         * @param priority number , 0:默认事件(框架需要), 101:页面拦截, 201:模态框拦截
         * @param callback function, 回调事件
         * @param backAction function, cordova拦截事件回调,用于注销拦截事件(框架需要)
         * */
        self.registerBackAction = function (priority, callback, backAction) {
            registerBackAction(priority, callback, backAction);
        };
        /**
         * @description 取消事件拦截
         * @param priority number, 0:默认事件(框架需要), 101:页面拦截, 201:模态框拦截
         * */
        self.cancelBackAction = function (priority) {
            cancelBackAction(priority);
        };
        /**
         * @description 设置微应用标题
         * @param title string, 微应用标题
         * */
        self.setNavTitle = function (title) {
            setNavTitle(title);
        };

        /**
         * @description 主要供iOS使用, 原生左上角返回事件
         * */
        self.historyBack = function () {
            cordova.fireDocumentEvent('backbutton');
        }
    })(window.ynjs);

    (function (ynjs) {
        /**
         * @name ynjs.Platform
         * @module ynjs
         * @description 判定当前设备类型, Android 或 IOS
         * @return boolean
         * @usage
         * var isAndroid = ynjs.Platform.isAndroid()
         * var isIOS = ynjs.Platform.isIOS()
         * */
        var self = ynjs.Platform = {
            navigator: window.navigator,
            ua: navigator.userAgent,
        }
        /**
         * @description 判定当前设备类型是否为Android
         * */
        self.isAndroid = function () {
            return self.ua.indexOf('Android') > 0;
        };
        /**
         * @description 判定当前设备类型是否为IOS
         * */
        self.isIOS = function () {
            return /iPhone|iPad|iPod/.test(self.ua);
        };
    })(window.ynjs);

    (function (ynjs) {
        /**
         * @name ynjs.Util
         * @module ynjs
         * @description 工具类
         * */
        var self = ynjs.Util = {}
        /**
         * @description 判断是否为函数
         * @param {*} value Reference to check.
         * @return boolean
         * */
        self.isFunction = function (value) {
            return typeof value === 'function';
        }
    })(window.ynjs);

    /**
     * @description Angular服务,路由控制
     * */
    angular.module(moduleName).factory('ynNavigator', ['$state', '$ionicPlatform', '$rootScope', function ($state, $ionicPlatform, $rootScope) {
        return {
            /**
             * @description 关闭微应用
             * */
            finish: function () {
                if (window.localStorage && window.localStorage.getItem($rootScope.microId)) {
                    window.localStorage.removeItem($rootScope.microId);
                }
                ynjs.Navigator.finish();
            },
            /**
             * @description 返回
             * @param force boolean ,true则忽略拦截事件
             * */
            pop: function (force) {
                ynjs.Navigator.pop(force);
            },
            /**
             * @description 注册返回事件
             * @param priority number , 0:默认事件(框架需要), 101:页面拦截, 201:模态框拦截
             * @param callback function, 回调事件
             * */
            registerBackAction: function (callback, priority) {
                var backAction = $ionicPlatform.registerBackButtonAction(callback, priority === 0 ? 101 : priority);
                ynjs.Navigator.registerBackAction(priority, callback, backAction);
            },
            /**
             * @description 取消事件拦截
             * @param priority number, 0:默认事件(框架需要), 101:页面拦截, 201:模态框拦截
             * */
            cancelBackAction: function (priority) {
                ynjs.Navigator.cancelBackAction(priority);
            },
            /**
             * @description 动态注册上级页面路由
             * @param preName string, 路由 name
             * */
            registerPrev: function (preName) {
                if (!$state.current.data) {
                    $state.current.data = {}
                }
                $state.current.data.prev = preName;
                this.registerBackAction(0, function () {
                    $state.go(preName);
                })
            },
            /**
             * @description 设置微应用标题
             * @param title string, 微应用标题
             * */
            setNavTitle: function (title) {
                ynjs.Navigator.setNavTitle(title);
            }
        }
    }]);

    /**
     * @description 路由事件初始化
     * */
    angular.module(moduleName).run(['$rootScope', '$state', '$ionicPlatform', 'ynNavigator', 'microNav', '$location', 'ynNavService',
        function ($rootScope, $state, $ionicPlatform, ynNavigator, microNav, $location, ynNavService) {
            // 路由事件
            $rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams) {
                if (!$rootScope.isReady) {
                    //baseInfo没初始化，阻断路由加载，等待广播
                    event.preventDefault();
                    $rootScope.$on('isReady', function () {
                        // 微应用选项卡及工作台防异步请求导致的抖动
                        ynNavService.getNav().then(function (data) {
                            // location:false, 保留get参数
                            $state.go(toState.name, toParams, {location: false})
                        }, function (error) {
                            // location:false, 保留get参数
                            $state.go(toState.name, toParams, {location: false})
                        });
                    })
                }
            });
            $rootScope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams) {
                $rootScope.$state = $state;
                $rootScope.fromState = fromState;

                // 返回事件注册, 默认为路由返回
                ynNavigator.cancelBackAction();
                // 默认关闭微应用
                ynNavigator.registerBackAction(function () {
                    ynNavigator.finish();
                }, 0)
                if (toState.data) {
                    if (toState.data.prev) {
                        //存在静态定义的上级路由, 注册默认返回事件为返回上级路由
                        ynNavigator.registerBackAction(function () {
                            $state.go(toState.data.prev);
                        }, 0)
                    }
                    if (toState.data.title != null) {
                        //设置标题
                        ynNavigator.setNavTitle(toState.data.title);
                    }
                    if (toState.data.micro) {
                        microNav.init();
                    } else {
                        microNav.clean();
                    }
                }
                // 数据埋点, key: E10046, value: 子应用路由
                try {
                    var stateName = toState.name;
                    console.log(stateName)
                    if(stateName !== 'loading' && stateName !== 'wr'){
                        yn.plugin.yncordova.sensorsDataAPI.trackAppClick({key:'E10046',value:stateName});
                    }
                }catch (e) {

                }

            });
            $rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {
                console.log('$stateChangeError');
            });
        }]);

    (function () {
        /**
         *
         * */
        angular.module(moduleName)
            .factory('ynNavService', ynNavService);

        ynNavService.$injiect = ['$q', '$rootScope', '$http'];

        function ynNavService($q, $rootScope, $http) {
            return {
                getNav: getNav,
                cleanNav: cleanNav
            };

            function getNav() {
                var deferred = $q.defer();
                if ($rootScope.microId) {
                    if (window.localStorage && window.localStorage.getItem($rootScope.microId)) {
                        var navData = angular.fromJson(window.localStorage.getItem($rootScope.microId));
                        deferred.resolve(navData);
                    } else {
                        $http
                            .get(basePath.replace("/smesis", "/ynedut") + '/third/microapp/get.htm?version=V1.0&microId=' + $rootScope.microId)
                            .success(function (data) {
                                if (data.status === 1) {
                                    if (data.result.length && data.result.length > 0) {
                                        var navData = data.result;
                                        window.localStorage.setItem($rootScope.microId, angular.toJson(navData));
                                        deferred.resolve(navData);
                                    } else {
                                        deferred.reject('navData is null');
                                    }
                                } else {
                                    deferred.reject('http status error');
                                }
                            })
                            .error(function (error) {
                                deferred.reject('http request error.');
                            });
                    }
                } else {
                    deferred.reject('microId is null.');
                }
                return deferred.promise;
            }

            function cleanNav() {

            }
        }
    })();

    (function () {
        /**
         * @description 服务, 微应用选项卡
         *
         * @usage microNav.init();
         * */
        var MICRO_APP = '<div class="nav-wrap" ng-if="isNavStatus">' +
            '<div class="mini-app-nav">' +
            '<div class="nav-item" ng-repeat="items in appList track by $index" ng-class="{\'active\':items.action.target === defaultActive}" ng-style="itemWidth" ng-click="navClick(items)">' +
            '<span ng-bind="items.name"></span>' +
            '</div>' +
            '<div class="nav-item nav-more" ng-if="isMoreStatus" ng-click="isMore = !isMore" ng-style="itemWidth">' +
            '<span ng-class="{\'color-theme\':isMoreChoose}"><span ng-bind="moreItem"></span><i class="icon {{isMore ? \'ion-arrow-up-b\' : \'ion-arrow-down-b\'}}"></i></span>' +
            '<div class="nav-more-list" ng-show="isMore">' +
            '<div class="nav-more-item" ng-repeat="item in appListMore track by $index" ng-class="{\'active\':item.action.target === defaultActive}" ng-click="navClick(item)">' +
            '<span ng-bind="item.name"></span>' +
            '</div>' +
            '</div>' +
            '</div>' +
            '</div>' +
            '</div>';

        var SUB_APP = '<div ng-if="isSubStatus" style="padding:15px;"><sub-app></sub-app></div>';

        angular.module(moduleName)
            .factory('microNav', microNav);
        microNav.$injector = ['$rootScope', '$state', '$ionicBody', '$compile', '$document', '$http', '$location', '$timeout', 'ynNavService'];

        function microNav($rootScope, $state, $ionicBody, $compile, $document, $http, $location, $timeout, ynNavService) {
            var servise = {
                    init: init,
                    clean: clean,
                    showSubApp: showSubApp
                },
                jqLite = angular.element,
                self = {};
            self.scope = $rootScope.$new();
            self.element = jqLite(MICRO_APP);

            var initDom = function () {
                /*获取选项卡位置并创建dom*/
                var get_nav_dom = $($document[0].body.children[0]);
                get_nav_dom.append(self.element[0]);
                // $ionicBody.get().appendChild(self.element[0]);
                $compile(self.element)(self.scope);

//                self.scope.isNavStatus = true;//是否显示菜单
                self.scope.isMoreStatus = false;//控制菜单更多

                var getMicro = function () {
                    if (self.scope.appList && self.scope.appList.length > 1) {
                        self.scope.isNavStatus = !self.scope.isSubStatus;
                        defaultChoose();
                        /*菜单多于3个则展示更多*/
                        if (self.scope.appList.length > 3) {
                            self.scope.isMoreStatus = true;
                            self.scope.itemWidth = {
                                "width": "33.333%"
                            };
                            var appLists = [];
                            self.scope.appListMore = [];
                            angular.forEach(self.scope.appList, function (datas, index) {
                                if (index < 2) {
                                    appLists.push(datas);
                                    self.scope.appList = appLists;
                                } else {
                                    self.scope.appListMore.push(datas);
                                }
                            });
                        } else {
                            self.scope.itemWidth = {
                                "width": 100 / self.scope.appList.length + '%'
                            };
                        }
                    } else {
                        self.scope.isNavStatus = false;
                    }
                    moreChoose();
                };
                ynNavService.getNav().then(function (data) {
                    self.scope.appList = data;
                    self.scope.isNavStatus = true;
                    getMicro();
                }, function (error) {
                    self.scope.isNavStatus = false;
                });
            };

            /*根据路由选中*/
            var defaultChoose = function () {
                angular.forEach(self.scope.appList, function (data, index) {
                    if ($state.current.name === data.action.target || (decodeURIComponent($location.absUrl()).indexOf(data.action.target)) > 0) {
                        return self.scope.defaultActive = data.action.target;
                    }
                });
            };

            /*选中更多*/
            var moreChoose = function () {
                self.scope.moreItem = "更多";
                if (self.scope.appListMore) {
                    angular.forEach(self.scope.appListMore, function (data, index) {
                        if (self.scope.defaultActive === data.action.target) {
                            self.scope.moreItem = data.name;
                            return self.scope.isMoreChoose = true;
                        }
                    });
                }
            };
            /*点击切换 回调*/
            self.scope.navClick = function (item) {
                self.scope.isMoreChoose = false;
                clickDom(servise.data, item);
            };

            var clickDom = function (data, item) {
                if (data !== undefined) {
                    data(item);
                } else {
                    if ((item.action.target).indexOf('/wr?') === 0) {
                        if (ynjs.Platform.isIOS()) {
                            var param = item.action.target.replace('/wr?', '');
                            var access_token = $rootScope.authorizationStr.access_token;
                            var server = basePath.replace('/smesis', '/wr');
                            var wrUrlBase = server.concat('/ynauth?accessToken=', access_token, '&', param);

                            window.webkit.messageHandlers.openUrl.postMessage({url: wrUrlBase});
                        } else {
                            self.scope.defaultActive = item.action.target;
                            $location.url('/loading');
                            $timeout(function () {
                                $location.url(item.action.target).replace();
                            }, 0);
                        }
                    } else {
                        self.scope.defaultActive = item.action.target;
                        $state.go(item.action.target);
                    }
                    moreChoose();
                }
            };

            function init(data) {
                servise.data = data;
                initDom();
            }

            function clean() {
                self.scope.isNavStatus = false;
                self.scope.isSubStatus = false;
                // if (window.localStorage && window.localStorage.getItem($rootScope.microId)) {
                //     window.localStorage.removeItem($rootScope.microId);
                // }
            }

            /**
             * 替换工作台成样式
             * 为解决ios报表新开空白效果*/
            function showSubApp() {
                self.scope.isNavStatus = false;
                self.scope.isSubStatus = true;
                self.element = jqLite(SUB_APP);
                var get_nav_dom = $($document[0].body.children[0]);
                get_nav_dom.append(self.element[0]);
                $compile(self.element)(self.scope);
            }

            return servise;
        }
    })();

    (function () {
        /**
         * @description 指令, 微应用工作台列表
         * */
        angular.module(moduleName).directive("subApp", subApp);

        subApp.$injector = ['ynNavService', '$location', '$timeout'];

        function subApp(ynNavService, $location, $timeout) {
            return {
                restrict: 'E',
                replace: true,
                scope: {
                    onItemClick: '='
                },
                template: '<div class="mini-app-list" ng-show="subappisStatus">' +
                    '<div  class="mini-app-item" ng-click="clickCallback(item)" ng-repeat="item in appList">' +
                    '<div class="app-icon">' +
                    '<img ng-if="originBaseUrl" ng-src="{{originBaseUrl+item.icon}}" err-src="img/micapp_icon.png"></div>' +
                    '<div class="app-name" ng-bind="item.name"></div>' +
                    '</div>' +
                    '</div>',
                controller: Ctrl
            };

            function Ctrl($scope, $state, $http, $rootScope) {
                $scope.originBaseUrl = basePath;
                $scope.subappisStatus = false;

                ynNavService.getNav().then(function (data) {
                    $scope.appList = data;
                    $scope.subappisStatus = true;
                }, function (error) {
                    console.log(error);
                    $scope.subappisStatus = false;
                });

                $scope.clickCallback = function (item) {
                    if ($scope.onItemClick !== undefined) {
                        $scope.onItemClick(item);
                    } else {
                        if ((item.action.target).indexOf('/wr?') === 0) {
                            if (ynjs.Platform.isIOS()) {
                                var param = item.action.target.replace('/wr?', '');
                                var access_token = $rootScope.authorizationStr.access_token;
                                var server = basePath.replace('/smesis', '/wr');
                                var wrUrlBase = server.concat('/ynauth?accessToken=', access_token, '&', param);

                                window.webkit.messageHandlers.openUrl.postMessage({url: wrUrlBase});
                            } else {
                                // 工作台自定义报表， 区别与选项卡报表逻辑
                                $timeout(function () {
                                    $location.url((item.action.target + '&microName=' + item.name).replace('/wr', '/wrstation')).replace();
                                }, 0);
                            }
                        } else {
                            $state.go(item.action.target);
                        }
                    }
                };
            }
        }
    })();

    (function () {
        /**
         * @description 图片加载
         * */
        angular.module(moduleName).directive("errSrc", errSrc);

        function errSrc() {
            return {
                link: function(scope, element, attrs) {
                    element.bind("error", function() {
                        if (attrs.src !== attrs.errSrc) {
                            attrs.$set("src", attrs.errSrc);
                        }
                    });
                }
            }
        }
    })();


})();