/**
 * @Description: 工作任务
 * @Author: qiuchegn Lu
 * @Date: 2021年4月14日11:11:54
 */
(function () {
    'use strict';
    angular
        .module('myApp')
        .config(stateConfig)
        .controller('taskManageController', taskManageController)
        .controller('addTaskController', addTaskController)
        .controller('taskViewController', taskViewController)
        .directive('taskEditComplete', taskEditComplete)
        .controller('jobReportController', jobReportController)
        .controller('jobReportAddController', jobReportAddController)
        .controller('jobReportDetailController', jobReportDetailController)
        .controller('jobRecordController', jobRecordController)

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        /*任务交办数据展示页面*/
            .state('task_manage', {
                homePage: true,
                url: '/task_manage',
                templateUrl: 'views/task_manage/task_manage.html',
                data: {
                    micro: true,
                    title: '工作任务'
                },
                controller: 'taskManageController'
            })
            /*任务交办任务添加页面*/
            .state('add_task', {
                url: '/add_task',
                templateUrl: 'views/task_manage/add_task.html',
                data: {
                    title: '任务交办',
                    prev: 'task_manage'
                },
                controller: 'addTaskController'
            })
            /*任务交办具体数据展示页面*/
            .state('task_view', {
                url: '/task_view',
                templateUrl: 'views/task_manage/task_view.html',
                data: {
                    title: '任务交办',
                    prev: 'task_manage'
                },
                controller: 'taskViewController'
            })
            /*工作报告主界面*/
            .state('job_report', {
                homePage: true,
                url: '/job_report',
                templateUrl: 'views/job_report/job_report.html',
                data: {
                    micro: true,
                    title: '工作任务'
                },
                controller: 'jobReportController'
            })
            /*添加或修改工作报告*/
            .state('add_report', {
                url: '/add_report',
                templateUrl: 'views/job_report/add_report.html',
                data: {
                    title: '工作报告',
                    prev: 'job_report'
                },
                controller: 'jobReportAddController'
            })
            /*查看报告/报告详情*/
            .state('report_detail', {
                url: '/report_detail',
                templateUrl: 'views/job_report/report_detail.html',
                data: {
                    title: '工作报告',
                    prev: 'job_report'
                },
                controller: 'jobReportDetailController'
            })
            /*工作日志主界面*/
            .state('job_record', {
                homePage: true,
                url: '/job_record',
                templateUrl: 'views/job_record/job_record.html',
                data: {
                    micro: true,
                    title: '工作任务'
                },
                controller: 'jobRecordController'
            })
    }


    taskManageController.$inject = ['$scope', '$ionicPopup', '$http', '$ionicLoading', '$ionicScrollDelegate', '$location'];

    /*任务交办数据展示页面*/
    function taskManageController($scope, $ionicPopup, $http, $ionicLoading, $ionicScrollDelegate, $location) {

        /* 传入的数据id */
        var search = $location.search();
        var tabIndex = search.tabIndex;

        var basePathResource = basePath + "/third/taskmanageresource";
        /** 查询数据 查询条件 **/
        $scope.conditions = {};
        /** 当前分页信息 **/
        var pageable = {pageSize: 10, pageNumber: 0};
        /** 展示数据集合 **/
        $scope.dataList = [];

        /**
         * Description: 点击顶部标签页 修改查询数据
         * Author: chenlaichun
         * Date: 2018/7/17 10:16
         */
        $scope.changeStatus = function (type) {
            $scope.tabIndex = parseInt(type);

            $scope.dataList = [];
            /* 每次点击标签页 就清空展示的数据 重新查询*/
            pageable.pageNumber = 0;
            /* 每次点击标签页 就重新从第一页数据查询*/

            /* 修改查询条件 */
            setCheckBox(2);
            /* 默认查询 未完成 */
            $scope.conditions.userType = type;
            /* 顶部查询内容 指定查询状态*/
            /* 获取数据 */
            $scope.loadData(pageable);
        };

        /**
         * Description: 获取展示数据方法  conditions 查询条件
         * Author: chenlaichun
         * Date: 2018/7/17 10:21
         */
        $scope.isLastPage = true;

        var getDataList = function (conditions, pageabel, loadType) {
            pageabel = pageabel || {pageSize: 10, pageNumber: 0};
            var config = {
                method: "POST",
                url: basePathResource + "/findTaskManageDTOByConditions",
                params: pageabel,
                data: conditions || {}
            };
            $scope.ionicLoadingShow();
            $http(config)
                .success(function (data) {
                    $scope.isError = false;
                    /* 错误状态 为false*/
                    var dataPage = data;
                    /* 获取的数据 */
                    $scope.isLastPage = dataPage.lastPage;
                    /* 是否最后一页数据*/
                    /* 只有底部加载的数据 才加载合并集合*/
                    if ('footerLoading' === loadType) {
                        $scope.dataList = $scope.dataList.concat(dataPage.content);
                    } else {
                        $scope.dataList = dataPage.content;
                    }
                })
                .error(function () {
                    $scope.isError = true;
                    $scope.dataList = [];
                })
                .finally(function () {
                    /* 根据加载类型 判断关闭加载圆圈*/
                    if (loadType === 'footerLoading') {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    } else if (loadType === 'topLoading') {
                        $scope.$broadcast('scroll.refreshComplete');
                    }
                    $scope.ionicLoadingHide();
                });
        };
        //加载中 提示信息
        $scope.ionicLoadingShow = function () {
            // $ionicLoading.show({
            //     template: '<ion-spinner class="spinner-theme"></ion-spinner><h4 class="text-theme">加载中</h4>'
            // });
        };
        // 关闭正在加载提示信息
        $scope.ionicLoadingHide = function () {
            // $ionicLoading.hide();
        };
        /**
         * Description: 加载数据
         * Author: chenlaichun
         * Date: 2018/7/17 16:20
         */
        $scope.loadData = function (pageable, loadType) {
            getDataList($scope.conditions, pageable, loadType);
        };

        /**
         * Description: 点击行操作
         * Author: chenlaichun
         * Date: 2018/7/17 14:01
         */
        $scope.clickRow = function (item) {
            $location.path('/task_view').search({id: item.id, tabIndex: $scope.tabIndex});
        };

        /**
         * Description: 跳转到添加任务页面
         * Author: chenlaichun
         * Date: 2018/7/17 17:01
         */
        $scope.goAddTask = function () {
            $location.path('/add_task').search({tabIndex: $scope.tabIndex});
        };

        /**
         * Description: 点击完成状态
         * Author: chenlaichun
         * Date: 2018/7/17 15:58
         */
        $scope.checkBox = {completed: false, hangInAir: true};
        $scope.checkBoxClick = function (type) {
            $scope.dataList = [];
            /* 修改完成状态 那就清空数据*/
            pageable.pageNumber = 0;
            /* 从第一页重新加载*/
            setCheckBox(type);
            $scope.loadData(pageable);
        };
        /**设置 完成状态 并且展示**/
        var setCheckBox = function (completeStatus) {
            /* 完成状态为1 那就是已完成*/
            if (Number(completeStatus) === 1) {
                $scope.checkBox = {completed: true, hangInAir: false, cancel: false, moreCompleted: false};
            } else if (Number(completeStatus) === 2) {
                /* 完成状态不为 1 那就是未完成 */
                $scope.checkBox = {completed: false, hangInAir: true, cancel: false, moreCompleted: false};
            } else if (Number(completeStatus) === 3) {
                $scope.checkBox = {completed: false, hangInAir: false, cancel: true, moreCompleted: false};
            } else if (Number(completeStatus) === 99) {
                $scope.checkBox = {completed: false, hangInAir: false, cancel: false, moreCompleted: true};
            }
            $scope.conditions.completeStatus = completeStatus;
        };

        /**
         * Description: 瀑布流加载数据
         * Author: chenlaichun
         * Date: 2018/7/17 16:31
         */
        $scope.ionRefresher = {
            topRefresher: function () {
                pageable.pageNumber = 0;
                $scope.loadData(pageable, 'topLoading');
            },
            footerRefresher: function () {
                pageable.pageNumber += 1;
                $scope.loadData(pageable, 'footerLoading');
            }
        };
        /* 获取 配置加载规则 */
        $http.get(basePathResource + "/findNowWorkTaskSet").success(function (data) {
            if (data.status === "0") {
                $scope.workTaskSet = data.result;
                $scope.changeStatus(tabIndex || 2);
            }
        });
    }

    addTaskController.$inject = ['$scope', '$ionicPopup', '$http', '$ionicLoading', '$ionicScrollDelegate', '$location', 'ynNavigator'];

    /*任务交办任务添加页面*/
    function addTaskController($scope, $ionicPopup, $http, $ionicLoading, $ionicScrollDelegate, $location, ynNavigator) {

        /**新建任务 任务对象**/
        $scope.addTaskData = {isWorkTask: true};

        /**错误提示信息方法**/
        var errorLoading = function (template) {
            $ionicLoading.show({
                template: template,
                duration: 2000
            });
        };
        /* 是否允许 点击保存*/
        $scope.opreation = {
            cancelSubmit: true
        };
        /**
         * Description: 用于人员选择器回填 集合获取
         * Author: chenlaichun
         * Date: 2018/7/20 10:01
         */
        var getUserListt = function (details) {
            var users = [];
            if (angular.isArray(details)) {
                angular.forEach(details, function (data) {
                    users.push({id: data.userId, name: data.userName, jobNumber: data.jobNumber});
                });
            }
            return users;
        };

        /**
         * Description: 人员选择器 选择回填 ()
         * Author: chenlaichun
         * Date: 2018/7/17 17:09
         */
        $scope.selectUser = {
            getNewDetail: function (userInfo, userType) {
                return {userName: userInfo.name, userId: userInfo.id, userType: userType};
            },
            getDetailList: function (userInfoList, userType, map, romveMap) {
                var list = [];
                map = map || {};
                if (angular.isArray(userInfoList)) {
                    angular.forEach(userInfoList, function (userInfo) {
                        var newDetail = $scope.selectUser.getNewDetail(userInfo, userType);
                        newDetail.planTime = map[userInfo.id];
                        if (romveMap) {
                            newDetail.isRomve = romveMap[userInfo.id];
                        }
                        list.push(newDetail);
                    });
                }
                return list;
            },
            /* 展示人员选择器 */
            showSelector: function (onField) {
                if (onField) {
                    $scope.$broadcast(onField);
                }
            },
            /* 主办人回填 */
            mainUser: function (item) {
                $scope.addTaskData.mainDetailDTO = $scope.selectUser.getNewDetail(item, 2);
            },
            /* 协办人 回填*/
            helpUser: function (items) {
                /* 先备份 协办人员的 计划工时 */
                var detailMap = {}, isRomveMap = {}, noRomveMap = {}, noRomveIds = [];
                if (angular.isArray($scope.addTaskData.helpDetailDTOList)) {
                    angular.forEach($scope.addTaskData.helpDetailDTOList, function (data) {
                        detailMap[data.userId] = data.planTime;
                        isRomveMap[data.userId] = data.isRomve;
                        if (data.isRomve) {
                            noRomveMap[data.userId] = data;
                            noRomveIds.push(data.userId);
                        }
                    });
                }
                var newDetails = $scope.selectUser.getDetailList(items, 3, detailMap, isRomveMap);
                angular.forEach(noRomveIds, function (id) {
                    var isFlag = false;
                    angular.forEach(newDetails, function (val) {
                        if (id == val.userId) {
                            isFlag = true;
                        }
                    });
                    if (!isFlag) {
                        newDetails.push(noRomveMap[id]);
                    }
                });
                $scope.addTaskData.helpDetailDTOList = newDetails;
                $scope.addTaskData.helpSelectUserList = items;
                /* 用于回填 */
                /* 处理工时问题 */
                updateTaskUser($scope.addTaskData.helpDetailDTOList);
            },
            /* 关注人 */
            watchUser: function (items) {
                $scope.addTaskData.watchDetailDTOList = $scope.selectUser.getDetailList(items, 4);
                $scope.addTaskData.watchSelectUserList = items;
                /* 用于回填 */
                var userNames = [];
                angular.forEach(items, function (val) {
                    userNames.push(val.name);
                });
                $scope.addTaskData.watchUserNames = userNames.toString();
            },
            /* 移除指定集合指定位置人员 */
            reomveUser: function (users, index, isRomve) {
                if (angular.isArray(users) && !isRomve) {
                    users.splice(index, 1);
                }
            }
        };

        /**
         * @Description: 时间比较
         * @Author chenlaichun
         * @Date 2018/10/20 09:52
         */
        var compareDate = function (start, end) {
            if (start && end) {
                return (new Date(start.replace(/-/g, "\/"))) > (new Date(end.replace(/-/g, "\/")));
            }
            return false;
        };

        /**
         * Description: 底部方法
         * Author: chenlaichun
         * Date: 2018/7/18 10:09
         */
        $scope.footerFun = {
            /**返回**/
            back: function (isSave) {
                if (isSave) {
                    if (id) {
                        $location.path("/task_view").search({tabIndex: tabIndex, id: id});
                    } else {
                        $location.path("/task_manage").search({tabIndex: tabIndex});
                    }
                } else {
                    $ionicPopup.confirm({
                        title: '返回提示',
                        template: '<h5 class="margin-bottom-0">返回后当前编辑内容将丢失,确定要返回吗？</h5>',
                        buttons: [
                            {text: '继续编辑', type: 'button-outline button-theme button-local'},
                            {
                                text: '确定返回', type: ' button-theme button-local',
                                onTap: function () {
                                    if (isView && id) {
                                        $location.path("/task_view").search({tabIndex: tabIndex, id: id});
                                    } else {
                                        $location.path("/task_manage").search({tabIndex: tabIndex});
                                    }
                                }
                            }
                        ]
                    });
                }
            },
            /**保存**/
            save: function (saveTask) {
                /* 验证 必填项 */
                /* 1 任务名称*/
                if (!saveTask.taskName) {
                    return errorLoading("任务名称不能为空");
                }
                /* 1 办理截止日期*/
                if (!saveTask.startTime) {
                    return errorLoading("办理起始日期不能为空");
                }
                if (!saveTask.endTime) {
                    return errorLoading("办理截止日期不能为空");
                }
                if (compareDate(saveTask.startTime, saveTask.endTime)) {
                    return errorLoading("办理起始日期不能大于办理截止日期");
                }
                /* 1 主办人*/
                if (!saveTask.mainDetailDTO || !saveTask.mainDetailDTO.userId) {
                    return errorLoading("主办人不能为空");
                }

                /*验证人员是否重复*/
                var repeatMessage = "";
                /* 验证 计划工时 */
                var mainPlanTimeFlag = checkPlanTime(saveTask.mainDetailDTO.planTime);
                if (!mainPlanTimeFlag) {
                    return errorLoading("计划工时填写范围：0.2-10小时（支持1位小数）！");
                }
                /* 验证 协办人 */
                var helpDetailList = saveTask.helpDetailDTOList;
                var helpUserIds = [];
                if (helpDetailList && angular.isArray(helpDetailList)) {
                    var errorMessage = [];
                    angular.forEach(helpDetailList, function (val) {
                        helpUserIds.push(val.userId);
                        if (!checkPlanTime(val.planTime)) {
                            errorMessage.push(val.userName);
                        }
                        if (val.userId == saveTask.mainDetailDTO.userId) {
                            repeatMessage = "协办人不能和主办人相同";
                        }
                    });
                    if (repeatMessage) {
                        return errorLoading(repeatMessage);
                    }
                    if (errorMessage.length > 0) {
                        return errorLoading("计划工时填写范围：0.2-10小时（支持1位小数）！");
                    }
                }
                /* 验证 关注人 */
                var watchDetailList = saveTask.watchDetailDTOList;
                if (watchDetailList && angular.isArray(watchDetailList)) {
                    angular.forEach(watchDetailList, function (val) {
                        if (!repeatMessage) {
                            if (val.userId == saveTask.mainDetailDTO.userId) {
                                repeatMessage = "关注人不能和主办人相同";
                            }
                            if (helpUserIds.indexOf(val.userId) > -1) {
                                repeatMessage = "关注人不能和协办人相同";
                            }
                        }
                    });
                    if (repeatMessage) {
                        return errorLoading(repeatMessage);
                    }
                }
                ;

                $scope.opreation.cancelSubmit = false;
                /* 保存数据 */
                $http.post(basePath + "/third/taskmanageresource/saveOrUpdateTaskManage", saveTask).success(function (data) {
                    $scope.opreation.cancelSubmit = true;
                    if (data.status === '0') {
                        $scope.footerFun.back(true);
                    } else {
                        return errorLoading(data.message);
                    }
                });
            }
        };
        //框架返回拦截处理
        ynNavigator.registerBackAction(function () {
            $scope.footerFun.back();
        }, 101);
        /**
         * Description: 验证指定计划工时是否满足条件
         * Author: chenlaichun
         * Date: 2018/7/21 11:04
         */
        var checkPlanTime = function (planTime) {
            /* 因为允许为空 所以 为空返回true */
            if (!planTime) {
                return false;
            }
            return /^((0\.[2-9])|([1-9](\.[0-9])?)|10|10.0)$/.test(planTime);
        };

        /**
         * Description: 展示更多
         * Author: chenlaichun
         * Date: 2018/7/18 9:56
         */
        $scope.clickMore = function () {
            $scope.showMore = !$scope.showMore;
        };

        /* 传入的数据id */
        var search = $location.search();
        var id = search.id;
        var tabIndex = search.tabIndex;
        var isView = search.isView;

        if (id) {
            //修改title
            ynNavigator.setNavTitle("编辑");
            /* 保存数据 */
            $http.get(basePath + "/third/taskmanageresource/findTaskManageDTOById?id=" + id).success(function (data) {
                $scope.addTaskData = angular.copy(data);
                /* 处理 协办人人员选择器回填 */
                $scope.addTaskData.helpSelectUserList = getUserListt(data.helpDetailDTOList);
                /* 处理 关注人 人员选择器回填 */
                $scope.addTaskData.watchSelectUserList = getUserListt(data.watchDetailDTOList);

                $scope.updateMainPlanTime($scope.addTaskData.mainDetailDTO.planTime, true);

                /* 通知调用 文件加载指令*/
                if ($scope.addTaskData && $scope.addTaskData.fsAnnexIDs) {
                    $scope.$broadcast('filesDone');
                }
            })
        } else {
            /* 保存数据 */
            $http.get(basePath + "/third/taskmanageresource/findTaskCommonlyUsers").success(function (data) {
                if (data) {
                    /* 主办人 */
                    var mainUserInfo = data["2"];
                    if (mainUserInfo && angular.isArray(mainUserInfo) && mainUserInfo.length > 0) {
                        $scope.addTaskData.mainDetailDTO = mainUserInfo[0];
                    }
                    /* 协办人 */
                    var helpUserInfoList = data["3"];
                    if (helpUserInfoList && angular.isArray(helpUserInfoList)) {
                        $scope.addTaskData.helpDetailDTOList = helpUserInfoList;
                        /* 处理 协办人人员选择器回填 */
                        $scope.addTaskData.helpSelectUserList = getUserListt(helpUserInfoList);
                    }
                    /* 关注人 */
                    var watchUserInfoList = data["4"];
                    if (watchUserInfoList && angular.isArray(watchUserInfoList)) {
                        $scope.addTaskData.watchDetailDTOList = watchUserInfoList;
                        var userNames = [];
                        angular.forEach(watchUserInfoList, function (val) {
                            userNames.push(val.userName);
                        });
                        $scope.addTaskData.watchUserNames = userNames.toString();
                        /* 处理 关注人人员选择器回填 */
                        $scope.addTaskData.watchSelectUserList = getUserListt(watchUserInfoList);
                    }
                }
            });
        }
        /**
         * Description: 处理计划工时问题
         * Author: chenlaichun
         * Date: 2018-11-14 15:40
         */
        var updateTaskUser = function (list, isLoad) {
            (angular.isArray(list) && !isLoad) && list.forEach(function (val) {
                (!val['planTime']) && (val['planTime'] = $scope.mainPlanTime);
            });
        };
        /**
         * Description: 计划工时填写完成后处理
         * Author: chenlaichun
         * Date: 2018-11-14 15:43
         */
        $scope.updateMainPlanTime = function (planTime, isLoad) {
            $scope.mainPlanTime = planTime;
            updateTaskUser($scope.addTaskData.helpDetailDTOList, isLoad);
        };

    }

    taskViewController.$inject = ['$scope', '$ionicPopup', '$http', '$ionicLoading', '$ionicScrollDelegate', '$location', 'Attachment', 'ynNavigator'];

    /*任务交办具体数据展示页面*/
    function taskViewController($scope, $ionicPopup, $http, $ionicLoading, $ionicScrollDelegate, $location, Attachment, ynNavigator) {

        var basePathResource = basePath + "/third/taskmanageresource";
        /**错误提示信息方法**/
        var errorLoading = function (template) {
            $ionicLoading.show({
                template: template,
                duration: 2000
            });
        };
        /** 需要提示确认的提示信息 **/
        var popupConfirm = function (message, onTap) {
            $ionicPopup.confirm({
                title: '提示',
                template: message || "",
                buttons: [
                    {text: '取消'},
                    {
                        text: '确定', type: "button-positive",
                        onTap: function () {
                            if (angular.isFunction(onTap)) {
                                onTap();
                            }
                        }
                    }
                ]
            });
        };
        /** 需要提示确认的提示信息 **/
        var popupShow = function (message, onTap) {
            $ionicPopup.show({
                title: '提示', template: message || "",
                buttons: [
                    {text: '取消', type: 'button-outline button-theme button-local'},
                    {
                        text: '确定', type: "button-theme button-local",
                        onTap: function () {
                            if (angular.isFunction(onTap)) {
                                onTap();
                            }
                        }
                    }
                ]
            });
        };
        /**
         *  查看附件
         */
        $scope.viewFileFun = function (fsIds) {
            if (fsIds && fsIds.length > 0) {
                Attachment.show(fsIds.toString());
            }
        };

        //获取事务完成状态
        $http.get(basePath + "/third/affairsassigned/findMobileCompleteStatus").success(function (data) {
            if (data) {
                $scope.completeDataList = data;
            }
        });

        /* 传入的数据id */
        var search = $location.search();
        var id = search.id;
        var tabIndex = search.tabIndex;

        var getTaskData = function (id) {
            /* 查询展示数据 */
            $http.get(basePathResource + "/findTaskViewMapById?id=" + id).success(function (data) {
                $scope.taskData = angular.copy(data);
            });
        };
        getTaskData(id);

        /**
         * Description: 详细描述 展示更多按钮方法
         * Author: chenlaichun
         * Date: 2018/7/20 10:46
         */
        $scope.descritionShowMore = function (data) {
            data.descriptionShow = data.description;
        };
        /**
         * Description: 点击顶部tab 获取数据展示
         * Author: chenlaichun
         * Date: 2018/7/19 17:02
         */
        $scope.updateTab = function (isTab) {
            $scope.isTab = isTab;
            if (isTab === 1) {
                /* 基本信息查看 */
                $http.get(basePathResource + "/findTaskBaseInfoById?id=" + id).success(function (data) {
                    /* 处理创建方式展示 */
                    if (data.createWayMessage && data.createWayMessage.indexOf(";")) {
                        var wayMessages = data.createWayMessage.split(";");
                        data.createWayMessage = wayMessages[1];
                    }
                    /* 处理 附件展示 */
                    data.fileNumber = 0;
                    if (data.fileIds) {
                        var fileIds = data.fileIds.split(",");
                        data.fileNumber = fileIds.length;
                        data.fileIdList = fileIds;
                    }
                    /* 处理 详细描述 展示 */
                    if (data.description && data.description.length >= 50) {
                        data.descriptionShow = data.description.substring(0, 50) + "...";
                    } else {
                        data.descriptionShow = data.description;
                    }
                    $scope.taskBaseInfo = angular.copy(data);
                });
            } else if (isTab === 2) {
                /* 关联人员查看 */
                $http.get(basePathResource + "/findTaskAssociatesById?id=" + id).success(function (data) {
                    $scope.associates = angular.copy(data);
                });
            } else if (isTab === 3) {
                /* 子任务查看 */
                $http.get(basePathResource + "/findTaskSubtaskById?id=" + id).success(function (data) {
                    $scope.subTasks = angular.copy(data);
                });
            } else if (isTab === 4) {
                /* 工作报告查看 */
                $http.get(basePathResource + "/findTaskReportById?id=" + id).success(function (data) {
                    if (angular.isArray(data)) {
                        /* 遍历处理 附件展示问题*/
                        angular.forEach(data, function (val) {
                            val.fileNumber = 0;
                            if (val.fileIds) {
                                var fileIds = val.fileIds.split(",");
                                val.fileNumber = fileIds.length;
                                val.fileIdList = fileIds;
                            }
                        });
                        $scope.reports = angular.copy(data);
                    }
                });
            }
        };
        /* 默认展示 tab 1*/
        $scope.updateTab(1);

        /**
         * Description: 底部操作按钮
         * Author: chenlaichun
         * Date: 2018/7/19 18:22
         */
        $scope.footerFun = {
            back: function () {
                $location.path("/task_manage").search({tabIndex: tabIndex});
                setTimeout(function () {
                    $scope.$apply();
                });
            },
            update: function () {
                $location.path('/add_task').search({id: id, tabIndex: tabIndex, isView: true});
            },
            addReport: function () {
                $location.path('/add_report').search({taskId: id, taskTabIndex: tabIndex});
            },
            /* 取消任务 */
            cancelTask: function () {
                var cancelFun = function () {
                    $http.get(basePathResource + "/updateCancelStatus?id=" + id).success(function (data) {
                        if (data.status !== "0") {
                            return errorLoading(data.message);
                            /* 给出提示 */
                        }
                        /*重新加载数据判断权限*/
                        /* 重新加载当前页面 数据按钮*/
                        getTaskData(id);
                        $scope.updateTab($scope.isTab);
                        errorLoading("取消成功");
                        /* 给出提示 */
                    });
                };
                popupConfirm("是否确认取消当前交办任务？", cancelFun);
            },
            /* 删除任务 */
            delTask: function () {
                var delFun = function () {
                    $http.get(basePathResource + "/deleteTaskById?id=" + id).success(function (data) {
                        if (data.status !== "0") {
                            return errorLoading(data.message);
                        }
                        errorLoading("删除任务成功");
                        $scope.footerFun.back();
                    });
                };
                popupShow("确定要删除所选吗？删除后无法恢复。", delFun);
            }
        };
        //框架返回拦截处理
        ynNavigator.registerBackAction(function () {
            $scope.footerFun.back();
        }, 101);
        /**
         * Description: 修改完成状态和计划工时
         * Author: chenlaichun
         * Date: 2018/7/19 18:27
         */
        $scope.updateCompleteStatus = function (item, data) {
            var saveData = {id: item.id, reallyTime: data.reallyTime, complateCode: data.complateCode};
            /* 保存数据 成功后重新加载数据 失败给出提示*/
            $http.post(basePathResource + "/updateComplate", saveData).success(function (data) {
                if (data.status === "0") {
                    $scope.updateTab($scope.isTab);
                } else {
                    errorLoading(data.message);
                }
            });
        };

        /**
         * @Description 编辑任务完成状态
         * @Author chenlaichun
         * @Date 2018/9/7 0007 17:34
         */
        $scope.completeStatusList = [{code: '1', name: '已完成'}, {code: '2', name: '未完成'}, {code: '3', name: '已取消'}];
        $scope.updateComplete = function (item) {
            if (item) {
                $http.get(basePathResource + "/updateCompleteStatus?id=" + id + "&completeStatus=" + item.code).success(function (data) {
                    getTaskData(id);
                    $scope.updateTab($scope.isTab);
                });
            }
        };

    }

    taskEditComplete.$inject = ["$http", "$ionicLoading", '$ionicPopup'];

    function taskEditComplete($http, $ionicLoading, $ionicPopup) {

        var template = "<div class='button-list'>" +
            "<div class='row col-lefttext-rightinput' >" +
            "<strong class='left-text text-left'>办理工时</strong>" +
            "<input type='text' class='form-control input-border-bottom' ng-model='selectData.reallyTime' maxlength='10' ng-disabled='selectData.isDisabled' style='background-color: transparent;'>" +
            "</div>" +
            // "<div class='row'> " +
            //     "<strong class='pull-left'>完成状态</strong>"+
            // "</div>" +
            "<div class='slide-select-buttons' style='margin-bottom: 0'>" +
            "<div class='slide-select-button' ng-repeat='info in initList track by $index'>" +
            "<button class='button button-local button-block button-theme button-outline'" +
            " ng-class='{\"active\": selectData.complateCode === info.dictCode}' ng-click='selectNode(info)'>" +
            "{{info.dictName}}" +
            "</button>" +
            "</div>" +
            "</div>" +
            "</div>";

        return {
            scope: {
                modal: '=',
                initList: "=",
                onBackill: "&onBackill"
            },
            controller: ['$scope', '$ionicModal', function ($scope, $ionicModal) {


                /**错误提示信息方法**/
                var errorLoading = function (template) {
                    $ionicLoading.show({
                        template: template,
                        duration: 2000
                    });
                };
                /**
                 * Description: 验证指定计划工时是否满足条件
                 * Author: chenlaichun
                 * Date: 2018/7/21 11:04
                 */
                var checkPlanTime = function (planTime) {
                    /* 因为允许为空 所以 为空返回true */
                    if (!planTime) {
                        return true;
                    }
                    return /^\d+(?:\.\d{1})?$/.test(planTime);
                };

                /* 判断是否传入了 集合 如果没有那就设置为集合*/
                if (!angular.isArray($scope.initList)) {
                    $scope.initList = [];
                }

                /* 拟态框 对象 */
                $scope.selectData = {
                    reallyTime: "",
                    complateCode: "1" /* 默认为未做 */
                };

                /**
                 * Description: 选中状态
                 * Author: chenlaichun
                 * Date: 2018/7/19 18:52
                 */
                $scope.selectNode = function (item) {
                    $scope.selectData.isDisabled = false;
                    $scope.selectData.complateCode = item.dictCode;
                    if ("1,3".indexOf(item.dictCode) > -1) {
                        $scope.selectData.isDisabled = true;
                    }
                };


                /**
                 * Description: 展示拟态框
                 * Author: chenlaichun
                 * Date: 2018/7/19 18:55
                 */
                $scope.openModal = function () {
                    /* 还原 默认值*/
                    $scope.selectData = {reallyTime: 0, complateCode: "1", isDisabled: true /* 默认为未做 */};

                    $ionicPopup.show({
                        title: "任务进度",
                        template: template,
                        scope: $scope,
                        buttons: [
                            {text: '取消', type: 'button-theme button-local button-outline'},
                            {
                                text: '确认', type: 'button-theme button-local',
                                onTap: function (e) {
                                    /* 判断如果 选中完成状态不为未做 那就必填办理工时  */
                                    if (($scope.selectData.complateCode !== "1" && $scope.selectData.complateCode !== "3") && !$scope.selectData.reallyTime) {
                                        e.preventDefault();
                                        return errorLoading("请填写办理工时");
                                    }
                                    if (!checkPlanTime($scope.selectData.reallyTime)) {
                                        e.preventDefault();
                                        return errorLoading("办理工时格式不正确");
                                    }
                                    /* 调用回调函数 */
                                    $scope.onBackill({item: $scope.modal, data: $scope.selectData});
                                }
                            }
                        ]
                    });
                };

            }],
            link: function (scope, element, attrs) {
                element.on('click', function () {
                    scope.openModal();
                });
            }
        };

    }

    /*工作报告主界面*/
    jobReportController.$inject = ['$scope', '$ionicPopup', '$ionicModal', '$location', '$http', '$ionicLoading', '$timeout'];

    function jobReportController($scope, $ionicPopup, $ionicModal, $location, $http, $ionicLoading, $timeout) {
        $scope.reportList = [];  //页面展示数据
        $scope.isTab = $location.search().isTab || 1;
        //设置默认 分页对象 初始 要重置就调用此方法
        var getPageDataFun = function () {
            return {
                maxLen: 1,
                number: 0,
                size: 10,
                totalPages: 100    // --2017-5-22 11:38:39 chenlaichun 要处理 数据为0 的时候进不了没有数据的判断 默认总数为100 查询一次返回数据就修改为数据库的总数据
            };
        }
        $scope.pageData = getPageDataFun();
        //点击 顶部tab 获取数据方法
        // var maxLen = 0;
        $scope.setIsTabFun = function (item) {
            loadMoreFlag = false;
            $scope.ionicLoadingShow();
            if (item) {
                $scope.isMoreData = false;
                $scope.isTab = item;    //查询类型
                $scope.reportList = [];   //重置集合
                $scope.pageData = getPageDataFun();
            }
            if (!$scope.pageData.totalPages || $scope.pageData.totalPages <= $scope.pageData.maxLen) {
                $scope.isMoreData = true;
                $scope.ionicLoadingHide();
                $scope.$broadcast('scroll.infiniteScrollComplete');
            } else {
                var suFun = function (data) {
                    if (item) $scope.reportList = [];   //重置集合
                    if(data.content){
                        $scope.reportList = $scope.reportList.concat(data.content);
                    }
                    // angular.forEach($scope.reportList, function (val) {
                    //     var newStr = val.reportContent.replace(/<[^>]*>|<\/[^>]*>/gm, '');
                    //     // var con = $sce.trustAsHtml(val.reportContent);
                    //     val.reportContent = newStr;
                    // });
                    $scope.pageData.maxLen = $scope.pageData.number;//当前页数
                    $scope.pageData.number = data.number + 1;
                    $scope.pageData.size = data.size;
                    $scope.pageData.totalPages = data.totalPages;
                    $scope.ionicLoadingHide();
                    $scope.$broadcast('scroll.infiniteScrollComplete');


                };
                httpVisit("findJSTXWorkReportDTOByPage", {
                    type: $scope.isTab,
                    pageNumber: $scope.pageData.number,
                    pageSize: $scope.pageData.size
                }, {}, suFun);
            }
        };


        //瀑布流加载
        var loadMoreFlag = false;
        $scope.loadMoreData = function () {
            if(loadMoreFlag){
                setTimeout(function () {
                    $scope.setIsTabFun();
                }, 1000);
            }
        };
        //加载中 提示信息
        $scope.ionicLoadingShow = function () {
            // $ionicLoading.show({
            //     template: '<ion-spinner class="spinner-theme"></ion-spinner><h4 class="text-theme">加载中</h4>'
            // });
        };
        // 关闭正在加载提示信息
        $scope.ionicLoadingHide = function () {
            // $ionicLoading.hide();
        };
        /**
         *  跳转 方法
         */
        $scope.jumpFun = {
            add: function () {
                $location.path('/add_report').search({});
            },
            view: function (info) {
                $location.path('/report_detail').search({id: info.id, isTab: $scope.isTab});
            }
        };


        /**
         *  获取 数据方法
         * @param url  路径
         * @param params get数据
         * @param data post 数据
         * @param fun 访问成功 方法
         * @param errFun 访问失败方法
         */
        var httpVisit = function (url, params, data, fun, errFun) {
            //$scope.ionicLoadingShow();
            params = params || angular.noop;
            data = data || angular.noop;
            fun = fun || angular.noop;
            errFun = errFun || angular.noop;
            var config = {
                url: basePath + "/third/workreport/" + url,
                method: "post",
                params: params, //后台用 get接收
                data: data //后台用@RequestBody 接收
            };
            $http(config).success(function (resultData) {
                $scope.isError = false;
                fun && fun(resultData);
            }).error(function (resultData) {
                $scope.isError = true;
                $scope.ionicLoadingHide();
                errFun && errFun(resultData);
            }).finally(function () {
                setTimeout(function () {
                    loadMoreFlag = true;
                },1000)
            });
        };

        //时间 格式改变
        $scope.getReportTime = function (date) {
            if (date) {
                var dates = date.split("-");
                return dates[1] + "/" + dates[2];
            }
        };
        //进入加载
        $scope.setIsTabFun(2);
    }

    /*添加或修改工作报告*/
    jobReportAddController.$inject = ['$scope', '$ionicPopup', '$http', '$filter', '$ionicLoading', '$ionicScrollDelegate', '$location', 'ynNavigator'];

    function jobReportAddController($scope, $ionicPopup, $http, $filter, $ionicLoading, $ionicScrollDelegate, $location, ynNavigator) {
        $scope.id = $location.search().id;
        $scope.type = $location.search().type;
        $scope.taskId = $location.search().taskId;
        var taskTabIndex = $location.search().taskTabIndex;
        $scope.reportData = {};  //页面展示数据
        $scope.importantList = [{dictName: "低", dictCode: "1"}, {dictName: "中", dictCode: "2"}, {
            dictName: "高",
            dictCode: "3"
        }];
        /* 回填选中 关联任务*/
        $scope.selectTaskNode = {id: "", taskName: ""};
        //点击 顶部tab
        $scope.getDataFun = function (id) {
            var suFun = function (data) {
                $scope.reportData = angular.copy(data);
                //放置编辑器的值
                // $scope.reportData.reportContent = $scope.reportData.reportContent.replaceAll("'","\\\\'");
                // $scope.reportData.reportContent = $scope.reportData.reportContent.replaceAll("\"","\\\\\"");
                // $('#summernote').summernote('code',$scope.reportData.reportContent);
                var newStr = $scope.reportData.reportContent.replace(/(<(.[^>]*)>)|(&nbsp;)/g, "");
                $scope.reportData.reportContent = newStr;
                $scope.selectTaskNode = {id: data.workTaskId, taskName: data.workTaskName};
                $scope.userNames = $scope.getUserName($scope.reportData.userDTOList);
                // 通知
                if ($scope.reportData && $scope.reportData.fsAnnexIDs) {
                    $scope.$broadcast('filesDone');
                }
            };
            httpVisit("findJSTXWorkReportDTOById", {reportId: id}, {}, suFun);
        };
        /**
         *  获取文字的 长度
         */
        $scope.getContentLength = function (info) {
            if (info) {
                return info.length;
            } else {
                return 0;
            }
        };

        // 获取 展示的人员名称
        $scope.getUserName = function (list) {
            var names = [];
            if (list && list.length == 0) return "无";
            angular.forEach(list, function (val) {
                names.push(val.userName);
            });
            return names.toString();
        }
        /**
         *  保存数据方法
         */
        //控制操作按钮
        $scope.opreation = {canSubmit: false};
        $scope.saveData = function () {
            var checkFun = function (item) {
                //验证 标题
                if (!item.title) {
                    getMessageFun("提示信息", "请填写标题！");
                    return false;
                }
                //验证 内容
                // item.reportContent = $("#summernote").summernote("code");
                if (!item.reportContent) {
                    getMessageFun("提示信息", "请填写内容！");
                    return false;
                }

                //验证 报告类型
                if (!item.reportTypeName) {
                    getMessageFun("提示信息", "请选择报告类型！");
                    return false;
                }
                //验证 重要级别
                if (!item.importantName) {
                    getMessageFun("提示信息", "请选择重要级别！");
                    return false;
                }
                //验证 主送人
                if (!item.mainUserName) {
                    getMessageFun("提示信息", "请选择主送人！");
                    return false;
                }
                //验证主送人和抄送人 不能一致
                if (item.userDTOList && item.userDTOList.length > 0) {
                    var flag = false;
                    angular.forEach(item.userDTOList, function (val) {
                        if (val.id == item.mainUserId) {
                            flag = true;
                        }
                    });
                    if (flag) {
                        getMessageFun("提示信息", "主送人和抄送人重复，请重新选择！");
                        return false;
                    }
                }
                return true;
            };
            var suFun = function (data) {
                $scope.opreation.canSubmit = false;
                if (data.status == '0') {
                    $scope.jumpFun.back();
                } else {
                    getMessageFun("操作失败", data.message);
                }
            }
            //转换 附件信息
            if (checkFun($scope.reportData)) {
                $scope.opreation.canSubmit = true;
                httpVisit("saveOrUpdateJSTXWorkReport", null, $scope.reportData, suFun);
            }
        };

        // 人员选择器
        $scope.selectMainUser = function (item) {
            $scope.reportData.mainUserName = item.name;
            $scope.reportData.mainUserId = item.id;
        };
        $scope.selectUserList = function (userList) {
            var names = [], userDTOList = [];
            angular.forEach(userList, function (val) {
                names.push(val.name);
                userDTOList.push(val);
            });
            $scope.userNames = angular.copy(names);
            $scope.reportData.userDTOList = angular.copy(userDTOList);
        };
        var getMessageFun = function (title, message) {
            $ionicLoading.show({
                template: message,
                cssClass: 'text-color:red', // String, 附加的CSS样式类
                duration: 2000   /* 2000毫秒后自动关闭提示*/
            });
        };
        //提示信息 添加自定义 按钮和按钮方法
        var getMessage_new_fun = function (title, mess_1, mess_2, buttons) {
            $ionicPopup.show({
                title: title,
                template: '<h5> ' + mess_1 + '</h5>' +
                '<p class="text-gray">' + mess_2 + '</p>',
                buttons: buttons || []
            });
        };
        //返回 页面方法
        $scope.backMethod = function () {
            var buttons = [
                {text: '继续编辑', type: ' button-outline button-theme button-local'},
                {
                    text: '确认返回', type: ' button-theme button-local', onTap: function () {
                        $scope.jumpFun.back();
                    }
                }
            ];
            getMessage_new_fun("返回提示", "返回后，当前编辑内容将丢失", "确定要返回吗？", buttons);
        };
        if ($scope.id) {
            ynNavigator.setNavTitle("编辑");
        }
        //框架返回拦截处理
        ynNavigator.registerBackAction(function () {
            $scope.backMethod();
        }, 101);
        /**
         *  跳转 方法
         */
        $scope.jumpFun = {
            back: function () {
                if ($scope.taskId) {
                    $location.path('/task_view').search({id: $scope.taskId, tabIndex: taskTabIndex});
                } else {
                    if ($scope.id) {
                        $location.path('/report_detail').search({id: $scope.id, isTab: 1});
                    } else {
                        $location.path('/job_report').search({isTab: 1});
                    }
                }
                setTimeout(function () {
                    $scope.$apply();
                });
            },
            update: function () {
                $location.path('/add_report').search({id: $scope.id});
            }
        };
        $scope.reportTypeSelectData = {};
        $scope.importantSelectData = {};
        // 选择 报告类型
        $scope.reportTypeSelect = function (item) {
            $scope.reportTypeSelectData = angular.copy(item);
            $scope.reportData.reportTypeName = item.dictName;
            $scope.reportData.reportTypeCode = item.dictCode;
        };
        $scope.importantSelect = function (item) {
            $scope.reportData.importantName = item.dictName;
            $scope.reportData.importantStatus = item.dictCode;
        };

        /**
         *  获取 数据方法
         * @param url  路径
         * @param params get数据
         * @param data post 数据
         * @param fun 访问成功 方法
         * @param errFun 访问失败方法
         */
        var httpVisit = function (url, params, data, fun, errFun) {
            params = params || angular.noop;
            data = data || angular.noop;
            fun = fun || angular.noop;
            errFun = errFun || angular.noop;
            var config = {
                url: basePath + "/third/workreport/" + url,
                method: "post",
                params: params, //后台用 get接收
                data: data //后台用@RequestBody 接收
            };
            $http(config).success(function (resultData) {
                fun && fun(resultData);
            }).error(function (resultData) {
                $scope.isError = true;
                errFun && errFun(resultData);
            });
        };
        //获得报告类型码表值
        $scope.getReportTypeList = function () {
            var suFun = function (data) {
                $scope.reportTypeList = data;
                /* 默认为要事汇报*/
                angular.forEach(data, function (val) {
                    if (val.dictCode === "06") {
                        $scope.reportTypeSelect(val);
                    }
                });
            };
            httpVisit("findReportType", null, null, suFun);
        };
        $scope.getReportTypeList();
        //判断是编辑还是 新添
        if ($scope.id) {
            $scope.getDataFun($scope.id);
        }

        /* 选中关联任务 执行方法*/
        $scope.selectTaskInfo = function (item) {
            $scope.reportData.workTaskName = item.taskName;
            $scope.reportData.workTaskId = item.id;
            /* 主送人 */
            if (item['mainUserInfo']) {
                $scope.selectMainUser(item['mainUserInfo']);
            }
            /* 抄送人 */
            if (item['copyUserInfoList'] && angular.isArray(item['copyUserInfoList'])) {
                $scope.selectUserList(item['copyUserInfoList']);
            }
        };

        /**
         * Description: 验证是否是工作任务过来的 如果是 那就固定默认管理工作任务
         * Author: chenlaichun
         * Date: 2018/7/20 9:24
         */
        $scope.isAddTaskReport = function (taskId) {
            if (taskId) {
                var config = {
                    method: "POST",
                    url: basePath + '/third/workreport/findMyWorkTaskById',
                    params: {taskId: taskId}
                };
                $http(config).then(function (response) {
                    var data = response.data;
                    $scope.selectTaskInfo(data);
                    $scope.reportData.title = "关于“" + data.taskName + "”工作报告";
                });
            }
        };

        $scope.isAddTaskReport($scope.taskId);
    }

    /*查看报告/报告详情*/
    jobReportDetailController.$inject = ['$scope', '$ionicPopup', '$ionicModal', '$location', '$http', '$ionicLoading', 'Attachment', '$timeout', '$ionicScrollDelegate', 'ynNavigator'];

    function jobReportDetailController($scope, $ionicPopup, $ionicModal, $location, $http, $ionicLoading, Attachment, $timeout, $ionicScrollDelegate, ynNavigator) {
        $scope.id = $location.search().id;
        $scope.type = $location.search().isTab;
        $scope.reportData = {};  //页面展示数据
        //点击 顶部tab
        $scope.getDataFun = function (id) {
            //重新计算页面大小
            $ionicScrollDelegate.resize();
            $scope.isTab = 1;
            var suFun = function (data) {
                $scope.reportData = angular.copy(data);
                if ($scope.reportData && $scope.reportData.reportContent) {
                    // $scope.reportData.instructionShow = $scope.getTitle($scope.reportData.reportContent);
                    $scope.reportData.instructionShow = $scope.reportData.reportContent;
                    $scope.reportData.instructionShow = $scope.reportData.instructionShow.replace(/(<(.[^>]*)>)|(&nbsp;)/g, "");
                    $scope.reportData.instructionShow = $scope.getTitle($scope.reportData.instructionShow);
                }
                if ($scope.reportData.fsAnnexIDs) {
                    $scope.reportData.uploadVoList = $scope.reportData.fsAnnexIDs.split(",");
                }
                //如果有反馈批示默认选中反馈批示否则选中基本信息

            }
            httpVisit("findJSTXWorkReportDTOById", {reportId: $scope.id}, {}, suFun);
        };
        /**
         *  获取 抄送人
         */
        $scope.getUserName = function (list) {
            var names = [];
            if (list && list.length == 0) return "无";
            angular.forEach(list, function (val) {
                names.push(val.userName);
            });
            return names.toString();
        }
        /**
         * 删除
         */
        $scope.del = function (id) {
            var fun = function () {
                var suFun = function (data) {
                    $scope.jumpFun.back();
                }
                httpVisit("delJSTXWorkReport", {reportId: id}, {}, suFun);
            }
            getMessageFun("删除", "确定要删除此工作报告吗？", fun, true);
        };

        /**
         *  查看附件
         */
        $scope.viewFileFun = function (fsIds) {
            if (fsIds && fsIds.length > 0) {
                Attachment.show(fsIds.toString());
            }
        };

        /**
         *  跳转 方法
         */
        $scope.jumpFun = {
            back: function () {
                $location.path('/job_report').search({isTab: 1});
                setTimeout(function () {
                    $scope.$apply();
                });
            },
            update: function () {
                $location.path('/add_report').search({id: $scope.id});
            }
        };
        //框架返回拦截处理
        ynNavigator.registerBackAction(function () {
            $scope.jumpFun.back();
        }, 101);
        //反馈和批示
        $scope.feedBack = function (item) {
            $scope.report = {};
            $scope.show = {};
            $scope.feedType = "";
            if (item != null && item == "0") {
                $scope.feedType = 0;
                $scope.show.showText = "反馈";
                $scope.show.message = "反馈成功!"
            } else {
                $scope.feedType = 1;
                $scope.show.showText = "批示";
                $scope.show.message = "批示成功!"
            }
            //item 0 反馈 1 批示
            var confirmPopup = $ionicPopup.show({
                title: '' + $scope.show.showText + '',
                template: '<textarea type="input" rows="5" class="form-control"  placeholder="输入' + $scope.show.showText + '内容" maxlength="1000" ng-model="report.content"></textarea>',
                scope: $scope,
                buttons: [
                    {
                        text: '取消',
                        type: 'button-theme button-local button-outline'
                    },
                    {
                        text: '确认',
                        type: 'button-theme button-local',
                        onTap: function (e) {
                            if (!$scope.report.content) {
                                $scope.showFirm("" + $scope.show.showText + "内容不能为空!");
                                e.preventDefault();
                            } else {
                                var dataInfo = {
                                    type: $scope.feedType,
                                    workReportId: $scope.id,
                                    content: $scope.report.content
                                }
                                $http.post(basePath + "/third/workreport/saveFeedBackMessage?", dataInfo).success(function (data) {
                                    if (data.status == "0") {
                                        $scope.getAppoval();
                                    } else {
                                        if (item && item == 0) {
                                            $scope.show.message = "反馈失败!"
                                        } else {
                                            $scope.show.message = "批示失败!"
                                        }
                                        $scope.showFirm($scope.show.message)
                                    }


                                })
                            }

                        }
                    }
                ]
            });


        }

        //提示信息
        $scope.showFirm = function (msg) {
            $ionicLoading.show({
                template: msg
            });
            setTimeout(function () {
                $ionicLoading.hide();
            }, 2000);
        };

        //获取反馈和批示记录
        $scope.getAppoval = function (type) {
            //重新计算页面大小
            $ionicScrollDelegate.resize();
            if (!type) {
                $scope.isTab = 2;
            }
            $http.post(basePath + "/third/workreport/findAppovalDataById?reportId=" + $scope.id).success(function (data) {
                if (data.status == '0') {
                    $scope.appovalData = data.result;
                    if ($scope.appovalData.length > 0) {
                        $scope.isTab = 2;
                        angular.forEach($scope.appovalData, function (item) {
                            item.instructionShow = $scope.getTitle(item.content);
                        });
                    } else {
                        if (type) {
                            $scope.isTab = 1;
                        }

                    }
                }
            });
        }
        $scope.getAppoval(1);

        //按时间倒序排列
        $scope.timedesc = true;
        $scope.timeDesc = function () {
            $scope.timedesc = !$scope.timedesc;

        }

        //对字符串进行截取
        $scope.getTitle = function (data) {
            var title = "";
            if (data != null && data.length > 50) {
                $scope.showTitle = true;
                title = data.substring(0, 50) + "...";
            } else {
                title = data;
            }
            return title;

        }

        //查看更多
        $scope.showMore = function (item, type) {
            if (item.instructionShow.length > 53) {
                if (type == 2) {
                    item.instructionShow = $scope.getTitle(item.content);
                } else {
                    item.instructionShow = $scope.getTitle(item.content);
                }

            } else {
                if (type == 2) {
                    item.instructionShow = item.content;
                } else {
                    item.instructionShow = "";
                    // item.instructionShow = item.reportContent;
                    item.instructionShow = item.reportContent.replace(/(<(.[^>]*)>)|(&nbsp;)/g, "");
                }

            }


        }


        /**
         *  获取 数据方法
         * @param url  路径
         * @param params get数据
         * @param data post 数据
         * @param fun 访问成功 方法
         * @param errFun 访问失败方法
         */
        var httpVisit = function (url, params, data, fun, errFun) {
            params = params || angular.noop;
            data = data || angular.noop;
            fun = fun || angular.noop;
            errFun = errFun || angular.noop;
            var config = {
                url: basePath + "/third/workreport/" + url,
                method: "post",
                params: params, //后台用 get接收
                data: data, //后台用@RequestBody 接收
            };
            $http(config).success(function (resultData) {
                fun && fun(resultData);
            }).error(function (resultData) {
                $scope.isError = true;
                errFun && errFun(resultData);
            });
        };
        // 提示 信息
        var getMessageFun = function (title, message, fun, isCancel) {
            var config = {
                title: title,
                template: '<h5> ' + message + '</h5>',
                buttons: [
                    {
                        text: '确认', type: ' button-theme button-local',
                        onTap: function () {
                            fun && fun();
                        }
                    }
                ]
            };
            if (isCancel) {
                config.buttons.push({text: '取消', type: ' button-theme button-local'});
            }
            $ionicPopup.show(config);
        }

        $scope.getDataFun($scope.id);
    }

    jobRecordController.$inject = ['$scope', '$ionicPopup', '$http', '$timeout', '$ionicLoading', '$ionicModal', '$filter', 'stringsConstant', '$ionicPlatform', 'ynNavigator'];

    function jobRecordController($scope, $ionicPopup, $http, $timeout, $ionicLoading, $ionicModal, $filter, stringsConstant, $ionicPlatform, ynNavigator) {

        // Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function () {
            // $scope.add_task.remove();
            // $scope.add_task_modal.remove();
            // $scope.view_task_modal.remove();
        });

        $scope.pageData = {
            rule: null,
            allDateList: [],
            beforeTask: [],
            afterTask: [],
            selectedTaskDetail: null,
            selectedTaskIndex: null,
            selectedAttribute: null,
            selectedIsModify: false,
            //声明默认按钮可点击
            canSubmit: false,
            //提交总结
            canComplate: false
        };

        $scope.conditions = {
            lastDate: ""
        };

        $scope.clickRow = clickRow;     // 点击行事件处理
        $scope.getDayStr = getDayStr;   // 处理 今、明、昨天的显示
        $scope.getMonthAndDay = getMonthAndDay;   // 处理日期显示
        $scope.getTaskCountStr = getTaskCountStr; // 处理计划项显示
        $scope.getAllTask = getAllTask; // 获取所有的计划数据
        $scope.loadMore = loadMore;     // 划到底部刷新
        $scope.findTaskDetail = findTaskDetail;   // 根据单个日期查询计划详细（用于添加）
        $scope.findRule = findRule;     // 获取填写规则
        $scope.saveData = saveData;     // 添加、修改保存数据
        $scope.getTask = getTask;       // 从交办和项目管理和工作任务中获取任务
        $scope.showAddTask = showAddTask;         // 显示添加任务
        $scope.closeAddTask = closeAddTask;       // 关闭添加任务
        $scope.deleteTask = deleteTask;           // 删除整个计划
        $scope.deleteTaskDetail = deleteTaskDetail;     // 删除单个任务
        $scope.showAddTaskDetail = showAddTaskDetail;   // 显示添加、修改单个任务
        $scope.closeAddTaskDetail = closeAddTaskDetail; // 关闭添加、修改单个任务
        $scope.addOneTaskDetail = addOneTaskDetail;     // 增加1项任务按钮
        $scope.addConsumptionTime = addConsumptionTime; // 加减工时
        $scope.confirmDetail = confirmDetail;     // 添加修改确定
        $scope.submitPlan = submitPlan; // 提交任务
        $scope.findTask = findTask;     // 查询任务详细（用于查看、修改）
        $scope.showViewTask = showViewTask;    // 显示查看、修改modal
        $scope.closeViewTask = closeViewTask;  // 隐藏查看、修改modal
        $scope.modifyPageAddTask = modifyPageAddTask;  // 修改页面增加一项任务
        $scope.showConclusionTask = showConclusionTask;  // 显示总结任务modal
        $scope.closeConclusionTask = closeConclusionTask;  // 关闭总结任务modal
        $scope.submitConclusion = submitConclusion;  // 提交总结
        $scope.formatNumber = formatNumber;  // 格式化输入小时
        $scope.showCompleteState = showCompleteState;  // 打开完成情况模态框
        $scope.closeCompleteState = closeCompleteState;  // 关闭完成情况模态框
        $scope.selectCompleteState = selectCompleteState;  // 选择内容
        // 注册Android的物理返回键
        // $rootScope.registerBackButtonAction($scope.closeAddTask, 'closeAddTask');
        // 默认获取一次规则
        $scope.findRule();

        //获取事务完成状态
        $http.get(basePath + "/third/affairsassigned/findMobileCompleteStatus?type=2").success(function (data) {
            if (data) {
                $scope.completeDataList = data;
            }
        });
        //设置事务进度的值
        function selectCompleteState (item) {
            $scope.completeDetail.completeStateName = item.dictName;
            $scope.completeDetail.completeState = item.dictCode;
            $scope.completeDetail.actualDisable = false;
            /* 是否允许编辑 办理工时 */
            /* 取消/未做 不允许填写办理工时 并默认办理工时为 0 */
            if (["1", "3"].indexOf("" + $scope.completeDetail.completeState) > -1) {
                // item.oldActualTime = angular.copy(item.actualConsumptionTime); /* 保存一个清空*/
                $scope.completeDetail.actualConsumptionTime = 0;
                $scope.completeDetail.actualDisable = true;
            }
            activeComplete();
            closeCompleteState();
        };

        function activeComplete() {
            angular.forEach($scope.completeDataShowList, function (value) {
                value.active = false;
                if ($scope.completeDetail.completeState == value.dictCode) {
                    value.active = true;
                }
            })
        }

        function showCompleteState(detail){
            $scope.completeDataShowList = angular.copy($scope.completeDataList);
            $scope.completeDetail = detail;
            activeComplete();
            $scope.complete_state_modal.show();
            $scope.complateStateShow = true;
            //注销总结对应的模态框拦截
            ynNavigator.cancelBackAction(201);
        }
        function closeCompleteState(){
            $scope.complete_state_modal.hide().then(function () {
                $scope.complete_state_modal.remove().then(function () {
                    $ionicModal.fromTemplateUrl('complete_state_modal.html', {
                        scope: $scope,
                        animation: 'slide-in-right'
                    }).then(function (modal) {
                        $scope.complete_state_modal = modal;
                    })
                })
            });
        }
        //全局监听模态框关闭
        $scope.$on('modal.hidden', function () {
            //如果是完成情况模态框，做业务处理
            if($scope.complateStateShow){
                $scope.complateStateShow = false;
                //开启总结对应的模态框拦截
                registerConclusion();
            }
        });
        // 添加任务modal框
        $ionicModal.fromTemplateUrl('add-task.html', {
            scope: $scope,
            animation: 'slide-in-right'
        }).then(function (modal) {
            $scope.add_task = modal;
        });

        $ionicModal.fromTemplateUrl('add-task-modal.html', {
            scope: $scope,
            animation: 'slide-in-right',
            backdropClickToClose: false
        }).then(function (modal) {
            $scope.add_task_modal = modal;
        });

        $ionicModal.fromTemplateUrl('task-view.html', {
            scope: $scope,
            animation: 'slide-in-right'
        }).then(function (modal) {
            $scope.view_task_modal = modal;
        });

        $ionicModal.fromTemplateUrl('task-conclusion.html', {
            scope: $scope,
            animation: 'slide-in-right'
        }).then(function (modal) {
            $scope.conclusion_task_modal = modal;
        });
        //选择任务modal
        var choiceTaskModal = function () {
            $ionicModal.fromTemplateUrl('choice-task-modal.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.choice_task_modal = modal;
            });
        }
        choiceTaskModal();

        //完成情况
        $ionicModal.fromTemplateUrl('complete_state_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.complete_state_modal = modal;
        });


        //声明查询数据对象
        $scope.searchData = {
            selectType: '1',
            tabType: 1//默认加载一次性完成的选项卡
        };
        //是否继续加载我的工作任务
        $scope.isMyTaskLoadData = true;
        //我的工作任务对象List
        $scope.myWorkTaskDataList = [];
        //选择导入任务
        $scope.choiceImport = function () {
            $scope.searchData.tabType = 1;//默认加载一次性完成的选项卡
            $scope.selectMyTask(1);
            $scope.isMyTaskLoadData = false;
            $scope.myWorkTaskDataList = [];
            $scope.choice_task_modal.show();
        };
        //关闭选择导入任务模态框
        $scope.closeChoiceTask = function () {
            $scope.choice_task_modal.remove();
            choiceTaskModal();
        };
        //选择任务确定
        $scope.sureChoiceTask = function () {
            var newList = [];
            angular.forEach($scope.myWorkTaskDataList, function (oldData) {
                if (oldData.selected) {
                    var newData = {
                        taskName: $scope.searchData.tabType != 2 ? oldData.taskName : oldData.taskName + "-?",
                        consumptionTime: oldData.consumptionTime,
                        isImportant: oldData.isImportant,
                        isUrgent: oldData.isUrgent,
                        taskId: oldData.taskId,
                        completeState: oldData.completeState,
                        xtgbAssId: oldData.xtgbAssId,
                        workTaskId: oldData.workTaskId,
                        xtbgProjectId: oldData.xtbgProjectId,
                        taskType: oldData.taskType,
                        modify: $scope.searchData.tabType != 2 ? oldData.modify : true,//一次性或者累计的不能修改名称，当天选择多次完成的能修改名称
                        del: false,
                        isModifyTime: $scope.searchData.tabType != 2 ? oldData.isModifyTime : false,//选择的多次完成，计划工时可以修改
                        importType: angular.copy($scope.searchData.tabType),//导入类型 1：一次性导入 2：多次导入
                        relatedWorkTaskId: oldData.id,//关联任务ID
                        relatedTask: oldData.taskName,//关联任务名称
                        okrId: oldData.okrId,
                        okrTeamId: oldData.okrTeamId
                    };
                    newList.push(newData);
                }
            });
            if (newList.length == 0) {
                $scope.notifyMsg("请至少选择一项！");
                return;
            }
            var planTime = new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.planTime);
            var currentTime = new Date();
            if (planTime > currentTime) {
                // 事先计划
                $scope.pageData.beforeTask = $scope.pageData.beforeTask.concat(newList)
                    .goAir().goHeavy()/*.suppFun()*/;
            } else {
                // 延后登记
                $scope.pageData.afterTask = $scope.pageData.afterTask.concat(newList)
                    .goAir().goHeavy()/*.suppFun()*/;
            }
            $scope.choice_task_modal.remove();
            choiceTaskModal();
        };
        //根据条件查询我的工作任务
        $scope.selectMyTask = function (type) {
            $scope.searchData.selectType = type;
            $scope.myWorkTaskDataList = [];
            $scope.loadMyTaskMore(0);
        };
        //我的工作任务下拉刷新
        $scope.loadMyTask = function () {
            $scope.loadMyTaskMore(0, 2);
        };
        //加载更多我的工作任务
        $scope.loadMyTaskMore = function (number, type) {
            //将一次导入和多次导入的工作任务ID分开存储
            //页面选择了一次任务，虽然没有进数据库，但直接又导入，也不显示该条数据
            //页面选择的是多次任务，虽然没有保存数据库，但一次完成选项卡也不查询该条数据
            var oneCompletionList = [];//一次ID
            var multipleCompletionList = [];//多次ID
            var arrData = $scope.pageData.beforeTask.concat($scope.pageData.afterTask);
            angular.forEach(arrData, function (item) {
                if (item.relatedWorkTaskId) {
                    if (item.importType == 1) {//一次性
                        oneCompletionList.push(item.relatedWorkTaskId);
                    }
                    if (item.importType == 2) {//多次完成
                        multipleCompletionList.push(item.relatedWorkTaskId);
                    }
                }
            })

            var pageNumber = number;
            //声明查询参数对象
            var searchData = {
                pageNumber: pageNumber,
                pageSize: 20,
                queryDateType: $scope.searchData.selectType,
                tabType: $scope.searchData.tabType,
                oneCompletionList: oneCompletionList,
                multipleCompletionList: multipleCompletionList
            };
            $http.post(basePath + "/third/jobrecord/findMobileAllImportData?", searchData).success(function (data) {
                if (data.status == '0') {
                    pageNumber++;
                    if (type != 2) {
                        $scope.myWorkTaskDataList = $scope.myWorkTaskDataList.concat(data.result.content);
                    } else {
                        $scope.myWorkTaskDataList = data.result.content;
                    }

                    if (data.result.content && data.result.content.length < 20) {
                        $scope.isMyTaskLoadData = true;
                    }

                    if (type == 2) {
                        $scope.$broadcast('scroll.refreshComplete');
                    } else {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    }
                }
            });
        };

        //切换选项卡的时候xianzhongping 2018年7月16日14:20:36
        $scope.selectTabTaskData = function (type) {
            $scope.searchData.tabType = type;
            $scope.myWorkTaskDataList = [];
            $scope.loadMyTaskMore(0);
        }

        //设置选中的值
        $scope.setMyTaskData = function (data) {
            data.selected = !data.selected;
        };

        function clickRow(rowData) {
            $scope.delectedTask = [];
            $scope.currentRowData = angular.copy(rowData);
            // 格式化日期
            $scope.currentRowData.formatShowDate = $scope.currentRowData.showDate.split('-')[1] + '月' +
                $scope.currentRowData.showDate.split('-')[2] + '日';
            if (rowData.teskQuantity === 0 && rowData.showDay > 1) {
                $ionicPopup.show({
                    title: '提示',
                    template: '<h5>只允许添加昨天、今天、明天的工作任务</h5>',
                    buttons: [{
                        text: '确定',
                        type: 'button-theme button-local'
                    }]
                });
            } else if (rowData.showDay <= 1 && rowData.teskQuantity > 0) {
                // 修改
                $scope.showViewTask(rowData);
            } else if (rowData.showDay <= 1 && rowData.teskQuantity <= 0) {
                // 添加
                $scope.showAddTask(rowData);
            } else {
                // 查看
                $scope.showViewTask(rowData);
            }
        }

        function getDayStr(type) {
            if (type === '-1') {
                return "[明天]";
            } else if (type === '0') {
                return "[今天]";
            } else if (type === '1') {
                return "[昨天]";
            } else {
                return "";
            }
        }

        function getMonthAndDay(date) {
            if (date) {
                var ol = date.split("-");
                if (ol.length > 2) {
                    return ol[1] + "-" + ol[2];
                }
            }
            return date;
        }

        function getTaskCountStr(taskCount) {
            if (taskCount > 0) {
                return "共" + taskCount + "项任务";
            } else {
                return "未计划";
            }
        }

        function getAllTask(params) {
            return $http.get(basePath + '/third/jobrecord/findJSTXJobRecordDTOByConditions?loading=disabled', {
                params: params
            }).then(function (response) {
                if (params.showDate) {
                    $scope.pageData.allDateList = $scope.pageData.allDateList.concat(response.data);
                } else {
                    $scope.pageData.allDateList = response.data;
                }
                return response;
            })
        }

        function findTaskDetail(params) {
            return $http.get(basePath + '/third/jobrecord/findJSTXJObRecordDetailDTOByShowDateAndAll', {
                params: params
            }).then(function (response) {
                return response;
            })
        }

        function findRule() {
            return $http.get(basePath + '/third/jobrecord/findWorkLogSet').then(function (response) {
                $scope.pageData.rule = response.data.result;
                return response;
            })
        }

        function saveData(params, postParams) {
            $scope.show();
            return $http.post(basePath + '/third/jobrecord/saveOrUpdateJSTXJObRecordDetail?loading=disabled', postParams, {
                params: params
            }).success(function (response) {
                $scope.hide();
                return response;
            }).error(function (response) {
                $scope.error();
            })
        }

        //显示遮罩
        $scope.show = function () {
            $ionicLoading.show({
                template: '<h4>数据保存中...</h4>'
            });
        };
        //显示遮罩
        $scope.error = function () {
            $ionicLoading.show({
                template: '<h4>保存失败...</h4>',
                duration: 3000
            });
        };
        $scope.hide = function () {
            $timeout(function () {
                $ionicLoading.hide();
            }, 1000);
        };

        function getTask(params) {
            return $http.get(basePath + '/third/jobrecord/findJSTXJObRecordDetailDTOByShowDateAndGet', {
                params: params
            }).then(function (response) {
                return response;
            })
        }

        //------------------------------------ 翻页加载 组件添加 start ------------------------------

        $scope.address = "";
        $scope.loadGPSAddress = function () {
            $scope.addressFlag = 1;//定位中
            $scope.address = stringsConstant.gps.progress;
            $scope.locationType = 0;  // 定位类型
            var tipsIndex = 0;
            var gpsTimer = window.setInterval(function () {
                if (tipsIndex > 2) tipsIndex = 2;
                $scope.address = ["正在搜索GPS信号...", "GPS信号较弱，请稍等...", "搜索基站或WI-FI信号..."][tipsIndex];
                tipsIndex++;
            }, 1500);

            navigator.geolocation.getCurrentPosition(function (data) {
                console.log('定位结果：' + JSON.stringify(data));
                window.clearInterval(gpsTimer);
                var userId = JSON.parse(window.localStorage.getItem('authentication')).platformSysUserId;

                if(data.status === 1 && data.result.address){
                    $scope.addressFlag = 2;
                    var result = data.result;
                    $scope.locationType = result.locationType;
                    $scope.address = result.address;
                }else {
                    console.log('errorCode: ' + data.result.errorCode + ', errorInfo: ' + data.result.errorInfo);
                    gpsError();
                }
            }, function (getCurrentPositionError) {
                window.clearInterval(gpsTimer);
                gpsError();
                console.error('定位失败geolocation:' + JSON.stringify(getCurrentPositionError));
            });
        };

        function gpsError() {
            // 设置延迟，视觉缓冲
            setTimeout(function () {
                $scope.item.gpsAddress = $scope.address = stringsConstant.gps.error;
                $scope.addressFlag = 3;//定位失败
                $scope.$digest();
            }, 500)
        }

        $ionicPlatform.ready(function () {
            $scope.loadGPSAddress();
        });


        function loadMore() {
            $scope.isLoadData = true;
            if ($scope.showMore) {
                return null;
            }
            $scope.getAllTask({showDate: $scope.conditions.lastDate}).then(function () {
                $scope.isLoadData = false;
                if (!$scope.pageData.allDateList || $scope.pageData.allDateList.length === 0) {
                    $scope.showMore = true;
                }
                if ($scope.pageData.allDateList.length * 7 >= 100) {
                    $scope.showMore = true;
                }
                $scope.conditions.lastDate = $scope.pageData.allDateList.getAttr().getAttr('showDate');
                $timeout(function () {
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                }, 1000);
            });
        }

        //------------------------------------ 翻页加载 组件添加 end --------------------------------

        function showAddTask(rowData) {
            $scope.pageData.showTip = true;
            $scope.pageData.beforeTask = [];
            $scope.pageData.afterTask = [];
            ynNavigator.registerBackAction(function () {
                closeAddTask();
            }, 201);
            $scope.add_task.show().then(function () {
                // 根据日期查询已有的pdca
                $scope.findTaskDetail({showDate: rowData.showDate}).then(function (response) {
                    $http.post(basePath + "/third/jobrecord/findMobileAutomaticImportData?logDate=" + rowData.showDate).success(function (data) {
                        if (data.status == 0) {

                            //查询上次pdca的关注人员
                            $http.post(basePath + "/third/jobrecord/findYesterdayPDCAUserData?logDate=" + rowData.showDate).success(function (data) {
                                if (data.status == 0) {
                                    var userNames = [], ids = [];
                                    $scope.workingLogSysUserMidDTOList = data.result;
                                    angular.forEach($scope.workingLogSysUserMidDTOList, function (val) {
                                        userNames.push(val.name);
                                        if (ids == "") {
                                            ids = val.id
                                        } else {
                                            ids = ids + "," + val.id
                                        }
                                    });
                                    $scope.userIds = ids;
                                    $scope.userNames = angular.copy(userNames);
                                }
                            })

                            // 判断当前时间是否超过事先计划时间
                            var planTime = new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.planTime);
                            var currentTime = new Date();
                            if (planTime > currentTime) { // 事先计划
                                $scope.pageData.beforeTask = [];
                                $scope.pageData.beforeTask = $scope.pageData.beforeTask.concat(response.data).concat(data.result)
                                    .goAir()./*goHeavy().*/suppFun();
                            } else { // 延后登记
                                $scope.pageData.afterTask = [];
                                $scope.pageData.afterTask = $scope.pageData.afterTask.concat(response.data).concat(data.result)
                                    .goAir()./*goHeavy().*/suppFun();
                            }
                        }
                    });
                });
            });
        }
        function hideAddTask() {
            $scope.add_task.hide();
            ynNavigator.cancelBackAction(201);
        }
        function closeAddTask() {
            $ionicPopup.show({
                title: '提示',
                template: '<h5>确定要放弃当前填写的计划吗？</h5>',
                buttons: [
                    {text: '继续编辑', type: 'button-outline button-theme button-local'},
                    {
                        text: '确定返回', type: 'button-theme button-local',
                        onTap: function () {
                            hideAddTask();
                        }
                    }
                ]
            });
        }

        $scope.getTaskByProject = getTaskByProject;

        function getTaskByProject() {
            $ionicLoading.show({
                template: '<h4>正在获取...</h4>',
                scope: $scope
            });
            $scope.getTask({
                showDate: $scope.currentRowData.showDate,
                isObtain: true
            }).then(function (response) {
                $ionicLoading.hide();
                var count = 0, i, j, tasks = [];
                for (i = 0; i < response.data.length; i++) {
                    if (response.data[i].isAdd) {
                        continue;
                    }
                    var index = null;
                    for (j = 0; j < $scope.delectedTask.length; j++) {
                        if (response.data[i].taskType === $scope.delectedTask[j].taskType &&
                            response.data[i].taskName === $scope.delectedTask[j].taskName) {
                            // tasks.push($scope.delectedTask[i]);
                            index = j;
                            break;
                        }
                    }
                    // 移除
                    if (null !== index) {
                        $scope.delectedTask.splice(index, 1);
                    }
                    tasks.push(response.data[i]);
                }
                var beforeCount = 0, afterCount = 0;
                if ($scope.pageData.beforeTask.length > 0) {
                    // 获取之前的任务条数
                    beforeCount = $scope.pageData.beforeTask.goAir().length;
                    $scope.pageData.beforeTask = $scope.pageData.beforeTask.concat(tasks);
                    $scope.pageData.beforeTask = $scope.pageData.beforeTask.goAir().goHeavy().suppFun();
                    // 获取之后的任务条数
                    afterCount = $scope.pageData.beforeTask.goAir().length;
                } else {
                    // 获取之前的任务条数
                    beforeCount = $scope.pageData.afterTask.goAir().length;
                    $scope.pageData.afterTask = $scope.pageData.afterTask.concat(tasks);
                    $scope.pageData.afterTask = $scope.pageData.afterTask.goAir().goHeavy().suppFun();
                    // 获取之后的任务条数
                    afterCount = $scope.pageData.afterTask.goAir().length;
                }
                $ionicPopup.show({
                    title: '提示',
                    template: afterCount - beforeCount === 0 ? '<h5>没有获取到任务</h5>' : '<h5>成功获取' + (afterCount - beforeCount) + '条任务</h5>',
                    buttons: [{
                        text: '确定',
                        type: 'button-theme button-local'
                    }]
                });
            })
        }

        function deleteTask() {
            $ionicPopup.confirm({
                title: '提示',
                template: '<h5>删除工作计划将删除里面所有的任务，确定要删除吗？</h5>',
                buttons: [{
                    text: '取消',
                    type: 'button-outline button-theme button-local'
                }, {
                    text: '确定',
                    type: 'button-theme button-local',
                    onTap: function () {
                        $http.get(basePath + '/third/jobrecord/deleteWorkingLogByShowDate', {
                            params: {
                                showDate: $scope.currentRowData.showDate
                            }
                        }).then(function () {
                            $ionicLoading.show({
                                template: '<h4>删除成功</h4>',
                                scope: $scope,
                                duration: 2000
                            }).then(function () {
                                $scope.getAllTask({showData: ''}).then(function () {
                                    $scope.conditions.lastDate = $scope.pageData.allDateList.getAttr().getAttr('showDate');
                                    $scope.view_task_modal.hide();
                                });
                            });
                        });
                    }
                }]
            });
        }

        function deleteTaskDetail(attribute, index) {
            var msg;
            if ($scope.pageData.canModify) {
                if ($scope.pageData.beforeTask.length + $scope.pageData.afterTask.length === 1) {
                    msg = '<h5>删除最后一条任务后，整个' + $scope.currentRowData.formatShowDate + '的计划都将被删除</h5>';
                } else {
                    msg = '<h5>删除后，任务无法恢复</h5>';
                }
            } else {
                msg = '<h5>删除后，当前添加的任务无法恢复</h5>';
            }
            $ionicPopup.show({
                title: '提示',
                template: msg,
                buttons: [
                    {text: '取消', type: 'button-outline button-theme button-local'},
                    {
                        text: '确定删除', type: 'button-theme button-local',
                        onTap: function () {
                            // 代表是修改页面的删除，要去数据库删除（不能修改的逻辑删除
                            if ($scope.pageData.canModify) {
                                $http.get(basePath + '/third/jobrecord/deleteDetailsById', {
                                    params: {
                                        id: $scope.pageData[attribute][index].id
                                    }
                                }).then(function () {
                                    $ionicLoading.show({
                                        template: '<h4>删除成功</h4>',
                                        duration: 2000
                                    }).then(function () {
                                        $scope.getAllTask({showData: ''}).then(function () {
                                            $scope.conditions.lastDate = $scope.pageData.allDateList.getAttr().getAttr('showDate');
                                        });
                                        // 需要返回主页面
                                        if ($scope.pageData.beforeTask.length + $scope.pageData.afterTask.length === 0) {
                                            $scope.view_task_modal.hide();
                                        }
                                    })
                                })
                            }
                            if ($scope.pageData[attribute][index].id) {//没有保存过的数据删除就不保存的数据库中 xianzhongping 2018年7月16日15:22:10
                                $scope.pageData[attribute][index].del = true;
                                var flag = false;
                                for (var i = 0; i < $scope.delectedTask.length; i++) {
                                    if ($scope.delectedTask[i].taskName === $scope.pageData[attribute][index].taskName &&
                                        $scope.delectedTask[i].taskType === $scope.pageData[attribute][index].taskType) {
                                        flag = true;
                                        break;
                                    }
                                }
                                if (!flag) {
                                    $scope.delectedTask.push($scope.pageData[attribute][index]);
                                }
                            }
                            $scope.pageData[attribute].splice(index, 1);
                        }
                    }
                ]
            });
        }

        function showAddTaskDetail(rowData, attribute, index) {
            /* 默认一个自建个人任务 */
            if (!rowData.taskTypeCodeName) {
                rowData.taskTypeCodeName = "自建个人任务";
            }

            $scope.pageData.selectedTaskDetail = angular.copy(rowData);
            // 处理工时
            if (isNaN(parseFloat($scope.pageData.selectedTaskDetail.consumptionTime))) {
                $scope.pageData.selectedTaskDetail.consumptionTime = 0;
            }
            // 添加的需要清空taskName
            if (rowData.isAdd) {
                $scope.pageData.selectedTaskDetail.taskName = null;
                // 如果是添加的，需要去取最小的需要添加的任务
                for (var i = 0; i < $scope.pageData[attribute].length; i++) {
                    if ($scope.pageData[attribute][i].isAdd) {
                        index = i;
                        break;
                    }
                }
            }
            $scope.pageData.selectedAllTaskIndex = index;
            if (attribute === 'afterTask') {
                $scope.pageData.selectedAllTaskIndex += $scope.pageData.beforeTask.length
            }
            $scope.pageData.selectedTaskIndex = index;
            $scope.pageData.selectedAttribute = attribute;
            if (null === $scope.pageData.selectedTaskDetail.remindTime) {
                $scope.pageData.selectedTaskDetail.remindTime = '00:00';
            }
            $scope.add_task_modal.show();

            ynNavigator.registerBackAction(function () {
                closeAddTaskDetail();
            }, 201);
        }

        function closeAddTaskDetail() {
            if ($scope.pageData.selectedTaskDetail.taskName) {
                $ionicPopup.show({
                    title: '提示',
                    template: '<h5>取消后编辑的内容将丢失，确定取消吗？</h5>',
                    buttons: [
                        {text: '继续编辑', type: 'button-outline button-theme button-local'},
                        {
                            text: '确定返回', type: 'button-theme button-local',
                            onTap: function () {
                                $scope.add_task_modal.hide().then(function () {
                                    $scope.add_task_modal.remove().then(function () {
                                        $ionicModal.fromTemplateUrl('add-task-modal.html', {
                                            scope: $scope,
                                            animation: 'slide-in-right',
                                            backdropClickToClose: false
                                        }).then(function (modal) {
                                            $scope.add_task_modal = modal;
                                        });
                                    });
                                });
                                $scope.pageData.selectedTaskDetail = null;
                                // $rootScope.deregisterBackButtonAction('closeAddTaskDetail');
                                // $rootScope.registerBackButtonAction($scope.closeAddTask, 'closeAddTask');
                            }
                        }
                    ]
                });
            } else {
                $scope.add_task_modal.hide().then(function () {
                    $scope.add_task_modal.remove().then(function () {
                        $ionicModal.fromTemplateUrl('add-task-modal.html', {
                            scope: $scope,
                            animation: 'slide-in-right',
                            backdropClickToClose: false
                        }).then(function (modal) {
                            $scope.add_task_modal = modal;
                        });
                    });
                });
                $scope.pageData.selectedTaskDetail = null;
            }
            ynNavigator.cancelBackAction(201);
        }

        function addOneTaskDetail() {
            /*if ($scope.pageData.beforeTask.length + $scope.pageData.afterTask.length >= 10) {
                $ionicPopup.show({
                    title: '提示',
                    template: '<h5>最多只能添加10项任务</h5>',
                    buttons: [{
                        text: '确定',
                        type: 'button-theme button-local'
                    }]
                });
                return false;
            }*/
            // 取当前时间，判断事前计划或延后登记
            var planTime = new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.planTime);
            var currentTime = new Date();
            if (planTime > currentTime) { // 事先计划
                $scope.pageData.beforeTask.push({
                    taskName: '',
                    isAdd: true,
                    taskType: 1,
                    remind: false,
                    modify: true,
                    del: false,
                    importType: 1// 导入类型 1：一次性导入 2：多次导入
                })
            } else { // 延后登记
                $scope.pageData.afterTask.push({
                    taskName: '',
                    isAdd: true,
                    taskType: 1,
                    remind: false,
                    modify: true,
                    del: false,
                    importType: 1// 导入类型 1：一次性导入 2：多次导入
                })
            }
        }

        var isNumber = function (value) {
            return /^(\d+(\.\d+)?)$/.test(value);
        };

        function updateConsumption(time, step) {
            var m = 1000000;
            time = parseInt((time || 0) * m);
            step = parseInt((step || 0) * m);
            return parseInt(time + step) / m;
        }

        function addConsumptionTime(step, obj, type) {

            if (type) {
                /* 不允许编辑 */
                if (obj.actualDisable) {
                    return;
                }
                if (!isNumber(obj.actualConsumptionTime)) {
                    obj.actualConsumptionTime = 0;
                } else {
                    obj.actualConsumptionTime = updateConsumption(obj.actualConsumptionTime, step);
                    if (obj.actualConsumptionTime < 0) {
                        obj.actualConsumptionTime = 0;
                    }
                }
            } else {
                if ($scope.pageData.selectedTaskDetail.isModifyTime) {
                    return;
                }
                if (obj) {
                    if (!isNumber(obj.consumptionTime)) {
                        obj.consumptionTime = 0;
                    }
                    obj.consumptionTime = updateConsumption(obj.consumptionTime, step);
                    if (obj.consumptionTime < 0) {
                        obj.consumptionTime = 0;
                    }
                } else {
                    if (!isNumber($scope.pageData.selectedTaskDetail.consumptionTime)) {
                        $scope.pageData.selectedTaskDetail.consumptionTime = 0;
                    }
                    $scope.pageData.selectedTaskDetail.consumptionTime = updateConsumption($scope.pageData.selectedTaskDetail.consumptionTime, step);
                    if ($scope.pageData.selectedTaskDetail.consumptionTime < 0) {
                        $scope.pageData.selectedTaskDetail.consumptionTime = 0;
                    }
                }
            }
        }

        function confirmDetail() {
            // 验证
            if (!$scope.pageData.selectedTaskDetail.taskName) {
                $scope.notifyMsg("请输入任务名称！");
                return;
            } else {
                var regex = new RegExp(/^(\d+\.\d|\d+)$/);
                //如果有Id的时候就验证实际工时
                if ($scope.pageData.selectedTaskDetail.id) {

                } else {
                    //验证计划工时不能为空和0
                    if (!$scope.pageData.selectedTaskDetail.consumptionTime ||
                        $scope.pageData.selectedTaskDetail.consumptionTime == 0 || $scope.pageData.selectedTaskDetail.consumptionTime == '0') {
                        $scope.notifyMsg("计划工时不能为空或0");
                        return;
                    }
                }
                if (!checkPlanTime($scope.pageData.selectedTaskDetail.consumptionTime)) {
                    $scope.notifyMsg("计划工时填写范围：0.2-10小时（支持1位小数）！");
                    return false;
                }
                // 计划工时
                if ($scope.pageData.selectedTaskDetail.consumptionTime) {
                    // 格式化一下数字
                    $scope.pageData.selectedTaskDetail.consumptionTime =
                        parseFloat($scope.pageData.selectedTaskDetail.consumptionTime) + '';
                }
                // 实际工时
                if ($scope.pageData.selectedTaskDetail.actualConsumptionTime) {
                    if (!regex.test($scope.pageData.selectedTaskDetail.actualConsumptionTime)) {
                        $scope.notifyMsg("工时格式不正确！");
                        return false;
                    }
                    $scope.pageData.selectedTaskDetail.actualConsumptionTime =
                        parseFloat($scope.pageData.selectedTaskDetail.actualConsumptionTime) + '';
                }
                if (!$scope.pageData.selectedTaskDetail.completeState) {
                    $scope.pageData.selectedTaskDetail.completeState = 1;
                    $scope.pageData.selectedTaskDetail.completeStateName = '未做';
                }
                if ($scope.pageData.selectedTaskDetail.remind && undefined === $scope.pageData.selectedTaskDetail.remindTime) {
                    $scope.pageData.selectedTaskDetail.remindTime = '00:00';
                }

                // 更新对应的任务
                $scope.pageData.selectedTaskDetail.isAdd = false;
                $scope.pageData[$scope.pageData.selectedAttribute][$scope.pageData.selectedTaskIndex] =
                    $scope.pageData.selectedTaskDetail;
                // 大于0代表是修改进来的那时候点击确定才保存
                /* if ($scope.currentRowData.teskQuantity > 0) {
                     var type = angular.isUndefined($scope.pageData.selectedTaskDetail.id) ? 'add' : 'modify';
                     var arr = buildSaveTask();
                     if(!arr){
                         return false;
                     }
                     var status = "";
                     if(type == 'add' ){
                         status = '0';
                     }else{
                         status = '1';
                     }
                     $scope.saveData({showDate: $scope.currentRowData.showDate,status:status,address:$scope.address}, arr).then(function () {
                         $ionicLoading.show({
                             template: type === 'add' ? '<h4>添加成功</h4>' : '<h4>修改成功</h4>',
                             scope: $scope,
                             duration: 1000
                         }).then(function () {
                             $scope.getAllTask({showData: ''}).then(function () {
                                 $scope.conditions.lastDate = $scope.pageData.allDateList.getAttr().getAttr('showDate');
                                 saveTaskAfter();
                             });
                         });
                     });
                 }*/
                $scope.add_task_modal.hide().then(function () {
                    $scope.add_task_modal.remove().then(function () {
                        $ionicModal.fromTemplateUrl('add-task-modal.html', {
                            scope: $scope,
                            animation: 'slide-in-right',
                            backdropClickToClose: false
                        }).then(function (modal) {
                            $scope.add_task_modal = modal;
                        });
                    });
                });
                ynNavigator.cancelBackAction(201);
            }
        }

        //提示信息
        $scope.notifyMsg = function (msg) {
            $ionicLoading.show({
                template: '<h5>' + msg + '</h5>',
                maxHeight: 500
            });
            setTimeout(function () {
                $ionicLoading.hide();
            }, 2000);
        };

        /**
         * 组装计划中的任务数据
         * @returns {Array}
         */
        function buildSaveTask() {
            var arr = [], i;
            for (i = 0; i < $scope.pageData.beforeTask.length; i++) {
                if ($scope.pageData.beforeTask[i].taskName && !$scope.pageData.beforeTask[i].isAdd) {
                    $scope.pageData.beforeTask[i].planning = 1;
                    arr.push($scope.pageData.beforeTask[i]);
                }
            }
            for (i = 0; i < $scope.pageData.afterTask.length; i++) {
                if ($scope.pageData.afterTask[i].taskName && !$scope.pageData.afterTask[i].isAdd) {
                    $scope.pageData.afterTask[i].planning = 2;
                    arr.push($scope.pageData.afterTask[i]);
                }
            }
            /* if(arr && arr.length >10){
                 $scope.notifyMsg("当日任务数不能超过10条！");
                 return false;
             }*/
            var taskNameFlag = $scope.checkTaskName(arr);
            if (taskNameFlag) {
                $scope.notifyMsg("同一天内的任务名称不能重复！");
                return false;
            }

            //验证多次完成情况的时候，任务名称不能和父级任务名称 相同 xianzhongping 2018年7月16日16:48:26
            var value = $scope.checkManyTaskName(arr);
            if (value) {
                $scope.notifyMsg("【任务：" + value.taskName + "】与关联工作任务名称重复！");
                return false;
            }

            return arr.concat($scope.delectedTask);
        }

        //验证任务名称是否与关联工作任务名称重复
        $scope.checkManyTaskName = function (dataList) {
            //判断导入多次完成的数据，任务 名称是否和父级任务名称一样
            var taskValue = null;
            if (dataList && dataList.length > 0) {
                angular.forEach(dataList, function (value) {
                    if (!taskValue) {
                        if (value.taskName == value.relatedTask && 2 == value.importType) {//多次完成导入的，任务名称不能和夫级一样
                            taskValue = value;
                        }
                    }
                });
            }

            return taskValue;
        }

        //验证当天任务名称不能重复
        $scope.checkTaskName = function (dataList) {
            if (dataList && dataList.length > 0) {
                var taskName = [];
                var number = 0;
                angular.forEach(dataList, function (value) {
                    if ((taskName.indexOf(value.taskName) > 0) || taskName == value.taskName) {
                        number++;
                    } else {
                        taskName.push(value.taskName);
                    }
                });
                //验证有没有重名的
                if (number > 0) {
                    return true;
                } else {
                    return false;
                }
            }

        };

        function checkDataAndSave(type, clickType) {//clickType(2:总结计划按钮，3保存计划)
            var arr = buildSaveTask();
            if (!arr) {
                return false;
            }
            var status = "";
            if (type == 'add') {
                status = '0';
            } else {
                status = '1';
            }

            //验证多次导入的名称是否跟其他地方子任务名称相同 xianzhongping 2018年7月16日16:56:32
            $http.post(basePath + "/third/jobrecord/checkXTBGWorkingDetailByMobile?loading=disabled", arr).success(function (data) {
                if (data.status == 0) {
                    if (data.result) {
                        $scope.notifyMsg(data.result);
                        return false;
                    } else {
                        $scope.show();
                        $scope.saveData({
                            showDate: $scope.currentRowData.showDate,
                            status: status,
                            address: $scope.address,
                            clickType: clickType,
                            userIds: $scope.userIds
                        }, arr).then(function (response) {
                            $scope.pageData.canSubmit = false;
                            if (response.data.status === '1') {
                                // $ionicLoading.show({
                                //     // template: type === 'add' ? '<h4>添加成功</h4>' : '<h4>修改成功</h4>',
                                //     template: '保存成功！',
                                //     scope: $scope,
                                //     duration: 2000
                                // }).then(function () {
                                $scope.getAllTask({showData: ''}).then(function () {
                                    $scope.conditions.lastDate = $scope.pageData.allDateList.getAttr().getAttr('showDate');
                                    if (type === 'add') {
                                        if(clickType == 3){
                                            closeViewTask();
                                        }else {
                                            hideAddTask();
                                        }
                                    } else {
                                        saveTaskAfter();
                                    }
                                    //点击的总结计划按钮延迟一下跳转到总结页面，直接重新查询数据 xianzhongping 2018年7月26日10:14:26
                                    if (2 == clickType) {
                                        $timeout(function () {
                                            //点击总结计划先查询一下数据，不然没有ID就总结，数据会重复
                                            $scope.showViewTask($scope.currentRowData, clickType);
                                        }, 300)
                                    }
                                });

                                // });
                            }
                        })
                        $scope.hide();
                    }
                }
            })
        }

        /**
         * 保存了任务之后需要做的处理
         */
        function saveTaskAfter() {
            $scope.add_task_modal.hide().then(function () {
                $scope.add_task_modal.remove().then(function () {
                    $ionicModal.fromTemplateUrl('add-task-modal.html', {
                        scope: $scope,
                        animation: 'slide-in-right',
                        backdropClickToClose: false
                    }).then(function (modal) {
                        $scope.add_task_modal = modal;
                    });
                });
            });
            ynNavigator.cancelBackAction(201);
            $scope.findTask({showDate: $scope.currentRowData.showDate}).then(function (response) {
                if (response.data.length > 0) {
                    $scope.currentRowData.summaryExplain = response.data[0].summaryExplain;
                    var count = 0, cancel = 0, beforeTask = [], afterTask = [];
                    for (var i = 0; i < response.data.length; i++) {
                        if (response.data[i].del) {
                            $scope.delectedTask.push(response.data[i]);
                            continue;
                        }
                        if (response.data[i].completeState === 2 || response.data[i].completeState == '2') {
                            count += 1;
                        }
                        if (response.data[i].completeState === 3 || response.data[i].completeState == '3') {
                            cancel += 1;
                        }
                        if (response.data[i].planning === 1) { // 事先计划
                            beforeTask.push(response.data[i]);
                        } else { // 延后登记
                            afterTask.push(response.data[i]);
                        }
                    }
                    $scope.pageData.beforeTask = beforeTask;
                    $scope.pageData.afterTask = afterTask;
                    var length = $scope.pageData.beforeTask.length + $scope.pageData.afterTask.length;
                    $scope.pageData.taskCountMsg = '共' + (length) + '项任务、已完成' +
                        count + '项、未完成' + (length - count - cancel) + '项、任务取消' +
                        (cancel) + '项';
                }
            });
        }

        var checkPlanTime = function (planTime) {
            /* 因为允许为空 所以 为空返回true */
            if (!planTime) {
                return false;
            }
            return /^((0\.[2-9])|([1-9](\.[0-9])?)|10|10.0)$/.test(planTime);
        };

        function submitPlan(clickType) {//clickType（2：总结计划）//总结计划之前先保存一下数据 3：保存计划 xianzhongping 2018年7月26日10:09:04
            var count = 0, countTime = 0;
            isArray($scope.pageData.beforeTask) && $scope.pageData.beforeTask.forEach(function (val) {
                if (val.taskName) {
                    count++;
                    (!val.isAdd) && ((!checkPlanTime(val.consumptionTime)) && (countTime++));
                }
            });
            isArray($scope.pageData.afterTask) && $scope.pageData.afterTask.forEach(function (val) {
                if (val.taskName) {
                    count += 1;
                    (!val.isAdd) && ((!checkPlanTime(val.consumptionTime)) && (countTime++));
                }
            });
            //验证工时为必填
            if (countTime > 0) {
                $scope.notifyMsg("计划工时填写范围：0.2-10小时（支持1位小数）！");
                return false;
            }
            if (count === 0) {
                $scope.notifyMsg("请至少填写一项工作任务");
                return false;
            } else {
                if ($scope.currentRowData.showDay === '1' && 2 != clickType) { // 是昨天的添加需要给出提示,点击总结计划按钮，不做此提示 xianzhongping 2018年7月26日10:10:40
                    $ionicPopup.show({
                        title: '提示',
                        template: '<h5>您添加的是昨天的计划，提交后将无法修改</h5>',
                        buttons: [{
                            text: '继续编辑',
                            type: 'button-theme button-local button-outline'
                        }, {
                            text: '确定提交',
                            type: 'button-theme button-local',
                            onTap: function () {
                                checkDataAndSave('add', clickType);
                            }
                        }]
                    });
                } else {
                    checkDataAndSave('add', clickType);
                }
            }
        }

        function findTask(params) {
            return $http.get(basePath + '/third/jobrecord/findJSTXJObRecordDetailDTOByShowDate', {
                params: params
            }).then(function (response) {
                return response;
            })
        }

        function showViewTask(rowData, clickType) {//clickType:(2:点击的是总结计划，3保存计划)
            $scope.pageData.showTip = true;
            $scope.pageData.beforeTask = [];
            $scope.pageData.afterTask = [];
            $scope.pageData.viewTips = '';
            $scope.pageData.taskCountMsg = '';
            if(clickType == '2' || clickType == 'fh'){
                //总结
                viewTaskFun();
            }else {
                $scope.view_task_modal.show().then(function () {
                    viewTaskFun();
                });
            }
            function viewTaskFun() {
                $scope.currentRowData = angular.copy(rowData);
                $scope.currentRowData.formatShowDate = $scope.currentRowData.showDate.split('-')[1] + '月' +
                    $scope.currentRowData.showDate.split('-')[2] + '日';
                var now = new Date();
                // 最后可修改时间
                var lastModifyTime = new Date(
                    $scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.planTimeEnd + ' +0800');
                $scope.pageData.canModify = now < lastModifyTime;
                // 最后可总结时间
                var lastSummaryTime = new Date(
                    new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.sumaryTimeEnd + ' +0800')
                        .setSeconds(60 * 60 * 24));
                $scope.pageData.canSummary = now < lastSummaryTime;
                // 显示提示信息
                if ($scope.pageData.canModify && $scope.pageData.canSummary) {
                    $scope.pageData.viewTips = '请在' + $filter('date')(lastSummaryTime, 'MM月dd号HH:mm')
                        + '前完成总结，如需修改任务请在' + $scope.currentRowData.formatShowDate + $scope.pageData.rule.planTimeEnd
                        + '前操作';
                } else if (!$scope.pageData.canModify && $scope.pageData.canSummary) {
                    $scope.pageData.viewTips = '已超时不能修改任务，请在' + $filter('date')(lastSummaryTime, 'MM月dd号HH:mm')
                        + '前完成总结';
                } else {
                    $scope.pageData.viewTips = '超时不允许修改任务和总结计划';
                }
                var beforeTask = [];
                var afterTask = [];

                /* 处理数据 */
                function to_response(list) {
                    var count = 0, cancel = 0, total = 0;
                    isArray(list) && list.forEach(function (val) {
                        if (val.del) {
                            $scope.delectedTask.push(val);
                        } else {
                            total = (total || 0) + 1;
                            if (val.completeState === 2 || val.completeState === "2") {
                                count = (count || 0) + 1;
                            } else if (val.completeState === 3 || val.completeState === "3") {
                                cancel = (cancel || 0) + 1;
                            }
                            if (val.planning === 1) {
                                $scope.pageData.beforeTask.push(val);
                            } else if (val.planning !== 1) {
                                $scope.pageData.afterTask.push(val);
                            }
                        }
                    });
                    return {count: count, cancel: cancel, total: total};
                }

                function to_data(list) {
                    var currentTime = new Date(),
                        planTime = new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.planTime);
                    isArray(list) && list.forEach(function (val) {
                        if (currentTime < planTime) {
                            val.planning = 1;
                            $scope.pageData.beforeTask.push(val);
                        }
                        else {
                            val.planning = 2;
                            $scope.pageData.afterTask.push(val);
                        }
                    });
                }

                function to_total(clickType, page) {
                    var length = page.total;
                    $scope.pageData.taskCountMsg = '共' + (length) + '项任务、已完成' +
                        (page.count) + '项、未完成' + (length - (Number(page.count) || 0) - (Number(page.cancel) || 0)) + '项、任务取消' +
                        (Number(page.cancel) || 0) + '项';
                    if ("2" === (clickType + "")) {//点击总结计划的时候，调用总结计划方法 xianzhongping 2018年7月26日11:31:38
                        setTimeout(function () {
                            $scope.showConclusionTask(clickType);
                        });
                    }
                }

                // 查询
                $scope.findTask({
                    showDate: $scope.currentRowData.showDate,
                    clickType: clickType
                }).then(function (response) {
                    if (response.data.length > 0) {
                        $scope.currentRowData.summaryExplain = response.data[0].summaryExplain;
                        var page = to_response(response.data);
                        if (clickType !== 2 && (now < lastSummaryTime)) {
                            $http.post(basePath + "/third/jobrecord/findMobileAutomaticImportData?loading=disabled&logDate=" + $scope.currentRowData.showDate).success(function (data) {
                                if (("" + data.status) === "0") {
                                    to_data(data.result);
                                    to_total(clickType, page)
                                }
                            });
                        } else {
                            to_total(clickType, page);
                        }
                    }
                });

                $scope.names = "";
                //查询关注人员
                $http.post(basePath + "/third/jobrecord/findUserNames?loading=disabled&showDate=" + $scope.currentRowData.showDate).success(function (data) {
                    if (data.status == 0) {
                        var userNames = [], ids = [];
                        $scope.workingLogSysUserMidDTOList = data.result;
                        angular.forEach($scope.workingLogSysUserMidDTOList, function (val) {
                            userNames.push(val.name);
                            if (ids == "") {
                                ids = val.id
                            } else {
                                ids = ids + "," + val.id
                            }
                            if ($scope.names == "") {
                                $scope.names = val.name
                            } else {
                                $scope.names = $scope.names + "," + val.name
                            }
                        });
                        $scope.userIds = ids;
                        $scope.userNames = angular.copy(userNames);
                    }
                })


                $scope.pageData.beforeTask = beforeTask;
                $scope.pageData.afterTask = afterTask;
            }
        }

        function closeViewTask() {
            $scope.view_task_modal.hide();
        }

        function modifyPageAddTask() {
            $scope.pageData.selectedTaskDetail = {
                taskName: '',
                taskTypeCodeName: "自建个人任务",
                isAdd: true,
                taskType: 1,
                remind: false,
                modify: true,
                del: false,
                importType: 1,// 导入类型 1：一次性导入 2：多次导入
                consumptionTime: 0
            };
            var planTime = new Date($scope.currentRowData.showDate + ' ' + $scope.pageData.rule.planTime);
            var currentTime = new Date();
            if (currentTime > planTime) { // 延后登记
                $scope.pageData.selectedAttribute = 'afterTask';
                $scope.pageData.selectedTaskDetail.planning = 2;
            } else { // 事先计划
                $scope.pageData.selectedAttribute = 'beforeTask';
                $scope.pageData.selectedTaskDetail.planning = 1;
            }
            $scope.pageData.selectedAllTaskIndex = $scope.pageData.beforeTask.length + $scope.pageData.afterTask.length;
            $scope.pageData.selectedTaskIndex = $scope.pageData[$scope.pageData.selectedAttribute].length;
            $scope.pageData.selectedTaskDetail.taskType = 1; // 通常任务
            $scope.add_task_modal.show();

            ynNavigator.registerBackAction(function () {
                closeAddTaskDetail();
            }, 201);
        }

        function showConclusionTask(clickType) {
            $scope.pageData.showTip = true;
            var now = new Date();
            // 最后可总结时间
            var lastSummaryTime = new Date(
                new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.sumaryTimeEnd + ' +0800')
                    .setSeconds(60 * 60 * 24));
            // 按时总结时间
            var firstSummaryTime = new Date(
                new Date($scope.currentRowData.showDate.replace(/-/g, '/') + ' ' + $scope.pageData.rule.sumaryTime + ' +0800')
                    .setSeconds(60 * 60 * 24));
            // 判断是不是按时总结
            $scope.pageData.summaryState = now > firstSummaryTime ? 3 : 2;
            // 显示提示信息
            $scope.pageData.conclusionTips = '请在' + $filter('date')(lastSummaryTime, 'MM月dd号HH:mm') + '前完成总结';

            for (var i = 0; i < $scope.pageData.beforeTask.length; i++) {
                var actualConsumptionTime = $scope.pageData.beforeTask[i].actualConsumptionTime;//总结的时候，办理工时为空的时候，将默认显示计划工时 xianzhongping 2018年7月25日15:33:35
                if ((2 == clickType && null == actualConsumptionTime) || (2 == clickType && 0 == actualConsumptionTime)) {
                    actualConsumptionTime = $scope.pageData.beforeTask[i].consumptionTime;
                }
                $scope.pageData.beforeTask[i].actualConsumptionTime = actualConsumptionTime;

                /* 取消/未做 不允许填写办理工时 并默认办理工时为 0 */
                if (["1", "3"].indexOf("" + $scope.pageData.beforeTask[i].completeState) > -1) {
                    // item.oldActualTime = angular.copy(item.actualConsumptionTime); /* 保存一个清空*/
                    $scope.pageData.beforeTask[i].actualConsumptionTime = 0;
                    $scope.pageData.beforeTask[i].actualDisable = true;
                }
            }
            for (var i = 0; i < $scope.pageData.afterTask.length; i++) {
                var actualConsumptionTime = $scope.pageData.afterTask[i].actualConsumptionTime;//总结的时候，办理工时为空的时候，将默认显示计划工时 xianzhongping 2018年7月25日15:33:35
                if ((2 == clickType && null == actualConsumptionTime) || (2 == clickType && 0 == actualConsumptionTime)) {
                    actualConsumptionTime = $scope.pageData.afterTask[i].consumptionTime;
                }
                $scope.pageData.afterTask[i].actualConsumptionTime = actualConsumptionTime;

                /* 取消/未做 不允许填写办理工时 并默认办理工时为 0 */
                if (["1", "3"].indexOf("" + $scope.pageData.afterTask[i].completeState) > -1) {
                    // item.oldActualTime = angular.copy(item.actualConsumptionTime); /* 保存一个清空*/
                    $scope.pageData.afterTask[i].actualConsumptionTime = 0;
                    $scope.pageData.afterTask[i].actualDisable = true;
                }
            }

            $scope.conclusion_task_modal.show();
            registerConclusion();
        }
        //总结模态框拦截
        function registerConclusion() {
            ynNavigator.registerBackAction(function () {
                closeConclusionTask();
            }, 201);
        }
        function closeConclusionTask() {
            $ionicPopup.alert({
                title: '提示',
                template: '<h5>返回后，此次编辑的总结内容将丢失</h5>',
                buttons: [{
                    text: '继续编辑',
                    type: 'button-theme button-local button-outline'
                }, {
                    text: '确定返回',
                    type: 'button-theme button-local',
                    onTap: function () {
                        $scope.currentRowData.summaryExplain = '';
                        $scope.conclusion_task_modal.hide().then(function () {
                            $scope.conclusion_task_modal.remove().then(function () {
                                $ionicModal.fromTemplateUrl('task-conclusion.html', {
                                    scope: $scope,
                                    animation: 'slide-in-right'
                                }).then(function (modal) {
                                    $scope.conclusion_task_modal = modal;
                                }).then(function () {
                                    $scope.getAllTask({showDate: null}).then(function () {
                                        for (var i = 0; i < $scope.pageData.allDateList.length; i++) {
                                            for (var j = 0; j < $scope.pageData.allDateList[i].length; j++) {
                                                if ($scope.pageData.allDateList[i][j].showDate === $scope.currentRowData.showDate) {
                                                    $scope.currentRowData = angular.copy($scope.pageData.allDateList[i][j]);
                                                    break;
                                                }
                                            }
                                        }
                                        setTimeout(function () {
                                            $scope.showViewTask($scope.currentRowData,'fh');
                                        })
                                    });
                                })
                            })
                            ynNavigator.cancelBackAction(201);
                        });
                    }
                }]
            });
        }

        function isArray(list) {
            return angular.isArray(list) && list.length > 0;
        }

        function submitConclusion() {
            var arr = [], i, msg, complete = 0, error = 0, cancel = 0, number = 0;
            var regex = new RegExp(/^(\d+\.\d|\d+)$/);
            /* 判断是否选择 完成状态 */
            var isComplateStatus = false;
            isArray($scope.pageData.beforeTask) && $scope.pageData.beforeTask.forEach(function (value) {
                (!value.completeState) && (isComplateStatus = true);
            });
            isArray($scope.pageData.afterTask) && $scope.pageData.afterTask.forEach(function (value) {
                (!value.completeState) && (isComplateStatus = true);
            });
            if (isComplateStatus) {
                $scope.notifyMsg("请填写完成状态！");
                return false;
            }
            for (i = 0; i < $scope.pageData.beforeTask.length; i++) {
                if ($scope.pageData.beforeTask[i].taskName) {
                    if ($scope.pageData.beforeTask[i].consumptionTime &&
                        !regex.test($scope.pageData.beforeTask[i].consumptionTime)) {
                        error += 1;
                        break;
                    }
                    if ($scope.pageData.beforeTask[i].actualConsumptionTime &&
                        !regex.test($scope.pageData.beforeTask[i].actualConsumptionTime)) {
                        error += 1;
                        break;
                    }
                    $scope.pageData.beforeTask[i].planning = 1;
                    arr.push($scope.pageData.beforeTask[i]);
                    if ($scope.pageData.beforeTask[i].completeState === 2 || $scope.pageData.beforeTask[i].completeState == '2') {
                        complete += 1;
                    } else if ($scope.pageData.beforeTask[i].completeState === 3 || $scope.pageData.beforeTask[i].completeState == '3') {
                        cancel += 1;
                    }
                }
            }
            for (i = 0; i < $scope.pageData.afterTask.length; i++) {
                if ($scope.pageData.afterTask[i].taskName) {
                    if ($scope.pageData.afterTask[i].consumptionTime &&
                        !regex.test($scope.pageData.afterTask[i].consumptionTime)) {
                        error += 1;
                        break;
                    }
                    if ($scope.pageData.afterTask[i].actualConsumptionTime &&
                        !regex.test($scope.pageData.afterTask[i].actualConsumptionTime)) {
                        error += 1;
                        break;
                    }
                    $scope.pageData.afterTask[i].planning = 2;
                    arr.push($scope.pageData.afterTask[i]);
                    if ($scope.pageData.afterTask[i].completeState === 2 || $scope.pageData.afterTask[i].completeState == '2') {
                        complete += 1;
                    } else if ($scope.pageData.afterTask[i].completeState === 3 || $scope.pageData.afterTask[i].completeState == '3') {
                        cancel += 1;
                    }
                }
            }

            //验证：只有取消和未做的时候，办理工时可以为0，其他状态必须大于0 xianzhongping 2018年7月17日10:10:54
            var summaryFlag = true;
            angular.forEach(arr, function (newData) {
                if (!newData.del) {//少量、近半、大半、完成时，办理共时需大于0
                    if ((4 == newData.completeState || 5 == newData.completeState || 6 == newData.completeState || 2 == newData.completeState)
                        && (!newData.actualConsumptionTime || newData.actualConsumptionTime == 0 || newData.actualConsumptionTime == '0')) {
                        summaryFlag = false;
                    }
                }
            });
            if (!summaryFlag) {
                $scope.notifyMsg("少量、近半、大半、完成时，办理工时需大于0！");
                return false;
            }

            if (error) {
                $ionicPopup.show({
                    title: '提示',
                    template: '<h5>工时格式不正确</h5>',
                    buttons: [{
                        text: '确定',
                        type: 'button-theme button-local'
                    }]
                });
                return false;
            }
            msg = '共' + arr.length + '项任务，已完成' + complete + '项，未完成' +
                (arr.length - complete - cancel) + '项，任务取消' + cancel + '项';
            arr = arr.concat($scope.delectedTask);
            $ionicPopup.show({
                title: '提示',
                template: '<h5>' + msg + '</h5>',
                buttons: [{
                    text: '继续编辑',
                    type: 'button-theme button-local button-outline'
                }, {
                    text: '确定提交',
                    type: 'button-theme button-local',
                    onTap: function () {
                        $scope.pageData.canComplate = true;
                        $scope.saveData({
                            showDate: $scope.currentRowData.showDate,
                            summaryExplain: $scope.currentRowData.summaryExplain,
                            summaryState: $scope.pageData.summaryState,
                            status: '2',
                            address: $scope.address,
                            userIds: $scope.userIds
                        }, arr).then(function () {
                            $scope.pageData.canComplate = false;
                            $ionicLoading.show({
                                template: '<h4>提交成功</h4>',
                                scope: $scope,
                                duration: 2000
                            }).then(function () {
                                // $scope.showViewTask($scope.currentRowData);
                                $scope.conclusion_task_modal.hide().then(function () {
                                    $scope.conclusion_task_modal.remove().then(function () {
                                        $ionicModal.fromTemplateUrl('task-conclusion.html', {
                                            scope: $scope,
                                            animation: 'slide-in-right'
                                        }).then(function (modal) {
                                            $scope.conclusion_task_modal = modal;
                                        }).then(function () {
                                            $scope.getAllTask({showDate: null}).then(function () {
                                                for (var i = 0; i < $scope.pageData.allDateList.length; i++) {
                                                    for (var j = 0; j < $scope.pageData.allDateList[i].length; j++) {
                                                        if ($scope.pageData.allDateList[i][j].showDate === $scope.currentRowData.showDate) {
                                                            $scope.currentRowData = angular.copy($scope.pageData.allDateList[i][j]);
                                                            break;
                                                        }
                                                    }
                                                }
                                                setTimeout(function () {
                                                    $scope.showViewTask($scope.currentRowData,'fh');
                                                })
                                            });
                                        })
                                    })
                                    ynNavigator.cancelBackAction(201);
                                });
                            });
                        });
                    }
                }]
            });
        }

        $scope.showRemindTime = showRemindTime;

        function showRemindTime(detail) {
            var msg = $scope.currentRowData.formatShowDate + detail.remindTime + '提醒我';
            $ionicLoading.show({
                template: '<h5>' + msg + '</h5>',
                scope: $scope
            }).then(function () {
                $timeout(function () {
                    $ionicLoading.hide();
                }, 2000);
            })
        }

        function formatNumber(obj) {
            var newChar = obj.consumptionTime.substr(obj.consumptionTime.length - 1);
            var regex = new RegExp(/[^0-9|.]/);
            if (regex.test(newChar)) {
                obj.consumptionTime = obj.consumptionTime.substr(0, obj.consumptionTime.indexOf(newChar));
            }
            // obj.consumptionTime = parseFloat(obj.consumptionTime).toFixed(1);
        }

        // 获取 指定属性
        Array.prototype.getAttr = function (code) {
            if (this && this.length > 0) {
                if (code) {
                    return this[this.length - 1][code];
                } else {
                    return this[this.length - 1];
                }
            } else {
                return {};
            }
        };

        // 补充集合 数据
        Array.prototype.suppFun = function () {
            if (this.length < 6) {
                for (var i = this.length; i < 6; i++) {
                    this.push({
                        taskName: '添加第' + i + '项新任务',
                        isAdd: true,
                        taskType: 1,
                        remind: false,
                        modify: true,
                        del: false,
                        importType: 1
                    });
                }
            }
            // else if (this.length < 10) {
            //     this.push({taskName: '添加一项新任务'});
            // }
            return this;
        };

        // 判断id
        function checkId(info) {
            if (info.isAdd) {
                return false;
            } else {
                /*if (info.id) {
                    return true;
                } else*/
                if (info.xtgbAssId) {
                    return true;
                } else if (info.xtbgProjectId) {
                    return true;
                } else if (info.workTaskId) {
                    return true;
                } else {
                    return true;
                }
            }
            return false;
        }

        // 去除集合空 数据
        Array.prototype.goAir = function () {
            var res = [];
            for (var i = 0; i < this.length; i++) {
                var obj = this[i];
                if (checkId(obj)) {
                    res.push(this[i]);
                }
            }
            return res;
        };

        // 去重
        Array.prototype.goHeavy = function () {
            var res = [];
            var json = {};
            for (var i = 0; i < this.length; i++) {
                var obj = this[i];
                if (obj.taskType && obj.taskType === 1) {
                    /*if (obj.id) {
                        if (!json[obj.id]) {
                            res.push(obj);
                            json[obj.id] = true;
                        }
                    } else {*/
                    res.push(obj);
                    //}
                } else {
                    var xtId = obj.xtgbAssId || obj.xtbgProjectId || obj.workTaskId;
                    if (xtId) {
                        if (!json[xtId + obj.taskName]) {//用导入数据ID和名称一起去重 xianzhongping 2018年7月17日10:26:32
                            json[xtId + obj.taskName] = true;
                            res.push(obj);
                        }
                    } else {
                        res.push(obj);
                    }
                }
            }
            return res;
        };


        $scope.selectUserList = function (userList) {
            //$scope.userNames="";
            var names = [], userDTOList = [], ids = "";
            angular.forEach(userList, function (val) {
                names.push(val.name);
                userDTOList.push(val);
                if (ids == "") {
                    ids = val.id
                } else {
                    ids = ids + "," + val.id
                }
            });
            $scope.userIds = ids;
            $scope.userNames = angular.copy(names);
            $scope.workingLogSysUserMidDTOList = angular.copy(userDTOList);
        };
    }
})();
