/**
 * Created by qiucheng Lu on 2021年4月9日13:38:21
 * 公共service服务
 */
angular.module('starter')
    .factory('viewsParameterService', function () {
        // 不同视图之间传递对象
        var jsonObj = {};
        return {
            clearParameter: function () {

                if (window && window.localStorage) {
                    window.localStorage.removeItem("selectSutTemp");
                }
            },
            getParameter: function () {
                var back = jsonObj;
                if (window && window.localStorage) {
                    var temp = window.localStorage.getItem("selectSutTemp");
                    if (temp) {
                        back = JSON.parse(temp);
                    }
                }
                return back;
            },
            setParameter: function (obj) {
                if (window && window.localStorage) {
                    window.localStorage.setItem("selectSutTemp", JSON.stringify(obj));
                }
                jsonObj = obj;
            },
            //判断是否是刷新，jsonObj = {} 就是刚进入页面或者刷新了
            getTempParameter: function () {
                var jStr = JSON.stringify(jsonObj);
                if (jStr == "{}" || !jStr) {
                    return null;
                } else {
                    return jsonObj;
                }
            }
        }

    })
    /**
     * 模态框管理器
     * 管理模态框的生命周期
     */
    .factory("modalManager", function () {
        var modals = {};

        return {
            /**
             * 判断是否存在
             * @param modalName
             * @returns {boolean}
             */
            exist: function (modalName) {
                var modal = modals[modalName];
                if (modal) {
                    return true;
                }
                return false;
            },
            put: function (modalName, modal) {
                if (!this.exist(modalName)) {
                    modals[modalName] = modal;
                }
            },
            /**
             * 获取
             * @param modalName
             * @returns {*}
             */
            get: function (modalName) {
                if (this.exist(modalName)) {
                    return modals[modalName];
                }
                return null;
            },
            /**
             * 显示
             * @param modalName
             */
            show: function (modalName) {
                if (this.exist(modalName)) {
                    modals[modalName].show();
                    this.showModals();
                }
            },
            /**
             * 关闭
             * @param modalName
             */
            close: function (modalName) {
                if (this.exist(modalName)) {
                    modals[modalName].hide();
                    this.showModals();
                }
            },
            /**
             * 移除
             * @param modalName
             */
            remove: function (modalName) {
                if (this.exist(modalName)) {
                    modals[modalName].remove();
                    delete modals[modalName];
                    this.showModals();
                }
            },
            showModals: function () {
                // console.log(modals);
            }
        };
    })
    /***
     * 本地数据缓存
     */
    .factory("storageService", function () {
        /**
         * 可以插入undefined  null 或者是对象
         * 对key值的保护，只返回string
         * @param key
         */
        var translateKeyToStr = function (key) {
            if (angular.isUndefined(key)) {
                return $rootScope.DEFAULT_KEY;
            } else if (angular.isObject(key) || angular.isArray(key) || angular.isNumber(+key || key)) {
                return angular.toJson(key) + $rootScope.path;
            }
            /*增加对空字符串的支持*/
            else if (angular.isString(key)) {
                if (key.length > 0) {
                    return key;
                } else {
                    return $rootScope.DEFAULT_KEY;
                }
            }
            /*增加对布尔值的支持*/
            else if (angular.isBoolean(key)) {
                return key + "";
            }
            return $rootScope.DEFAULT_KEY;
        };
        /**
         * 根据 key删除缓存的数据
         * @param key
         */
        var removeValue = function (key) {
            if (window && window.localStorage) {
                window.localStorage.removeItem(translateKeyToStr(key));
            }
        };
        /***
         * 保存数据和删除数据
         */
        return {
            getItem: function (key) {
                if (window && window.localStorage) {
                    var _$ = window.localStorage.getItem(translateKeyToStr(key));
                    removeValue(translateKeyToStr(key));
                    if (_$) {
                        return angular.copy(JSON.parse(_$));
                    }
                    return null;
                }
            },
            getItemNoDel: function (key) {
                if (window && window.localStorage) {
                    var _$ = window.localStorage.getItem(translateKeyToStr(key));
                    if (_$) {
                        return angular.copy(JSON.parse(_$));
                    }
                    return null;
                }
            },
            clearKey: function (key) {
                removeValue(translateKeyToStr(key));
            },
            setItem: function (key, value) {
                if (window && window.localStorage) {
                    if (value) {
                        window.localStorage.setItem(translateKeyToStr(key), JSON.stringify(value));
                    }
                }
            }
        }
    })
    .factory("creditStorageService", function () {
        /**
         * 可以插入undefined  null 或者是对象
         * 对key值的保护，只返回string
         * @param key
         */
        var translateKeyToStr = function (key) {
            if (angular.isUndefined(key)) {
                return $rootScope.DEFAULT_KEY;
            } else if (angular.isObject(key) || angular.isArray(key) || angular.isNumber(+key || key)) {
                return angular.toJson(key) + $rootScope.path;
            }
            /*增加对空字符串的支持*/
            else if (angular.isString(key)) {
                if (key.length > 0) {
                    return key;
                } else {
                    return $rootScope.DEFAULT_KEY;
                }
            }
            /*增加对布尔值的支持*/
            else if (angular.isBoolean(key)) {
                return key + "";
            }
            return $rootScope.DEFAULT_KEY;
        };
        /**
         * 根据 key删除缓存的数据
         * @param key
         */
        var removeValue = function (key) {
            if (window && window.localStorage) {
                window.localStorage.removeItem(translateKeyToStr(key));
            }
        };
        /***
         * 保存数据和删除数据
         */
        return {
            getItem: function (key) {
                if (window && window.localStorage) {
                    var _$ = window.localStorage.getItem(translateKeyToStr(key));
                    removeValue(translateKeyToStr(key));
                    if (_$) {
                        return angular.copy(JSON.parse(_$));
                    }
                    return null;
                }
            },
            getItemNoDel: function (key) {
                if (window && window.localStorage) {
                    var _$ = window.localStorage.getItem(translateKeyToStr(key));
                    if (_$) {
                        return angular.copy(JSON.parse(_$));
                    }
                    return null;
                }
            },
            clearKey: function (key) {
                removeValue(translateKeyToStr(key));
            },
            setItem: function (key, value) {
                if (window && window.localStorage) {
                    if (value) {
                        window.localStorage.setItem(translateKeyToStr(key), JSON.stringify(value));
                    }
                }
            }
        }
    })
    //自定义保存存储服务
    .service("classListService", function () {
        //初始化服务列表
        return {
            getAllList: function () {
                var classList = window.localStorage.getItem("_class_list_storage");
                return !classList ? [] : JSON.parse(classList);
            },
            save: function (arr) {
                window.localStorage.setItem("_class_list_storage", null == arr ? "" : JSON.stringify(arr));
            }
        }
    })
    .run(["$rootScope", "classListService", function ($rootScope, classListService) {
        $rootScope.$on("$stateChangeSuccess", function (event, toState, toParams, fromState, fromParams) {
            var state = ["class_search", "search_classList", "selectClass_examine_project", "select_class", "class_patrol"];
            var toStatuRoute = toState.name, fromStatuRoute = fromState.name;
            if (fromStatuRoute == "") {
                return;
            }
            //如果是从其他地方跳转过来的，就需要删除原来的数据格式
            if (!state.some(function (t) {
                return t == fromStatuRoute
            })) {
                // classListService.save(null);
                return;
            }
            if (!state.some(function (t) {
                return t == toStatuRoute
            })) {
                // classListService.save(null);
                return;
            }
        });
    }])
    /**
     * 课堂考勤手机端服务
     */
    .service("kqktMobileService", function ($http, $q, $ionicPopup) {

        var basePath = originBaseUrl + "/third/kqkt/mobile";

        //获取课堂考勤初始化信息
        function findKqktRollCallInitInfo() {
            var deferred = $q.defer(),
                promise = deferred.promise;
            $http.get(basePath + "/findKqktRollCallInitInfo.htm").success(function (data) {
                deferred.resolve(data);
            });
            return promise;
        }

        //根据学期和日期获取周和星期
        function findWeekAndDay(termId, date) {
            var deferred = $q.defer(),
                promise = deferred.promise;
            $http.get(basePath + "/findWeekAndDay.htm", {
                params: {
                    termId: termId,
                    date: date
                }
            }).success(function (data) {
                deferred.resolve(data);
            });
            return promise;
        }

        //根绝学期和日期获取节次信息
        function findPkTeachWeekTimeList(termId, date) {
            var deferred = $q.defer(),
                promise = deferred.promise;
            $http.get(basePath + "/findPkTeachWeekList.htm", {
                params: {
                    termId: termId,
                    date: date
                }
            }).success(function (data) {
                if (data.status == 0) {
                    deferred.resolve(data);
                }
            });
            return promise;
        }

        //根据knobKey获取
        function findKnobByKey(knobArr, knobKey) {
            for (var i = 0; i < knobArr.length; i++) {
                var k = knobArr[i];
                if (k.knobKey == knobKey) {
                    return k;
                }
            }
            return null;
        }

        //根据节次信息和选中节次获取选中节次的时间
        function getCurrentTeachWeekTimeByKnob(knobArr, knobKey) {
            var knobObj = findKnobByKey(knobArr, knobKey);
            return getKqktTimeInfo(knobObj);
        }

        function getCurrentTeachWeekTimeIndex(knobArr, index) {
            for (var i = 0; i < knobArr.length; i++) {
                if (i == index) {
                    return getKqktTimeInfo(knobArr[i]);
                }
            }
        }


        //根据节次信息和时间获取当前节次和课堂时间
        function getCurrentTeachWeekTime(knobArr, time) {
            //将节次的时间转换为时间搓 （秒）
            angular.forEach(knobArr, function (item) {
                item.startTimeSec = timeTosec(item.startTime);
                item.endTimeSec = timeTosec(item.endTime);
            });
            return findKnobTime(knobArr, timeTosec(time))
        }

        //获取课堂时间
        function getKqktTimeInfo(knobObj) {
            if (!knobObj) {
                return;
            }
            var startLastIndex = knobObj.startTime.lastIndexOf(":");
            var endLastIndex = knobObj.endTime.lastIndexOf(":");
            var ktStartTime = knobObj.startTime.substring(0, startLastIndex);
            var ktEndTime = knobObj.endTime.substring(0, endLastIndex);
            return {ktStartTime: ktStartTime, ktEndTime: ktEndTime, knobKey: knobObj.knobKey};
        }

        /**
         * 获取当前节次
         * @param knobArr 节次信息
         * @param timeSec  时间搓（秒）
         * @returns {*}
         */
        function findKnobTime(knobArr, timeSec) {
            if (!knobArr) {
                return "";
            }
            for (var i = 0; i < knobArr.length; i++) {
                if (knobArr[i].startTimeSec <= timeSec && knobArr[i].endTimeSec >= timeSec) {
                    return getKqktTimeInfo(knobArr[i]);
                }
            }
            return "";
        }

        /**
         * 时间转为秒
         * @param time 时间(00:00:00)
         * @returns {number} 时间戳（单位：秒）
         */
        function timeTosec(time) {
            if (!time) {
                return 0;
            }
            var timeArr = time.split(':');
            var hour = timeArr[0];
            var min = timeArr[1];
            var sec = timeArr[2];
            return Number(hour * 3600) + Number(min * 60) + Number(sec);
        }

        //时间比较
        function compareTime(startTime, endTime) {
            var starTimeArr = startTime.split(":");
            var endTimeArr = endTime.split(":");
            var gtHour = parseInt(starTimeArr[0]) > parseInt(endTimeArr[0]);
            var eqHour = parseInt(starTimeArr[0]) == parseInt(endTimeArr[0]);
            var gtMi = parseInt(starTimeArr[1]) >= parseInt(endTimeArr[1]);
            if (gtHour) {
                return false;
            } else if (eqHour && gtMi) {
                return false;
            }
            return true;
        }

        //获取课堂考勤初始化信息
        function recognitionRateFace(type, submitKqktData) {
            var deferred = $q.defer(),
                promise = deferred.promise;

            var access_token = JSON.parse(window.localStorage.getItem("authorizationStr")).access_token;

            var url = "";

            //1为教师，2为班干部
            if (type == 1) {
                url = basePath + "/recognitionRateFaceRollCall.htm?access_token=" + access_token;
            } else if (type == 2) {
                url = basePath + "/recognitionRateFaceCommonRollCall.htm?access_token=" + access_token;
            }

            $.ajax({
                url: url,
                type: "post",
                async: false,
                dataType: "json",
                data: submitKqktData,
                success: function (data) {
                    if (data.status == 0) {
                        var obj = data.result;
                        if (obj.flag) {

                            var htmlTip = "<span>为保证人脸识别率，建议您在本节课开始<span style='color: red'>" + obj.inClassMinutes + "</span>分钟后开始点名。</span>";

                            var confirmPopup = $ionicPopup.confirm({
                                title: "当前时间正在进行人脸识别自动考勤，确定要点名吗？",
                                template: htmlTip,
                                cancelText: "取消",
                                okText: "确定"
                            });
                            confirmPopup.then(function (flag) {
                                if (flag) {
                                    deferred.resolve({go: true});
                                } else {
                                    deferred.resolve({go: false});
                                }
                            });
                        } else {
                            deferred.resolve({go: true});
                        }
                    } else {
                        deferred.resolve({go: true});
                    }
                }
            });
            return promise;
        }

        return {
            //获取课堂考勤初始化信息
            findKqktRollCallInitInfo: findKqktRollCallInitInfo,
            //根据学期和日期获取周和星期
            findWeekAndDay: findWeekAndDay,
            //根绝学期和日期获取节次信息
            findPkTeachWeekTimeList: findPkTeachWeekTimeList,
            //根据节次信息和时间获取当前节次和课堂时间
            getCurrentTeachWeekTime: getCurrentTeachWeekTime,
            getCurrentTeachWeekTimeIndex: getCurrentTeachWeekTimeIndex,
            //时间比较
            compareTime: compareTime,
            recognitionRateFace: recognitionRateFace,
            //根据节次信息和选中节次获取选中节次的时间
            getCurrentTeachWeekTimeByKnob: getCurrentTeachWeekTimeByKnob
        };
    })
    /**
     * 浮动框——已选的学生
     */
    .directive("selectedStuViewer", function () {
        return {
            restrict: "AE",
            // scope: {
            //     param: "=",
            //     tkInfo: "=" /**听课信息*/
            // },
            // 设置模板路径
            templateUrl: function (tElement, tAttrs) {
                return "templates/moralityMeasurement/selectedStuViewer.html";
            },
            controller: ["$scope", "$http", "$filter", "creditStorageService", function ($scope, $http, $filter, creditStorageService) {
                $scope.selectedStuList = creditStorageService.getItemNoDel("credit_selectedStuList");
                if (!$scope.selectedStuList) {
                    $scope.selectedStuList = [];
                    creditStorageService.setItem("credit_selectedStuList", $scope.selectedStuList);
                }

                /**
                 * 移除已选中的学生
                 * @param id
                 */
                $scope.removeStu = function (platformSysUserId) {
                    var index = 0;
                    // 移除已选中学生
                    angular.forEach($scope.selectedStuList, function (selectedStu) {
                        if (selectedStu.platformSysUserId == platformSysUserId) {
                            $scope.selectedStuList.splice(index, 1);
                        }
                        index++;
                    });
                    // 如果有查询出来的学生
                    if ($scope.searchStuList) {
                        // 将移除的学生标记为未选中
                        angular.forEach($scope.searchStuList, function (stu) {
                            if (stu.platformSysUserId == platformSysUserId) {
                                stu.isSelected = false;
                            }
                        });
                    }
                    // 及时放入缓存
                    creditStorageService.setItem("credit_selectedStuList", $scope.selectedStuList);
                };
            }]
        };
    })
    //课表组件
    .directive('scheduleDirective', ['$http', '$timeout', function ($http, $timeout) {
        return {
            restrict: 'AE',
            replace: true,
            templateUrl: 'templates/schedule/schedule-directive.html',
            scope: {
                options: "="
            },
            link: scheduleLink
        };

        function scheduleLink(scope) {
            /*开放接口*/
            scope.options.queryTimeTableByWeek = function (weekNum, userId, userType) {
                if (weekNum) {
                    scope.query(weekNum, userId, userType);
                } else {
                    console.error("weekNum is null !");
                }
            };

            /*查询数据*/
            scope.tableByWeekList = [];
            // scope.scheduleList = {};
            scope.query = function (weekNum, userId, userType) {
                scope.nocourse = false;
                $http.get(originBaseUrl + '/third/schedules/queryTimeTableByWeek.htm?' +
                    'week=' + (weekNum === undefined ? "" : weekNum) +
                    '&queryObjectId=' + userId +
                    '&requestSource=' + userType
                ).success(function (res) {
                    scope.isNoNgKnob = false;
                    scope.isNozzKnob = false;
                    // scope.weekCourse = false;
                    // scope.weekActivity = false;
                    if (res.status == 0) {
                        if (res.result.schedule) {
                            if (scope.tableByWeekList == null) {
                                scope.loadErrorMsg = "课表加载失败！";
                            }
                            var scheduleList = res.result.schedule;
                            scope.tableByWeekList = scheduleList.scheduleDayVOList;
                            // scope.scheduleList = scheduleList.ScheduleWeekCourseListVO;
                            scope.dataContent = true;
                            scope.amKnob = scope.tableByWeekList[0].amKnobList.length;
                            scope.pmKnob = scope.tableByWeekList[0].pmKnobList.length;
                            scope.ngKnob = 0;
                            scope.zzKnob = 0;
                            if (scope.tableByWeekList[0].ngKnobList) {
                                scope.ngKnob = scope.tableByWeekList[0].ngKnobList.length;
                            }
                            if (scope.tableByWeekList[0].zzxKnobList) {
                                scope.zzKnob = scope.tableByWeekList[0].zzxKnobList.length;
                            }
                            /*是否有晚自习的课*/
                            if (scope.ngKnob > 0) {
                                scope.isNoNgKnob = true;
                            }
                            /*是否有早自习的课*/
                            if (scope.zzKnob > 0) {
                                scope.isNozzKnob = true;
                            }
                            // //早自习周课
                            // var zzxWeek= scheduleList.scheduleWeekCourseListVO.zzxWeeks;
                            // scope.zzxWeek=showWeekInfo(zzxWeek);
                            //周课
                            var courseWeek = scheduleList.scheduleWeekCourseListVO.courseWeeks;
                            scope.courseWeek = showWeekInfo(courseWeek);
                            //活动周
                            var activeWeek = scheduleList.scheduleWeekCourseListVO.activeWeeks;
                            scope.activeWeek = showWeekInfo(activeWeek);
                            // //晚自习周课
                            // var wzxWeek =scheduleList.scheduleWeekCourseListVO.wzxWeeks;
                            // scope.wzxWeek=showWeekInfo(wzxWeek);
                            //没有周课/活动周直接计算
                            if (!scope.nocourse) {
                                calculateDiv();
                            }
                            scope.loadErrorMsg = '';
                        } else {
                            scope.loadErrorMsg = "课表加载失败！";
                            scope.dataContent = false;
                            if (scope.options.errorCallAction) {
                                scope.options.errorCallAction();
                            }
                        }
                    } else {
                        scope.loadErrorMsg = res.message;
                    }
                }).error(function () {
                    if (scope.options.errorCallAction) {
                        scope.options.errorCallAction();
                    }
                    scope.loadErrorMsg = '加载失败，请重试！';
                });
            };

            //周课、活动周展示
            function showWeekInfo(weeks) {
                var weekList = [];
                if (!weeks || weeks.length === 0) {
                    return [];
                }
                scope.nocourse = true;
                angular.forEach(weeks, function (week) {
                    var showInfo = "";
                    if (week.teacherName) {
                        showInfo += showInfo ? "，" + week.teacherName : week.teacherName;
                    }
                    if (week.addressName) {
                        showInfo += showInfo ? "，" + week.addressName : week.addressName;
                    }
                    if (week.teachAdminClassName) {
                        showInfo += showInfo ? "，" + week.teachAdminClassName : week.teachAdminClassName;
                    }
                    weekList.push({name: week.name, info: showInfo});
                });
                return weekList;
            }

            scope.calculateDiv = calculateDiv;

            function calculateDiv() {
                var het = scope.nocourse ? angular.element("#testa").height() : 0;
                /*设置一天课表，节次高度*/
                var wrapHeight = angular.element(".schedule-times-right").height() - (het ? het : 0),
                    itemNumber = scope.amKnob + scope.pmKnob + scope.ngKnob + scope.zzKnob,
                    numberHeight = wrapHeight / itemNumber,
                    weekWidth = 68 * scope.tableByWeekList.length;

                scope.itemHeight = {
                    "height": numberHeight + 'px',
                    "line-height": numberHeight + 'px'
                };
                scope.zzKnobHeight = {
                    "height": scope.zzKnob * (numberHeight) + 'px',
                    "width": weekWidth + 'px'
                };
                scope.amKnobHeight = {
                    "height": scope.amKnob * (numberHeight) + 'px',
                    "width": weekWidth + 'px'
                };
                scope.pmKnobHeight = {
                    "height": scope.pmKnob * (numberHeight) + 'px',
                    "width": weekWidth + 'px'
                };
                scope.ngKnobHeight = {
                    "height": scope.ngKnob * (numberHeight) + 'px',
                    "width": weekWidth + 'px'
                };
            }

            /*课程详情弹框显示*/
            scope.showMoreCourse = function (courseList, daily) {
                if (courseList.courseList == null) {

                } else {
                    scope.isShowMoreCourse = !scope.isShowMoreCourse;
                    scope.courseMsgList = courseList.courseList;
                    scope.knob = courseList.knob;
                    scope.timeTypeValue = courseList.timeTypeValue;
                    scope.dailys = daily;
                }
            };
            scope.hideMoreCourse = function () {
                scope.isShowMoreCourse = !scope.isShowMoreCourse;
            };
            (function () {
                scope.query(scope.options.weekNum, scope.options.userId, scope.options.userType);
            })()
        }
    }])
    /**
     * 文本域样式控制指令
     */
    .directive("textareaAnswerStyle", function ($timeout) {
        return {
            restrict: "A",
            require: "?ngModel",
            link: function (scope, element, attrs, ctrl) {
                if (!ctrl) {
                    return; // do nothing if no ng-model
                }
                element.on('input', function () {
                    adaptiveHeight();
                });

                ctrl.$formatters.push(function (viewValue) {
                    $timeout(function () {
                        adaptiveHeight();
                    }, 50);
                    return viewValue;
                });

                /**
                 * 自适应高度
                 */
                function adaptiveHeight() {
                    var scrollHeight = element[0].scrollHeight;
                    var height = element[0].offsetHeight;
                    var defHeight = attrs.defHeight ? parseInt(attrs.defHeight) : 120;
                    // 如果内容高度已经大于默认的文本域高度
                    if (scrollHeight > defHeight && height < scrollHeight) {
                        if (height < scrollHeight) {
                            element.attr("style", "height:" + scrollHeight + "px!important;");
                        }
                    }
                }
            }
        };
    })
    .directive('inputTimerSerach', ['$ionicLoading', function ($ionicLoading) {
        return {
            restrict: 'A',
            scope: {
                onSend: '&',
                times: '@',
                bshade: '@',
                shadetimes: '@'
            },
            link: function (scope, element, attrs) {
                var last;
                scope.times = scope.times || 1000;
                scope.shadetimes = scope.shadetimes || 500;
                $(element[0]).keyup(function (event) {
                    last = event.timeStamp;
                    setTimeout(function () {
                        if (last - event.timeStamp == 0) {
                            if (!scope.bshade) {
                                scope.onSend();
                            } else {
                                $ionicLoading.show({
                                    content: 'Loading',
                                    animation: 'fade-in',
                                    showBackdrop: true,
                                    maxWidth: 200,
                                    showDelay: 0
                                });
                                scope.onSend().then(
                                    function (data) {
                                        setTimeout(function () {
                                            $ionicLoading.hide();
                                        }, scope.shadetimes);
                                    }
                                );
                            }
                        }
                    }, scope.times);
                });
            }
        }
    }
    ])
    //消息配置
    .factory('ynSendWay', ["$q","$http", function ($q,$http) {
        return {
            listMessageSendWay : function(functionId,userType){
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.get(originBaseUrl + "/third/msg/listMessageSendWay.htm?functionId="+functionId+"&userType="+userType).success(function(data){
                    if(data.status == 0){
                        deferred.resolve(data.result);
                    }
                });
                return promise;
            }
        }
    }]);



/**
 * 把obj转化为Spring可接受状态
 * @param obj
 * @returns {{}}
 */
function parseParamForSpringMVC (obj) {
    var resultObj = {};
    var deepParseParams = function (key, value, prefix) {
        if (value instanceof Array) {
            for (var i in value) {
                deepParseParams("", value[i], prefix + key + "[" + i + "]");
            }
        }
        else if (value instanceof Object) {
            for (var i in value) {
                deepParseParams("." + i, value[i], prefix + key);
            }
        }
        else {
            resultObj[prefix + key] = value;
        }
    };
    for (var i in obj) {
        deepParseParams("", obj[i], i);
    }
    return resultObj;
}