/**
 * 调课申请
 * @author Jin Tan
 */
(function () {
    'use strict';

    angular.module('starter').config(stateConfig)
        .controller('tkApplyCtrl', tkApplyCtrl)
        .controller('tkAddCtrl', tkAddCtrl)
        .controller('tkAuditCtrl', tkAuditCtrl);

    stateConfig.$inject = ['$stateProvider', '$urlRouterProvider'];

    function stateConfig($stateProvider, $urlRouterProvider) {
        $stateProvider
            // 待提交申请
            .state('tk_apply', {
                url: '/tk_apply',
                templateUrl: 'templates/Lessons_substitution/ls_apply.html',
                data: {
                    micro: true,
                    title: '调课'
                },
                controller: 'tkApplyCtrl',
                controllerAs: 'vm'
            })
            // 发起调课申请
            .state('tk_add', {
                url: '/tk_add',
                templateUrl: 'templates/Lessons_substitution/ls_add.html',
                data: {
                    title: '调课',
                    micro: true,
                    // prev: 'tk_apply'
                },
                controller: 'tkAddCtrl',
                controllerAs: 'vm'
            })
            // 调课审核
            .state('tk_audit', {
                url: '/tk_audit',
                templateUrl: 'templates/Lessons_substitution/tkAudit.html',
                data: {
                    micro: true,
                    title: '调课'
                },
                controller: 'tkAuditCtrl',
                controllerAs: 'vm'
            })
            //流程审核
            .state('askfortk', {
                url: '/askfortk',
                templateUrl: 'templates/leave/askforleave/leave.html',
                data: {
                    title: '调课审核',
                    prev: 'tk_audit'
                },
                controller: 'askforLeaveCtrl',
            });
            $urlRouterProvider.otherwise('/tk_apply');
    }

    tkApplyCtrl.$inject = ['$scope', '$http', '$location', 'ynuiNotification', '$document', '$ionicPopup', '$state'];

    function tkApplyCtrl($scope, $http, $location, ynuiNotification, $document, $ionicPopup, $state) {

        var vm = this;

        vm.selectAllFlag = false;
        vm.selectIds = [];

        vm.findByConditions = findByConditions;
        vm.changeAllSelect = changeAllSelect;
        vm.changeSelect = changeSelect;
        vm.submit = submit;
        vm.clickDel = clickDel;
        vm.operationClick = operationClick;
        vm.gotoAddPage = gotoAddPage;

        findByConditions();

        /**
         * 查询草稿的调课申请
         */
        function findByConditions() {
            return $http.get(originBaseUrl + '/third/tkMobile/findByConditions.htm', {
                params: {
                    auditState: -1
                }
            }).then(function (response) {
                vm.draftArray = response.data.result;
                // 添加选择位
                if (vm.draftArray && vm.draftArray.length > 0) {
                    angular.forEach(vm.draftArray, function (draft) {
                        draft.select = false;
                    });
                }
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 全选/全不选
         */
        function changeAllSelect() {
            vm.selectAllFlag = !vm.selectAllFlag;
            angular.forEach(vm.draftArray, function (draft) {
                draft.select = vm.selectAllFlag;
                if (vm.selectAllFlag) {
                    vm.selectIds.push(draft.id);
                }
            });
            if (!vm.selectAllFlag) {
                vm.selectIds = [];
            }
        }

        /**
         * 单选/取消
         * @param item 选择的数据
         */
        function changeSelect(item) {
            item.select = !item.select;
            if (item.select && vm.selectIds.indexOf(item.id) === -1) {
                vm.selectIds.push(item.id);
            } else if (!item.select) {
                vm.selectIds.splice(vm.selectIds.indexOf(item.id), 1);
            }
            vm.selectAllFlag = vm.selectIds.length === vm.draftArray.length;
        }

        /**
         * 删除草稿申请
         * @param ids ids
         */
        function deleteByIds(ids) {
            return $http.post(originBaseUrl + '/third/tkMobile/delByIds.htm', {
                ids: ids
            }).then(function (response) {
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 提交审核前的验证
         * @param ids 申请id
         */
        function auditCheck(ids) {
            return $http.post(originBaseUrl + '/third/tkMobile/auditCheck.htm', {
                ids: ids
            }).then(function (response) {
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 提交审核
         * @param ids 申请id
         */
        function submitAudit(ids) {
            return $http.post(originBaseUrl + '/third/tkMobile/submitAudit.htm', {
                ids: ids,
                systemId: '07-JSGZXT',
                menuId: '042-TKGL-001-001'
            }).then(function (response) {
                return response;
            }, function (error) {
                return error
            });
        }

        /**
         * 提交审核
         */
        function submit() {
            vm.errorInfo = false;
            if (vm.selectIds.length === 0) {
                ynuiNotification.error({msg: "请至少勾选一项！"});
                return;
            }
            auditCheck(vm.selectIds).then(function (response) {
                if (response.status === 200 && response.data.status === -1) {
                    ynuiNotification.error({msg: response.data.message});
                    return false;
                }
                if (response.status === 200 && response.data.result.length === 0) {
                    submitAudit(vm.selectIds).then(function (response) {
                        if (response.status === 200) {
                            if (response.data.status === -1) {
                                ynuiNotification.error({msg: response.data.message});
                            } else {
                                // 提交成功
                                findByConditions().then(function () {
                                    // 添加选择位
                                    if (vm.draftArray && vm.draftArray.length > 0) {
                                        angular.forEach(vm.draftArray, function (draft) {
                                            draft.select = false;
                                        });
                                    }
                                    changeAllSelect();
                                });
                            }
                        }
                    });
                } else if (response.status === 200 && response.data.result.length > 0) {
                    vm.errorInfo = true;
                    for (var i = 0; i < vm.draftArray.length; i++) {
                        for (var j = 0; j < response.data.result.length; j++) {
                            if (vm.draftArray[i].id === response.data.result[j].id) {
                                vm.draftArray[i].errorInfo = response.data.result[j].errorInfo;
                                break;
                            }
                        }
                    }
                }
            });
        }

        /**
         * 点击删除
         */
        function clickDel(id) {
            var ids = [];
            if (id) {
                ids.push(id);
            } else {
                // ids = vm.selectIds;
                angular.forEach(vm.draftArray, function (draft) {
                    ids.push(draft.id);
                });
            }
            if (ids.length === 0) {
                // ynuiNotification.error({msg: "没有需要删除的申请！"});
                return;
            }
            var alertConfig = {
                template: id ? '确定要删除所选吗？' : '确定要删除全部吗？',
                title: '提示',
                scope: $scope,
                buttons: [{
                    text: '取消'
                }, {
                    text: '<b>确定</b>',
                    type: 'button-positive',
                    onTap: function () {
                        deleteByIds(ids).then(function (response) {
                            if (response.status === 200) {
                                ynuiNotification.success({msg: "操作成功！"});
                                findByConditions().then(function () {
                                    // 添加选择位
                                    if (vm.draftArray && vm.draftArray.length > 0) {
                                        angular.forEach(vm.draftArray, function (draft) {
                                            draft.select = false;
                                        });
                                    }
                                });
                            }
                        });
                    }
                }]
            };
            $ionicPopup.show(alertConfig)
        }

        /**
         * 出现操作按钮
         * @param $event 事件
         * @param index 下标
         */
        function operationClick($event, index) {
            $event.stopPropagation();
            var del = $document.find('#item-operation-wrap_' + index);
            del.fadeIn();
            del.css({'line-height': $document.find('.examine-list-item.item')[index].offsetHeight + 'px'});
        }

        function gotoAddPage() {
            $location.path('tk_add').search({state:$state.$current.name});
        }

        vm.gotoApply = gotoApply;

        // 跳转到原生 我的申请
        function gotoApply() {
            var goto = yn.plugin.yngoto;
            goto.gotoNative({target: 'ApplyView', params: {tabId: 1}}, function () {
                // 跳转成功
            }, function (error) {
                // 跳转失败
            });
        }
    }

    tkAddCtrl.$inject = ['$scope', '$http', '$ionicPopup', 'ynuiNotification', '$ionicModal', '$timeout','ynNavigator','$location'];

    /**
     * 添加调课申请的 Controller
     */
    function tkAddCtrl($scope, $http, $ionicPopup, ynuiNotification, $ionicModal, $timeout,ynNavigator,$location) {
        var vm = this;

        vm.pageData = {
            reasonStr: null,
            reason: null,
            adjustReasonType: null,
            adjustType: "",
            start: '',
            end: null,
            teacherType: '1',
            substituteType: 1,
            substituteReason: '',
            teacherId: '',
            teacherName: '',
            teachers: [],
            statistic: '1',
            uploadFiles:[]
        };
        vm.selectTeacherType={
            typeList:[{id:"1",name:"无需指定老师看班/代课"},{id:"3",name:"由各自的班主任看班/代课"},{id:"2",name:"选择具体老师"},{id:"4",name:"从空闲任课老师中选择"}],
            teacherTypeName:"无需指定老师看班/代课",
            onclick:function(item){
                vm.pageData.teacherType=item.id;
                this.teacherTypeName=item.name;

            },
            selectTeacher:function(){
                if(vm.pageData.teacherType !=1){
                    if(vm.pageData.adjustType==2){
                        showSelectClassTeacher(vm.interchangeModal);
                    }else if(vm.pageData.adjustType==1){
                        showSelectClassTeacher(vm.modulationModal);
                    }else{
                        showSelectClassTeacher(vm.courseCancelModal);
                    }
                }
            },
            teacherName:"",
            findTeacherByNameLike:findTeacherByNameLike
        };

        vm.term = null;

        vm.beforeAllSelect = false;
        vm.beforeSelectIds = [];
        vm.teacherName = '';
        vm.afterTeacherId = null;
        vm.beforeAdminClassIds = null;

        vm.showSelectClassRoomHtml = false;
        vm.showSelectClassTeacherHtml = false;
        vm.classRoomName = '';
        vm.afterClassRoomIds = [];
        vm.changeTypeList={
            changeType:0,//调换的更换类型 0:时间 1:老师和地点   2:老师 ,3地点
            timeTableInfo:[],//选中的节次
            knobInfo:"",//节次详情
        };
        vm.reasonSelect = reasonSelect;
        vm.customReason = customReason;
        vm.changeDate = changeDate;
        vm.courseBeforeAllSelect = courseBeforeAllSelect;
        vm.courseBeforeSelect = courseBeforeSelect;
        vm.showModal = showModal;
        vm.findTeacherByAdminClass = findTeacherByAdminClass;
        vm.showAdjustModel = showAdjustModel;
        vm.saveCancel = saveCancel;
        vm.changeAfterDate = changeAfterDate;
        vm.changeAfterKnob = changeAfterKnob;
        vm.saveCourseExchange = saveCourseExchange;
        vm.changeAfterDateOrAfterTeacher = changeAfterDateOrAfterTeacher;
        vm.selectAfterFormal = selectAfterFormal;
        vm.saveCourseSwap = saveCourseSwap;
        // 查询调课原因
        findReason().then(function () {
            // 默认第一个原因
            if (vm.reasonArr && vm.reasonArr.length > 0) {
                vm.pageData.adjustReasonType = vm.reasonArr[0].dictCode;
                vm.pageData.reasonStr = vm.reasonArr[0].dictName;
            }
        });
        // 查询调课设置
        getApplyDateSet().then(function (data) {
            // 设置了只允许申请当天及以后的课
            if (1 === data.applyDateSet) {
                // 当前日期
                var dateArr = data.currentDate.split('-');
                vm.datetimeSettings = {
                    minDate: new Date(parseInt(dateArr[0]), parseInt(dateArr[1]) - 1, dateArr[2], 0, 0, 0, 0)
                };
            }
            // 查询当前时间和用户
            findCurrentTimeAndUser().then(function () {
                findCourseByTeacher(vm.pageData.start);
            });
        });
        createModal();

        /**
         * 选择原因
         */
        function reasonSelect(reason) {
            vm.pageData.adjustReasonType = reason.dictCode;
            vm.pageData.reasonStr = reason.dictName;
        }
        /**
         * 自定义原因
         */
        function customReason() {
            vm.customReasonStr = null;
            var customReasonConfig = {
                template: '<textarea cols="30" rows="10" class="textarea-border" ng-model="vm.customReasonStr"></textarea>',
                title: '自定义调/停课原因',
                scope: $scope,
                buttons: [{
                    text: '取消'
                }, {
                    text: '<b>提交</b>',
                    type: 'button-positive',
                    onTap: function (e) {
                        if (null === vm.customReasonStr || '' === vm.customReasonStr) {
                            ynuiNotification.error({msg: "调/停课原因不能为空！"});
                            e.preventDefault();
                            return false;
                        }
                        vm.pageData.reason = vm.customReasonStr;
                        vm.pageData.reasonStr = vm.customReasonStr;
                    }
                }]
            };
            $ionicPopup.show(customReasonConfig);
        }

        /**
         * 改变日期重新查询课程
         */
        function changeDate() {
            vm.beforeSelectIds = [];
            findCourseByTeacher(vm.pageData.start);
        }

        /**
         * 获取可以调课的课程
         */
        function findCourseByTeacher(start) {
            return $http.get(originBaseUrl + '/third/tkMobile/findCourseByTeacher.htm', {
                params: {
                    beginDate: start
                }
            }).then(function (response) {
                vm.courseInfoArr = response.data.result;
                angular.forEach(vm.courseInfoArr, function (info) {
                    info.select = false;
                });
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 查询调停课原因
         */
        function findReason() {
            return $http.get(originBaseUrl + '/third/tkMobile/queryDictionaryByKey.htm', {
                params: {
                    key: "TKGL_REASON"
                }
            }).then(function (response) {
                vm.reasonArr = response.data.result;
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 获取系统时间和当前的登录用户
         */
        function findCurrentTimeAndUser() {
            return $http.get(originBaseUrl + '/third/tkMobile/findCurrentTimeAndUser.htm').then(
                function (response) {
                    vm.platformSysUserVO = response.data.result.platformSysUserVO;
                    vm.userMoreInfo = '（' + (vm.platformSysUserVO.sex === 1 ? '男' : '女') + '，'
                        + vm.platformSysUserVO.userNumber + '）';
                    vm.pageData.start = response.data.result.currentTime.split(' ')[0];
                    vm.term = response.data.result.term;
                    return response;
                }, function (error) {
                    return error;
                });
        }
        function findTeacherByNameLike(type) {
            if(!vm.selectTeacherType.teacherName && !type){
                return;
            }
            return $http.get(originBaseUrl + '/third/tkMobile/findTeacherByNameLike.htm', {
                params: {
                    name: vm.selectTeacherType.teacherName,
                    formalIdStr:vm.beforeSelectIds.join(","),
                    teacherType:vm.pageData.teacherType,
                }
            }).then(function (response) {
                vm.selectTeacherArr = response.data.result;
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 保存取消
         *
         * @param vo 参数
         */
        function submitSaveCancel(vo) {
            return $http.post(originBaseUrl + '/third/tkMobile/saveTKCourseTimetableCancel.htm',
                vo
            ).then(function (response) {
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 获取可调换的节次
         *
         * @param date
         * @param ids
         */
        function getCourseSchedule(date, ids) {
            return $http.get(originBaseUrl + '/third/tkMobile/findAfterKnob.htm', {
                params: {
                    date: date,
                    beforeIds: ids
                }
            }).then(function (response) {
                vm.afterKnobArr = response.data.result;
                return response;
            });
        }

        /**
         * 提交调换
         * @param vo 参数
         */
        function submitExchange(vo) {
            return $http.post(originBaseUrl + '/third/tkMobile/saveTKCourseTimetableAdjust.htm',
                vo
            ).then(function (response) {
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 根据教学行政班查询老师
         * @param adminClassIds 教学行政班id
         */
        vm.isLoading=false;
        function findTeacherByAdminClass() {
            // 获得取消课程的节次和id数组
            var timetableIds=[];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    timetableIds.push(info.id);
                }
            });
            vm.afterTeacherId = null;
            vm.afterTeacherName = null;
            vm.afterFormalArr = [];
            return $http.get(originBaseUrl + '/third/tkMobile/findTeacherByAdminClass.htm', {
                params: {
                    adminClassIds: vm.beforeAdminClassIds,
                    timetableIds: timetableIds,
                    date:vm.pageData.end
                }
            }).then(function (response) {
                vm.isLoading=true;
                vm.afterTeacherArr = response.data.result;
                return response;
            }, function (error) {
                return error;
            })
        }
        /**
         * 根据条件查询课表
         * @param teacherId 教师id
         * @param date 日期
         * @param pkTeachClassId 教学班id
         * @param adminClassIds 教学行政班id
         */
        function findCourseByConditions(teacherId, date, pkTeachClassId, adminClassIds, beforeIds) {
            vm.afterFormalArr=[];
            return $http.get(originBaseUrl + '/third/tkMobile/findCourseByConditions.htm', {
                params: {
                    teacherId: teacherId,
                    date: date,
                    pkTeachClassId: pkTeachClassId,
                    adminClassIds: adminClassIds,
                    beforeIds: beforeIds
                }
            }).then(function (response) {
                vm.afterFormalArr = response.data.result;
                if (vm.afterFormalArr == null || vm.afterFormalArr.length === 0) {
                    ynuiNotification.error({msg: "没有可以对调的节次！"});
                }
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 保存对调申请
         * @param vo 参数
         */
        function submitCourseSwap(vo) {
            return $http.post(originBaseUrl + '/third/tkMobile/saveTKCourseTimetableRefore.htm',
                vo
            ).then(function (response) {
                return response;
            }, function (error) {
                return error;
            });
        }

        /**
         * 全选/取消全选 课程
         */
        function courseBeforeAllSelect() {
            vm.beforeSelectIds = [];
            vm.beforeAllSelect = !vm.beforeAllSelect;
            angular.forEach(vm.courseInfoArr, function (info) {
                if (!(info.beforeTeacherName || info.type === '1' || '1' === info.isGroup + '')) {
                    info.select = vm.beforeAllSelect;
                    if (info.select) {
                        vm.beforeSelectIds.push(info.id);
                    }
                }
            });
        }

        /**
         * 单选/取消课程
         */
        function courseBeforeSelect(item) {
            console.log(item);
            if (item.beforeTeacherName || item.type === '1') {
                item.select = !item.select;
                return;
            }
            if (item.select && vm.beforeSelectIds.indexOf(item.id) === -1) {
                vm.beforeSelectIds.push(item.id);
            } else if (!item.select) {
                vm.beforeSelectIds.splice(vm.beforeSelectIds.indexOf(item.id), 1);
            }
            vm.beforeAllSelect = vm.beforeSelectIds.length === vm.courseInfoArr.length;
        }

        /**
         * 创建模态框
         */
        function createModal() {
            // 课程取消
            $ionicModal.fromTemplateUrl('courseCancel.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                vm.courseCancelModal = modal;
            });
            // 课程调换
            $ionicModal.fromTemplateUrl('modulation.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                vm.modulationModal = modal;
            });
            // 课程对调
            $ionicModal.fromTemplateUrl('interchange.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                vm.interchangeModal = modal;
            });
        }

        /**
         * 弹出弹框
         * @param type 1.调换 2.对调 3.取消
         */
        function showModal(type) {
            if (vm.pageData.uploadFiles) {
                if (vm.pageData.uploadFiles.length > 10) {
                    var alertPopup = $ionicPopup.alert({
                        title: '',
                        template: '最多只能上传10个文件!',
                        okText: '关闭'
                    });
                    alertPopup.then(function(res) {
                    });
                    return;
                }
            }
            if (!vm.pageData.adjustReasonType) {
                ynuiNotification.error({msg: "请选择调/停课原因分类！"});
                return;
            }
            if (!checkDate(vm.pageData.start)) {
                return;
            }
            if (!checkCourse()) {
                return;
            }
            if (vm.beforeSelectIds.length === 0) {
                ynuiNotification.error({msg: "请至少勾选一项！"});
                return;
            }
            var selected = [];
            if (type !== 3) {
                for (var i = 0; i < vm.courseInfoArr.length; i++) {
                    if (vm.courseInfoArr[i].select) {
                        selected.push(vm.courseInfoArr[i]);
                    }
                }
                for (var i = 0; i < selected.length; i++) {
                    for (var j = 0; j < selected.length; j++) {
                        if (i !== j && j > i) {
                            if (selected[i].adminClassIds !== selected[j].adminClassIds) {
                                ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能与其他老师调课！"});
                                return;
                            }
                            if (selected[i].timeType !== selected[j].timeType) {
                                ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能与其他老师调课！"});
                                return;
                            }
                            if (parseInt(selected[i].knob) - parseInt(selected[j].knob) !== -1) {
                                ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能与其他老师调课！"});
                                return;
                            }
                            break;
                        }
                    }
                }
            }
            // 初始化
            vm.pageData.end = null;
            vm.pageData.teacherType = '1';
            vm.pageData.substituteType ='';
            vm.pageData.substituteReason = null;
            vm.pageData.teachers = [];
            vm.selectTeacherArr = [];
            vm.teacherName = null;
            vm.confilctInfo = [];
            vm.pageData.adjustType=type;
            switch (type) {
                case 1:
                    // 调换
                    vm.afterKnobArr = [];
                    vm.confilctInfo = null;
                    vm.afterClassRooms = [];
                    vm.afterClassRoomIds = [];
                    $scope.isShowMore = !$scope.isShowMore;
                    break;
                case 2:
                    // 对调
                    vm.beforeAdminClassIds = selected[0].adminClassIds;
                    if (!vm.beforeAdminClassIds) {
                        ynuiNotification.error({'msg': '任意选修课不支持对调！'});
                        return;
                    }
                    vm.afterTeacherId = null;
                    vm.afterTeacherName = null;
                    vm.afterFormalArr = [];
                    vm.interchangeModal.show();
                    break;
                default:
                    // 取消
                    vm.selectTeacherType.onclick(vm.selectTeacherType.typeList[0]);
                    vm.afterClassTeachers=[];
                    vm.afterClassTeacherIds=[];
                    vm.courseCancelModal.show();
            }
        }
        function showAdjustModel(changeType){
            //调换的更换类型 0:时间 1:老师和地点   2:老师 ,3地点
            vm.changeTypeList.changeType=changeType;
            vm.modulationModal.show();
            var teacherNames=[],teacherIds=[];
            if(changeType==1){
                vm.changeTypeList.timeTableInfo = [];
                var morningKnob=[];//早上节次
                var afterKnob=[];//下午节次
                var nightKnob=[];//晚上节次
                vm.pageData.end=angular.copy(vm.pageData.start);
                vm.pageData.substituteType=2;
                vm.afterKnobArr=[];
                angular.forEach(vm.courseInfoArr, function (info) {
                    if (info.select) {
                        vm.changeTypeList.timeTableInfo.push(info);
                        switch (info.timeType) {
                            case "1":
                                morningKnob.push(info.knob);
                                break;
                            case "2":
                                afterKnob.push(info.knob);
                                break;
                            case "3":
                                nightKnob.push(info.knob);
                                break;
                        }

                        vm.afterKnobArr.push({knobStr:info.knobStr,week:info.week,knob:info.knob,timeType:info.timeType,day:info.day,select:true});
                    }
                });
                var knobInfo=[];
                if(morningKnob.length>0){
                    knobInfo.push("上午第"+morningKnob.join("、")+"节");
                }
                if(afterKnob.length>0){
                    knobInfo.push("下午第"+afterKnob.join("、")+"节");
                }
                if(nightKnob.length>0){
                    knobInfo.push("晚上第"+nightKnob.join("、")+"节");
                }
                vm.changeTypeList.knobInfo=knobInfo.join("，");
                if(vm.afterKnobArr.length>0){
                    geBuildingRoomList();
                }
                getTeacherInfo(teacherIds, teacherNames);
                vm.selectTeacherType.onclick(vm.selectTeacherType.typeList[2]);
            }else{
                vm.selectTeacherType.onclick(vm.selectTeacherType.typeList[0]);
            }
            vm.afterClassTeachers=teacherNames;
            vm.afterClassTeacherIds=teacherIds;
            $scope.isShowMore=false;
        }
        function getTeacherInfo(teacherIds, teacherNames) {
            if (vm.changeTypeList.changeType == 1) {
                angular.forEach(vm.courseInfoArr, function (info) {
                    if (info.select && info.teacherIds && info.teacherNames) {
                        var ids = info.teacherIds.split(',');
                        var names = info.teacherNames.split(',');
                        for (var i = 0; i < ids.length; i++) {
                            if (teacherIds.indexOf(ids[i]) === -1) {
                                teacherNames.push({
                                    id: ids[i],
                                    name: names[i]
                                });
                                teacherIds.push(ids[i]);
                            }
                        }
                    }
                });
            }
        }
        /**
         * 课程取消提交
         * @param auditState 审核状态
         */
        function saveCancel(auditState) {
            if (!vm.pageData.adjustReasonType) {
                ynuiNotification.error({msg: "请选择调/停课原因分类！"});
                return;
            }
            var knobs = [];
            // 获得取消课程的节次和id数组
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    knobs.push(info.knob);
                }
            });
            if ((vm.pageData.teacherType === '2' || vm.pageData.teacherType === '4') && vm.pageData.teachers.length === 0) {
                ynuiNotification.error({msg: "请选择代课老师！"});
                return;
            }
            if (!vm.pageData.substituteType && vm.pageData.teacherType!=1) {
                ynuiNotification.error({msg: "请选择代课类型！"});
                return;
            }
            var substituteType=vm.pageData.teacherType==1? 1:vm.pageData.substituteType
            // 保存vo
            var tkSaveCourseCancelVO = {
                timetableIds: vm.beforeSelectIds,
                knobs: knobs,
                teachers: vm.pageData.teachers,
                teacherType: vm.pageData.teacherType,
                reason: vm.pageData.reason,
                adjustReasonType: vm.pageData.adjustReasonType,
                systemId: '07-JSGZXT',
                menuId: '042-TKGL-001-001',
                substituteType: substituteType,
                substituteReason: substituteType === 1 ? "代上自习" : vm.pageData.substituteReason,
                fsIds:vm.pageData.uploadFiles,
                auditState: auditState === 0 ? -2 : auditState
            };
            submitSaveCancel(tkSaveCourseCancelVO).then(function (response) {
                if (response.status === 200) {
                    if (response.data.status === -1) {
                        ynuiNotification.error({msg: response.data.message});
                    } else {
                        vm.pageData.uploadFiles = [];
                        vm.pageData.reason = "";
                        vm.courseCancelModal.hide();
                        ynuiNotification.success({msg: "提交成功！"});
                        changeDate();
                    }
                }
            });
        }

        /**
         * 判断只能选择当前学期内的日期
         *
         * @param date 选择的日期
         * @returns {boolean}
         */
        function checkDate(date) {
            var startDate = null, endDate = null, selectDate = null;
            if (vm.term.termBeginDateString) {
                var startDateArr = vm.term.termBeginDateString.split('-');
                startDate = new Date(startDateArr[0], startDateArr[1], startDateArr[2]);
            }
            if (vm.term.termEndDateString) {
                var endDateArr = vm.term.termEndDateString.split('-');
                endDate = new Date(endDateArr[0], endDateArr[1], endDateArr[2]);
            }
            if (date) {
                var selectArr = date.split('-');
                selectDate = new Date(selectArr[0], selectArr[1], selectArr[2]);
            }
            if (null != startDate && null != endDate && null != selectDate) {
                if (selectDate.getTime() < startDate.getTime() || selectDate.getTime() > endDate.getTime()) {
                    ynuiNotification.error({msg: "只能选择当前学期内的日期！"});
                    return false;
                }
            }
            return true;
        }

        /**
         * 对调改变日期
         */
        function changeAfterDate() {
            if (vm.pageData.end && checkDate(vm.pageData.end)) {
                getCourseSchedule(vm.pageData.end, vm.beforeSelectIds).then(function () {
                    if (vm.afterKnobArr.length === 0) {
                        vm.errorInfo = '您选择的老师、班级或教室在' + vm.pageData.end + '没有空节次可供调换！';
                    } else {
                        vm.errorInfo = null;
                    }
                });
            }
        }

        /**
         * 改变节次
         * @param knob 节次
         */
        function changeAfterKnob(knob) {
            knob.select = !knob.select;
            var afterKnobs = [], afterWeek = null, afterDay = null, timeType = null, selected = [];
            for (var i = 0; i < vm.afterKnobArr.length; i++) {
                if (vm.afterKnobArr[i].select) {
                    if (null == afterWeek) {
                        afterWeek = vm.afterKnobArr[i].week;
                    }
                    if (null == afterDay) {
                        afterDay = vm.afterKnobArr[i].day;
                    }
                    if (null == timeType) {
                        timeType = vm.afterKnobArr[i].timeType;
                    }
                    afterKnobs.push(vm.afterKnobArr[i].knob);
                    selected.push(vm.afterKnobArr[i]);
                }
            }
            for (var i = 0; i < selected.length; i++) {
                for (var j = 0; j < selected.length; j++) {
                    if (i !== j && j > i) {
                        if (selected[i].adminClassIds !== selected[j].adminClassIds) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            knob.select = !knob.select;
                            return;
                        }
                        if (selected[i].timeType !== selected[j].timeType) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            knob.select = !knob.select;
                            return;
                        }
                        if (parseInt(selected[i].knob) - parseInt(selected[j].knob) !== -1) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            knob.select = !knob.select;
                            return;
                        }
                        break;
                    }
                }
            }
            var roomIds = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select && info.classRoomIds) {
                    roomIds = roomIds.concat(info.classRoomIds.split(','));
                }
            });
            var params = {
                timeTableIds: vm.beforeSelectIds,
                week: afterWeek,
                day: afterDay,
                timeType: timeType,
                knobs: afterKnobs,
                roomIds: roomIds
            };
            if (vm.afterClassRoomIds.length === 0) {
                selectAdjustRoom(params).then(function (data) {
                    if ("" === data.result) {
                        geBuildingRoomList();
                    } else {
                        vm.afterClassRooms = [];
                        vm.afterClassRoomIds = [];
                    }
                });
            }
        }
        function geBuildingRoomList() {
            var buildingRoomArr = [], buildingRoomIds = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select && info.classRoomIds && info.buildingClassRoomNames) {
                    var ids = info.classRoomIds.split(',');
                    var names = info.buildingClassRoomNames.split('、');
                    for (var i = 0; i < ids.length; i++) {
                        if (buildingRoomIds.indexOf(ids[i]) === -1) {
                            buildingRoomArr.push({
                                id: ids[i],
                                showName: names[i]
                            });
                            buildingRoomIds.push(ids[i]);
                        }
                    }
                }
            });
            vm.afterClassRooms = buildingRoomArr;
            vm.afterClassRoomIds = buildingRoomIds;
        }
        /**
         * 调换提交审核
         * @param auditState
         */
        $scope.isShowMore=false;
        function saveCourseExchange(auditState) {
            if (!vm.pageData.adjustReasonType) {
                ynuiNotification.error({msg: "请选择调/停课原因分类！"});
                return;
            }
            if (!vm.pageData.end) {
                ynuiNotification.error({msg: "请选择调换日期！"});
                return;
            }
            // 被调节次
            var beforeKnobs = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    beforeKnobs.push(info.knob);
                }
            });
            if (beforeKnobs.length === 0) {
                ynuiNotification.error({msg: "请选择被调节次！"});
                return;
            }
            // 调换节次
            var afterKnobs = [], afterWeek = null, afterDay = null, timeType = null, selected = [];
            for (var i = 0; i < vm.afterKnobArr.length; i++) {
                if (vm.afterKnobArr[i].select) {
                    if (null == afterWeek) {
                        afterWeek = vm.afterKnobArr[i].week;
                    }
                    if (null == afterDay) {
                        afterDay = vm.afterKnobArr[i].day;
                    }
                    if (null == timeType) {
                        timeType = vm.afterKnobArr[i].timeType;
                    }
                    afterKnobs.push(vm.afterKnobArr[i].knob);
                    selected.push(vm.afterKnobArr[i]);
                }
            }
            for (var i = 0; i < selected.length; i++) {
                for (var j = 0; j < selected.length; j++) {
                    if (i !== j && j > i) {
                        if (selected[i].adminClassIds !== selected[j].adminClassIds) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            return;
                        }
                        if (selected[i].timeType !== selected[j].timeType) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            return;
                        }
                        if (parseInt(selected[i].knob) - parseInt(selected[j].knob) !== -1) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调课！"});
                            return;
                        }
                        break;
                    }
                }
            }
            if (afterKnobs.length === 0) {
                ynuiNotification.error({msg: "请选择调换节次！"});
                return;
            }
            // 节次不相等
            if (beforeKnobs.length !== afterKnobs.length) {
                ynuiNotification.error({msg: "您需选择" + beforeKnobs.length + "节课进行调课。"});
                return;
            }
            if ((vm.pageData.teacherType === '2' || vm.pageData.teacherType === '4') && vm.afterClassTeacherIds.length === 0) {
                ynuiNotification.error({msg: "请选择代课老师！"});
                return;
            }
            if (!vm.pageData.substituteType && vm.pageData.teacherType!=1) {
                ynuiNotification.error({msg: "请选择代课类型！"});
                return;
            }
            var substituteType=vm.pageData.teacherType==1? 1:vm.pageData.substituteType
            var changeType=vm.changeTypeList.changeType;//0:时间 1:老师和地点   2:老师 ,3地点
            if(changeType==1){
                var tempRoom=[];
                angular.forEach(vm.courseInfoArr, function (info) {
                    if (info.select && info.classRoomIds && tempRoom.indexOf(info.classRoomIds)==-1) {
                        tempRoom.push(info.classRoomIds);
                    }
                });
                var teacherNames=[],tempTeacher=[];
                getTeacherInfo(tempTeacher, teacherNames);
                var isRoom=JSON.stringify(tempRoom.sort())==JSON.stringify(vm.afterClassRoomIds.sort());
                var isTeacher=JSON.stringify(tempTeacher.sort())==JSON.stringify(vm.afterClassTeacherIds.sort());
                if(isTeacher&&isRoom){
                    ynuiNotification.error({msg: "调换时至少更换教室或教师其中一个！"});
                    return false;
                }
                if(!isRoom){
                    changeType=3;
                }
                if(!isTeacher){
                    changeType=2;
                }
                if(!isRoom&&!isTeacher){
                    changeType=1;
                }
            }
            // 满足条件后组装保存条件
            var tkSaveCourseAdjustVO = {
                timeTableIds: vm.beforeSelectIds,
                week: afterWeek,
                day: afterDay,
                timeType: timeType,
                beforeKnobs: beforeKnobs,
                afterKnobs: afterKnobs,
                teachers: vm.afterClassTeacherIds,
                teacherType: vm.pageData.teacherType,
                reason: vm.pageData.reason,
                adjustReasonType: vm.pageData.adjustReasonType,
                systemId: '07-JSGZXT',
                menuId: '042-TKGL-001-001',
                substituteType: substituteType,
                substituteReason: substituteType === 1 ? "代上自习" : vm.pageData.substituteReason,
                auditState: auditState === 0 ? -2 : auditState,
                rooms: vm.afterClassRoomIds.length > 0 ? vm.afterClassRoomIds : null,
                fsIds:vm.pageData.uploadFiles,
                changeType:changeType
            };
            submitExchange(tkSaveCourseAdjustVO).then(function (response) {
                if (response.status === 200) {
                    if (response.data.status === -1) {
                        ynuiNotification.error({msg: response.data.message});
                    } else {
                        vm.modulationModal.hide();
                        vm.pageData.uploadFiles = [];
                        vm.pageData.reason = "";
                        ynuiNotification.success({msg: "提交成功！"});
                        changeDate();
                    }
                }
            });
        }

        /**
         * 对调改变选择人员和日期
         */
        function changeAfterDateOrAfterTeacher(item) {
            if(item){
                vm.afterTeacherId = item.id;
                vm.afterTeacherName = item.name;
            }
            if (checkDate(vm.pageData.end) && vm.afterTeacherId && vm.pageData.end) {
                findCourseByConditions(vm.afterTeacherId, vm.pageData.end, null, vm.beforeAdminClassIds,
                    vm.beforeSelectIds);
            }
        }

        /**
         * 选中对调课程
         */
        function selectAfterFormal(item) {
            if ('1' !== item.isGroup + '') {
                item.select = !item.select;
            }
        }

        /**
         * 保存对调
         * @param auditState 审核状态
         */
        function saveCourseSwap(auditState) {
            if (!vm.pageData.end) {
                ynuiNotification.error({msg: "请选择对调日期！"});
                return;
            }
            if (!vm.afterTeacherId) {
                ynuiNotification.error({msg: "请选择对调老师！"});
                return;
            }
            if (!vm.pageData.adjustReasonType) {
                ynuiNotification.error({msg: "请选择调/停课原因分类！"});
                return;
            }
            // 被调节次
            var beforeKnobs = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    beforeKnobs.push(info.knob);
                }
            });
            if (beforeKnobs.length === 0) {
                ynuiNotification.error({msg: "请选择被调节次！"});
                return;
            }
            // 调换节次
            var afterKnobs = [], selected = [], afterFormalIds = [];
            for (var i = 0; i < vm.afterFormalArr.length; i++) {
                if (vm.afterFormalArr[i].select) {
                    afterKnobs.push(vm.afterFormalArr[i].knob);
                    selected.push(vm.afterFormalArr[i]);
                    afterFormalIds.push(vm.afterFormalArr[i].id);
                }
            }
            if (afterKnobs.length === 0) {
                ynuiNotification.error({msg: "请选择对调节次！"});
                return;
            }
            for (var i = 0; i < selected.length; i++) {
                for (var j = 0; j < selected.length; j++) {
                    if (i !== j && j > i) {
                        if (selected[i].adminClassIds !== selected[j].adminClassIds) {
                            ynuiNotification.error({msg: "只能选择" + beforeKnobs.length + "节课，且他们必须是连续的、教学班相同的！"});
                            return;
                        }
                        if (selected[i].timeType !== selected[j].timeType) {
                            ynuiNotification.error({msg: "只能选择" + beforeKnobs.length + "节课，且他们必须是连续的、教学班相同的！"});
                            return;
                        }
                        if (parseInt(selected[i].knob) - parseInt(selected[j].knob) !== -1) {
                            ynuiNotification.error({msg: "只能选择" + beforeKnobs.length + "节课，且他们必须是连续的、教学班相同的！"});
                            return;
                        }
                        break;
                    }
                }
            }
            var tkSaveCourseReforeVO = {
                beforeTimetableIds: vm.beforeSelectIds,
                afterTimetableIds: afterFormalIds,
                beforeKnobs: beforeKnobs,
                afterKnobs: afterKnobs,
                reason: vm.pageData.reason,
                adjustReasonType: vm.pageData.adjustReasonType,
                systemId: '07-JSGZXT',
                menuId: '042-TKGL-001-001',
                fsIds:vm.pageData.uploadFiles,
                auditState: auditState === 0 ? -2 : auditState
            };
            submitCourseSwap(tkSaveCourseReforeVO).then(function (response) {
                if (response.status === 200) {
                    if (response.data.status === -1) {
                        ynuiNotification.error({msg: response.data.message});
                    } else {
                        vm.interchangeModal.hide();
                        vm.pageData.uploadFiles = [];
                        vm.pageData.reason = "";
                        ynuiNotification.success({msg: "提交成功！"});
                        changeDate();
                    }
                }
            });
        }

        function checkCourse() {
            var selected = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    selected.push(info);
                }
            });
            for (var i = 0; i < selected.length; i++) {
                for (var j = 0; j < selected.length; j++) {
                    if (i !== j && j > i) {
                        if (selected[i].adminClassIds !== selected[j].adminClassIds) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调/停课！"});
                            return false;
                        }
                        if (selected[i].timeType !== selected[j].timeType) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调/停课！"});
                            return false;
                        }
                        if (parseInt(selected[i].knob) - parseInt(selected[j].knob) !== -1) {
                            ynuiNotification.error({msg: "只有选中相同教学班，且节次连续时才能调/停课！"});
                            return false;
                        }
                        break;
                    }
                }
            }
            return true;
        }

        /**
         * 获取调课选项配置
         * @returns {*}
         */
        function getApplyDateSet() {
            return $http.get(originBaseUrl + '/third/tkMobile/queryTKAuditProcess.htm').then(function (response) {
                return response.data.result;
            });
        }

        /**
         * 获取所有使用中的楼栋
         * @returns {*}
         */
        function findAllBuilding() {
            return $http.get(originBaseUrl + '/third/tkMobile/findAllBuilding.htm').then(function (response) {
                return response.data.result;
            });
        }

        /**
         * 获取教室
         * @param params 查询条件
         * @returns {*}
         */
        function queryAllClassRoomByConditions(params) {
            return $http.get(originBaseUrl + '/third/tkMobile/findClassRoomByConditions.htm', {
                params: params
            }).then(function (response) {
                return response.data.result;
            });
        }

        /**
         * 查询当前课程的教室在目标节次是否冲突
         * @param params 参数
         * @returns {*}
         */
        function selectAdjustRoom(params) {
            return $http.post(originBaseUrl + '/third/tkMobile/selectAdjustRoom.htm',
                params
            ).then(function (response) {
                return response.data;
            });
        }

        /**
         * 初始化拦截
         */
        function canalModel() {
            ynNavigator.registerBackAction(function () {
                if($location.search().state){
                    //强制返回上一级
                    ynNavigator.pop(true);
                }else {
                    //关闭当前微应用
                    ynNavigator.finish();
                }
            },101);
        }
        //初始化拦截
        canalModel();
        vm.afterClassRoomName = '';
        vm.afterClassRoomIds = [];

        vm.showSelectClassRoom = showSelectClassRoom;
        vm.cancelSelectClassRoom = cancelSelectClassRoom;
        vm.confirmSelectClassRoom = confirmSelectClassRoom;

        vm.cancelSelectClassTeacher = cancelSelectClassTeacher;
        vm.confirmSelectClassTeacher = confirmSelectClassTeacher;
        vm.removeSelectedTeacher = removeSelectedTeacher;

        vm.selectBuilding = selectBuilding;
        vm.removeSelectedRoom = removeSelectedRoom;
        vm.refreshClassRoom = refreshClassRoom;

        function showSelectClassRoom(modal) {
            vm.classRoomName = '';
            vm.allClassRoom = [];
            vm.showSelectClassRoomHtml = true;
            vm.selectedModal = modal;
            vm.selectedModal.hide();
            findAllBuilding().then(function (data) {
                vm.allBuilding = data.content;
                vm.selectedBuilding = {id: null, name: '楼栋'};
                refreshClassRoom();
            });
            ynNavigator.registerBackAction(function () {
                cancelSelectClassRoom();
            },101);
        }
        function cancelSelectClassRoom() {
            vm.showSelectClassRoomHtml = false;
            canalModel();;
            vm.selectedModal.show();
        }
        function showSelectClassTeacher(modal) {
            vm.classTeacherName = '';
            vm.selectTeacherArr = [];
            vm.selectedModal = modal;
            vm.selectedModal.hide();
            $timeout(function(){
                vm.showSelectClassTeacherHtml = true;
                ynNavigator.registerBackAction(function () {
                    cancelSelectClassRoom();
                },101);
            },300);

        }
        function cancelSelectClassTeacher() {
            vm.showSelectClassTeacherHtml = false;
            canalModel();;
            vm.selectedModal.show();
        }
        function selectBuilding(b) {
            if (null != vm.selectedBuilding && vm.selectedBuilding.id === b.id) {
                vm.selectedBuilding = {id: null, name: '楼栋'};
            } else {
                vm.selectedBuilding = b;
            }
        }

        function confirmSelectClassRoom() {
            var selectArr = [], afterClassRoomIds = [];
            angular.forEach(vm.allClassRoom, function (room) {
                if (room.select) {
                    selectArr.push(room);
                    afterClassRoomIds.push(room.id);
                }
            });
            if (afterClassRoomIds.length === 0) {
                ynuiNotification.error({msg: "请至少勾选一项！"});
                return false;
            }
            $http.post(originBaseUrl + '/third/tkMobile/selectAdjustRoomWeekCourse.htm',{
                timeTableIds: vm.beforeSelectIds,
                week: vm.afterKnobArr[0].week,
                roomIds: afterClassRoomIds
            }).success(function (data) {
                if(data.result!=""){
                    var errorMap = data.result;
                    angular.forEach(selectArr,function(room){
                        if(errorMap[room.id]){
                            room.errorInfo="建议换个教室，因为他第"+vm.afterKnobArr[0].week+"周有周课";
                        }
                    })
                    vm.afterClassRooms = selectArr;
                    vm.afterClassRoomIds = afterClassRoomIds;
                    vm.showSelectClassRoomHtml = false;
                    canalModel();;
                    vm.selectedModal.show();
                }
            });

        }
        function confirmSelectClassTeacher() {
            var selectArr = [], selectIdArr = [];
            angular.forEach(vm.selectTeacherArr, function (teacher) {
                if (teacher.select) {
                    selectArr.push(teacher);
                    selectIdArr.push(teacher.id);
                }
            });
            if (selectIdArr.length === 0) {
                ynuiNotification.error({msg: "请至少勾选一项！"});
                return false;
            }
            // 验证是否冲突
            var knobs = [];
            angular.forEach(vm.courseInfoArr, function (info) {
                if (info.select) {
                    knobs.push(info.timeType + '_' + info.knob);
                    var _index=selectIdArr.indexOf(info.teacherIds);
                    if(_index>-1){
                        selectIdArr.splice(_index);
                    }
                }
            });
            if(selectIdArr.length>0){
                $http.post(originBaseUrl + '/third/tkMobile/getScheduleByDateAndKnobAndTeacherIds.htm', {
                    start: vm.pageData.start,
                    end: vm.pageData.start,
                    knobs: knobs,
                    teacherIds: selectIdArr
                }).success(function (data) {
                    var errorMap = data.result;
                    angular.forEach(selectArr,function(teacher){
                        teacher.errorInfo=errorMap[teacher.id];
                    })
                    setAfterClassInfo(selectArr);
                });
            }else{
                setAfterClassInfo(selectArr);
            }
        }
        function setAfterClassInfo(selectArr){
            angular.forEach(selectArr,function(item){
                if(vm.pageData.teachers.indexOf(item.id)==-1){
                    vm.pageData.teachers.push(item.id);
                }
                if(vm.afterClassTeacherIds.indexOf(item.id)==-1){
                    vm.afterClassTeacherIds.push(item.id);
                    vm.afterClassTeachers.push(item);
                }
            })
            vm.showSelectClassTeacherHtml = false;
            canalModel();;
            vm.selectedModal.show();
        }

        function removeSelectedTeacher(id, index) {
            vm.afterClassTeachers.splice(index, 1);
            vm.afterClassTeacherIds.splice(vm.afterClassTeacherIds.indexOf(id), 1);
        }
        function removeSelectedRoom(id, index) {
            vm.afterClassRooms.splice(index, 1);
            vm.afterClassRoomIds.splice(vm.afterClassRoomIds.indexOf(id), 1);
        }

        function refreshClassRoom() {
            var params = {
                buildId: vm.selectedBuilding ? vm.selectedBuilding.id: null,
                termId: vm.term.id,
                name: vm.classRoomName
            };
            var timeTypeKnobs = [];
            for (var i = 0; i < vm.afterKnobArr.length; i++) {
                if (vm.afterKnobArr[i].select) {
                    params.week = vm.afterKnobArr[i].week;
                    params.day = vm.afterKnobArr[i].day;
                    timeTypeKnobs.push(vm.afterKnobArr[i].timeType + '_' + vm.afterKnobArr[i].knob);
                }
            }
            params.timeTypeKnobs = timeTypeKnobs;
            queryAllClassRoomByConditions(params).then(function (data) {
                vm.allClassRoom = data;
                angular.forEach(vm.allClassRoom, function (room) {
                    room.select = false;
                });
            });
        }
    }

    tkAuditCtrl.$inject = ['$scope', '$http', 'ynuiNotification', '$ionicPopup', '$location'];

    function tkAuditCtrl($scope, $http, ynuiNotification, $ionicPopup, $location) {
        var vm = this;

        vm.selectAllFlag = false;
        vm.selectIds = [];
        vm.timetables = [];

        vm.findByAdminAudit = findByAdminAudit;
        vm.changeAllSelect = changeAllSelect;
        vm.changeSelect = changeSelect;
        vm.auditFun = auditFun;
        vm.toProc = toProc;

        findByAdminAudit();

        /**
         * 查询待当前用户审核的申请
         *
         * @returns {*}
         */
        function findByAdminAudit() {
            return $http.get(originBaseUrl + '/third/tkMobile/findByAdminAudit.htm', {
                params: {
                    requestSource: 1,
                    auditState: 0,
                    effect: true,
                    effectPassive: true
                }
            }).then(function (response) {
                vm.timetables = response.data.result;
                return response.data.result;
            });
        }

        /**
         * 同意 or 不同意
         *
         * @param checkType 0同意，1不同意
         * @param tkIds     申请id
         * @returns {*}
         */
        function batchCheckMyWaitTaskByProcInstId(checkType, tkIds) {
            return $http.post(originBaseUrl + '/third/tkMobile/batchCheckMyWaitTaskByProcInstId.htm', {
                checkType: checkType,
                tkIds: tkIds
            }).then(function (response) {
                return response.data;
            });
        }

        /**
         * 全选/全不选
         */
        function changeAllSelect() {
            vm.selectAllFlag = !vm.selectAllFlag;
            angular.forEach(vm.timetables, function (draft) {
                draft.select = vm.selectAllFlag;
                if (vm.selectAllFlag) {
                    vm.selectIds.push(draft.id);
                }
            });
            if (!vm.selectAllFlag) {
                vm.selectIds = [];
            }
        }

        /**
         * 单选/取消
         * @param item 选择的数据
         */
        function changeSelect(item) {
            item.select = !item.select;
            if (item.select && vm.selectIds.indexOf(item.id) === -1) {
                vm.selectIds.push(item.id);
            } else if (!item.select) {
                vm.selectIds.splice(vm.selectIds.indexOf(item.id), 1);
            }
            vm.selectAllFlag = vm.selectIds.length === vm.timetables.length;
        }

        /**
         * 同意 or 不同意
         *
         * @param checkType 0同意，1不同意
         * @returns {boolean}
         */
        function auditFun(checkType) {
            if (0 === vm.selectIds.length) {
                ynuiNotification.error({msg: "请至少勾选一项！"});
                return false;
            }
            var up = '您确认要把所选调课申请审核为' + (0 === checkType ? '<strong class="text-danger">通过</strong>' : '不通过') + '吗？';
            var down = '操作成功后' + (0 === checkType ? '相关流程将继续流转。' : '将终止相关流程。');
            var config = {
                template: up + down,
                title: '提示',
                scope: $scope,
                buttons: [
                    {
                        text: '<b>确定</b>',
                        type: 'button-positive',
                        onTap: function () {
                            batchCheckMyWaitTaskByProcInstId(checkType, vm.selectIds).then(function (data) {
                                if (data.result && data.result.length > 0) {
                                    var message = "";
                                    if (vm.selectIds.length === 1) {
                                        message = data.result[0].failedReason;
                                    } else {
                                        var s = "<li>您所选择的数据中有" + data.result.length + "条提交失败，原因如下：</li>";
                                        angular.forEach(data.result, function (failedInfo, key) {
                                            s += '<li>' + (key + 1) + '、' + failedInfo.failedReason + '</li>';
                                        });
                                        message = '<ul class="list-unstyled">' + s + '</ul>';
                                    }
                                    $ionicPopup.show({
                                        template: message,
                                        title: '提交失败！',
                                        scope: $scope,
                                        buttons: [{
                                            text: '确定',
                                            type: 'button-positive',
                                            onTap: function () {
                                                findByAdminAudit();
                                            }
                                        }]
                                    });
                                } else {
                                    ynuiNotification.success({msg: '操作成功！'});
                                    findByAdminAudit();
                                }
                                vm.selectIds = [];
                                vm.selectAllFlag = false;
                            });
                        }
                    },
                    {text: '取消'}
                ]
            };
            $ionicPopup.show(config);
        }

        /**
         * 跳转到流程详情页面
         *
         * @param procInstId lcId
         */
        function toProc(procInstId) {
            $location.path("/askfortk").search({"fromType": 0, "procInstId": procInstId, "fromBusiness": 1});
        }
    }
})();
