/**
 * 班主任成绩
 * @author qiucheng Lu
 * @Date 2021年4月14日15:57:19
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        .controller('AchievementTeacherCtrl', AchievementTeacherCtrl)
        .controller('AchievementDetailCtrl', AchievementDetailCtrl)

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        //班主任成绩-期中
            .state('acvmt_teacher_midterm', {
                url: '/acvmt_teacher_midterm',
                templateUrl: 'templates/achievement/acvmt_teacher.html',
                data: {
                    prev: 'workspaceForTeacher',
                    title: '期中成绩'
                }
            })
            .state('acvmt_detail', {
                url: '/acvmt_detail',
                templateUrl: 'templates/achievement/acvmt_detail.html',
                data: {
                    prev: 'acvmt_teacher_midterm'
                }
            })
            //班主任成绩-期末
            .state('acvmt_teacher_terminal', {
                url: '/acvmt_teacher_terminal',
                templateUrl: 'templates/achievement/acvmt_teacher.html',
                data: {
                    prev: 'workspaceForTeacher',
                    title: '期末成绩'
                }
            })
            .state('acvmt_detail_terminal', {
                url: '/acvmt_detail_terminal',
                templateUrl: 'templates/achievement/acvmt_detail.html',
                data: {
                    prev: 'acvmt_teacher_terminal',
                    title: '期末成绩'
                }
            })
    }

    AchievementTeacherCtrl.$inject = ['$location', '$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', "$rootScope"];

    // 学生成绩
    function AchievementTeacherCtrl($location, $scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, $rootScope) {
        $scope.isBack = false;
        $scope.dataLoading = true;
        if ($location.$$path == "/acvmt_teacher_midterm") {//期中
            $scope.scoreProperty = 2;
        } else {//期末
            $scope.scoreProperty = 3;
        }
        $scope.items = [];
        $scope.chooseTerm = function (term, func) {
            $scope.page = null;//重新获取page对象
            if (!term) {
                term = $scope.curTerm;
            }
            $scope.selectedTerm = term;
            $scope.items = [];
            $scope.getData(0, func);
        };
        $scope.chooseAdminClass = function (item, func) {
            $scope.selectedAdminClass = item;
            $scope.chooseTerm($scope.selectedTerm, func);
        };
        //请求行政班&学期
        ($scope.getAdminClassAndTerm = function (func) {
            $scope.hideHead = false;
            $http.post(originBaseUrl + "/third/appAcvmt/getAdminClassAndTerm.htm?", {userId: $rootScope.authorizationStr.userId}).success(function (data) {
                $scope.loadError = false;
                var result = data.result;
                $scope.curTerm = result.curTerm;
                $scope.termList = result.termList;
                $scope.adminClassList = result.adminClassList;
                if (!angular.isArray($scope.adminClassList) || $scope.adminClassList.length < 1) {
                    if (func) {
                        func();
                    }
                    $scope.curTerm = null;
                    $scope.termList = null;
                    $scope.dataLoading = false;
                    $scope.loadError = true;
                    $scope.hideHead = true;
                    $scope.loadErrorMsg = '没有管理的班级，无法查看成绩！';
                    return false;
                }
                if (!$scope.curTerm) {
                    if (!angular.isArray($scope.termList) || $scope.termList.length < 1) {
                        if (func) {
                            func();
                        }
                        $scope.dataLoading = false;
                        $scope.loadError = true;
                        $scope.hideHead = true;
                        $scope.loadErrorMsg = '您没有学期信息，无法查看成绩！';
                        return false;
                    }
                    $scope.curTerm = $scope.termList[0];
                }
                $scope.chooseAdminClass($scope.adminClassList[0], func);
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.hideHead = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
            });
        })();
        //模拟请求数据
        $scope.getData = function (pageNumber, func) {
            $scope.loadError = false;
            $http.post(originBaseUrl + "/third/appAcvmt/queryResultByTeacher.htm",
                {
                    classId: $scope.selectedAdminClass.id,
                    termId: $scope.selectedTerm.id,
                    pageNumber: pageNumber,
                    scoreProperty: $scope.scoreProperty,
                    userId: $rootScope.authorizationStr.userId
                }).success(function (data) {
                $scope.loadError = false;
                $scope.dataLoading = false;
                if (data.result) {
                    $scope.page = data.result;
                    $scope.items = $scope.items.concat($scope.page.content);
                }
                if ($scope.items.length < 1) {
                    $scope.loadError = true;
                    $scope.loadErrorMsg = '您没有管理的班级或管理的班级没有课程，无法查看成绩！';
                }
                if (func) {
                    func();
                }
            }).error(function () {
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                if (func) {
                    func();
                }
            });
        };
        //刷新数据
        $scope.reloadData = function () {
            if (!$scope.termList || !$scope.adminClassList) {
                $scope.doRefresh();
            } else {
                $scope.dataLoading = true;
                $ionicLoading.show({
                    template: '正在刷新...'
                });
                if ($scope.selectedAdminClass && $scope.selectedTerm && $scope.scoreProperty) {
                    $scope.getData(0, function () {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        $ionicScrollDelegate.scrollTop();
                        $ionicLoading.hide();
                    });
                } else {
                    $scope.dataLoading = false;
                    $timeout(function () {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        $ionicScrollDelegate.scrollTop();
                        $ionicLoading.hide();
                    }, 250);
                }
            }
        };
        $scope.loadMore = function () {
            //请求数据
            $scope.getData($scope.page.number + 1, function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        };

        $scope.$on('stateChangeSuccess', function () {
            $scope.loadMore();
        });

        $scope.moreDataCanBeLoaded = function () {
            return $scope.page && $scope.items.length < $scope.page.totalElements;
        };

        $scope.doRefresh = function () {
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.page = null;//重新获取page对象
            $scope.items = [];
            $scope.getAdminClassAndTerm(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        $scope.showWarning = function (msg) {
            $ionicLoading.show({
                template: msg
            });
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 500);
        };
        //明细跳转
        $scope.clickItem = function (item) {
            var url = "/acvmt_detail";
            if ($scope.scoreProperty == 3) {
                url = "/acvmt_detail_terminal";
            }
            var param = {
                classId: $scope.selectedAdminClass.id,
                state: $scope.scoreProperty,
                courseId: item.courseId,
                termId: $scope.selectedTerm.id,
                teachType: (item.teachType == '实操' ? 2 : 1),
                executeTerm: item.executeTerm
            };
            $location.path(url).search(param);
        }
    }

    AchievementDetailCtrl.$inject = ['$location', '$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', "$rootScope", "ynNavigator"];

    function AchievementDetailCtrl($location, $scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, $rootScope, ynNavigator) {
        $scope.isBack = true;
        $scope.status = 0;
        $scope.searchParam = $location.search();
        $scope.items = [];
        $scope.page = undefined;
        $scope.dataLoading = true;
        $scope.sort = "asc";
        //模拟请求数据
        ($scope.getData = function (pageNumber, func, sort) {
            $scope.loadError = false;
            $http.post(originBaseUrl + "/third/appAcvmt/queryResultByCourse.htm", {
                classId: $scope.searchParam.classId,
                termId: $scope.searchParam.termId,
                courseId: $scope.searchParam.courseId,
                scoreProperty: $scope.searchParam.state,
                teachType: $scope.searchParam.teachType,
                executeTerm: $scope.searchParam.executeTerm,
                pageNumber: pageNumber,
                isPass: $scope.status == 1 ? 1 : $scope.status == 2 ? 2 : undefined,
                name: $scope.name,
                sort: sort,
                userId: $rootScope.authorizationStr.userId
            }).success(function (data) {
                $scope.loadError = false;
                $scope.dataLoading = false;
                $scope.items = $scope.items.concat(data.result.content);
                $scope.page = data.result;
                if ($scope.searchBar) {//如果处于搜索状态，则过滤数据
                    $scope.search();
                }
                if ($scope.items.length < 1) {
                    $scope.loadError = true;
                    $scope.loadErrorMsg = '没有可查看的成绩！';
                }
                if (func) {
                    func();
                }
            }).error(function () {
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                if (func) {
                    func();
                }
            });
        })(0);

        /**
         * 排序
         * @param sort
         */

        $scope.sortData = function (sort) {
            $scope.page = undefined;//重新获取page对象
            $scope.items = [];
            $scope.sort = $scope.sort == "asc" ? "desc" : "asc";
            $scope.getData(0, null, $scope.sort);
        };

        $scope.doRefresh = function () {
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.page = undefined;//重新获取page对象
            $scope.items = [];
            $scope.getData(0, function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        $scope.changeStatus = function (status) {
            $scope.items = [];
            $scope.page = undefined;
            $scope.status = status;
            $scope.getData(0, function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        $scope.loadMore = function () {
            //请求数据
            $scope.getData($scope.page.number + 1, function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        };

        $scope.$on('stateChangeSuccess', function () {
            $scope.loadMore();
        });

        $scope.moreDataCanBeLoaded = function () {
            return $scope.page && $scope.items.length < $scope.page.totalElements;
        };

        //搜索
        $scope.searchBar = false;
        $scope.waitSearch = false;
        $scope.search = function () {
            if ($scope.waitSearch) {//已经有定时过滤则return
                return;
            } else {//改变定时过滤，return以后的过滤
                $scope.waitSearch = true;
                $scope.items = [];
                $scope.page = undefined;
            }
            $timeout(function () {
                $scope.items = [];
                $scope.getData(0, function () {
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                    $ionicScrollDelegate.scrollTop();
                    $ionicLoading.hide();
                    $scope.waitSearch = false;
                });
            }, 500);
        };
        $scope.cancelBack = function () {
            $scope.searchBar = !$scope.searchBar;
            $scope.name = undefined;
            $scope.doRefresh();
        };

        $scope.doBack = function () {
            history.back(-1);
        };
        $scope.showWarning = function (msg) {
            $ionicLoading.show({
                template: msg
            });
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 500);
        };
    }
})();
