/**
 * 学生成绩
 * @author qiucheng Lu
 * @Date 2021年4月13日15:57:19
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        .controller('achievementCtrl', achievementCtrl)
        .controller('retestRebuildCtrl', retestRebuildCtrl)
        .controller('acvmtAlysisCtrl', acvmtAlysisCtrl)

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        //学生成绩-期中
            .state('acvmt_stu_midterm', {
                url: '/acvmt_stu_midterm',
                templateUrl: 'templates/achievement/acvmt_stu.html',
                data: {
                    prev: 'achievementworkspace',
                    title: '期中成绩'
                }
            })
            //学生成绩-期末attendance
            .state('acvmt_stu_terminal', {
                url: '/acvmt_stu_terminal',
                templateUrl: 'templates/achievement/acvmt_stu.html',
                data: {
                    prev: 'achievementworkspace',
                    title: '期末成绩'
                }
            })
            //学生成绩-补考
            .state('acvmt_stu_retest', {
                url: '/acvmt_stu_retest',
                templateUrl: 'templates/achievement/retest_rebuild.html',
                data: {
                    prev: 'achievementworkspace',
                    title: '补考成绩'
                }
            })
            //学生成绩-重修
            .state('acvmt_stu_rebuild', {
                url: '/acvmt_stu_rebuild',
                templateUrl: 'templates/achievement/retest_rebuild.html',
                data: {
                    prev: 'achievementworkspace',
                    title: '重修成绩'
                }
            })
            //学生成绩-成绩分析
            .state('acvmt_stu_alysis', {
                url: '/acvmt_stu_alysis',
                templateUrl: 'templates/achievement/acvmt_alysis.html',
                data: {
                    prev: 'achievementworkspace',
                    title: '成绩分析'
                }
            })
    }

    achievementCtrl.$inject = ['$location', '$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', "$ionicModal"];
    retestRebuildCtrl.$inject = ['$location', '$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', "$ionicModal"];
    acvmtAlysisCtrl.$inject = ['$location', '$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', "$ionicModal"];

    // 学生成绩(期中、期末)
    function achievementCtrl($location, $scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, $ionicModal) {
        $scope.conditions = {
            termId: "",
            sortField: "1",
            scoreType: $location.$$path === "/acvmt_stu_midterm" ? 2 : 3
        };
        $scope.scoreConfig = {
            constituent: false,
            ranking: false,
        };
        //查询成绩配置
        initFindConfig();
        //初始化查询学期
        getTerm();
        //格式化显示
        $scope.validationNull = function(value){
            if(value === undefined || value === null){
                return "--"
            }
            return value;
        };
        //重新请求成绩
        $scope.reloadData = function () {
            if (!$scope.termList) {
                $scope.doRefresh();
                return;
            }
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            if ($scope.term && $scope.term.id) {
                getData(function () {
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                    $ionicScrollDelegate.scrollTop();
                    $ionicLoading.hide();
                });
                return;
            }
            $scope.dataLoading = false;
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 250);
        };
        //刷新数据
        $scope.doRefresh = function () {
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            getTerm(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        //切换学期
        $scope.toLastOrNextTerm = function (type) {
            if ($scope.termList.length) {
                var result = getLastOrNextTerm($scope.termList, type);
                if (result) {
                    $scope.term = result;
                    getData();
                    return;
                }
            }
            showWarning("没有了！")
        };

        /**
         * 查询成绩录入配置
         */
        function initFindConfig() {
            $http.post(originBaseUrl + "/third/appAcvmt/config/find.htm?version=V1.0&moduleCode=66_5").success(function (data) {
                if (data.status == 0) {
                    var resultList = data.result;

                    if (resultList.length > 0) {
                        angular.forEach(resultList, function (item) {
                            if ($scope.conditions.scoreType === 2) {
                                //是否允许学生查看期中成绩的构成项
                                if (item.code === 'cj_t_mid_constituent_config') {
                                    $scope.scoreConfig.constituent = item.isOpen;
                                }
                                //是否允许学生查看期中成绩排名
                                if (item.code === 'cj_t_mid_ranking_config') {
                                    $scope.scoreConfig.ranking = item.isOpen;
                                }
                            } else if ($scope.conditions.scoreType === 3) {
                                //是否允许学生查看期末成绩的构成项
                                if (item.code === 'cj_t_final_constituent_config') {
                                    $scope.scoreConfig.constituent = item.isOpen;
                                }
                                //是否允许学生查看期末成绩排名
                                if (item.code === 'cj_t_final_ranking_config') {
                                    $scope.scoreConfig.ranking = item.isOpen;
                                }
                            }
                        });
                    }

                }
            });
        }

        //查询学期
        function getTerm(fun) {
            $scope.hideHead = false;
            $http.post(originBaseUrl + "/third/appAcvmt/term/find.htm?version=V1.0", $scope.conditions).success(function (data) {
                $scope.loadError = false;
                var result = data.result;
                $scope.termList = result.termList;
                //当前学期
                if (result.currentTerm) {
                    $scope.term = result.currentTerm;
                    getData(fun);
                    return;
                }
                //最近学期
                if ($scope.termList.length) {
                    $scope.term = $scope.termList[0];
                    getData(fun);
                    return;
                }
                if (fun) {
                    fun();
                }
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.hideHead = true;
                $scope.loadErrorMsg = '您没有学期信息，无法查看成绩！';
            }).error(function () {
                if (fun) {
                    fun();
                }
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';

            });
        }

        $scope.dataLoading = true;
        $scope.studentScore = null;

        //请求成绩数据
        function getData(func) {
            $scope.studentScore = null;
            $scope.dataLoading = true;
            $scope.conditions.termId = $scope.term.id;
            $http.post(originBaseUrl + "/third/appAcvmt/studentscorre/find.htm?version=V1.0", $scope.conditions).success(function (data) {
                $scope.loadError = false;
                $scope.dataLoading = false;
                $scope.studentScore = data.result;
                //格式化显示
                formatCourse($scope.studentScore.studentCourseVOList);

                if (!$scope.studentScore.studentCourseVOList.length) {
                    $scope.loadError = true;
                    $scope.loadErrorMsg = '您在该学期没有课程，无法查看成绩！';
                }
                if (func) {
                    func();
                }
            }).error(function () {
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                if (func) {
                    func();
                }
            });
        }

        //格式化显示内容
        function formatCourse(items) {
            var details;
            angular.forEach(items, function (item) {
                details = [];
                if (item.teachTypeName === "实操") {
                    details.push(item.teachTypeName);
                }
                if (item.electiveTypeName) {
                    details.push(item.electiveTypeName);
                }
                if (item.ruleTypeName) {
                    details.push(item.ruleTypeName);
                }
                item.detailValue = details.join("|");
            })
        }

        //切换学期
        function getLastOrNextTerm(termList, type) {
            if (!(termList instanceof Array)) {
                return false;
            }
            for (var i = 0, len = termList.length; i < len; i++) {
                if (termList[i].id === $scope.term.id) {
                    if (type < 0 && i > 0) {
                        termList[i - 1].isFirst = i === 1;
                        return termList[i - 1];
                    }
                    if (type > 0 && i < len - 1) {
                        termList[i + 1].isLast = i === len - 2;
                        return termList[i + 1];
                    }
                }
            }
            return false;
        }

        function showWarning(msg) {
            $ionicLoading.show({
                template: msg
            });
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 1500);
        }

        /*成绩明细*/
        $ionicModal.fromTemplateUrl('viewCustom.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.viewCustomModal = modal;
        });
        $scope.viewCustomClick = function (item) {
            if (!$scope.scoreConfig.constituent) {
                showWarning('管理员已设置不允许查看成绩构成项！');
                return;
            }
            //组装显示数据
            $scope.viewCustom = {
                name: item.courseName,
                customs: [],
                ruleType:item.ruleType,
                remarks:item.remarks,
                invalid:item.invalid,
            };
            if (item.customItem) {
                var customs = item.customItem.split("；");
                angular.forEach(customs, function (custom,key) {
                    var values = custom.split(":");
                    var index = Math.floor(key/3);
                    if(!$scope.viewCustom.customs[index]){
                        $scope.viewCustom.customs[index] = [];
                    }
                    $scope.viewCustom.customs[index] .push({
                        name: values[0],
                        value: values[1],
                    });
                })
            }
            if (!$scope.viewCustom.customs.length) {
                showWarning('没有成绩构成项！');
                return;
            }
            $scope.viewCustomModal.show();
        };
        $scope.closeModal = function () {
            $scope.viewCustomModal.hide();
        };
    }

    // 学生成绩(补考、重修)
    function retestRebuildCtrl($location, $scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, $ionicModal) {
        $scope.conditions = {
            termId: "",
            sortField: "1",
            scoreType: $location.$$path === "/acvmt_stu_retest" ? 4 : 6
        };
        //格式化显示
        $scope.validationNull = function(value){
            if(value === undefined || value === null){
                return "--"
            }
            return value;
        };
        //重新请求成绩
        $scope.reloadData = function () {
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            //学期
            getTerm(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        //初始化查询
        $scope.reloadData();
        //查询学期
        function getTerm(fun) {
            $scope.hideHead = false;
            $http.post(originBaseUrl + "/third/appAcvmt/term/find.htm?version=V1.0", $scope.conditions).success(function (data) {
                $scope.loadError = false;
                var result = data.result;
                if(result){
                    $scope.termList = result.termList;
                }
                //查列表
                getData(fun);
            }).error(function () {
                if (fun) {
                    fun();
                }
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';

            });
        }

        $scope.dataLoading = true;

        //请求成绩数据
        function getData(func) {
            $scope.dataLoading = true;
            $http.post(originBaseUrl + "/third/appAcvmt/studentscorre/find.htm?version=V1.0", $scope.conditions).success(function (data) {
                $scope.loadError = false;
                $scope.dataLoading = false;
                var studentScore = data.result;
                //按学期封装显示信息
                pushTermCourse(studentScore.studentCourseVOList);
                if (!studentScore.studentCourseVOList.length) {
                    $scope.loadError = true;
                    $scope.loadErrorMsg = $scope.conditions.scoreType === 4 ? '没有补考记录！' : '没有重修记录！';
                }
                if (func) {
                    func();
                }
            }).error(function () {
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                if (func) {
                    func();
                }
            });
        }

        //格式化显示内容
        function formatCourse(item) {
            var details = [];
            if (item.teachTypeName === "实操") {
                details.push(item.teachTypeName);
            }
            if (item.electiveTypeName) {
                details.push(item.electiveTypeName);
            }
            if (item.ruleTypeName) {
                details.push(item.ruleTypeName);
            }
            item.detailValue = details.join("|");
        }

        //按学期封装显示信息
        function pushTermCourse(items) {
            //格式化显示
            angular.forEach(items, function (item) {
                formatCourse(item);
            });
            angular.forEach($scope.termList, function (term) {
                //封装课程
                term.courses = [];
                angular.forEach(items, function (item) {
                    if (term.id === item.inputTermId) {
                        term.courses.push(item);
                    }
                });
            })
        }

        function showWarning(msg) {
            $ionicLoading.show({
                template: msg
            });
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 1500);
        }

        /*成绩明细*/
        $ionicModal.fromTemplateUrl('viewCustom.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.viewCustomModal = modal;
        });
        $scope.viewCustomClick = function (item) {
            //组装显示数据
            $scope.viewCustom = angular.copy(item);
            $scope.viewCustomModal.show();
        };
        $scope.closeModal = function () {
            $scope.viewCustomModal.hide();
        };
    }

    // 学生成绩分析
    function acvmtAlysisCtrl($location, $scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, $ionicModal) {
        $scope.tab = 1;

        //格式化显示
        $scope.validationNull = function(value){
            if(value === undefined || value === null){
                return "--"
            }
            return value;
        };
        //重新请求成绩
        $scope.reloadData = function () {
            $scope.dataLoading = true;
            $ionicLoading.show({
                template: '正在刷新...'
            });
            //重修学期
            getTerm(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        //初始化查询学期
        $scope.reloadData();
        //切换学期
        $scope.toLastOrNextTerm = function (type) {
            if ($scope.termList.length) {
                var term = getLastOrNextTerm($scope.termList, type);
                if (term) {
                    $scope.viewTab($scope.tab,term);
                    return;
                }
            }
            showWarning("没有了！")
        };
        /**
         * @Description 组装显示数据
         */
        $scope.viewTab = function (tab,term) {
            $scope.loadError = false;
            if(!termResult){
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                return;
            }
            //成绩达标情况
            if (tab === 1) {
                if (!$scope.analysis || !$scope.analysis.cultivatePlanVOList || !$scope.analysis.cultivatePlanVOList.length) {
                    $scope.loadError = true;
                    $scope.loadErrorMsg = '未找到专业人才培养方案无法分析成绩达标情况！';
                }
                return;
            }
            if(!termResult.termList.length){
                $scope.loadError = true;
                $scope.loadErrorMsg = '您没有学期信息！';
                return;
            }
            //取选中的学期
            $scope.term = term;
            if(!$scope.term){
                getNowTerm(term);
            }
            $scope.termCourse = null;
            angular.forEach($scope.analysis.termCourseList, function (item) {
               if(item.termId==$scope.term.id){
                   $scope.termCourse = angular.copy(item);
                   //格式化显示信息
                   formatCourse($scope.termCourse.studentCourseVOList);
                   formatCourse($scope.termCourse.studentNotPlanCourseVOList);
               }
            });
            //修读情况
            if (!$scope.termCourse) {
                $scope.loadError = true;
                $scope.loadErrorMsg = '您在该学期没有课程，无法查看修读情况！';
            }
        };

        var termResult;
        //查询学期
        function getTerm(fun) {
            $http.post(originBaseUrl + "/third/appAcvmt/term/find.htm?version=V1.0", {scoreType: 3}).success(function (data) {
                $scope.loadError = false;
                termResult = data.result;
                $scope.termList = termResult.termList;
                getData(fun);
            }).error(function () {
                if (fun) {
                    fun();
                }
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';

            });
        }

        //取得当前学期
        function getNowTerm() {
            $scope.term = {};
            //当前学期
            if (termResult.currentTerm) {
                $scope.term = termResult.currentTerm;
            }
            //最近学期
            if (termResult.termList.length) {
                $scope.term = termResult.termList[0];
            }
        }

        $scope.dataLoading = true;

        //请求成绩数据
        function getData(func) {
            $scope.dataLoading = true;
            $http.post(originBaseUrl + "/third/appAcvmt/studentanalysis/find.htm?version=V1.0").success(function (data) {
                $scope.analysis = data.result;
                $scope.dataLoading = false;
                //初始化组装数据
                $scope.viewTab($scope.tab);
                if (func) {
                    func();
                }
            }).error(function () {
                $scope.dataLoading = false;
                $scope.loadError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
                if (func) {
                    func();
                }
            });
        }

        //切换学期
        function getLastOrNextTerm(termList, type) {
            if (!(termList instanceof Array)) {
                return false;
            }
            for (var i = 0, len = termList.length; i < len; i++) {
                if (termList[i].id === $scope.term.id) {
                    if (type < 0 && i > 0) {
                        termList[i - 1].isFirst = i === 1;
                        return termList[i - 1];
                    }
                    if (type > 0 && i < len - 1) {
                        termList[i + 1].isLast = i === len - 2;
                        return termList[i + 1];
                    }
                }
            }
            return false;
        }
        //格式化显示内容
        function formatCourse(items) {
            var details;
            angular.forEach(items, function (item) {
                details = [];
                if (item.teachTypeName === "实操") {
                    details.push(item.teachTypeName);
                }
                if (item.electiveTypeName) {
                    details.push(item.electiveTypeName);
                }
                if (item.ruleTypeName) {
                    details.push(item.ruleTypeName);
                }
                item.detailValue = details.join("|");
            })
        }
        function showWarning(msg) {
            $ionicLoading.show({
                template: msg
            });
            $timeout(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, 1500);
        }
    }
})();
