/**
 * @Description 学籍异动申请
 * @author qiucheng Lu
 * @date 2022/6/30 15:25
 */
(function () {
    'use strict';

    angular
        .module('starter')
        .config(config)
        //学籍异动管理
        .controller('changeManageCtrl', changeManageCtrl)
        //学籍异动申请
        .controller('changeSchoolRollApplyCtrl', changeSchoolRollApplyCtrl)
        //学生升学申请
        .controller('updateLevelApplyCtrl', updateLevelApplyCtrl)
        .controller('listCtrl', listCtrl)
        .controller('stuUnusualChangeInfoCtr', stuUnusualChangeInfoCtr)
    ;

    config.$inject = ['$stateProvider'];

    function config($stateProvider) {
        $stateProvider
            .state('changeManage', {
                url: '/changeManage',
                templateUrl: 'templates/change/index.html',
                cache: false,
                controller: 'changeManageCtrl',
                data: {
                    prev: 'workspaceForTeacher',
                    title: "学籍异动管理"
                }
            })
            //学籍异动记录查看
            .state('stu_unusual_change_info', {
                url: '/stu_unusual_change_info',
                templateUrl: 'templates/change/stuUnusualChangeInfo.html',
                data: {
                    prev: 'changeManage',
                    title: '学籍异动记录查看'
                }
            })
            //修改学籍异动申请
            .state('changeSchoolRollApplyUpdate', {
                url: '/changeSchoolRollApplyUpdate',
                templateUrl: 'templates/change/changeSchoolRollApply.html',
                data: {
                    prev: 'changeManage',
                    title: '修改学籍异动申请'
                }
            })
            //修改学生升学申请
            .state('updateLevelApplyUpdate', {
                url: '/updateLevelApplyUpdate',
                templateUrl: 'templates/change/updateLevelStudent.html',
                data: {
                    prev: 'changeManage',
                    title: '修改学生升学申请'
                }
            })
        ;
    }

    changeManageCtrl.$inject = ['$scope'];

    function changeManageCtrl($scope) {
        //初始化选项卡
        $scope.tabRepeat = [
            {id: "1", name: "申请记录查看", active: true},
            {id: "2", name: "添加学籍异动申请", active: false},
            {id: "3", name: "添加升学申请", active: false}
        ];
        //点击选项卡
        $scope.clickTab = function (index) {
            $scope.activeKey = index;
            angular.forEach($scope.tabRepeat, function (value) {
                value.active = false;
                if (value.id === index) {
                    value.active = true;
                }
            })
        };
        //初始化选中
        $scope.clickTab("1");
    }

    //学籍异动申请
    changeSchoolRollApplyCtrl.$inject = ['$scope', '$http', 'ynuiNotification', '$ionicPopup', '$ionicModal', '$location', 'ynNavigator'];

    function changeSchoolRollApplyCtrl($scope, $http, ynuiNotification, $ionicPopup, $ionicModal, $location, ynNavigator) {
        var vm = $scope.vm = this;
        vm.id = $location.search().id;
        //初始化数据
        initParams();
        //年级
        getGradeList();
        //异动码表
        getUnusualChangeTypeList().then(function () {
            //修改数据
            if (vm.id) {
                updateInitParams();
            }
        });
        //异动类型对应key
        var applyTypeKey = {
            //转专业、转班、留级、跳级
            "1": "1", "10": "1", "5": "1", "11": "1",
            //转学转出、退学、开除、取消学籍、死亡、失踪、其他离校
            "6": "2", "7": "2", "8": "2", "9": "2", "12": "2", "13": "2", "14": "2",
            //休学
            "3": "3",
            //复学
            "4": "4"
        };
        //初始化方法
        vm.clickTypeItem = clickTypeItem;
        vm.clickReasonItem = clickReasonItem;
        vm.clickGradeItem = clickGradeItem;
        vm.clickSpecialtyItem = clickSpecialtyItem;
        vm.clickArriveClassTime = clickArriveClassTime;
        vm.submit = submit;

        function getGradeList() {
            vm.gradeList = [];
            //年级
            $http.get(originBaseUrl + '/third/grade/list.htm').success(function (data) {
                if (data.status === 0) {
                    vm.gradeList = data.result;
                }
            });
        }
        function getUnusualChangeTypeList() {
            vm.unusualChangeTypeList = [];
            //取得异动码表
            return $http.get(originBaseUrl + '/third/tkMobile/queryDictionaryByKey.htm', {
                params: {
                    key: "UNUSUAL_CHANGE_TYPE"
                }
            }).then(function (response) {
                //过滤掉转学转入【即插班生】
                if (response.data && response.data.result) {
                    vm.unusualChangeTypeList = response.data.result.filter(function (value) {
                        return value.dictCode !== "2";
                    });
                }
                return response;
            });
        }
        //级联异动原因
        function findReasonByCode(code) {
            //先清空
            vm.changeReasonList = [];
            //取得异动类型
            return $http.get(originBaseUrl + '/third/unusual/change/reason/find.htm', {
                params: {
                    type: code,
                    version: "V1.0"
                }
            }).then(function (response) {
                vm.changeReasonList = response.data.result;
                //追加自定义原因
                vm.changeReasonList.push({id: "srzdyyy", reason: "输入自定义原因"});
                return vm.changeReasonList;
            });
        }

        //初始化参数
        function initParams(noClean) {
            vm.changeApply = {
                unusualChangeType: null,
                isCancelAccount: 1,
                isUnderGraduate: 0,
                arriveClassTime: moment().format("YYYY-MM-DD"),
                leaveClassTime: moment().format("YYYY-MM-DD"),
                afterPlatformSysOrgOrgNo: null,
                leaveYear: null,
                leaveStartYear: null,
                leaveEndYear: null,
                afterPlatformSysOrgName: null,
                afterPlatformSysGradeId: null,
                afterPlatformSysAdminClassId: null,
                afterPlatformSysAdminClassName: null,
                afterPlatformSysSpecialtyId: null,
                levelName: null,
                ids: [],
                userName: null,
                unusualChangeReasonId: null,
                unusualChangeReason: null
            };
            vm.changeApplyType = null;
            //不还原类型对象
            if (!noClean) {
                vm.unusualChangeTypeObj = null;
            }
            vm.grade = null;
            vm.changeReason = null;
            vm.changeReasonList = [];
            vm.specialty = null;
            vm.specialtyList = [];
            vm.studentList = [];
            vm.classList = [];
            //禁用年级、专业
            vm.disabledGradeSpecailty = false;
            //年级专业id
            vm.gradeSpecialtyIds = [];
            vm.beforeAdminClassIds = [];
            vm.beforeLevelCodes = [];
            vm.studentName = null;
            vm.className = null;
        }

        //修改
        function updateInitParams() {
            $http.get(originBaseUrl + '/third/unusual/change/find/' + vm.id + '.htm').success(function (data) {
                if (data.status === 0) {
                    var change = data.result;
                    vm.changeApply = {
                        id: change.id,
                        isCancelAccount: change.isCancelAccount,
                        isUnderGraduate: change.isUnderGraduate,
                        arriveClassTime: change.arriveClassTime,
                        leaveClassTime: change.leaveClassTime,
                        leaveStartYear: change.leaveStartYear,
                        leaveEndYear: change.leaveEndYear,
                        afterPlatformSysGradeId: change.stuUnusualChangeAuxiliaryVo.afterPlatformSysGradeId,
                        afterPlatformSysAdminClassId: change.stuUnusualChangeAuxiliaryVo.afterPlatformSysAdminClassId,
                        afterPlatformSysSpecialtyId: change.stuUnusualChangeAuxiliaryVo.afterPlatformSysSpecialtyId,
                        auxiliaryId: change.stuUnusualChangeAuxiliaryVo.id,
                        ids: change.ids,
                        userName: change.name
                    };
                    if (change.leaveYear && change.leaveYear !== "0") {
                        vm.changeApply.leaveYear = Number(change.leaveYear);
                    }
                    //回填异动类型
                    clickTypeItem({dictCode: String(change.unusualChangeType)}, true);
                    //回填异动原因
                    findReasonByCode(change.unusualChangeType).then(function () {
                        var param = {id: change.unusualChangeReasionId};
                        //自定义回填
                        if (!change.unusualChangeReasionId && change.unusualChangeReasion) {
                            param.id = "srzdyyy";
                            param.customerReason = change.unusualChangeReasion;
                        }
                        clickReasonItem(param);
                    });
                    //转专业、转班、留级、跳级 || 复学
                    if (vm.changeApplyType === "1" || vm.changeApplyType === "4") {
                        //回填年级、班级、专业
                        updateCallSelect();
                    }

                }
            });
        }

        //修改回填年级、班级、专业
        function updateCallSelect() {
            //回填班级、年级、专业信息
            findClass().then(function () {
                var classSelect, specilaty;
                angular.forEach(vm.classList, function (value) {
                    if (value.id === vm.changeApply.afterPlatformSysAdminClassId) {
                        classSelect = value;
                    }
                });
                if (classSelect) {
                    //回填班级、年级
                    enterClass(classSelect, true);
                }
                //专业
                angular.forEach(vm.specialtyList, function (value) {
                    if (value.id === vm.changeApply.afterPlatformSysSpecialtyId) {
                        specilaty = value;
                    }
                });
                if (specilaty) {
                    clickSpecialtyItem(specilaty);
                }
            });
        }

        //异动类型
        function clickTypeItem(item, update) {
            angular.forEach(vm.unusualChangeTypeList, function (value) {
                value.checked = false;
                if (angular.equals(item.dictCode, value.dictCode)) {
                    value.checked = true;
                    //修改的时候不还原
                    if (!update) {
                        //还原已有参数
                        initParams(true);
                        //重置年级已选状态
                        clickGradeItem({});
                        //级联异动原因
                        findReasonByCode(value.dictCode);
                    }
                    //重新赋值
                    vm.unusualChangeTypeObj = value;
                    //异动类型key
                    vm.changeApplyType = applyTypeKey[vm.unusualChangeTypeObj.dictCode];
                }
            })
        }

        //异动原因
        function clickReasonItem(item) {
            angular.forEach(vm.changeReasonList, function (value) {
                value.checked = false;
                if (angular.equals(item.id, value.id)) {
                    value.checked = true;
                    vm.changeReason = value;
                    vm.changeReason.customerReason = item.customerReason;
                }
            });
        }

        //年级
        function clickGradeItem(item, change) {
            angular.forEach(vm.gradeList, function (value) {
                value.checked = false;
                if (angular.equals(item.id, value.id)) {
                    value.checked = true;
                    vm.grade = value;
                    //清空行政班[级联时不清空]
                    if (!change) {
                        clearClass();
                    }
                }
            });
        }

        //清空行政班
        function clearClass() {
            vm.classList = [];
            vm.changeApply.afterPlatformSysAdminClassId = null;
            vm.changeApply.afterPlatformSysAdminClassName = null;
            vm.changeApply.afterPlatformSysOrgOrgNo = null;
            vm.changeApply.afterPlatformSysOrgName = null;
        }

        //专业
        function clickSpecialtyItem(item) {
            angular.forEach(vm.specialtyList, function (value) {
                value.checked = false;
                if (angular.equals(item.id, value.id)) {
                    value.checked = true;
                    vm.specialty = value;
                    vm.changeApply.afterLevelName = vm.specialty.schoolLevelName;
                }
            });
        }

        //复学生效日期点击事件
        function clickArriveClassTime() {
            ynuiNotification.error({msg: "复学申请只允许当天生效！"});
        }

        //保存数据
        function submit() {
            //验证必填
            if (validationForm()) {
                return false;
            }

            $ionicPopup.confirm({
                title: '提示',
                template: getTemplateHeader(),
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    //保存数据
                    $http.post(originBaseUrl + '/third/unusual/change/save.htm', getParam()).success(function (data) {
                        if (data.status == 0) {
                            if (data.result && data.result.length > 0) {
                                //批量错误提示
                                batchNotification(data.result);
                            } else {
                                ynuiNotification.success({msg: "保存成功！"});
                                if (vm.id) {
                                    //强制返回上一级
                                    ynNavigator.pop(true);
                                    setTimeout(function () {
                                        $scope.$apply();
                                    });
                                    return;
                                }
                                //重置参数
                                initParams();
                                //重置异动类型已选状态
                                clickTypeItem({});
                                //重置年级已选状态
                                clickGradeItem({});
                            }

                        } else {
                            ynuiNotification.error({msg: data.message});
                        }
                    });
                }
            });
        }

        //批量错误提示
        function batchNotification(result) {
            var message = "<ul class='help-inline'>";
            if (result.length === 1) {
                message += '<li>' + result[0].userName + result[0].failedReason + '</li>';
            } else {
                angular.forEach(result, function (item, key) {
                    message += '<li>' + (key + 1) + '、' + item.userName + item.failedReason + '</li>';
                });
            }
            message += "</ul>";
            $ionicPopup.alert({
                title: '提交失败',
                template: message,
                okText: '关闭'
            });
        }

        //获取保存提示信息
        function getTemplateHeader() {
            var template;
            switch (vm.changeApplyType) {
                case "2":
                //转学转出、退学、开除、取消学籍、死亡、失踪、其他离校
                case "3":
                    //休学
                    template = '您正在提交 ' +
                        '<span class="text-danger">' + vm.changeApply.userName + '</span> 的 ' +
                        '<span class="text-danger">' + vm.unusualChangeTypeObj.dictName + '</span>  异动申请，异动后学生将从行政班中移出，请确认！';
                    break;
                default :
                    //转专业、转班、留级、跳级 || 休学
                    template = '您正在提交 ' +
                        '<span class="text-danger">' + vm.changeApply.userName + '</span> 的 ' +
                        '<span class="text-danger">' + vm.unusualChangeTypeObj.dictName + '</span>  异动申请，异动后的行政班为 ' +
                        '<span class="text-danger">' + vm.changeApply.afterPlatformSysAdminClassName + '</span> ，请确认！';
                    break;
            }
            return template;
        }

        //验证必填
        function validationForm() {
            if (!vm.unusualChangeTypeObj) {
                ynuiNotification.error({msg: "请选择异动类型！"});
                return true;
            }
            if (!vm.changeReason) {
                ynuiNotification.error({msg: "请选择异动原因！"});
                return true;
            } else if (vm.changeReason.id === "srzdyyy" && !vm.changeReason.customerReason) {
                ynuiNotification.error({msg: "请输入自定义异动原因！"});
                return true;
            }
            if (!vm.changeApply.ids.length) {
                ynuiNotification.error({msg: "请选择异动学生！"});
                return true;
            }
            //转专业、转班、留级、跳级 || 复学
            if (vm.changeApplyType === "1" || vm.changeApplyType === "4") {
                if (!vm.grade) {
                    ynuiNotification.error({msg: "请选择年级！"});
                    return true;
                }
                if (!vm.changeApply.afterPlatformSysAdminClassId) {
                    ynuiNotification.error({msg: "请选择行政班！"});
                    return true;
                }
                if (!vm.specialty) {
                    ynuiNotification.error({msg: "请选择专业方向！"});
                    return true;
                }
                // 转专业特殊判断
                if (vm.unusualChangeTypeObj.dictCode === "1") {
                    if (vm.beforeLevelCodes[0] + '' === "1" && vm.specialty.schoolLevelCode + '' === "2") {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '您选择的学生<span class="text-danger">存在跨层次的异动</span>，请前往添加升学申请进行操作！',
                            okText: '确定'
                        });
                        return true;
                    }
                    if (vm.beforeAdminClassIds && vm.beforeAdminClassIds.indexOf(vm.changeApply.afterPlatformSysAdminClassId) >= 0)  {
                        ynuiNotification.error({msg: "异动前后的行政班不能相同！"});
                        return true;
                    }
                }
                // 转班的特殊验证
                if (vm.unusualChangeTypeObj.dictCode === "10") {
                    if (vm.beforeAdminClassIds && vm.beforeAdminClassIds.indexOf(vm.changeApply.afterPlatformSysAdminClassId) >= 0)  {
                        ynuiNotification.error({msg: "异动前后的行政班不能相同！"});
                        return true;
                    }
                }
            }
            //休学
            if (vm.changeApplyType === "3") {
                if (vm.changeApply.leaveStartYear && vm.changeApply.leaveEndYear &&
                    vm.changeApply.leaveEndYear < vm.changeApply.leaveStartYear) {
                    ynuiNotification.error({msg: "休学时段的结束时间不能小于开始时间！"});
                    return true;
                }
                if (vm.changeApply.leaveYear && Number(vm.changeApply.leaveYear) <= 0) {
                    ynuiNotification.error({msg: "休学年限只能输入正数！"});
                    return true;
                }
            }
            return false;
        }

        //组装保存参数
        function getParam() {
            var param = {
                id: vm.changeApply.id,
                ids: vm.changeApply.ids,
                isRecord: 1,
                isRetain: 1,
                userType: 2,
                unusualChangeOperate: getOperate(),
                unusualChangeType: vm.unusualChangeTypeObj.dictCode,
                unusualChangeReasionId: vm.changeReason.id,
                unusualChangeReasion: vm.changeReason.reason
            };
            if (vm.changeReason.id === "srzdyyy") {
                //自定义原因
                param.unusualChangeReasionId = null;
                param.unusualChangeReasion = vm.changeReason.customerReason;
            }
            switch (vm.changeApplyType) {
                //转专业、转班、留级、跳级
                case "1":
                    param.arriveClassTime = vm.changeApply.arriveClassTime;
                    param.stuUnusualChangeAuxiliaryVo = {
                        id: vm.changeApply.auxiliaryId,
                        afterPlatformSysGradeId: vm.grade.id,
                        afterPlatformSysAdminClassId: vm.changeApply.afterPlatformSysAdminClassId,
                        afterPlatformSysOrgOrgNo: vm.changeApply.afterPlatformSysOrgOrgNo,
                        afterPlatformSysSpecialtyId: vm.specialty.id
                    };
                    break;
                case "2":
                    //转学转出、退学、开除、取消学籍、死亡、失踪、其他离校
                    param.leaveClassTime = vm.changeApply.leaveClassTime;
                    param.isCancelAccount = vm.changeApply.isCancelAccount;
                    param.isUnderGraduate = vm.changeApply.isUnderGraduate;
                    param.stuUnusualChangeAuxiliaryVo = {
                        id: vm.changeApply.auxiliaryId
                    };
                    break;
                case "3":
                    //休学
                    param.leaveClassTime = vm.changeApply.leaveClassTime;
                    param.leaveYear = vm.changeApply.leaveYear;
                    param.leaveStartYear = vm.changeApply.leaveStartYear;
                    param.leaveEndYear = vm.changeApply.leaveEndYear;
                    param.stuUnusualChangeAuxiliaryVo = {
                        id: vm.changeApply.auxiliaryId
                    };
                    break;
                case "4":
                    //复学
                    param.arriveClassTime = vm.changeApply.arriveClassTime;
                    param.isRecover = 1;
                    param.stuUnusualChangeAuxiliaryVo = {
                        id: vm.changeApply.auxiliaryId,
                        afterPlatformSysGradeId: vm.grade.id,
                        afterPlatformSysAdminClassId: vm.changeApply.afterPlatformSysAdminClassId,
                        afterPlatformSysOrgOrgNo: vm.changeApply.afterPlatformSysOrgOrgNo,
                        afterPlatformSysSpecialtyId: vm.specialty.id
                    };
                    break;
            }
            return parseParamForSpringMVC(param)
        }

        /*************************************************************************模态框相关****************************************************************************/
        /*学生*/
        vm.openStudentModal = openStudentModal;
        vm.changeFindStudent = changeFindStudent;
        vm.enterStudent = enterStudent;
        $ionicModal.fromTemplateUrl('studentModal.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.studentModal = modal;
        });

        function openStudentModal() {
            //修改学生禁用
            if (vm.changeApply.id) {
                return false;
            }
            vm.studentModal.show();
            //查询学生
            findStudent();
        }

        function closeStudentModal() {
            vm.studentModal.hide();
        }

        function enterStudent() {
            var selectedIds = [];
            var selectedNames = [];
            //年级专业id
            vm.gradeSpecialtyIds = [];
            vm.beforeAdminClassIds = [];
            vm.beforeLevelCodes = [];
            angular.forEach(vm.studentList, function (item) {
                if (item.checked) {
                    selectedIds.push(item.id);
                    selectedNames.push(item.name);
                    var gradeSpecialtyId = item.gradeId + "_" + item.specialtyId;
                    if (vm.gradeSpecialtyIds.indexOf(gradeSpecialtyId) === -1) {
                        vm.gradeSpecialtyIds.push(gradeSpecialtyId);
                    }
                    //学生对应的专业层次
                    vm.changeApply.stuSchoolLevel = item.schoolLevel;
                    if (item.classId && vm.beforeAdminClassIds.indexOf(item.classId) === -1) {
                        vm.beforeAdminClassIds.push(item.classId);
                    }
                    if (item.levelCode && vm.beforeLevelCodes.indexOf(item.levelCode) === -1) {
                        vm.beforeLevelCodes.push(item.levelCode);
                    }
                }
            });
            //无数据
            if (!selectedIds.length) {
                ynuiNotification.error({msg: "请选择异动学生！"});
                return;
            }
            //禁用年级、专业
            vm.disabledGradeSpecailty = false;
            if (vm.unusualChangeTypeObj.dictCode === "10") {
                //转班特殊业务
                if (vm.gradeSpecialtyIds.length !== 1) {
                    //只能选择同年级同专业的学生
                    ynuiNotification.error({msg: "请选择相同年级和专业的学生进行“转班”！"});
                    return;
                }
                vm.disabledGradeSpecailty = true;
                var gradeSpecialtyIdsArr = vm.gradeSpecialtyIds[0].split("_");
                //回填年级【清空行政班信息】
                clickGradeItem({id: gradeSpecialtyIdsArr[0]});
                //学生直接级联专业
                vm.selectedStuSpecialty = {id: gradeSpecialtyIdsArr[1]};
            }
            vm.changeApply.userName = selectedNames.join("、");
            vm.changeApply.ids = selectedIds;
            //关闭弹框
            closeStudentModal();
        }

        //操作类型
        function getOperate() {
            var operate;
            switch (vm.changeApplyType) {
                case "1":
                    operate = 1;
                    break;
                case "2":
                    operate = 3;
                    break;
                default:
                    operate = 2;
                    break;
            }
            return operate;
        }

        //监听
        var timeout;

        function changeFindStudent() {
            if (timeout) {
                clearTimeout(timeout);
            }
            //延迟500毫秒
            timeout = setTimeout(function () {
                findStudent();
            }, 500);
        }

        function findStudent() {
            var unusualChangeOperate = null;
            switch (vm.changeApplyType) {
                case '2':
                    unusualChangeOperate = '3';
                    break;
                case '3':
                case '4':
                    unusualChangeOperate = '2';
                    break;
                default:
                    unusualChangeOperate = vm.changeApplyType;
            }
            var param = {
                userType: 2,
                //异动操作类型  1：表示班级变更异动，2：休学复学异动，3：转退异动添加
                unusualChangeOperate: unusualChangeOperate,
                name: vm.studentName,
            };
            //休学、复学
            if (param.unusualChangeOperate === "2") {
                param.findType = vm.unusualChangeTypeObj.dictCode === "3" ? 1 : 2;
            }
            // 复学需要查询所有的非在读学生，所以就不需要传userType这个参数了
            if (vm.unusualChangeTypeObj.dictCode === '4') {
                delete param.userType;
            }
            $http.post(originBaseUrl + '/third/unusual/change/stu/find.htm?version=V1.0', param).then(function (response) {
                vm.studentList = response.data.result.content;
                if (vm.changeApply.ids.length) {
                    //回填已选数据
                    angular.forEach(vm.studentList, function (value) {
                        if (vm.changeApply.ids.indexOf(value.id) !== -1) {
                            value.checked = true;
                        }
                    });
                }
                setTimeout(function () {
                    $scope.$apply();
                })
            });
        }

        /*行政班*/
        vm.openClassModal = openClassModal;
        vm.filterClass = filterClass;
        vm.enterClass = enterClass;
        $ionicModal.fromTemplateUrl('classModal.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.classModal = modal;
        });

        function openClassModal() {
            vm.classModal.show();
            //查询数据
            findClass();
        }

        function closeClassModal() {
            vm.classModal.hide();
        }

        function enterClass(item, update) {
            vm.changeApply.afterPlatformSysAdminClassId = item.id;
            vm.changeApply.afterPlatformSysAdminClassName = item.name;
            vm.changeApply.afterPlatformSysOrgOrgNo = item.platformSysOrgNo;
            vm.changeApply.afterPlatformSysOrgName = item.orgName;
            //年级
            clickGradeItem(item.platformSysGrade, true);
            //专业
            vm.specialty = null;
            vm.specialtyList = [];
            angular.forEach(item.specialtyList, function (major) {
                vm.specialtyList.push(major.platformSysSpecialty);
            });
            if (vm.selectedStuSpecialty && vm.disabledGradeSpecailty) {
                //转班特殊业务
                clickSpecialtyItem(vm.selectedStuSpecialty);
            } else
            //只有一个专业，默认回填
            if (vm.specialtyList.length === 1 && !update) {
                clickSpecialtyItem(vm.specialtyList[0]);
            }
            //关闭弹框
            closeClassModal();
        }

        //前端过滤
        function filterClass() {
            if (!vm.className) {
                vm.classList = angular.copy(vm.classAllList);
                return false;
            }
            vm.classList = vm.classAllList.filter(function (item) {
                return item.name.indexOf(vm.className) !== -1;
            });
        }

        function getSpecialtyId() {
            if(!vm.unusualChangeTypeObj){
                return null;
            }
            if(vm.unusualChangeTypeObj.dictCode !== "10"){
                return null;
            }
            if(vm.specialty){
                return vm.specialty.id;
            }
            if(vm.selectedStuSpecialty){
                return vm.selectedStuSpecialty.id;
            }
            return null;
        }

        //查询
        function findClass() {
            var param = {
                gradeId: vm.grade ? vm.grade.id : null,
                // 复学异动只查询自己管理的班级
                teacher: vm.unusualChangeTypeObj && vm.unusualChangeTypeObj.dictCode === "4",
                // 转班只能查询同专业的班级
                // 取学生的第一个专业是因为转班只能选择相同专业的人一起转
                specialityId: getSpecialtyId()
            };
            return $http.post(originBaseUrl + '/third/unusual/change/classinfo/find.htm?version=V1.0', param).then(function (response) {
                vm.classAllList = response.data.result;
                filterClass();
                setTimeout(function () {
                    $scope.$apply();
                })
                return vm.classAllList;
            });
        }
    }

    //添加学生升学
    updateLevelApplyCtrl.$inject = ['$scope', '$location', '$http', 'ynuiNotification', '$ionicPopup', '$ionicModal', 'ynNavigator'];

    function updateLevelApplyCtrl($scope, $location, $http, ynuiNotification, $ionicPopup, $ionicModal, ynNavigator) {
        var vm = $scope.vm = this;
        vm.id = $location.search().id;
        //初始化数据
        initParams();

        vm.searchSpecialtyFun = searchSpecialtyFun;
        vm.clickGradeItem = clickGradeItem;
        vm.clickSpecialtyItem = clickSpecialtyItem;
        //高等职业教育的层次的行政班
        vm.searchAdminClassFun = searchAdminClassFun;
        //查询学生
        vm.searchConditionStudent = searchStudent;
        vm.searchConditionAdminClass = searchConditionAdminClass;
        vm.submit = submit;
        //修改数据
        if (vm.id) {
            $http.post(originBaseUrl + '/third/level/stu/query/stuUpdateInfo.htm'
                , {id: vm.id}).success(function (data) {
                if (data.status === 0) {
                    var result = data.result;
                    vm.changeApply = {
                        id: result.id,
                        gradeId: result.gradeId,
                        className: "",
                        name: "",
                        userName: result.studentName,
                        adminClassId: result.adminClassId,
                        //升学的专业方向
                        platformSysSpecialtyId: result.platformSysSpecialtyId,
                        studentIds: result.studentIds,
                        reason: result.reason,
                    };
                    vm.studentMap = {};
                    vm.adminClass = {};
                    vm.grade = {};
                    vm.specialty = {};
                    //初始化年级
                    selectObject(vm.gradeList, vm.changeApply.gradeId, "grade");
                    //初始化班级
                    searchAdminClassFun(true);
                    //查询专业
                    searchSpecialtyFun(true);
                } else {
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        //查询行政班
        function searchAdminClassFun(init) {
            $http.post(originBaseUrl + '/third/level/stu/query/class.htm', {
                className: vm.changeApply.className,
                gradeId: vm.changeApply.gradeId
            }).success(function (data) {
                if (data.status === 0) {
                    vm.adminClassList = data.result;
                    //初始化
                    if (init) {
                        selectObject(vm.adminClassList, vm.changeApply.adminClassId, "adminClass");
                    }
                }
            });
        }

        function searchConditionAdminClass() {
            var timeout;
            if (timeout) {
                clearTimeout(timeout);
            }
            timeout = window.setTimeout(function () {
                searchAdminClassFun();
            }, 500);
        }

        //查询专业
        function searchSpecialtyFun(init) {
            //专业
            $http.post(originBaseUrl + '/third/level/stu/query/specialty.htm', {adminClassId: vm.changeApply.adminClassId}).success(function (data) {
                if (data.status === 0) {
                    vm.specialtyList = data.result;
                    if (init) {
                        selectObject(vm.specialtyList, vm.changeApply.platformSysSpecialtyId, "specialty", "specialtyId");
                        return;
                    }
                    if (vm.specialtyList && vm.specialtyList.length == 1) {
                        vm.changeApply.platformSysSpecialtyId = vm.specialtyList[0].specialtyId;
                        vm.specialty = vm.specialtyList[0];
                        vm.specialty.checked = true;
                    }
                }
            });
        }

        vm.gradeList = [];
        vm.specialtyList = [];
        vm.adminClassList = [];
        vm.studentInfoList = [];

        //初始化参数
        function initParams() {
            vm.changeApply = {
                gradeId: "",
                className: "",
                name: "",
                adminClassId: "",
                //升学的专业方向
                platformSysSpecialtyId: "",
                studentIds: [],
                reason: "",
            };
            vm.studentMap = {};
            vm.adminClass = {};
            vm.grade = {};
            vm.specialty = {};
            //年级
            $http.get(originBaseUrl + '/third/grade/list.htm').success(function (data) {
                if (data.status === 0) {
                    vm.gradeList = data.result;
                }
            });
        }

        initParams();

        function selectObject(objectList, selectId, property, key) {
            key = !key ? "id" : key;
            angular.forEach(objectList, function (value) {
                value.checked = false;
                if (angular.equals(selectId, value[key])) {
                    value.checked = true;
                    vm[property] = value;
                }
            });
        }

        //年级
        function clickGradeItem(item) {
            var tempGradeId = vm.changeApply.gradeId;
            angular.forEach(vm.gradeList, function (value) {
                value.checked = false;
                if (angular.equals(item.id, value.id)) {
                    value.checked = true;
                    vm.grade = value;
                    vm.changeApply.gradeId = vm.grade.id;
                }
            });
            //如果选择的年级不相等重置班级
            if (tempGradeId != vm.changeApply.gradeId) {
                vm.adminClass = {};
                vm.changeApply.adminClassId = "";
                vm.specialty = {};
                vm.changeApply.platformSysSpecialtyId = "";
            }
            searchAdminClassFun()
        }

        //专业
        function clickSpecialtyItem(item) {
            angular.forEach(vm.specialtyList, function (value) {
                value.checked = false;
                if (item.specialtyId == value.specialtyId) {
                    value.checked = true;
                    vm.specialty = value;
                    vm.changeApply.platformSysSpecialtyId = value.specialtyId;
                }
            });
        }

        //保存数据
        function submit() {
            //验证必填
            if (validationForm()) {
                return false;
            }
            $ionicPopup.confirm({
                title: '提示',
                template: '您正在对 <span class="text-danger">' + vm.changeApply.userName + '</span> 发起升学申请，升学后的行政班为 <span class="text-danger">' + vm.adminClass.name + '</span> ，请确认！',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    //保存数据
                    $http.post(originBaseUrl + '/third/level/stu/save/info.htm', getParam()).success(function (data) {
                        if (data.status == 0) {
                            if (data.result && data.result.length > 0) {
                                var message = "";
                                angular.forEach(data.result, function (item) {
                                    if (message) {
                                        message = "；";
                                    }
                                    message += item;
                                });
                                ynuiNotification.error({msg: message});
                            } else {
                                ynuiNotification.success({msg: "保存成功！"});
                                if (vm.id) {
                                    //强制返回上一级
                                    ynNavigator.pop(true);
                                    setTimeout(function () {
                                        $scope.$apply();
                                    });
                                    return false;
                                }
                                //重置参数
                                initParams();
                            }

                        } else {
                            ynuiNotification.error({msg: data.message});
                        }
                    });
                }
            });
        }

        //验证必填
        function validationForm() {
            if (!vm.changeApply.studentIds || vm.changeApply.studentIds.length === 0) {
                ynuiNotification.error({msg: "请选升学的学生！"});
                return true;
            }
            if (!vm.changeApply.gradeId) {
                ynuiNotification.error({msg: "请选年级！"});
                return true;
            }
            if (!vm.changeApply.adminClassId) {
                ynuiNotification.error({msg: "请选择行政班！"});
                return true;
            }
            if (!vm.changeApply.platformSysSpecialtyId) {
                ynuiNotification.error({msg: "请选择专业方向！"});
                return true;
            }
            return false;
        }

        //组装保存参数
        function getParam() {
            var param = {
                studentIds: vm.changeApply.studentIds,
                id: vm.changeApply.id,
                adminClassId: vm.changeApply.adminClassId,
                platformSysSpecialtyId: vm.changeApply.platformSysSpecialtyId,
                reason: vm.changeApply.reason
            };
            return parseParamForSpringMVC(param)
        }

        /*******************************模态框相关************************************/
        /*学生*/
        vm.openStudentModal = openStudentModal;
        vm.findStudent = findStudent;


        function searchStudent() {
            var timeout;
            if (timeout) {
                clearTimeout(timeout);
            }
            timeout = window.setTimeout(function () {
                findStudent();
            }, 500);
        }

        vm.enterStudent = enterStudent;
        $ionicModal.fromTemplateUrl('studentModal.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.studentModal = modal;
        });

        function openStudentModal() {
            findStudent();
            vm.changeApply.name = "";
            vm.studentModal.show();
        }

        function closeStudentModal() {
            vm.studentModal.hide();
        }

        function enterStudent() {
            var selectedIds = [];
            var selectedNames = [];
            var studentMap = {};
            angular.forEach(vm.studentInfoList, function (item) {
                if (item.checked) {
                    selectedIds.push(item.userId);
                    selectedNames.push(item.name);
                    studentMap[item.userId] = true;
                }
            });
            //无数据
            if (!selectedIds.length) {
                ynuiNotification.error({msg: "请选升学的学生！"});
                return;
            }
            vm.changeApply.userName = selectedNames.join("、");
            vm.changeApply.studentIds = selectedIds;
            vm.studentMap = studentMap;
            //关闭弹框
            closeStudentModal();
        }

        //查询班主任管理的在读学生
        function findStudent() {
            $http.post(originBaseUrl + '/third/level/stu/query/studentInfo.htm', {name: vm.changeApply.name}).success(function (data) {
                if (data.status === 0) {
                    vm.studentInfoList = data.result;
                    angular.forEach(vm.studentInfoList, function (item) {
                        item.checked = vm.studentMap[item.userId]
                    });
                }
            });
        }

        /*行政班*/
        vm.openClassModal = openClassModal;
        vm.enterClass = enterClass;
        $ionicModal.fromTemplateUrl('classModal.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.classModal = modal;
        });

        function openClassModal() {
            vm.classModal.show();
            vm.changeApply.className = "";
            //查询数据
            searchAdminClassFun();
        }

        function closeClassModal() {
            vm.classModal.hide();
        }

        function enterClass(item) {
            vm.adminClass = item;
            vm.changeApply.adminClassId = item.id;
            angular.forEach(vm.gradeList, function (grade) {
                grade.checked = false;
                if (grade.id == item.gradeId) {
                    vm.grade = grade;
                    vm.changeApply.gradeId = vm.grade.id;
                    grade.checked = true;
                }
            });
            //专业查询
            searchSpecialtyFun();
            vm.changeApply.platformSysSpecialtyId = "";
            vm.specialty = {};
            //关闭弹框
            closeClassModal();
        }
    }

    listCtrl.$inject = ['$scope', '$http', '$ionicScrollDelegate', '$ionicPopup', 'ynuiNotification', '$location'];

    function listCtrl($scope, $http, $ionicScrollDelegate, $ionicPopup, ynuiNotification, $location) {
        var vm = this;

        vm.loadMoreData = loadMoreData;
        vm.showGenderAndNumber = showGenderAndNumber;
        vm.selectClass = selectClass;
        vm.selectOtherParams = selectOtherParams;
        vm.editData = editData;
        vm.deleteData = deleteData;
        vm.toViewPage = toViewPage;

        vm.conditions = {
            name: null,
            classIds: [],
            checkStatus: null,
            unusualChangeType: null
            // unusualChangeTypes: ['1', '10', '7', '3', '4', 'other']
        };
        vm.readyForSearch = false;
        vm.classList = [];
        vm.checkStatusList = [
            {id: null, value: "全部"},
            {id: 0, value: '待审核'},
            {id: 1, value: '通过'},
            {id: 2, value: '不通过'}
        ];
        vm.unusualChangeTypeList = [
            {dictCode: null, dictName: "全部"}
        ];
        vm.pageInfo = {
            pageSize: 20,
            pageNumber: -1
        };
        vm.dataList = [];

        getUnusualChangeTypeList();
        getClassList().then(function () {
            // 加载了班级才刷新列表
            vm.moreDataCanBeLoaded = true;
        });

        function getClassList() {
            return $http.get(originBaseUrl + '/third/unusual/change/classinfo/find.htm', {
                params: {
                    teacher: true,
                    version: 'V1.0'
                }
            }).success(function (data) {
                if (data.status === 0) {
                    vm.classList = data.result;
                    if (vm.classList.length > 0) {
                        vm.conditions.classIds.push(vm.classList[0].id);
                    }
                }
                return data;
            });
        }

        function getUnusualChangeTypeList() {
            return $http.get(originBaseUrl + '/third/tkMobile/queryDictionaryByKey.htm', {
                params: {
                    key: "UNUSUAL_CHANGE_TYPE"
                }
            }).success(function (data) {
                if (data.status === 0) {
                    vm.unusualChangeTypeList = vm.unusualChangeTypeList
                      .concat(data.result)
                      .concat([{dictCode: 'other', dictName: '升学'}]);
                }
            });
        }

        function findByConditions(params) {
            return $http.post(originBaseUrl + '/third/unusual/change/find/page.htm', params)
                .success(function (data) {
                    return data;
                });
        }

        function loadMoreData(init) {
            var obj = angular.copy(vm.conditions);
            if (obj.unusualChangeType) {
                obj.unusualChangeTypes = [];
            } else {
                obj.unusualChangeTypes = [];
                angular.forEach(vm.unusualChangeTypeList, function (t) {
                    if (t.dictCode) {
                        obj.unusualChangeTypes.push(t.dictCode);
                    }
                });
            }
            // 获取数据
            if (init) {
                obj.pageNumber = vm.pageInfo.pageNumber = -1;
            }
            obj.pageNumber = vm.pageInfo.pageNumber += 1;
            obj.pageSize = vm.pageInfo.pageSize;
            findByConditions(obj).success(function (data) {
                if (data.status === 0) {
                    if (init || null == vm.dataList) {
                        vm.dataList = data.result.content;
                        $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                    } else {
                        vm.dataList = vm.dataList.concat(data.result.content);
                    }
                    // 最后一页
                    vm.moreDataCanBeLoaded = !data.result.lastPage;
                } else {
                    // 报错，不能拉数据
                    vm.moreDataCanBeLoaded = false;
                    vm.dataList = [];
                    vm.countData = null;
                }
            }).error(function () {
                // 报错，不能拉数据
                vm.moreDataCanBeLoaded = false;
                vm.dataList = [];
                vm.countData = null;
            }).finally(function () {
                $scope.$broadcast('scroll.refreshComplete');
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        }

        function showGenderAndNumber(data) {
            var arr = [];
            if (data.gender) {
                arr.push(data.gender);
            }
            if (data.number) {
                arr.push(data.number);
            }
            if (arr.length > 0) {
                return "（" + arr.join("，") + "）";
            }
            return "";
        }

        function selectClass(clazz) {
            vm.conditions.classIds = [];
            vm.conditions.classIds.push(clazz.id);
            // 刷新
            loadMoreData(true);
        }

        function selectOtherParams(data, dataKey, paramsKey) {
            vm[paramsKey+"SelectDate"] = angular.copy(data);
            vm.conditions[paramsKey] = data[dataKey];
            loadMoreData(true);
        }

        function editData(data, event) {
            event.stopPropagation();
            if (data.checkStatus !== '0') {
                $ionicPopup.alert({
                    title: '提示',
                    template: '该申请已经过审核，不能修改！',
                    okText: '确定'
                });
            } else {
                // to edit page
                if (data.unusualChangeTypeName === '升学') {
                    $location.path('/updateLevelApplyUpdate').search({ id: data.id});
                } else {
                    $location.path('/changeSchoolRollApplyUpdate').search({ id: data.id});
                }
            }
        }

        function deleteData(data, event) {
            event.stopPropagation();
            if (data.checkStatus === '1') {
                $ionicPopup.alert({
                    title: '提示',
                    template: '该申请已经审核通过，不能删除！',
                    okText: '确定'
                });
            } else {
                var confirmPopup = $ionicPopup.confirm({
                    title: "提示",
                    template: "确定要删除所选吗？",
                    cancelText: "取消",
                    okText: "确定"
                });
                confirmPopup.then(function (confirm) {
                    if (confirm) {
                        // 没有值是代表升学记录
                        if (data.unusualChangeTypeName !== "升学") {
                            doDelete(data.id).then(function () {
                                ynuiNotification.success({msg: "删除成功！"});
                                // 刷新数据
                                loadMoreData(true);
                            });
                        } else {
                            doDeleteStuUpdateLevel(data.id).then(function () {
                                ynuiNotification.success({msg: "删除成功！"});
                                // 刷新数据
                                loadMoreData(true);
                            });
                        }
                    }
                });
            }
        }

        function doDelete(id) {
            return $http.post(originBaseUrl + '/third/unusual/change/delete.htm', {
                ids: [id]
            }).success(function (data) {
                return data;
            });
        }

        function doDeleteStuUpdateLevel(id) {
            return $http.post(originBaseUrl + '/third/unusual/change/delete/level.htm', {
                ids: [id]
            }).success(function (data) {
                return data;
            });
        }

        function toViewPage(data) {
            if (null == data) {
                return;
            }
            $location.path('/stu_unusual_change_info').search({ id: data.id,unusualChangeType: data.unusualChangeType });
        }
    }

    // 学生异动信息
    stuUnusualChangeInfoCtr.$inject = ['$scope', '$http', '$location'];

    function stuUnusualChangeInfoCtr($scope, $http, $location) {
        $scope.type = $location.search().unusualChangeType;
        var params = {
            id: $location.search().id
        };
        function findStuChange() {
            if ($scope.type === "other") {
                return $http.post(originBaseUrl + '/third/level/stu/query/changeInfo.htm', params).success(function (data) {
                    if (0 === data.status) {
                        $scope.change = data.result;
                    }
                });
            } else {
                return $http.post(originBaseUrl + '/third/xj/stu/info/changeInfo.htm', params).success(function (data) {
                    if (0 === data.status) {
                        $scope.change = data.result;
                    }
                });
            }
        }
        findStuChange();
    }
})();
