(function () {
  'use strict';

  angular
    .module('starter')
    .config(config)
    .controller('courseReplaceForStuCtrl', listCtrl)
    .controller('courseReplaceEditForStuCtrl', editCtrl)
    .controller('courseReplaceViewCtrl', viewCtrl)
    .directive('selectedCourse', selectedCourse)
  ;

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      // 列表
      .state('courseReplaceForStu', {
        firstPage: true,
        url: '/courseReplaceForStu',
        templateUrl: 'templates/cjstu/coursereplace/index.html',
        controller: 'courseReplaceForStuCtrl',
        controllerAs: 'vm',
        data: {
          title: '申请置换',
          prev: 'achievementworkspace',
        }
      })
      // 编辑
      .state('courseReplaceEditForStu', {
        url: '/courseReplaceEditForStu?id',
        templateUrl: 'templates/cjstu/coursereplace/edit.html',
        controller: 'courseReplaceEditForStuCtrl',
        controllerAs: 'vm',
        data: {
          title: '申请置换',
          prev: 'courseReplaceForStu'
        }
      })
    ;
  }

  listCtrl.$inject = ['$scope', '$http', '$state', '$location', '$ionicPopup'];

  /**
   * 列表页面
   */
  function listCtrl($scope, $http, $state, $location, $ionicPopup) {
    var vm = this;

    // 查询条件
    vm.condition = {
      pageNumber: -1,
      pageSize: 10
    };

    vm.replaceList = [];
    vm.pageData = {};
    // init();

    vm.loadMore = loadMore;
    vm.toEditPage = toEditPage;
    vm.toViewPage = toViewPage;
    vm.modify = modify;
    vm.doDelete = doDelete;

    /**
     * 查询申请
     * @returns {*}
     */
    function queryCourseReplaceByStu(next) {
      return $http.post(originBaseUrl + '/third/cj/coursereplace/list.htm', {
        pageSize: vm.condition.pageSize,
        pageNumber: vm.condition.pageNumber
      }).success(function (data) {
        if (data.status === 0) {
          vm.pageData = data.result;
          handlePageData(vm.pageData.content);
          if (next) {
            vm.replaceList = vm.replaceList.concat(vm.pageData.content);
          } else {
            vm.replaceList = vm.pageData.content;
          }
        } else {
          vm.pageData = null;
        }
      }).error(function () {
        vm.pageData = null;
      }).finally(function () {
        $scope.$broadcast('scroll.infiniteScrollComplete');
      });
    }

    function loadMore() {
      vm.condition.pageNumber += 1;
      queryCourseReplaceByStu(true);
    }

    function handlePageData(list) {
      angular.forEach(list, function (value) {
        var outCourseNames = [];
        var inCourseNames = [];
        // 培养方案外的课程
        angular.forEach(value.outCoursePlanList, function (oc) {
          outCourseNames.push(oc.outCourseName);
          // 培养方案内的课程
          angular.forEach(oc.inReplaceCourseVOList, function (ic) {
            inCourseNames.push(ic.inCourseName);
          });
        });
        value.outCourseNames = handleCourseNames(outCourseNames);
        value.inCourseNames = handleCourseNames(inCourseNames);
      });

      function handleCourseNames(courseNames) {
        var length = courseNames.length;
        if (courseNames.length > 4) {
          courseNames.splice(4, courseNames.length - 4);
          return courseNames.join("、") + '等' + length + '门课程';
        }
        return courseNames.join("、");
      }
    }

    function toEditPage() {
      $state.go('courseReplaceEditForStu');
    }

    function toViewPage(obj) {
      if (obj.lcBusinessId) {
        $location.path("/askforleave").search({
          "fromType": 0, "procInstId": obj.lcBusinessId, "fromBusiness": 1, state: $state.current.name
        });
      } else {
        $ionicPopup.alert({
          title: '提示',
          template: '管理员提交的置换申请无法查看流程！',
          okText: '确定'
        });
      }
    }

    function modify(item, e) {
      if (e) {
        e.stopPropagation();
      }
      $state.go('courseReplaceEditForStu', {id: item.id});
    }

    function deleteCourseReplace(id) {
      return $http.post(originBaseUrl + '/third/cj/coursereplace/delete.htm', {
        replacementId: id
      }).success(function (data) {
        return data;
      })
    }

    function doDelete(item, e) {
      if (e) {
        e.stopPropagation();
      }
      var confirmPopup = $ionicPopup.confirm({
        title: "提示",
        template: "确定要删除所选吗？",
        cancelText: "取消",
        okText: "确定"
      });
      confirmPopup.then(function(res) {
        if (res) {
          deleteCourseReplace(item.id).success(function (data) {
            if (data.status === 0 && null == data.result) {
              $ionicPopup.alert({
                title: '提示',
                template: '删除成功！',
                okText: '确定'
              });
              queryCourseReplaceByStu(false);
            } else {
              $ionicPopup.alert({
                title: '提示',
                template: '删除失败！' + data.result.failedReason,
                okText: '确定'
              });
            }
          });
        }
      });
    }
  }

  editCtrl.$inject = ['$scope', '$http', '$state', '$stateParams', '$ionicModal', '$ionicPopup', 'ynNavigator'];

  /**
   * 编辑页面
   */
  function editCtrl($scope, $http, $state, $stateParams, $ionicModal, $ionicPopup, ynNavigator) {
    var vm = this;

    // 修改会有id
    var id = $stateParams.id
    if (id) {
      vm.modifyFlag = true;
    }

    vm.replaceConfig = null;
    vm.stuInfo = null;
    vm.courses = [];
    vm.selectedReason = null;
    vm.saveList = [];

    vm.queryCourse = queryCourse;
    vm.selectReason = selectReason;
    vm.clickReason = clickReason;
    vm.apply = apply;
    vm.toSelf = toSelf;
    vm.isShowToSelfButton = isShowToSelfButton;
    vm.deleteReplaceCourse = deleteReplaceCourse;
    vm.selectedCourseFun = selectedCourseFun;
    vm.nextStep = nextStep;
    vm.closeReasonModal = closeReasonModal;
    vm.doSave = doSave;

    findReason().success(function () {
      findReplaceConfig();
      init();
    });

    function init() {
      if (id) {
        ynNavigator.setNavTitle('修改置换申请');
        findCourseReplace(id).success(function () {
          handleCourseInfo(vm.courses);
          angular.forEach(vm.courses, function (c) {
            handleCourseInfo(c.replaceCourseList);
          });
          // 选中原因
          angular.forEach(vm.reasons, function (r) {
            if (vm.stuInfo.reasonType + '' === r.dictCode) {
              vm.selectedReason = r;
            }
          });
          vm.saveList = vm.courses;
        });
      } else {
        ynNavigator.setNavTitle('添加置换申请');
        queryCourse().success(function () {
          handleCourseInfo(vm.courses);
        });
      }
    }

    function findReplaceConfig() {
      return $http.get(originBaseUrl + '/third/cj/coursereplace/findReplaceConfig.htm', {
        params: {type: 1}
      }).success(function (data) {
        if (data.status === 0) {
          vm.replaceConfig = data.result;
        }
      });
    }

    function findCourseReplace(id) {
      return $http.get(originBaseUrl + '/third/cj/coursereplace/' + id + '.htm').success(function (data) {
        if (data.status === 0) {
          // vm.courseReplace = data.result;
          vm.stuInfo = data.result;
          vm.courses = data.result.outCoursePlanList;
        }
      });
    }

    /**
     * 查询学生可以置换的课程
     * @returns {*}
     */
    function queryCourse() {
      return $http.get(originBaseUrl + '/third/cj/coursereplace/course/list.htm').success(function (data) {
        if (data.status === 0) {
          vm.stuInfo = data.result;
          vm.courses = data.result.outCoursePlanList;
        }
        return data;
      });
    }

    function findReason() {
      return $http.get(originBaseUrl + '/third/cj/coursereplace/findReplaceReason.htm').success(function (data) {
        if (data.status === 0) {
          vm.reasons = data.result;
          var rows = (vm.reasons.length / 3).toFixed(1);
          vm.reasonRows = [];
          for (var i = 0; i < rows; i++) {
            vm.reasonRows.push(i + 1);
          }
        }
        return data;
      });
    }

    function selectReason() {
      if (null == vm.selectedReasonModal) {
        $ionicModal.fromTemplateUrl('replace_reason.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function (modal) {
          vm.selectedReasonModal = modal;
          vm.selectedReasonModal.show();
        });
      } else {
        vm.selectedReasonModal.show();
      }
    }

    function clickReason(reason) {
      vm.selectedReason = reason;
      // vm.selectedReasonModal.hide();
    }

    function apply(course) {
      vm.course = course;
      if (null != course && course.replaceCourseList && course.replaceCourseList.length > 0) {
        vm.replaceCourse = course.replaceCourseList[0];
      }
      if (null == vm.selectedCourseModal) {
        $ionicModal.fromTemplateUrl('select_course.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function (modal) {
          vm.selectedCourseModal = modal;
          vm.selectedCourseModal.show();
        });
      } else {
        vm.selectedCourseModal.show();
      }
    }

    function toSelf(course) {
      vm.course = course;
      // 换成任意选修课
      var selectedCourse = angular.copy(course);
      selectedCourse.electiveType = 3;
      selectedCourse.replacePlanFinalId = course.replaceOutPlanFinalId;
      var msg = check(selectedCourse);
      if ('' !== msg) {
        $ionicPopup.alert({
          title: '提示',
          template: msg,
          okText: '确定'
        });
        return;
      }
      if (id) {
        selectedCourse.id = vm.course.replaceCourseList[0].id;
      }
      vm.course.replaceCourseList = [];
      vm.course.replaceCourseList.push(selectedCourse);
      // 把数据添加进保存队列里
      addToSaveList();
    }

    function deleteReplaceCourse(course) {
      var confirmPopup = $ionicPopup.confirm({
        title: "提示",
        template: "确定要删除所选吗？",
        cancelText: "取消",
        okText: "确定"
      });
      confirmPopup.then(function(res) {
        if (res) {
          course.replaceCourseList = [];
          // 移出保存列表
          var index = null;
          angular.forEach(vm.saveList, function (value, key) {
            if (course.id === value.id) {
              index = key;
            }
          });
          if (null != index) {
            vm.saveList.splice(index, 1);
          }
        }
      });
    }

    function isShowToSelfButton(course) {
      if (null != course.electiveType && course.electiveType === 1) {
        // 判断必修课是否显示作为任意选修按钮
        if (vm.replaceConfig.compulsoryReplace && vm.replaceConfig.compulsoryReplace.indexOf(3) >= 0) {
          return true;
        }
        return false;
      } else if (null != course.electiveType && course.electiveType !== 1) {
        // 判断必修课是否显示作为任意选修按钮
        if (vm.replaceConfig.electiveReplace && vm.replaceConfig.electiveReplace.indexOf(3) >= 0) {
          return true;
        }
        return false;
      }
    }

    function check(course) {
      var msg = '';
      // 必修课
      if (null != vm.course.electiveType && vm.course.electiveType === 1) {
        // 判断必修课可以置换的课程
        if (vm.replaceConfig.compulsoryReplace && vm.replaceConfig.compulsoryReplace.indexOf(course.electiveType) === -1) {
          msg = '必修课只能置换成' + getElectiveTypeNames(vm.replaceConfig.compulsoryReplace) + '课！';
        }
      }
      // 选修课
      if (null != vm.course.electiveType && vm.course.electiveType !== 1) {
        if (vm.replaceConfig.electiveReplace && vm.replaceConfig.electiveReplace.indexOf(course.electiveType) === -1) {
          msg = '指定选修课只能置换成' + getElectiveTypeNames(vm.replaceConfig.electiveReplace) + '课！';
        }
      }
      // 低学分不允许置换高学分
      if (!vm.replaceConfig.lowReplaceHigh && vm.course.credit < course.credit) {
        msg = '低学分课程不能置换高学分课程！';
      }
      return msg;
    }

    function addToSaveList() {
      // 把数据添加进保存队列里
      var index = null;
      if (vm.saveList.length > 0) {
        angular.forEach(vm.saveList, function (s, i) {
          if (s.replaceOutPlanFinalId === vm.course.replaceOutPlanFinalId) {
            index = i;
          }
        });
      }
      if (null == index) {
        vm.saveList.push(vm.course);
      } else {
        vm.saveList.splice(index, 1, vm.course);
      }
      vm.course = null;
      vm.replaceCourse = null;
    }

    function selectedCourseFun(course) {
      // 验证规则
      var msg = check(course);
      // 判断是否已经被选择了
      angular.forEach(vm.courses, function (d) {
        if (d.replaceCourseList && d.replaceCourseList.length > 0 && d.replaceCourseList[0].id === course.id) {
          msg = '所选课程“' + course.courseName + '”已经置换';
        }
      });
      if ('' !== msg) {
        $ionicPopup.alert({
          title: '提示',
          template: msg,
          okText: '确定'
        });
        return;
      }
      vm.selectedCourseModal.hide().then(function () {
        vm.selectedCourseModal.remove();
        vm.selectedCourseModal = null;
        if (id) {
          // 修改copy id
          course.id = vm.course.replaceCourseList[0].id;
        }
        vm.course.replaceCourseList = [];
        vm.course.replaceCourseList.push(course);
        // 把数据添加进保存队列里
        addToSaveList();
      });
    }

    function getElectiveTypeNames(types) {
      if (!types) {
        return;
      }
      var electiveType = {
        '1': '必修', '2': '指定选修', '3': '任意选修'
      };
      var names = [];
      angular.forEach(types.split(','), function (type) {
        names.push('“' + electiveType[type] + '”');
      });
      return names.join('、');
    }

    function save(obj) {
      return $http.post(originBaseUrl + '/third/cj/coursereplace/save.htm', obj).success(function (data) {
        return data;
      });
    }

    function nextStep() {
      if (vm.saveList.length === 0) {
        $ionicPopup.alert({
          title: '提示',
          template: '没有需要提交的置换申请！',
          okText: '确定'
        });
        return;
      }
      selectReason();
    }

    function closeReasonModal(remove) {
      vm.selectedReasonModal.hide();
      if (remove) {
        vm.selectedReasonModal.remove();
      }
    }

    function doSave() {
      if (null == vm.selectedReason) {
        $ionicPopup.alert({
          title: '提示',
          template: '请选择置换原因！',
          okText: '确定'
        });
        return;
      }
      closeReasonModal();
      // 修改需要把子表的id到新的子表vo上去
      // 因为修改的时候只会有一条数据
      if (id) {
        vm.saveList[0].replaceCourseList[0].id = vm.stuInfo.outCoursePlanList[0].replaceCourseList[0].id;
      } else {
        angular.forEach(vm.saveList, function (c) {
          delete c.replaceCourseList[0].id;
          delete c.replaceCourseList[0].startDate;
        });
      }
      var params = {
        id: id,
        coursePlanTeachingAdminClassId: vm.stuInfo.coursePlanTeachingAdminClassId,
        reasonType: vm.selectedReason.dictCode,
        cjCourseReplaceList: angular.copy(vm.saveList)
      };
      save(parseParamForSpringMVC(params)).success(function (data) {
        if (data.status === 0) {
          if (null == data.result) {
            $ionicPopup.alert({
              title: '提示',
              template: '提交成功',
              okText: '确定'
            });
            // 查新查询列表
            // vm.queryCourse();
            $state.go('courseReplaceForStu');
          } else {
            $ionicPopup.alert({
              title: '提示',
              template: data.result.failedReason,
              okText: '确定'
            });
          }
        } else {
          $ionicPopup.alert({
            title: '提示',
            template: data.message,
            okText: '确定'
          });
        }
      });
    }

  }

  viewCtrl.$inject = ['$scope', '$http'];

  /**
   * 查看页面
   */
  function viewCtrl($scope, $http) {
    var vm = this;

    vm.courseReplace = null;

    findCourseReplace($scope.lcFormInfoVO.businessKey).success(function () {
      handleCourseInfo(vm.courseReplace.outCoursePlanList);
      angular.forEach(vm.courseReplace.outCoursePlanList, function (c) {
        handleCourseInfo(c.replaceCourseList);
      });
    });

    function findCourseReplace(id) {
      return $http.get(originBaseUrl + '/third/cj/coursereplace/' + id + '.htm').success(function (data) {
        if (data.status === 0) {
          vm.courseReplace = data.result;
        }
      });
    }
  }

  /**
   * 选择课程组件
   */
  function selectedCourse() {
    var config = {
      restrict: 'E',
      templateUrl: 'templates/cjstu/coursereplace/selectedCourse.html',
      scope: {
        course: '=',
        callBackFun: '='
      },
      link: link,
      controller: ctrl,
      controllerAs: 'vm',
      bindToController: true
    };

    function link() {

    }

    ctrl.$inject = ['$scope', '$http', '$ionicPopup'];

    function ctrl($scope, $http, $ionicPopup) {
      var vm = this;

      vm.conditions = {
        courseValue: null
      };

      // 1代表下拉，2代表输入课程名称、课程号模糊查询
      vm.searchType = 1;
      vm.selectedTerm = null;
      vm.terms = [];
      vm.selectedType = null;
      vm.electiveTypes = [
        {id: "1", name: "必修"},
        {id: "2", name: "指定选修"}
      ];
      vm.selectedCourse = null;
      vm.courses = [];

      vm.queryCourse = queryCourse;
      vm.selectTerm = selectTerm;
      vm.selectElectiveType = selectElectiveType;
      vm.selectCourse = selectCourse;
      vm.confirm = confirm;

      queryTerm();
      queryCourse().success(function () {
        // 如果有传默认值，要选中默认值
        if (vm.course) {
          angular.forEach(vm.courses, function (value) {
            if (vm.course.id === value.id) {
              vm.selectedCourse = value;
            }
          });
        }
      });

      function queryTerm() {
        return $http.get(originBaseUrl + '/third/cj/coursereplace/term/list.htm').success(function (data) {
          if (data.status === 0) {
            vm.terms = data.result;
          }
          return data;
        });
      }

      function queryCourse() {
        return $http.get(originBaseUrl + '/third/cj/coursereplace/plancourse/list.htm', {
          params: {
            termId: vm.selectedTerm ? vm.selectedTerm.id : null,
            electiveType: vm.selectedType ? vm.selectedType.id : null,
            courseValue: vm.conditions.courseValue
          }
        }).success(function (data) {
          if (data.status === 0) {
            vm.courses = data.result;
            handleCourseInfo(vm.courses);
          }
          return data;
        });
      }

      function selectTerm(term) {
        vm.selectedTerm = term;
        queryCourse();
      }

      function selectElectiveType(type) {
        vm.selectedType = type;
        queryCourse();
      }

      function selectCourse(course) {
        vm.selectedCourse = course;
      }

      function confirm() {
        if (null == vm.selectedCourse) {
          $ionicPopup.alert({
            title: '提示',
            template: '请选择课程！',
            okText: '确定'
          });
          return;
        }
        if (vm.callBackFun && angular.isFunction(vm.callBackFun)) {
          vm.callBackFun(vm.selectedCourse);
        }
      }
    }

    return config;
  }

  /**
   * 拼接课程信息
   * @param courses 课程
   */
  function handleCourseInfo(courses) {
    if (null == courses || courses.length === 0) {
      return;
    }
    angular.forEach(courses, function (course) {
      var info = [];
      if (course.electiveTypeName) {
        info.push(course.electiveTypeName + '课');
      }
      if (course.termTotalHour) {
        info.push(course.termTotalHour + '学时');
      }
      if (course.credit) {
        info.push(course.credit + '学分');
      }
      if (course.displayScore) {
        var score = parseFloat(course.displayScore);
        info.push(isNaN(score) ? course.displayScore : course.displayScore + '分');
      }
      course.info = info.join(' | ');
    });
  }
})();
