(function () {
  'use strict';

  angular
    .module('starter')
    .config(config)
    .controller('delayApplyCtrl', listCtrl)
    .controller('delayApplyEditCtrl', editCtrl)
    .controller('delayApplyViewCtrl', viewCtrl)
    .directive('selectedCourseByDelay', selectedCourse)
  ;

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      // 列表
      .state('delayApplyForStu', {
        firstPage: true,
        url: '/delayApplyForStu',
        templateUrl: 'templates/cjstu/delay/index.html',
        controller: 'delayApplyCtrl',
        controllerAs: 'vm',
        data: {
          title: '申请缓考',
          prev: 'achievementworkspace',
        }
      })
      // 编辑页面
      .state('delayApplyEditForStu', {
        url: '/delayApplyEditForStu?id',
        templateUrl: 'templates/cjstu/delay/edit.html',
        controller: 'delayApplyEditCtrl',
        controllerAs: 'vm',
        data: {
          title: '申请缓考',
          prev: 'delayApplyForStu'
        }
      })
    ;
  }

  listCtrl.$inject = ['$scope', '$http', '$state', '$location', '$ionicPopup']

  function listCtrl($scope, $http, $state, $location, $ionicPopup) {
    var vm = this;

    vm.changeTerm = changeTerm;
    vm.queryDelayApply = queryDelayApply;
    vm.loadMore = loadMore;
    vm.toEditPage = toEditPage;
    vm.toViewPage = toViewPage;
    vm.modify = modify;
    vm.doDelete = doDelete;

    vm.conditions = {
      termId: null,
      pageSize: 10,
      pageNumber: -1
    };

    vm.terms = [];
    vm.currentTerm = null;
    vm.selectedTerm = null;
    vm.delayList = [];
    vm.pageData = {};

    init();

    function init() {
      queryTerms().success(function () {
        vm.conditions.termId = vm.selectedTerm.id;
        // queryDelayApply();
      });
    }

    function queryTerms() {
      return $http.get(originBaseUrl + '/third/term/list.htm', {
        params: {
          asc: false
        }
      }).success(function (data) {
        if (data.status === 0) {
          vm.terms = data.result.termList;
          vm.currentTerm = data.result.currentTerm;
          vm.selectedTerm = data.result.currentTerm;
        } else {
          vm.terms = null;
        }
        return data;
      }).error(function () {
        vm.terms = null;
      });
    }

    function changeTerm(term) {
      vm.selectedTerm = term;
      vm.conditions.termId = term.id;
      queryDelayApply();
    }

    function queryDelayApply(next) {
      return $http.get(originBaseUrl + '/third/delay/list.htm', {
        params: {
          pageSize: vm.conditions.pageSize,
          pageNumber: vm.conditions.pageNumber,
          termId: vm.conditions.termId
        }
      }).success(function (data) {
        if (data.status === 0) {
          angular.forEach(data.result.content, function (value) {
            handleCourseInfo(value);
          });
          vm.pageData = data.result;
          if (next) {
            vm.delayList = vm.delayList.concat(data.result.content);
          } else {
            vm.delayList = data.result.content;
          }
        } else {
          vm.delayList = null;
          vm.pageData = null;
        }
        return data;
      }).error(function (error) {
        console.log(error);
        vm.delayList = null;
        vm.pageData = null;
      }).finally(function () {
        $scope.$broadcast('scroll.infiniteScrollComplete');
      });
    }

    function handleCourseInfo(obj) {
      var array = [];
      if (obj.teachPlatformSysUserNames) {
        array.push(obj.teachPlatformSysUserNames);
      }
      if (obj.courseCredit) {
        array.push(obj.courseCredit + '分');
      }
      if (obj.electiveTypeName) {
        array.push(obj.electiveTypeName);
      }
      if (obj.assessWayName) {
        array.push(obj.assessWayName);
      }
      if (array.length > 0) {
        obj.info = array.join(' | ');
      }
    }

    function toEditPage() {
      $http.get(originBaseUrl + '/third/delay/config/switch.htm', {
        params: {
          moduleCode: '66_4'
        }
      }).success(function (data) {
        var hasAuth = true;
        if (data.status === 0 && data.result && data.result.length > 0) {
          angular.forEach(data.result, function (r) {
            if (r.code === 'cj_s_delay_config') {
              hasAuth = r.isOpen;
            }
          });
        }
        if (hasAuth) {
          $state.go('delayApplyEditForStu');
        } else {
          $ionicPopup.alert({
            title: '提示',
            template: '当前不允许提交缓考申请，请联系管理员老师！',
            okText: '确定'
          });
        }
      }).error(function () {
        $state.go('delayApplyEditForStu');
      });
    }

    function toViewPage(obj) {
      if (obj.lcBusinessId) {
        $location.path("/askforleave").search({
          "fromType": 0, "procInstId": obj.lcBusinessId, "fromBusiness": 1, state: $state.current.name
        });
      }
    }

    function loadMore() {
      vm.conditions.pageNumber += 1;
      queryDelayApply(true);
    }

    function modify(item, e) {
      if (e) {
        e.stopPropagation();
      }
      $state.go('delayApplyEditForStu', {id: item.id});
    }

    function deleteById(id) {
      return $http.post(originBaseUrl + '/third/delay/delete.htm', {
        id: id
      }).success(function (data) {
        return data;
      })
    }

    function doDelete(item, e) {
      if (e) {
        e.stopPropagation();
      }
      var confirmPopup = $ionicPopup.confirm({
        title: "提示",
        template: "确定要删除所选吗？",
        cancelText: "取消",
        okText: "确定"
      });
      confirmPopup.then(function (res) {
        if (res) {
          deleteById(item.id).success(function (data) {
            if (data.status === 0 && data.result.length === 0) {
              $ionicPopup.alert({
                title: '提示',
                template: '删除成功！',
                okText: '确定'
              });
              queryDelayApply();
            } else {
              $ionicPopup.alert({
                title: '提示',
                template: '删除失败！' + data.reuslt[0],
                okText: '确定'
              });
            }
          });
        }
      });
    }
  }

  editCtrl.$inject = ['$scope', '$http', '$state', '$stateParams', '$ionicModal', '$ionicPopup', 'stringsConstant',
    '$cordovaFileTransfer', '$ionicLoading', 'ynNavigator'];

  /**
   * 编辑页面
   */
  function editCtrl(
    $scope, $http, $state, $stateParams, $ionicModal, $ionicPopup, stringsConstant, $cordovaFileTransfer, $ionicLoading,
    ynNavigator
  ) {
    var vm = this;

    vm.selectCourse = selectCourse;
    vm.selectedCallback = selectedCallback;
    vm.selectFiles = selectFiles;
    vm.takePhoto = takePhoto;
    vm.takePicture = takePicture;
    vm.doDeleteFile = doDeleteFile;
    vm.save = save;

    vm.obj = {
      id: $stateParams.id,
      termId: null,
      courseId: null,
      courseName: null,
      teachClassId: null,
      reason: null,
      fileList: []
    };

    vm.currentTerm = null;
    vm.selectCourseModal = null;
    vm.selectedCourses = [];
    vm.single = false;

    vm.selectFilesModal = null;
    // vm.deleteFsIds = [];

    init();

    function init() {
      var id = $stateParams.id;
      if (null != id) {
        ynNavigator.setNavTitle('修改缓考申请');
        findDelayApply(id).success(function (data) {
          if (data.status === 0 && data.result.length > 0) {
            vm.obj.termId = data.result[0].termId;
            vm.obj.courseId = data.result[0].courseId;
            vm.obj.courseName = data.result[0].courseName;
            vm.obj.teachClassId = data.result[0].teachClassId;
            vm.obj.reason = data.result[0].applyInfo;
            vm.obj.fileList = data.result[0].attachmentVOList;
          }
        });
      } else {
        ynNavigator.setNavTitle('添加缓考申请');
      }
      queryTerms();
    }

    function findDelayApply(id) {
      return $http.get(originBaseUrl + '/third/delay/' + id + '.htm').success(function (data) {
        if (data.status === 0) {
          vm.delayApply = data.result[0];
        }
      });
    }

    function queryTerms() {
      return $http.get(originBaseUrl + '/third/term/list.htm', {
        params: {
          asc: false
        }
      }).success(function (data) {
        if (data.status === 0) {
          vm.currentTerm = data.result.currentTerm;
        }
        return data;
      });
    }

    function selectCourse() {
      if (vm.obj.id) {
        vm.single = true;
        vm.selectedCourses = [{id: vm.obj.teachClassId}];
      }
      if (null == vm.selectCourseModal) {
        $ionicModal.fromTemplateUrl('select_course.html', {
          scope: $scope,
          animation: 'slide-in-left'
        }).then(function (modal) {
          vm.selectCourseModal = modal;
          vm.selectCourseModal.show();
        });
      } else {
        vm.selectCourseModal.show();
      }
    }

    function selectedCallback(courses) {
      vm.selectedCourses = courses;
      // 处理名称
      var names = [];
      angular.forEach(courses, function (c) {
        names.push(c.courseName);
      });
      vm.obj.courseName = names.join('，');
      vm.selectCourseModal.hide().then(function () {
        vm.selectCourseModal.remove();
        vm.selectCourseModal = null;
      });
    }

    function selectFiles() {
      if (null == vm.selectFilesModal) {
        $ionicModal.fromTemplateUrl('file_sources.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function (modal) {
          vm.selectFilesModal = modal;
          vm.selectFilesModal.show();
        });
      } else {
        vm.selectFilesModal.show();
      }
    }

    function takePhoto() {
      getPicture(Camera.PictureSourceType.CAMERA);
    }

    function takePicture() {
      getPicture(Camera.PictureSourceType.PHOTOLIBRARY);
    }

    /**
     * 选择并上传文件
     * @param type Camera.PictureSourceType
     */
    function getPicture(type) {
      /**
       * 成功回调
       * @param data 文件路径
       * "file:///storage/emulated/0/截屏/截屏_20211015_095650.jpg"
       */
      function success(data) {
        $ionicLoading.show();
        upload(data.substr(data.lastIndexOf('/') + 1), data);
        vm.selectFilesModal.hide().then(function () {
          vm.selectFilesModal.remove();
          vm.selectFilesModal = null;
        });
      }
      // 失败回调
      function error(error) {
        console.log(JSON.stringify(error))
        vm.selectFilesModal.hide().then(function () {
          vm.selectFilesModal.remove();
          vm.selectFilesModal = null;
        });
      }
      // 选择并上传
      navigator.camera.getPicture(success, error, {sourceType: type});
    }

    function upload(name, uri) {
      // 参数
      var mac = stringsConstant.utils.uuid();
      var userId = JSON.parse(window.localStorage.getItem('authorizationStr')).userId;
      var options = new FileUploadOptions();
      options.fileName = name;
      options.params = {
        name: name,
        userId: userId,
        mac: mac
      };
      options.headers = {
        authorization: JSON.parse(window.localStorage.getItem("authorizationStr")).access_token
      };
      $cordovaFileTransfer
        .upload(stringsConstant.file.uploadServer(), uri, options)
        .then(function (uploadSuccessData) {
          $ionicLoading.hide();
          console.log(JSON.stringify(uploadSuccessData.response));
          // 上传完成
          var data = JSON.parse(uploadSuccessData.response);
          if (null == data.result) {
            $ionicPopup.alert({
              title: '提示',
              template: data.message,
              okText: '确定'
            });
          } else {
            vm.obj.fileList.push({
              attachmentId: data.result.fileId,
              attachmentName: data.result.fileName,
              size: data.result.size
            });
          }
        });
    }

    function deleteFile(fsId) {
      // 删除服务端文件
      return $http.get(stringsConstant.file.deleteServer() + fsId).success(function (data) {
        return data;
      });
    }

    function doDeleteFile(file, index) {
      var confirm = $ionicPopup.confirm({
        title: '删除确认',
        template: '确认要删除当前照片吗?',
        cancelText: '取消',
        okText: '删除'
      });
      confirm.then(function (data) {
        if (data && file.id) {
          vm.obj.fileList.splice(index, 1);
          // vm.deleteFsIds(file.attachmentId);
        } else if (data) {
          vm.obj.fileList.splice(index, 1);
          deleteFile(file.attachmentId);
        }
      });
    }

    function doSave(obj, valid) {
      var config = {
        url: originBaseUrl + '/third/delay/save.htm?valid=' + valid,
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        dataType: 'JSON',
        data: angular.toJson(obj)
      };
      return $http(config).success(function (data) {
        return data;
      });
    }

    function save() {
      if (null == vm.obj.id) {
        if (vm.selectedCourses.length === 0) {
          $ionicPopup.alert({
            title: '提示',
            template: '请选择课程！',
            okText: '确定'
          });
          return;
        }
      }
      if (null == vm.obj.reason || '' === vm.obj.reason) {
        $ionicPopup.alert({
          title: '提示',
          template: '请填写缓考原因！',
          okText: '确定'
        });
        return;
      }
      // 构造保存对象
      var array = [];
      // 修改才有，并且修改只有一条数据
      if (vm.obj.id) {
        var obj = {
          id: vm.obj.id,
          termId: vm.obj.termId,
          courseId: vm.obj.courseId,
          teachClassId: vm.obj.teachClassId,
          applyInfo: vm.obj.reason,
          attachmentVOList: vm.obj.fileList
        }
        array.push(obj);
      }
      // 添加可以选多个课程
      else {
        angular.forEach(vm.selectedCourses, function (c) {
          var obj = {
            courseId: c.courseId,
            teachClassId: c.pkTeachClassId,
            applyInfo: vm.obj.reason,
            termId: vm.currentTerm.id,
            attachmentVOList: vm.obj.fileList
          };
          array.push(obj);
        });
      }
      // 保存
      doSave(array, false).success(function (data) {
        if (data.status === 0 && null != data.result && data.result.length > 0 && data.result[0].failedId === '1') {
          var courses = [];
          angular.forEach(data.result, function (r) {
            courses.push(r.failedReason);
          });
          // 需要给提示
          var confirm = $ionicPopup.confirm({
            title: '提示',
            template: '您已在申请课程“' + courses.join("”、“") + '”的期末成绩单中，是否继续申请缓考？',
            cancelText: "取消",
            okText: "确定"
          });
          confirm.then(function (res) {
            // 点击继续
            if (res) {
              doSave(array, true).success(function (data) {
                saveSuccess(data);
              });
            }
          });
        } else {
          saveSuccess(data);
        }
      });
    }

    function saveSuccess(data) {
      if (data.status === 0 && null == data.result) {
        $ionicPopup.alert({
          title: '提示',
          template: '提交成功！',
          okText: '确定'
        });
        $state.go('delayApplyForStu');
      } else if (data.status === 0 && data.result.length > 0 && data.result[0].failedId === '2') {
        var courses = [];
        angular.forEach(data.result, function (r) {
          courses.push(r.failedReason);
        });
        $ionicPopup.alert({
          title: '提示',
          template: '您已在申请课程“' + courses.join("”、“") + '”的成绩单中且已经存在成绩，不能提交缓考申请！',
          okText: '确定'
        });
      } else if (data.status === -1) {
        // 错误消息
        $ionicPopup.alert({
          title: '提示',
          template: '提交失败！' + data.message,
          okText: '确定'
        });
      }
    }

  }

  viewCtrl.$inject = ['$scope', '$http', '$ionicPopup'];

  function viewCtrl($scope, $http, $ionicPopup) {
    var vm = this;

    vm.viewPic = viewPic;

    vm.delayApply = null;

    findDelayApply($scope.lcFormInfoVO.businessKey);

    function findDelayApply(id) {
      return $http.get(originBaseUrl + '/third/delay/' + id + '.htm').success(function (data) {
        if (data.status === 0) {
          vm.delayApply = data.result[0];
        }
      });
    }

    function viewPic(fsId) {
      console.log("文件下载地址：" + originBaseUrl + '/file/downloadStream.htm?fastDFSId=' + fsId);
      var cordovaFileOpen = cordova.plugins.disusered.open;
      cordovaFileOpen(originBaseUrl + '/file/downloadStream.htm?fastDFSId=' + fsId,
        function (ok) {
          console.log(ok);
        },
        function (code) {
          console.log(code);
          if (code === 1) {
            $ionicPopup.alert({
              title: '文件预览提示',
              template: '未能在手机已安装APP中找到可预览此文件的程序'
            });
          } else {
            $ionicPopup.alert({
              title: '文件预览提示',
              template: '预览时发生了未知错误 #' + code
            });
          }
        },
        true);
    }
  }

  /**
   * 选择课程
   */
  function selectedCourse() {
    return {
      restrict: 'E',
      templateUrl: 'templates/cjstu/delay/selectedCourse.html',
      scope: {
        course: '=',
        // 是否单选
        single: '=',
        callBackFun: '='
      },
      link: link,
      controller: ctrl,
      controllerAs: 'vm',
      bindToController: true
    }

    function link() {

    }

    function ctrl($scope, $http, $ionicPopup) {
      var vm = this;

      vm.selectCourse = selectCourse;
      vm.confirm = confirm;

      vm.courses = [];
      vm.selectedCourses = [];
      vm.selectedCourseIds = [];

      init();

      function init() {
        console.log(vm.course);
        if (vm.course && vm.course.length > 0) {
          angular.forEach(vm.course, function (c) {
            vm.selectedCourseIds.push(c.id);
          });
        }
        queryCourse();
      }

      function queryCourse() {
        return $http.get(originBaseUrl + '/third/delay/course/list.htm').success(function (data) {
          if (data.status === 0) {
            vm.courses = data.result;
            handleCourseInfo(vm.courses);
            // 默认选中
            if (vm.selectedCourseIds.length > 0 && vm.selectedCourses.length === 0) {
              angular.forEach(vm.courses, function (c) {
                if (vm.selectedCourseIds.concat(c.id)) {
                  vm.selectedCourses.push(c);
                }
              });
            }
          }
          return data;
        });
      }

      /**
       * 拼接课程信息
       * @param courses 课程
       */
      function handleCourseInfo(courses) {
        if (null == courses || courses.length === 0) {
          return;
        }
        angular.forEach(courses, function (course) {
          var info = [];
          if (course.teacherNames) {
            info.push(course.teacherNames);
          }
          if (course.termCredit) {
            info.push(course.termCredit + '学分');
          }
          if (course.electiveTypeName) {
            info.push(course.electiveTypeName + '课');
          }
          if (course.assessWayName) {
            info.push(course.assessWayName);
          }
          course.info = info.join(' | ');
        });
      }

      function selectCourse(course) {
        // 单选
        if (vm.single) {
          vm.selectedCourses = [];
          vm.selectedCourseIds = [];
          vm.selectedCourses.push(course);
          vm.selectedCourseIds.push(course.id);
          return;
        }
        var index = null;
        angular.forEach(vm.selectedCourses, function (c, key) {
          if (c.id === course.id) {
            index = key;
          }
        });
        if (null == index) {
          vm.selectedCourses.push(course);
          vm.selectedCourseIds.push(course.id);
        } else {
          vm.selectedCourses.splice(index, 1);
          vm.selectedCourseIds.splice(vm.selectedCourseIds.indexOf(course.id), 1);
        }
      }

      function confirm() {
        if (vm.selectedCourses.length === 0) {
          $ionicPopup.alert({
            title: '提示',
            template: '请选择课程！',
            okText: '确定'
          });
          return;
        }
        if (vm.callBackFun && angular.isFunction(vm.callBackFun)) {
          vm.callBackFun(vm.selectedCourses);
        }
      }
    }
  }

})();
