/**
 * 班级巡查考核
 * @author qiucheng Lu
 * @Date 2021年4月8日16:27:51
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        /**班级巡查考核*/
        .controller('classSearch', classSearch)
        .controller('searchClassList', searchClassList)
        .controller('selectClassExamineProject', selectClassExamineProject)
        .controller('selectClass', selectClass)
        .controller('classPatrolCtrl', classPatrolCtrl);

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        /*查找班级*/
            .state('class_search', {
                url: '/class_search',
                templateUrl: 'templates/classexamineall/class_search.html',
                data: {
                    micro: true,
                    title: '干部工作'
                },
                controller: 'classSearch'
            })
            /*开始查找班级*/
            .state('search_classList', {
                url: '/search_classList',
                templateUrl: 'templates/classexamineall/search_classList.html',
                data: {
                    title: '班级巡查考核',
                    prev: 'class_search'
                },
                controller: 'searchClassList'
            })
            /*选择班级*/
            .state('select_class', {
                url: '/select_class',
                templateUrl: 'templates/classexamineall/select_class.html',
                data: {
                    title: '班级巡查考核',
                    prev: 'class_search'
                },
                controller: 'selectClass'
            })
            /*选择考核项目*/
            .state('selectClass_examine_project', {
                url: '/selectClass_examine_project',
                templateUrl: 'templates/classexamineall/selectClass_examine_project.html',
                data: {
                    title: '班级巡查考核',
                    prev: 'search_classList'
                },
                controller: 'selectClassExamineProject'
            })/*巡查打分*/
            .state('class_patrol', {
                url: '/class_patrol',
                templateUrl: 'templates/classexamineall/class_patrol.html',
                data: {
                    title: '班级巡查考核',
                    prev: 'selectClass_examine_project'
                },
                controller: 'classPatrolCtrl'
            })

          // 教师端
          .state('class_search_by_teacher', {
              url: '/class_search_by_teacher',
              templateUrl: 'templates/classexamineall/class_search.html',
              data: {
                  micro: true,
                  title: '学生考核'
              },
              controller: 'classSearch'
          })
          /*开始查找班级*/
          .state('search_classList_by_teacher', {
              url: '/search_classList_by_teacher',
              templateUrl: 'templates/classexamineall/search_classList.html',
              data: {
                  title: '班级巡查考核',
                  prev: 'class_search_by_teacher'
              },
              controller: 'searchClassList'
          })
          /*选择班级*/
          .state('select_class_by_teacher', {
              url: '/select_class_by_teacher',
              templateUrl: 'templates/classexamineall/select_class.html',
              data: {
                  title: '班级巡查考核',
                  prev: 'class_search_by_teacher'
              },
              controller: 'selectClass'
          })
          /*选择考核项目*/
          .state('selectClass_examine_project_by_teacher', {
              url: '/selectClass_examine_project_by_teacher',
              templateUrl: 'templates/classexamineall/selectClass_examine_project.html',
              data: {
                  title: '班级巡查考核',
                  prev: 'search_classList_by_teacher'
              },
              controller: 'selectClassExamineProject'
          })/*巡查打分*/
          .state('class_patrol_by_teacher', {
              url: '/class_patrol_by_teacher',
              templateUrl: 'templates/classexamineall/class_patrol.html',
              data: {
                  title: '班级巡查考核',
                  prev: 'selectClass_examine_project_by_teacher'
              },
              controller: 'classPatrolCtrl'
          });
    }

    classSearch.$inject = ['classListService', '$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', '$cordovaBarcodeScanner', '$state'];

    /**
     * 选择班级
     */
    function classSearch(classListService, $scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, $cordovaBarcodeScanner, $state) {

        $scope.classListShow = false;

        $scope.selectedClass = classListService.getAllList();
        /**
         * 开始考核
         */
        $scope.startClassPatrol = function () {
            if ($scope.selectedClass.length == 0) {
                ynuiNotification.error({msg: "请选择巡查的班级"});
                return false;
            }
            classListService.save($scope.selectedClass);
            //去掉缓存的考核项
            cleanStorage();
            if ($state.$current.name === 'class_search_by_teacher') {
                $location.path("/selectClass_examine_project_by_teacher").search({prev: $state.$current.name});
            } else {
                $location.path("/selectClass_examine_project").search({prev: $state.$current.name});
            }
        };

        /**
         * 去掉缓存的考核项
         */
        function cleanStorage() {
            if (window.localStorage.getItem("_class_check_patrol_item_code_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_code_storage");
            }
            if (window.localStorage.getItem("_class_check_patrol_item_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_storage");
            }
        }

        /**
         * 显示浮动窗口
         */
        $scope.showClassListModal = function () {
            $scope.classListShow = !$scope.classListShow;
        };

        /**
         * 查询全校班级
         */
        $scope.toSearchAllClass = function () {
            classListService.save($scope.selectedClass);
            if ($state.$current.name === 'class_search_by_teacher') {
                $location.path("/select_class_by_teacher");
            } else {
                $location.path("/select_class");
            }
        };

        /**
         * 输入查询
         */
        $scope.inputClassInfoToSearch = function () {
            classListService.save($scope.selectedClass);
            if ($state.$current.name === 'class_search_by_teacher') {
                $location.path("/search_classList_by_teacher");
            } else {
                $location.path("/search_classList");
            }
        };

        /**
         * 扫描班级好牌
         */
        $scope.scanClassCode = function () {
            $cordovaBarcodeScanner.scan().then(function (barcodeData) {
                $scope.number = barcodeData.text;
                if (!$scope.number) {
                    return false;
                }
                $ionicLoading.show({
                    template: '正在刷新...'
                });
                $http.get(originBaseUrl + "/third/classPatrol/queryUserSecurityClass.htm?classCode=" + encodeURIComponent($scope.number)).success(function (data) {
                    $ionicLoading.hide();
                    if (data.status == 0) {
                        var arr = data.result.content;
                        if (arr.length > 0) {
                            angular.forEach(arr, function (a) {
                                if (!$scope.selectedClass.some(function (s) {
                                    return s.id == a.id;
                                })) {
                                    $scope.selectedClass.push(a);
                                }
                            });
                            $scope.classListShow = false;
                        } else {
                            ynuiNotification.error({msg: '没有班级到学生信息！'});
                        }
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        $ionicScrollDelegate.scrollTop();
                        $ionicLoading.hide();
                    } else {
                        ynuiNotification.error({msg: '获取班级信息失败！'});
                    }
                }).error(function (data) {
                    ynuiNotification.error({msg: '获取班级信息失败！'});
                });
            }, function (error) {
                ynuiNotification.error({msg: "扫描失败！"});
            });
        };
        /**
         *  选择或者是不行选择
         * @param index
         */
        $scope.unSelected = function (index) {
            $scope.selectedClass.splice(index, 1);
        };
    }

    searchClassList.$inject = ['classListService', '$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', 'ynNavigator', '$state'];

    /**
     * 开始查找班级
     */
    function searchClassList(classListService, $scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, ynNavigator, $state) {
        $scope.classListShow = false;
        $scope.search = false;
        /**
         * 全部的班级
         * @type {Array}
         */
        $scope.classList = [];
        /**
         * 被选中的班级
         * @type {Array}
         */
        $scope.selectedClassList = classListService.getAllList();

        $scope.className = "";

        $scope.clearSearch = function () {
            $scope.className = "";
        }
        /**
         * 上一步
         */
        ynNavigator.registerBackAction(function () {
            classListService.save($scope.selectedClassList);
            ynNavigator.pop(true);//强制返回上一级
            // if ($state.$current.name === 'search_classList_by_teacher') {
            //     $state.go('class_search_by_teacher');
            // } else {
            //     $state.go('class_search');
            // }
        }, 101);
        /**
         * 显示浮动窗口
         */
        $scope.showClassListModal = function () {
            $scope.classListShow = !$scope.classListShow;
        };
        /**
         * 开始考核
         */
        $scope.startClassPatrol = function () {
            if (!$scope.selectedClassList || $scope.selectedClassList.length == 0) {
                ynuiNotification.error({msg: "请选择巡查的班级"});
                return false;
            }
            classListService.save($scope.selectedClassList);
            //去掉缓存的考核项
            cleanStorage();
            if ($state.$current.name === 'search_classList_by_teacher') {
                $location.path("/selectClass_examine_project_by_teacher").search({prev: $state.$current.name});
            } else {
                $location.path("/selectClass_examine_project").search({prev: $state.$current.name});
            }
        };

        /**
         * 去掉缓存的考核项
         */
        function cleanStorage() {
            if (window.localStorage.getItem("_class_check_patrol_item_code_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_code_storage");
            }
            if (window.localStorage.getItem("_class_check_patrol_item_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_storage");
            }
        }

        /**
         * 获取全部的数据
         */
        $scope.getAllClassList = function () {
            $http.get(originBaseUrl + "/third/classPatrol/queryUserSecurityClass.htm?className=" + $scope.className).success(function (data) {
                if (data.status == 0) {
                    $scope.classList = data.result.content;
                    var tempArr = classListService.getAllList();
                    angular.forEach($scope.classList, function (item) {
                        item.selected = tempArr.length > 0 ? tempArr.some(function (t) {
                            return t.id == item.id;
                        }) : false;
                    });
                } else {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                }
            });
        };

        /**
         * 选中班级
         * @param item
         */
        $scope.selectItemed = function (item) {
            if (item.selected) {
                item.selected = false;
                angular.forEach($scope.selectedClassList, function (c, key) {
                    if (c.id == item.id) {
                        $scope.selectedClassList.splice(key, 1);
                    }
                });
            } else {
                item.selected = true;
                $scope.selectedClassList.unshift(item);
            }
        };
        /**
         *  删除选中的数据
         * @param index
         */
        $scope.unSelectedItem = function (index) {
            $scope.selectedClassList.splice(index, 1);
            angular.forEach($scope.classList, function (c) {
                c.selected = $scope.selectedClassList.some(function (t) {
                    return t.id == c.id;
                });
            })
        };

        $scope.$watch(function () {
            return $scope.className;
        }, function (newVal) {
            var timeout = window.setTimeout(function () {
                if ($scope.className) {
                    $scope.search = true;
                    $scope.getAllClassList();
                } else {
                    $scope.$apply(function () {
                        $scope.classList = [];
                    })
                }
                window.clearTimeout(timeout);
            })
        });

    }

    selectClassExamineProject.$inject = ['classListService', '$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', 'ynNavigator', '$state'];

    /**
     * 选择考核项目
     */
    function selectClassExamineProject(classListService, $scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, ynNavigator, $state) {

        $scope.classListShow = false;
        $scope.selectedClass = classListService.getAllList();
        $scope.classItems = [];
        $scope.classCheckItem = [];
        $scope.itemCode = "";
        //有缓存 取考核项
        var codeClassItem = null;
        if (window.localStorage.getItem("_class_check_patrol_item_code_storage")) {
            codeClassItem = JSON.parse(window.localStorage.getItem("_class_check_patrol_item_code_storage"));
        }
        //有缓存 取打分项
        var classItem = null;
        if (window.localStorage.getItem("_class_check_patrol_item_storage")) {
            classItem = JSON.parse(window.localStorage.getItem("_class_check_patrol_item_storage"));
        }
        /**
         * 上一步
         */
        $scope.lastStep = function () {
            classListService.save($scope.selectedClass);
            if ($location.search().prev) {
                $state.go($location.search().prev);
            } else {
                ynNavigator.pop(true);//强制返回上一级
            }
        };
        ynNavigator.registerBackAction(function () {
            $scope.lastStep();
        }, 101);
        /**
         * 下一步
         */
        $scope.nextStep = function () {
            if (!$scope.classItem) {
                ynuiNotification.error({msg: "请选择考核项目！"});
                return false;
            }
            //缓存 取考核项
            if ($scope.item) {
                window.localStorage.setItem("_class_check_patrol_item_code_storage", JSON.stringify($scope.item));
            }
            //缓存 取打分项
            window.localStorage.setItem("_class_check_patrol_item_storage", JSON.stringify($scope.classItem));

            if ($state.$current.name === 'selectClass_examine_project_by_teacher') {
                $location.path("/class_patrol_by_teacher").search({item: JSON.stringify($scope.classItem)});
            } else {
                $location.path("/class_patrol").search({item: JSON.stringify($scope.classItem)});
            }
        };

        /**
         * 获取全部的打分项目
         */
        $scope.queryAllClassChItem = function () {
            $http.get(originBaseUrl + "/third/classPatrol/queryAllClassChItem.htm").success(function (data) {
                if (data.status == 0) {
                    $scope.classItems = data.result;
                    //没有缓存，选中全部
                    $scope.classItems.unshift({
                        id: "",
                        typeNumber: "",
                        checkItemName: "全部"
                    });
                    var item = null;
                    angular.forEach($scope.classItems, function (value) {
                        value.selected = false;
                        if (codeClassItem && codeClassItem.id == value.id) {
                            value.selected = true;
                            item = value;
                        }
                    });
                    if (item) {
                        $scope.item = item;
                    } else if ($scope.classItems && $scope.classItems.length) {
                        $scope.classItems[0].selected = true;
                        $scope.item = $scope.classItems[0];
                    }
                    // $scope.queryPatrolClassItem($scope.item);
                } else {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                }
            });
        };

        /**
         * 获取全部的打分详列
         */

        $scope.queryPatrolClassItem = function (item) {
            angular.forEach($scope.classItems, function (item) {
                item.selected = false;
            });
            item.selected = true;
            $scope.item = item;
            $scope.getPatrolClassItemList(item);
        };

        /**
         * 获取数据列
         * @param item
         */
        $scope.getPatrolClassItemList = function (item) {
            $http.get(originBaseUrl + "/third/classPatrol/queryPatrolClassItem.htm?patrolItemId=" + (item && item.id ? item.id : "") + "&itemCode=" + $scope.itemCode).success(function (data) {
                if (data.status == 0) {
                    $scope.classCheckItem = data.result;
                    //选中缓存
                    $scope.activeItem(classItem);
                } else {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                }
            });
        };
        /**
         * 监视选择
         */
        $scope.$watch("itemCode", function () {
            if ($scope.itemCode) {
                angular.forEach($scope.classItems, function (item) {
                    item.selected = false;
                });
                $scope.classItems[0].selected = true;
                $scope.item = $scope.classItems[0];
                $scope.getPatrolClassItemList($scope.item);
            } else {
                if ($scope.item) {
                    angular.forEach($scope.classItems, function (item) {
                        item.selected = item.id == $scope.item.id;
                    });
                } else if ($scope.classItems && $scope.classItems.length) {
                    //初始化
                    $scope.classItems[0].selected = true;
                    $scope.item = $scope.classItems[0];
                }
                $scope.getPatrolClassItemList($scope.item);
            }
        });
        $scope.clearItemCode = function () {
            $scope.itemCode = '';
        };
        /**
         * 刷新
         */
        $scope.refreshAll = function () {
            var arr = $scope.classItems.filter(function (t) {
                return t.selected;
            });
            $scope.queryPatrolClassItem(arr.length > 0 ? arr[0] : {})
        };

        /**
         * 选中
         * @param item
         */
        $scope.activeItem = function (item) {
            $scope.classItem = item;
            angular.forEach($scope.classCheckItem, function (value) {
                value.active = false;
                if (item && value.id == item.id) {
                    value.active = true;
                }
            });

        };
        $scope.queryAllClassChItem();
    }

    selectClass.$inject = ['classListService', '$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', 'ynNavigator', '$state'];

    /**
     * 选择班级
     */
    function selectClass(classListService, $scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, ynNavigator, $state) {
        /**
         * 上一步
         */
        $scope.classList = [];
        $scope.gradeList = [];
        $scope.selectedClass = classListService.getAllList();
        ynNavigator.registerBackAction(function () {
            $scope.selectedClass = $scope.classList.filter(function (a) {
                return a.selected;
            });
            classListService.save($scope.selectedClass);
            ynNavigator.pop(true);//强制返回上一级
        }, 101);
        /**
         * 显示浮动窗口
         */
        $scope.showClassListModal = function () {
            $scope.classListShow = !$scope.classListShow;
        };
        /**
         * 开始考核
         */
        $scope.startClassPatrol = function () {
            $scope.selectedClass = $scope.classList.filter(function (a) {
                return a.selected;
            });
            if ($scope.selectedClass.length == 0) {
                ynuiNotification.error({msg: "请选择巡查的班级"});
                return false;
            }
            classListService.save($scope.selectedClass);

            //去掉缓存的考核项
            cleanStorage();
            if ($state.$current.name === 'select_class_by_teacher') {
                $location.path("/selectClass_examine_project_by_teacher").search({prev: $state.$current.name});
            } else {
                $location.path("/selectClass_examine_project").search({prev: $state.$current.name});
            }
        };

        /**
         * 去掉缓存的考核项
         */
        function cleanStorage() {
            if (window.localStorage.getItem("_class_check_patrol_item_code_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_code_storage");
            }
            if (window.localStorage.getItem("_class_check_patrol_item_storage")) {
                window.localStorage.removeItem("_class_check_patrol_item_storage");
            }
        }

        /**
         * 获得近5年有效的年级
         */
        $scope.getNearlyFiveYearsGrades = function () {
            $http.get(originBaseUrl + "/third/classPatrol/getNearlyFiveYearsGrades.htm").success(function (data) {
                if (data.status == 0) {
                    $scope.gradeList = data.result;
                    //逆排序
                    $scope.gradeList.sort(function (o1, o2) {
                        return o1.name.localeCompare(o2.name);
                    });
                    $scope.gradeList.unshift({
                        id: "",
                        name: "全部"
                    });
                    $scope.getAllClassList({id: ""});
                } else {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                }
            });
        };
        /**
         * 获取全校的班级信息
         * @param grade
         */
        $scope.getAllClassList = function (grade) {
            angular.forEach($scope.gradeList, function (g) {
                g.selected = g.id == grade.id;
            });
            grade.selected = true;
            $http.get(originBaseUrl + "/third/classPatrol/queryUserSecurityClass.htm?gradeId=" + (grade.id ? grade.id : "")).success(function (data) {
                if (data.status == 0) {
                    $scope.classList = data.result.content;
                    angular.forEach($scope.classList, function (item) {
                        item.selected = $scope.selectedClass.length > 0 ? $scope.selectedClass.some(function (t) {
                            return t.id == item.id;
                        }) : false;
                    });
                } else {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                }
            });
        };

        /**
         * 选中或者是不选中
         * @param item
         */
        $scope.selectItemClass = function (item) {
            item.selected = !item.selected;
            $scope.selectedClass = [];
            angular.forEach($scope.classList, function (c) {
                if (c.selected) {
                    $scope.selectedClass.push(c);
                }
            });
        };

        /**
         * 在已选择的名单中删除原来的数据
         */
        $scope.unSelected = function (index) {
            $scope.selectedClass.splice(index, 1);
            $scope.classList.forEach(function (clazz) {
                clazz.selected = $scope.selectedClass.some(function (t) {
                    return t.id == clazz.id;
                })
            })
        };
        $scope.getNearlyFiveYearsGrades();
    }

    classPatrolCtrl.$inject = ['classListService', '$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', '$filter', '$ionicLoading', '$ionicScrollDelegate', "$cordovaBarcodeScanner", "$timeout", '$state'];

    /**
     * 巡查打分
     */
    function classPatrolCtrl(classListService, $scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, $filter, $ionicLoading, $ionicScrollDelegate, $cordovaBarcodeScanner, $timeout, $state) {

        $scope.checkSuccess = false;

        $ionicModal.fromTemplateUrl('student.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            $scope.modal = modal;
        });
        /**
         * 考核项备注
         */
        var item = JSON.parse($location.search().item);
        var itemId = item.itemId;
        /**
         * 选择的班级的信息
         */
        $scope.selectedClass = classListService.getAllList();
        /**
         * 选择学生的列表
         */
        $scope.openName = function () {
            getClassStu();
            $scope.modal.show();
        };
        /**
         * 关闭查询学生接口
         */
        $scope.closeName = function () {
            $scope.modal.hide();
        };
        /**
         * 考核项备注
         * @type {boolean}
         */
        $scope.isOver = false;

        /**
         * 获取当前的时间
         * @returns {string}
         */
        $scope.getCurrentTime = function () {
            var currentTime = new Date();
            var month = (currentTime.getMonth() + 1) > 9 ? (currentTime.getMonth() + 1) : '0' + (currentTime.getMonth() + 1);
            var day = currentTime.getDate() > 9 ? currentTime.getDate() : '0' + currentTime.getDate();
            var hour = currentTime.getHours() > 9 ? currentTime.getHours() : '0' + currentTime.getHours();
            var minute = currentTime.getMinutes() > 9 ? currentTime.getMinutes() : '0' + currentTime.getMinutes();
            var currentTimeStr = currentTime.getFullYear() + "-" + month + "-" + day + " " + hour + ":" +
                minute;
            return currentTimeStr;
        };

        $scope.isOpen = false;
        $scope.submitObj = {
            moraleduChClassItemId: item.id,
            itemName: item.itemName,
            itemRemark: item.remark,
            remark: "",
            scoreType: 0,
            score: 0,
            baseScore: item.baseScore,
            delBeginScore: item.delBeginScore,
            delEndScore: item.delEndScore,
            addBeginScore: item.addBeginScore,
            addEndScore: item.addEndScore,
            stuIdList: [],//学生
            attachmentList: [],//文件
            platformAdminClassIds: [],//班级
            stuInfoList: [],//回传的学生的信息
            datetime: $scope.getCurrentTime()
        };


        /**
         * 返回打分页面
         */
        $scope.lastStep = function () {
            window.history.go(-1);
        };
        /**
         * js浮点数计算不准确计算解决
         * @param a
         * @param b
         * @returns {number}
         */
        var mul = function (a, b) {
            var c = 0,
                d = a.toString(),
                e = b.toString();
            try {
                c += d.split(".")[1].length;
            } catch (f) {
            }
            try {
                c += e.split(".")[1].length;
            } catch (f) {
            }
            return Number(d.replace(".", "")) * Number(e.replace(".", "")) / Math.pow(10, c);
        };
        /**
         * 加
         * @param a
         * @param b
         */
        var accAdd = function (a, b) {
            var c, d, e;
            try {
                c = a.toString().split(".")[1].length;
            } catch (f) {
                c = 0;
            }
            try {
                d = b.toString().split(".")[1].length;
            } catch (f) {
                d = 0;
            }
            return e = Math.pow(10, Math.max(c, d)), (mul(a, e) + mul(b, e)) / e;
        };
        /**
         *
         * @param a
         * @param b
         */
        var accSub = function (a, b) {
            var c, d, e;
            try {
                c = a.toString().split(".")[1].length;
            } catch (f) {
                c = 0;
            }
            try {
                d = b.toString().split(".")[1].length;
            } catch (f) {
                d = 0;
            }
            return e = Math.pow(10, Math.max(c, d)), (mul(a, e) - mul(b, e)) / e;
        }
        /**
         *
         * @param isAdd
         */
        $scope.isAddScore = function (isAdd) {
            if ($scope.submitObj.score == "") {
                $scope.submitObj.score = 0;
            }
            if (isAdd > 0) {
                $scope.submitObj.score = accAdd($scope.submitObj.score, 0.1);
            } else {
                $scope.submitObj.score = accSub($scope.submitObj.score, 0.1);
            }
            if ($scope.submitObj.scoreType == 0) {
                if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score < $scope.submitObj.addBeginScore) {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                    $scope.submitObj.score = $scope.submitObj.addBeginScore;
                } else if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score > $scope.submitObj.addEndScore) {
                    ynuiNotification.error({msg: "不能大于" + $scope.submitObj.addEndScore});
                    $scope.submitObj.score = $scope.submitObj.addEndScore;
                }
            } else {
                if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score > $scope.submitObj.delEndScore) {
                    ynuiNotification.error({msg: "不能大于" + $scope.submitObj.delEndScore});
                    $scope.submitObj.score = $scope.submitObj.delEndScore;
                } else if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score < $scope.submitObj.delBeginScore) {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.delBeginScore});
                    $scope.submitObj.score = $scope.submitObj.delBeginScore;
                }
            }
            $scope.returnItemScore();
        };
        /**
         * 监控
         */
        $scope.$watch(function () {
            return $scope.submitObj.score;
        }, function (newVal, oldVal) {
            var reg = /^\d+\.?\d{0,2}$/;
            if (newVal && !reg.test(newVal)) {
                $scope.submitObj.score = oldVal;
            }
        });
        /**
         * 监视成绩的改变
         * @returns {boolean}
         */
        $scope.changeScore = function () {
            var canGoOn = false;
            if ($scope.submitObj.scoreType == 0) {
                if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score < $scope.submitObj.addBeginScore) {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.addBeginScore});
                    $scope.submitObj.score = $scope.submitObj.addBeginScore;
                    canGoOn = true;
                } else if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score > $scope.submitObj.addEndScore) {
                    ynuiNotification.error({msg: "不能大于" + $scope.submitObj.addEndScore});
                    $scope.submitObj.score = $scope.submitObj.addEndScore;
                    canGoOn = true;
                }
            } else {
                if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score > $scope.submitObj.delEndScore) {
                    ynuiNotification.error({msg: "不能大于" + $scope.submitObj.delEndScore});
                    $scope.submitObj.score = $scope.submitObj.delEndScore;
                    canGoOn = true;
                } else if (($scope.submitObj.score && $scope.submitObj.score != 0) && $scope.submitObj.score < $scope.submitObj.delBeginScore) {
                    ynuiNotification.error({msg: "不能小于" + $scope.submitObj.delBeginScore});
                    $scope.submitObj.score = $scope.submitObj.delBeginScore;
                    canGoOn = true;
                }
            }
            $scope.returnItemScore();
            if (canGoOn) {
                return false;
            } else {
                return true;
            }
        };
        /**
         * 返回成绩
         */
        $scope.returnItemScore = function () {
            if ($scope.submitObj.scoreType == 0) {
                $scope.submitObj.itemScore = accAdd($scope.submitObj.baseScore, $scope.submitObj.score);
            } else {
                $scope.submitObj.itemScore = accSub($scope.submitObj.baseScore, $scope.submitObj.score);
            }
        };
        var confirmPopup = "";
        $scope.openModel = function () {
            confirmPopup.show();
        }
        $scope.closeHead = function () {
            confirmPopup.hide();
        }
        $ionicModal.fromTemplateUrl('templates/classexamineall/templ/confirmCheckInfoPop.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            confirmPopup = modal;
        });
        /**
         * 提交成绩
         * @returns {boolean}
         */

        $scope.submitScore = function () {
            if ($scope.selectedClass.length == 0) {
                ynuiNotification.warning({msg: "重新选择班级！"});
                return false;
            }

            if ($scope.submitObj.datetime) {
                var dateAndTime = $scope.submitObj.datetime.split(" ");
                if (!dateAndTime || dateAndTime.length != 2) {
                    return false;
                }
                $scope.submitObj.checkDate = $scope.submitObj.datetime;
            }

            $scope.confirmPopParam = {
                sendMsg: 0//1发送，0不发送
            };
            $scope.confirmPopParam.classNameStr = $scope.selectedClass.map(function (t) {
                return t.name
            });
            $scope.confirmPopParam.checkItemName = $scope.submitObj.itemName;
            $scope.confirmPopParam.scoreStr = ($scope.submitObj.scoreType == '1' ? '扣' : '加') + $scope.submitObj.score + "分";
            $scope.openModel();
            // var confirmPopup = $ionicPopup.confirm({
            //     title:"请确认考核信息",
            //     templateUrl: 'templates/classexamineall/templ/confirmCheckInfoPop.html',
            //     scope: $scope,
            //     cancelText:"取消",
            //     okText:"确认提交"
            // });
            // confirmPopup.then(function(res){
            //     if(!res){return false;}
            //     var obj = angular.copy($scope.submitObj);
            //     delete  obj.itemRemark;
            //     obj.stuInfoIdList = obj.stuInfoList.map(function(s){
            //         return s.id
            //     }).join(",");
            //     delete  obj.stuInfoList;
            //     obj.platformAdminClassIds = $scope.selectedClass.map(function(clazz){
            //         return  clazz.id;
            //     }).join(",");
            //     classListService.save([]);
            //     $http.post(originBaseUrl + '/third/classPatrol/savePatrolDetail.htm?', obj).success(function (data) {
            //         if (data.status != 0) {
            //             ynuiNotification.error({msg: data.message});
            //         } else {
            //             $scope.checkSuccess = true;
            //         }
            //     });
            // });
        };
        $scope.savePatrolDetail = function () {
            var obj = angular.copy($scope.submitObj);
            delete  obj.itemRemark;
            obj.stuInfoIdList = obj.stuInfoList.map(function (s) {
                return s.id
            }).join(",");
            delete  obj.stuInfoList;
            obj.platformAdminClassIds = $scope.selectedClass.map(function (clazz) {
                return clazz.id;
            }).join(",");
            obj.sendMsg = $scope.confirmPopParam.sendMsg;
            classListService.save([]);
            $http.post(originBaseUrl + '/third/classPatrol/savePatrolDetail.htm?', obj).success(function (data) {
                if (data.status != 0) {
                    ynuiNotification.error({msg: data.message});
                } else {
                    $scope.closeHead();
                    $timeout(function () {
                        $scope.checkSuccess = true;
                    }, 400);
                }
            });
        }
        $scope.isSendMSGTeacher = function () {
            $scope.confirmPopParam.sendMsg = $scope.confirmPopParam.sendMsg == 1 ? 0 : 1;
        }
        /**
         * 添加学生
         */
        var getClassStu = function (studentPlatformInfo) {
            $scope.classStudent = [];
            $scope.stuCheckedNum = 0;
            var classIds = $scope.selectedClass.map(function (c) {
                return c.id
            });
            $http.get(originBaseUrl + '/third/classPatrol/queryClassStudentByClassIds.htm?classIds=' + classIds + "&studentPlatformInfo=" + (studentPlatformInfo ? studentPlatformInfo : "") + '&time=' + (new Date()).getTime()).success(function (data) {
                if (data.status == 0) {
                    $scope.classStudent = data.result;
                    $scope.classStudentCopy = angular.copy(data.result);
                    angular.forEach($scope.classStudent, function (item, index) {
                        item.checked = false;
                        $scope.classStudentCopy[index].checked = false;
                        angular.forEach($scope.submitObj.stuInfoList, function (ite) {
                            if (item.id == ite.id) {
                                item.checked = true;
                                $scope.classStudentCopy[index].checked = true;
                                $scope.stuCheckedNum += 1;
                            }
                        })
                    });
                }
            });
        };

        /**
         * 扫描二位嘛
         */
        $scope.scanCode = function () {

            $cordovaBarcodeScanner.scan().then(function (barcodeData) {
                $scope.number = barcodeData.text;
                console.log($scope.number);
                if (!$scope.number) {
                    return false;
                }
                $scope.number = JSON.parse($scope.number);
                var classIds = $scope.selectedClass.map(function (c) {
                    return c.id
                });
                $http.get(originBaseUrl + '/third/classPatrol/queryClassStudentByClassIds.htm?classIds=' + classIds + "&studentPlatformInfo=" + encodeURIComponent($scope.number.userId) + '&time=' + (new Date()).getTime()).success(function (data) {
                    $ionicLoading.hide();
                    if (data.status == 0) {
                        var arr = data.result;
                        if (arr.length > 0) {
                            angular.forEach(arr, function (a) {
                                if (!$scope.submitObj.stuInfoList.some(function (s) {
                                    return s.id == a.id;
                                })) {
                                    $scope.submitObj.stuInfoList.push(a);
                                }
                            });
                        } else {
                            ynuiNotification.error({msg: '被考核班级中没有该学生!'});
                        }
                    } else {
                        ynuiNotification.error({msg: '获取学生信息失败！'});
                    }
                }).error(function (data) {
                    ynuiNotification.error({msg: '获取学生信息失败！'});
                });
            }, function (error) {
                ynuiNotification.error({msg: "扫描失败！"});
            });
        };

        /**
         * 刷新学生
         */
        $scope.doRefreshStudent = function () {
            getClassStu("");
        };
        /**
         * 点击或者是取消选中学生
         * @param index
         */
        $scope.stuCheckedNum = 0;
        $scope.changeChecked = function (index) {
            $scope.classStudent[index].checked = !$scope.classStudent[index].checked;
            $scope.stuCheckedNum = $scope.classStudent.filter(function (t) {
                return t.checked;
            }).length;
        };
        /**
         * 完成学生的选择
         */
        $scope.submitClassStu = function () {
            var arr = $scope.classStudent.filter(function (t) {
                return t.checked;
            });
            $scope.submitObj.stuInfoList = angular.copy(arr);
            $scope.closeName();
        };

        /**
         * 继续其他项目的考核
         */
        $scope.previousStep = function () {
            classListService.save($scope.selectedClass);
            window.history.go(-1);
        };

        /**
         * 其他班级的考核
         */
        $scope.checkOtherClass = function () {
            classListService.save([]);
            if ($state.$current.name === 'class_patrol_by_teacher') {
                $location.path("/class_search_by_teacher");
            } else {
                $location.path("/class_search");
            }
        };

        /**
         *  删除数据
         * @param index
         */
        $scope.unSelected = function (index) {
            $scope.selectedClass.splice(index, 1);
        };

        /**
         * 上一部
         */
        $scope.lastStep = function () {
            classListService.save($scope.selectedClass);
            window.history.go(-1);
        }
    }
})();
