/**
 * 课堂考勤
 * @author qiucheng Lu
 * @Date 2021年4月8日14:02:04
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        .controller('classleaderCoursesController', classleaderCoursesController)
        .controller('classleaderAddAttendanceController', classleaderAddAttendanceController)
        .controller('attendanceListController', attendanceListController)
        .factory("selectStudentFromClassService", selectStudentFromClassService)

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
            // 班干部课程列表
            .state('classleader_attendance', {
                url: '/classleader_attendance',
                templateUrl: 'templates/classroom_attendance/classleader/classleader_courses.html',
                data: {
                    micro: true,
                    title: '干部工作'
                },
                controller: 'classleaderCoursesController'
            })
            // 班干部添加考勤记录
            .state('classleader_add_attendance', {
                url: '/classleader_add_attendance',
                templateUrl: 'templates/classroom_attendance/classleader/classleader_add_attendance.html',
                data: {
                    title: '课堂考勤',
                    prev: 'classleader_attendance'
                },
                controller: 'classleaderAddAttendanceController'
            })
            //考勤列表
            .state('attendance_list', {
                url: '/attendance_list',
                templateUrl: 'templates/classroom_attendance/common/attendance_list.html',
                data: {
                    title: '课堂考勤',
                    prev: 'classleader_attendance'
                },
                controller: 'attendanceListController'
            });
    }

    classleaderCoursesController.$inject = ['$scope', '$ionicModal', '$http', '$location', '$filter', 'ynuiNotification', '$ionicScrollDelegate', 'kqktMobileService', '$ionicPopup'];

    // 班干部课程列表
    function classleaderCoursesController($scope, $ionicModal, $http, $location, $filter, ynuiNotification, $ionicScrollDelegate, kqktMobileService, $ionicPopup) {

        var bizType = "classleader";
        var basePath = originBaseUrl + "/third/kqkt/mobile";

        $scope.changeWeek = changeWeek;
        $scope.changeDay = changeDay;
        $scope.submitClassLeaderKqkt = submitClassLeaderKqkt;
        $scope.toAddAtendance = toAddAtendance;

        $scope.prevDay = prevDay;
        $scope.nextDay = nextDay;

        $scope.classLeaderData = {
            dateStr: "",
            date: "",
            weekInfoStr: "",
            weekInfoCode: "",
            weekDayObjList: [],
            week: "",
            day: "",
            weekInfo: {},
            recordList: []
        };



        function findKqktMobilaWeek() {
            $http.get(basePath + "/findKqktMobilaWeek.htm").success(function (data) {
                if (data.status == 0) {
                    $scope.classLeaderData.weekInfo = data.result;
                    if ($scope.classLeaderData.weekInfo) {
                        $scope.classLeaderData.weekInfoCode = data.result.week + "_" + data.result.day;
                        $scope.classLeaderData.week = data.result.week;
                        $scope.classLeaderData.weekInfoStr = convertWeekStr($scope.classLeaderData.weekInfoCode);
                        var nowDate = $filter('date')(new Date(), 'yyyy-MM-dd');
                        if (data.result.today === nowDate) {
                            $scope.classLeaderData.dateStr = getTodayStr(data.result.today);
                        } else {
                            $scope.classLeaderData.dateStr = data.result.today;
                        }
                        $scope.classLeaderData.date = data.result.today;
                        setWeekDayObjList();
                        findClassLeaderKqktRecordList();
                    }
                }
            });
        }

        function getTodayStr(today) {
            return "[今天]" + today;
        }

        function getWeekInfoCodeObj() {
            var weekInfoCodeArr = $scope.classLeaderData.weekInfoCode.split("_");
            return {week: weekInfoCodeArr[0], day: weekInfoCodeArr[1]}
        }

        findKqktMobilaWeek();

        function findClassLeaderKqktRecordList() {
            var weekInfoCodeArr = $scope.classLeaderData.weekInfoCode.split("_");
            var postData = {
                date: $scope.classLeaderData.date,
                week: weekInfoCodeArr[0],
                day: weekInfoCodeArr[1],
                termId: $scope.classLeaderData.weekInfo.termId
            };
            $http.post(basePath + "/findClassLeaderKqktRecordList.htm", postData).success(function (data) {
                if (data.status == 0) {
                    $scope.classLeaderData.recordList = data.result;
                    $ionicScrollDelegate.$getByHandle('listScroll').scrollTop(false);
                }
            });
        }

        function changeDay(weekCode) {
            $scope.classLeaderData.weekInfoStr = convertWeekStr(weekCode);
            $scope.classLeaderData.weekInfoCode = weekCode;
            var weekCodeArr = weekCode.split("_");
            getDayStr(weekCodeArr[0], weekCodeArr[1]);
            $scope.classLeaderData.week = weekCodeArr[0];
            findClassLeaderKqktRecordList();
        }

        function getDayStr(week, day) {
            var getData = {week: week, day: day, termId: $scope.classLeaderData.weekInfo.termId};
            $http.get(basePath + "/queryDayStrByTermIdAndWeekAndDay.htm", {params: getData}).success(function (data) {
                if (data.status == 0) {
                    $scope.classLeaderData.date = data.result;
                    var nowDate = $filter('date')(new Date(), 'yyyy-MM-dd');
                    if (data.result === nowDate) {
                        $scope.classLeaderData.dateStr = getTodayStr(data.result);
                    } else {
                        $scope.classLeaderData.dateStr = data.result;
                    }
                    //切换了日期刷新列表
                    findClassLeaderKqktRecordList();
                }
            });
        }

        function changeWeek(op) {
            var totalWeek = $scope.classLeaderData.weekInfo.totalWeek;
            if (op == "next") {
                var result = $scope.classLeaderData.week + 1;
                if (result <= totalWeek) {
                    $scope.classLeaderData.week = result;
                    setWeekDayObjList();
                }
            } else if (op == "prev") {
                var result = $scope.classLeaderData.week - 1;
                if (result > 0) {
                    $scope.classLeaderData.week = result;
                    setWeekDayObjList();
                }
            }
        }

        function setWeekDayObjList() {
            var weekDayObjList = [];
            var weekDayList = $scope.classLeaderData.weekInfo.weekDayList;
            var week = $scope.classLeaderData.week;
            for (var i = 0; i < weekDayList.length; i++) {
                weekDayObjList.push({id: week + "_" + (i + 1), name: weekDayList[i]});
            }
            $scope.classLeaderData.weekDayObjList = weekDayObjList;
        }

        function convertWeekStr(week) {
            var w = week.split("_");
            return "第" + w[0] + "周" + getWeekDayStr(w[1]);
        }

        function getWeekDayStr(weekDay) {
            var weekDayList = $scope.classLeaderData.weekInfo.weekDayList;
            for (var i = 0; i < weekDayList.length; i++) {
                if (weekDay == (i + 1)) {
                    return weekDayList[i];
                }
            }
            return "";
        }

        function buildQueryNearestParams(item) {
            var weekInfoCodeArr = $scope.classLeaderData.weekInfoCode.split("_");
            var postData = {
                week: weekInfoCodeArr[0],
                day: weekInfoCodeArr[1],
                kqTime: $scope.classLeaderData.date,
                teachClassId: item.teachClassId,
                termId: $scope.classLeaderData.weekInfo.termId,
                source: item.teachResources,
                timeType: item.timeType,
                knob: item.knob
            };
            return postData;
        }


        function buildQueryParams(item) {
            var weekObj = getWeekInfoCodeObj();
            var postData = buildQueryNearestParams(item);
            postData.courseId = item.courseId;
            postData.weekStr = getWeekDayStr(weekObj.day);
            postData.studentSource = $scope.classLeaderData.studentSource;

            return postData;
        }

        function submitClassLeaderKqkt(item) {
            //如果已点名
            if (item.rollCall) {
                $location.path("/attendance_list").search({id: item.id, bizType: bizType});
            } else {
                var postData = buildQueryParams(item);

                // kqktMobileService.recognitionRateFace(2,postData).then(function (data) {
                //    if(data.go){
                //
                //    }
                // });
                $http.post(basePath + "/submitClassLeaderKqktRollCall.htm", postData).success(function (data) {
                    if (data.status == 0) {
                        if (data.result != null) {
                            $location.path("/attendance_list").search({id: data.result, bizType: bizType});
                        }
                    } else if (data.status == 10) {
                        $ionicPopup.confirm({
                            title: '提示',
                            template: "当前时间正在进行课堂自动考勤，确定要手动点名吗？课堂自动考勤将自动生成学生课堂考勤记录，若您仍坚持手动点名，将导致系统无法生成数据。",
                            cancelText: '取消',
                            okText: '确认'
                        }).then(function (res) {
                            if (res) {
                                postData.submitFlag = true;
                                $http.post(basePath + "/submitClassLeaderKqktRollCall.htm", postData).success(function (data) {
                                    if (data.status == 0) {
                                        if (data.result != null) {
                                            $location.path("/attendance_list").search({
                                                id: data.result,
                                                bizType: bizType
                                            });
                                        }
                                    } else {
                                        ynuiNotification.error({msg: data.message});
                                    }
                                });
                            }

                        });
                    } else {
                        ynuiNotification.error({msg: data.message});
                    }
                });
            }
        }

        function prevDay() {
            changeDayPrevAndNext('prev');

        }

        function nextDay() {
            changeDayPrevAndNext();
        }

        function changeDayPrevAndNext(f) {

            var weekObj = getWeekInfoCodeObj();
            var week = parseInt(weekObj.week);
            var day = parseInt(weekObj.day);
            var weekLength = $scope.classLeaderData.weekInfo.weekDayList.length;
            var totalWeek = $scope.classLeaderData.weekInfo.totalWeek;
            if (f == "prev") {
                if ((day - 1) == 0 && (week - 1) == 0) {
                    ynuiNotification.error({msg: "已经是第一天了！"});
                    return;
                } else if ((day - 1) == 0) {
                    day = weekLength;
                    week = week - 1;
                } else {
                    day = day - 1;
                }
            } else {
                if ((day + 1) > weekLength && (week + 1) > totalWeek) {
                    ynuiNotification.error({msg: "已经是最后一天了！"});
                    return;
                } else if ((day + 1) > weekLength) {
                    day = 1;
                    week = week + 1;
                } else {
                    day = day + 1;
                }
            }
            changeDay(week + "_" + day);
        }

        function toAddAtendance() {
            $location.path("/classleader_add_attendance").search();
        }


    }

    classleaderAddAttendanceController.$inject = ['$scope', '$ionicModal', '$http', '$location', '$filter', 'ynuiNotification', '$ionicPopup', 'kqktMobileService', 'ynNavigator'];

    // 班干部添加考勤记录
    function classleaderAddAttendanceController($scope, $ionicModal, $http, $location, $filter, ynuiNotification, $ionicPopup, kqktMobileService, ynNavigator) {

        var basePath = originBaseUrl + "/third/kqkt/mobile";

        $scope.changeKnob = changeKnob;
        $scope.findTeacherClassList = findTeacherClassList;
        $scope.selectTeachClass = selectTeachClass;
        $scope.saveRollCallInfo = saveRollCallInfo;
        $scope.changeSelectData = changeSelectData;
        $scope.saveSelectTime = saveSelectTime;


        var bizType = "classleader";
        $scope.addAttendanceData = {
            dateStr: "",
            weekAndDay: {},
            now: {},
            selectDate: "",
            selectDateTemp: "",
            knobArr: [],
            knobTime: "",
            knobTimeIndex: 0,
            termInfo: {},
            teacherClassList: [],
            teacherClassListTmep: [],
            selectedTeaClass: {
                id: "",
                courseId: "",
                courseName: "",
                majorClassName: "",
                teacherName: "",
                classRoomName: "",
                source: "",
                classSourceName: ""
            },
            selectTime: {
                startTime: "",
                endTime: ""
            },
            filterCourseValue: ""
        };

        function initDate() {
            kqktMobileService.findKqktRollCallInitInfo().then(function (data) {
                    if (data.status == 0) {
                        var config = data.result.config;
                        var teachWeekList = data.result.teachWeekList;
                        var weekAndDay = data.result.weekAndDay;
                        //如果不在学期内，不操作
                        if (!config.inTerm) {
                            $scope.addAttendanceData.inTerm = false;
                            return;
                        }
                        //标识在学期内
                        $scope.addAttendanceData.inTerm = true;

                        $scope.addAttendanceData.now.date = config.nowDate;
                        $scope.addAttendanceData.now.time = config.nowTime;
                        $scope.addAttendanceData.selectDate = config.nowDate;
                        $scope.addAttendanceData.selectDateTemp = config.nowDate;

                        $scope.addAttendanceData.allowCheck = config.allowCheck;
                        $scope.addAttendanceData.termInfo.id = config.termId;
                        $scope.addAttendanceData.termInfo.name = config.termName;

                        $scope.addAttendanceData.knobArr = teachWeekList;
                        $scope.addAttendanceData.weekAndDay = weekAndDay;

                        $scope.addAttendanceData.teachingPeriodBeginDate = config.teachingPeriodBeginDate;
                        $scope.addAttendanceData.teachingPeriodEndDate = config.teachingPeriodEndDate;
                        //选中当前节次
                        setTeachWeekTime(teachWeekList, config.nowTime);
                        //加载周和星期
                        loadWeekAndDay(config.termId, config.nowDate);
                    }
                }
            );
        }

        //初始化数据
        initDate();

        function getKqTimeIndex(knobArr, knobKey) {
            for (var i = 0; i < knobArr.length; i++) {
                if (knobArr[i].knobKey == knobKey) {
                    return i;
                }
            }
            return 0;
        }

        //初始化节次
        function setTeachWeekTime(knobArr, time) {
            var obj = kqktMobileService.getCurrentTeachWeekTime(knobArr, time);
            if (obj) {
                $scope.addAttendanceData.knobTime = obj.knobKey;
                $scope.addAttendanceData.ktStartTime = obj.ktStartTime;
                $scope.addAttendanceData.ktEndTime = obj.ktEndTime;
                $scope.addAttendanceData.knobTimeIndex = getKqTimeIndex(knobArr, obj.knobKey);
                $scope.addAttendanceData.selectTime.startTime = obj.ktStartTime;
                $scope.addAttendanceData.selectTime.endTime = obj.ktEndTime;
            } else {
                //如果没有找到当前节次，默认第一节
                changeKnob(0);
            }
        }

        function selectTeachClass(item) {
            $scope.addAttendanceData.selectedTeaClass.id = item.id;
            $scope.addAttendanceData.selectedTeaClass.courseId = item.courseId;
            $scope.addAttendanceData.selectedTeaClass.courseName = item.courseName;
            $scope.addAttendanceData.selectedTeaClass.majorClassName = item.majorClassName;
            $scope.addAttendanceData.selectedTeaClass.source = item.source;
            findTeacherClassInfo();
            $scope.hideAddAttendanceClassLeaderClassListModal();
        }

        function changeKnob(index) {
            $scope.addAttendanceData.knobTimeIndex = index;
            var knobArr = $scope.addAttendanceData.knobArr;
            var obj = kqktMobileService.getCurrentTeachWeekTimeIndex(knobArr, index);
            if (obj) {
                $scope.addAttendanceData.knobTime = obj.knobKey;
                $scope.addAttendanceData.ktStartTime = obj.ktStartTime;
                $scope.addAttendanceData.ktEndTime = obj.ktEndTime;

                $scope.addAttendanceData.selectTime.startTime = obj.ktStartTime;
                $scope.addAttendanceData.selectTime.endTime = obj.ktEndTime;
            }
            findSelectdClass();
        }

        //获取教学班信息
        function findTeacherClassInfo() {
            var params = buildSelectClassParams();
            params.source = $scope.addAttendanceData.selectedTeaClass.source;
            params.teachClassId = $scope.addAttendanceData.selectedTeaClass.id;
            $http.post(basePath + "/findPlaceAndTeacher.htm", params).success(function (data) {
                if (data.status == 0) {
                    $scope.addAttendanceData.selectedTeaClass.classRoomName = data.result.classRoomName;
                    $scope.addAttendanceData.selectedTeaClass.teacherName = data.result.teacherName;
                }
            });
        }

        function loadWeekTimeList(termId, date) {
            kqktMobileService.findPkTeachWeekTimeList(termId, date).then(function (data) {
                if (data.status == 0) {
                    $scope.addAttendanceData.knobArr = data.result;
                    $scope.addAttendanceData.selectDate = date;
                    $scope.addAttendanceData.selectDateTemp = date;
                    setTeachWeekTime(data.result, $scope.addAttendanceData.now.time);
                }
            });
        }

        //构建选择教学班的参数
        function buildSelectClassParams() {
            var termId = $scope.addAttendanceData.termInfo.id;
            var week;
            var day;
            if ($scope.addAttendanceData.weekAndDay) {
                week = $scope.addAttendanceData.weekAndDay.week;
                day = $scope.addAttendanceData.weekAndDay.day;
            }
            if ($scope.addAttendanceData.knobTime) {
                var timeKnob = $scope.addAttendanceData.knobTime.split("_");
                var timeType = timeKnob[0];
                var knob = timeKnob[1];
            }
            return {termId: termId, week: week, day: day, timeType: timeType, knob: knob};
        }

        //获取选中的教学班
        function findSelectdClass() {
            $http.post(basePath + "/findClassLeaderSelectTeachClass.htm", buildSelectClassParams()).success(function (data) {
                if (data.status == 0) {
                    if (data.result != null) {
                        $scope.addAttendanceData.selectedTeaClass = data.result;
                    } else {
                        $scope.addAttendanceData.selectedTeaClass.id = "";
                    }
                }
            });
        }

        function loadWeekAndDay(termId, date) {
            kqktMobileService.findWeekAndDay(termId, date).then(function (data) {
                if (data.status == 0) {
                    $scope.addAttendanceData.weekAndDay = data.result;
                    $scope.addAttendanceData.dateStr = buildKqTimeStr(data.result);
                    findSelectdClass();
                }
            });
        }

        function buildKqTimeStr(weekAndDay) {
            var str = weekAndDay.dateStr + " " + weekAndDay.weekStr + " " + weekAndDay.dayStr;
            if (weekAndDay.dateStr == $scope.addAttendanceData.now.date) {
                str = "[今天]" + str;
            }
            return str;
        }

        //课程信息
        function findTeacherClassList() {
            $http.get(basePath + "/findClassLeaderTeachClassList.htm", {termId: $scope.addAttendanceData.termInfo.id}).success(function (data) {
                if (data.status == 0) {
                    $scope.addAttendanceData.teacherClassList = data.result;
                    $scope.addAttendanceData.teacherClassListTmep = data.result;
                }
            });
        }

        function changeSelectData() {

            var allowCheck = $scope.addAttendanceData.allowCheck;
            var date = $scope.addAttendanceData.selectDateTemp;
            var nowDate = $scope.addAttendanceData.now.date;

            var teachingPeriodBeginDate = $scope.addAttendanceData.teachingPeriodBeginDate;
            var teachingPeriodEndDate = $scope.addAttendanceData.teachingPeriodEndDate;

            if (!moment(date).isSame(teachingPeriodBeginDate) && !moment(date).isSame(teachingPeriodEndDate) && (moment(date).isAfter(teachingPeriodEndDate) || moment(date).isBefore(teachingPeriodBeginDate))) {
                ynuiNotification.error({msg: "只能当前学期教学周起止日期内的考勤日期！"});
                //复原日期
                $scope.addAttendanceData.selectDate = $scope.addAttendanceData.selectDateTemp;
                return;
            }
            //选择日期在当前日期之后
            if (moment(date).isAfter(nowDate)) {
                ynuiNotification.error({msg: "不允许添加今天之后上课节次的课堂考勤数据！"});
                //复原日期
                $scope.addAttendanceData.selectDate = $scope.addAttendanceData.selectDateTemp;
                return;
            }
            //不允许任课老师/班干部补登记、修改今天之前的课堂考勤记录,所选日期是小于当前服务器日期
            if (!allowCheck && moment(date).isBefore(nowDate)) {
                ynuiNotification.error({msg: "不允许添加今天之前上课节次的课堂考勤数据！"});
                //复原日期
                $scope.addAttendanceData.selectDate = $scope.addAttendanceData.selectDateTemp;
                return;
            }
            $scope.addAttendanceData.selectDate = $scope.addAttendanceData.selectDateTemp;

            var termId = $scope.addAttendanceData.termInfo.id;
            var selectDate = $scope.addAttendanceData.selectDate;

            loadWeekTimeList(termId, selectDate);
            loadWeekAndDay(termId, selectDate);
        }

        //提交考勤信息
        function saveRollCallInfo() {

            var submitKqktData = buildSelectClassParams();
            submitKqktData.source = $scope.addAttendanceData.selectedTeaClass.source;
            submitKqktData.teachClassId = $scope.addAttendanceData.selectedTeaClass.id;
            submitKqktData.kqTime = $scope.addAttendanceData.selectDate;

            submitKqktData.studentSource = $scope.addAttendanceData.studentSource;
            submitKqktData.ktStartTime = $scope.addAttendanceData.ktStartTime + ":00";
            submitKqktData.ktEndTime = $scope.addAttendanceData.ktEndTime + ":00";
            submitKqktData.courseId = $scope.addAttendanceData.selectedTeaClass.courseId;
            submitKqktData.weekStr = $scope.addAttendanceData.weekAndDay.dayStr;

            if (!submitKqktData.kqTime) {
                ynuiNotification.error({msg: "请选择考勤日期！"});
                return;
            }
            if (!submitKqktData.timeType) {
                ynuiNotification.error({msg: "请选择考勤节次！"});
                return;
            }
            if (!submitKqktData.teachClassId) {
                ynuiNotification.error({msg: "请选择考勤的上课课程！"});
                return;
            }
            $http.post(basePath + "/commonSubmitKqktRollCall.htm", submitKqktData).success(function (data) {
                if (data.status == 0) {
                    $location.path("/attendance_list").search({id: data.result, bizType: bizType});
                } else if (data.status == 10) {
                    var confirmPopup = $ionicPopup.confirm({
                        title: "提示",
                        template: '当前时间正在进行课堂自动考勤，确定要手动点名吗？课堂自动考勤将自动生成学生课堂考勤记录，若您仍坚持手动点名，将导致系统无法生成数据。',
                        cancelText: "取消",
                        okText: "确定"
                    });
                    confirmPopup.then(function (res) {
                        if (res) {
                            submitKqktData.submitFlag = true;
                            $http.post(basePath + "/commonSubmitKqktRollCall.htm", submitKqktData).success(function (data) {
                                if (data.status == 0) {
                                    $location.path("/attendance_list").search({id: data.result, bizType: bizType});
                                } else {
                                    ynuiNotification.error({msg: data.message});
                                }
                            });
                        }
                    });
                } else {
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        //返回事件拦截器
        ynNavigator.registerBackAction(function () {
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                template: '确定要放弃当前编辑内容吗？',
                cancelText: "继续编辑",
                okText: "放弃"
            });
            confirmPopup.then(function (res) {
                if (res) {
                    ynNavigator.pop(true);//强制返回上一级
                }
            });
        },101);

        function templateInit() {
            $ionicModal.fromTemplateUrl('templates/classroom_attendance/common/dialog/selectTime.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                $scope.selectTime = modal;
            });
        }

        templateInit();

        function saveSelectTime() {
            var startTime = $scope.addAttendanceData.selectTime.startTime;
            var endTime = $scope.addAttendanceData.selectTime.endTime;

            if (startTime == "") {
                ynuiNotification.error({msg: "请输入开始时间"});
                return false;
            }
            if (endTime == "") {
                ynuiNotification.error({msg: "请输入结束时间"});
                return false;
            }
            var timeFlag = kqktMobileService.compareTime(startTime, endTime);
            if (!timeFlag) {
                ynuiNotification.error({msg: "课堂开始时间不能大于等于课堂结束时间"});
                return false;
            }
            $scope.addAttendanceData.ktStartTime = startTime;
            $scope.addAttendanceData.ktEndTime = endTime;
            $scope.selectTime.hide();
            return true;
        }

        $ionicModal.fromTemplateUrl('classleader_add_attendance_classList_template', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            $scope.addAttendanceClassLeaderClassListModal = modal;
        });
        $scope.showAddAttendanceClassLeaderClassListModal = function () {
            findTeacherClassList();
            $scope.addAttendanceClassLeaderClassListModal.show();
        };
        $scope.hideAddAttendanceClassLeaderClassListModal = function () {
            $scope.addAttendanceClassLeaderClassListModal.hide();
        };
    }

    attendanceListController.$inject = ['$scope','$ionicModal','$http','$location','$filter','ynuiNotification','$ionicPopup','$ionicScrollDelegate','selectStudentFromClassService'];
    // 考勤列表
    function attendanceListController ($scope,$ionicModal,$http,$location,$filter,ynuiNotification,$ionicPopup,$ionicScrollDelegate,selectStudentFromClassService){

        var basePath = originBaseUrl + "/third/kqkt/mobile";

        $scope.changeKqStatus  = changeKqStatus;
        $scope.filterUserList  = filterUserList;
        $scope.changeKqktRollCallCommitStatus = changeKqktRollCallCommitStatus;
        $scope.showNotKqDialog = showNotKqDialog;
        $scope.showSubimtDialog   = showSubimtDialog;
        $scope.deleteConfirm = deleteConfirm;
        $scope.onScrollComplete = onScrollComplete;
        $scope.toAlphabet = toAlphabet;
        $scope.shouldComeUserList = shouldComeUserList;
        $scope.allUserList = allUserList;
        $scope.filterStatusUserlist = filterStatusUserlist;
        $scope.submitByNear  = submitByNear;
        $scope.saveOnTimeClick = saveOnTimeClick;
        $scope.absentClick = absentClick;
        $scope.lateClick = lateClick;
        $scope.leaveEarlyClick = leaveEarlyClick;
        $scope.realSubmit = realSubmit;
        $scope.submitNotKqReason = submitNotKqReason;
        $scope.selectNotKqReason = selectNotKqReason;
        $scope.deleteRollCall = deleteRollCall;

        $scope.addStudent = addStudent;
        $scope.clickSort = clickSort;

        var vm = $scope.vm = {
            searchInfo:{
                id:"1",
                name:"学号排序"
            }
        }

        var rollCallId = $location.search().id;
        var classleader = "classleader";
        var teacher     = "teacher";
        $scope.bizType = $location.search().bizType;

        $scope.alphabetListTmp = ['A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];
        $scope.alphabetList = [];

        $scope.attendanceData = {
            //当前日期
            nowDate:"",
            openFace:false,
            weidmNumActivated:false,
            notKqNumActivated:false,
            studentListTemp:[],
            kqktInfo:{},
            kqktStatisticsInfo:{},
            noNeedReasonKeyList:[],
            opStudent:{},
            notReasonTip:"请选择不考勤原因",
            notReasonObj:{studentId:"",key:"",remark:""},
            weidmNum:0,
            notKqNum:0,
            isSaveOnTime:true,
            //是否允许任课老师/班干部补登记、修改今天之前的课堂考勤记录
            allowCheck:false,
            //班干部提交考勤结果后，是否需任课老师确认
            needTeacherComfirm:false,
            //是否允许任课老师/班干部修改今天“已提交”的课堂考勤记录
            allowUpdateToday:false,
            //最近一次考勤ID
            nearestRollCallId:"",
            showSendMsgFlag:false,
            kqSendMsgStatus:{
                absent:true,
                late:false,
                leaveEarly:false
            },
            dateStatus:"",
            calm:"all",
            scHeight:54,
            compareDate:"",
            //是否显示任课老师编辑BAR
            isShowEditTeacherBar:false,
            //是否显示任课老师删除BAR
            isShowDeleteTeacherBar:false,
            //是否显示班干部编辑BAR
            isShowEditClassLeaderBar:false,
            //是否显示班干部删除BAR
            isShowDeleteClassLeaderBar:false,
            isEdit:false,
            nearMsg:"",
            clam :"all"
        };

        function initNotReasonTip() {
            $scope.attendanceData.notReasonTip = '请选择不考勤原因';
        }

        function selectNotKqReason(item) {
            $scope.attendanceData.notReasonTip = item.dictName;
            $scope.attendanceData.notReasonObj.key = item.dictCode;
        }

        function clickSort(type) {
            vm.searchInfo.id = type +"";
            if (type === 1){
                vm.searchInfo.name = "学号排序";
            }else {
                vm.searchInfo.name = "名称排序";
            }
            findMobileKqktInfo(rollCallId,true);
        }

        function addStudent() {
            selectStudentFromClassService.select(function (users) {

                var studentIdList = [];
                angular.forEach(users,function (item) {
                    studentIdList.push(item.id);
                });
                var data = {rollCallId:rollCallId,studentIdList:studentIdList};
                $http.post(basePath + "/addStudentToRollCall.htm",data).success(function(data){
                    if(data.status==0){
                        findMobileKqktInfo(rollCallId);
                        refreshRollCallStatisticsNum();
                        ynuiNotification.success({msg: '添加成功!'});
                    }else{
                        ynuiNotification.error({msg: data.message});
                    }
                });

            });
        }


        $scope.flag =false;

        $scope.statusClick = function(item){
            $scope.flag =true;
            item.attendanceStatus = !item.attendanceStatus;
        };

        function init(){
            findNoNeedReasonKeyList();
            findKqktConfig();
            findMobileKqktInfo(rollCallId);
        }
        init();
        $scope.click = function (event) {
            event.stopPropagation();
        };

        function submitNotKqReason() {
            if(!$scope.attendanceData.notReasonObj.key){
                ynuiNotification.error({msg: "请选择不考勤原因！"});
                return;
            }
            var postData = {kqktUserId:$scope.attendanceData.opStudent.id,isCheck:false,noNeedCheckReasonCode:$scope.attendanceData.notReasonObj.key,noNeedCheckReasonRemark:$scope.attendanceData.notReasonObj.remark};
            $http.post(basePath + "/changeKqktNeedCheck.htm",postData).success(function(data){
                if(data.status==0){
                    $scope.notKqDialog.hide();
                    ynuiNotification.success({msg: '保存成功'});
                    userStatusOperator.setNoReasonStatus($scope.attendanceData.notReasonObj);
                    retractOpStatus();
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
        }
        function findKqktConfig(){
            $http.get(basePath + "/findKqktConfigInfo.htm").success(function(data){
                if(data.status == 0){
                    $scope.attendanceData.allowCheck = data.result.allowCheck;
                    $scope.attendanceData.needTeacherComfirm = data.result.needTeacherComfirm;
                    $scope.attendanceData.allowUpdateToday   = data.result.allowUpdateToday;
                    $scope.attendanceData.nowDate   = data.result.nowDate;
                    $scope.attendanceData.openFace   = data.result.openFace;

                    findRollCallStatisticsInfo(rollCallId);
                }
            });
        }

        function isShowDeleteClassLeaderBar() {
            return $scope.bizType == 'classleader' && $scope.attendanceData.kqktStatisticsInfo.myCreate &&  $scope.attendanceData.kqktStatisticsInfo.commitStatus == '0' && !$scope.attendanceData.isEdit;
        }

        function isShowEditClassLeaderBar() {
            return $scope.bizType == 'classleader' && $scope.attendanceData.kqktStatisticsInfo.myCreate && $scope.attendanceData.isEdit;
        }

        function isShowEditTeacherBar() {
            return $scope.bizType == 'teacher' && $scope.attendanceData.isEdit;
        }

        function isShowDeleteTeacherBar() {
            return $scope.bizType == 'teacher' && $scope.attendanceData.kqktStatisticsInfo.commitStatus != '2' && !$scope.attendanceData.isEdit;
        }

        function isEdit() {
            return ($scope.attendanceData.compareDate =='2' &&  $scope.attendanceData.allowCheck) ||
                ($scope.attendanceData.compareDate =='1' &&  $scope.attendanceData.allowUpdateToday) ||
                ($scope.attendanceData.compareDate =='1' && !$scope.attendanceData.allowUpdateToday  && $scope.attendanceData.kqktStatisticsInfo.commitStatus != '2');
        }

        function compareNowDate(info) {
            if(moment(info.kqDate).isSame(info.nowDate)){
                return "1";
            }
            if(moment(info.kqDate).isBefore(info.nowDate)){
                return "2";
            }
            if(moment(info.kqDate).isAfter(info.nowDate)){
                return "3";
            }
        }

        function findRollCallStatisticsInfo(rollCallId) {
            $http.get(basePath + "/findRollCallStatisticsInfo.htm?rollCallId="+rollCallId).success(function(data){
                if(data.status==0){

                    $scope.attendanceData.kqktStatisticsInfo = data.result;
                    $scope.attendanceData.compareDate = compareNowDate(data.result);

                    $scope.attendanceData.isEdit = isEdit();
                    $scope.attendanceData.isShowEditTeacherBar = isShowEditTeacherBar();
                    $scope.attendanceData.isShowDeleteTeacherBar = isShowDeleteTeacherBar();

                    $scope.attendanceData.isShowEditClassLeaderBar = isShowEditClassLeaderBar();
                    $scope.attendanceData.isShowDeleteClassLeaderBar = isShowDeleteClassLeaderBar();


                    angular.forEach($scope.attendanceData.kqktStatisticsInfo.teachClassList,function (item) {
                        if(item.teacherList && item.teacherList.length >2){
                            item.teacherList.length = 2;
                        }
                    });
                    var teachClassList = $scope.attendanceData.kqktStatisticsInfo.teachClassList;
                    if(teachClassList && teachClassList.length > 2){
                        $scope.attendanceData.kqktStatisticsInfo.secondNumTeachClassList = [];
                        for(var i=2;i<teachClassList.length;i++){
                            $scope.attendanceData.kqktStatisticsInfo.secondNumTeachClassList.push(teachClassList[i]);
                        }
                    }
                    if($scope.attendanceData.kqktStatisticsInfo.teachClassList){
                        if($scope.attendanceData.kqktStatisticsInfo.teachClassList.length == 1){
                            $scope.attendanceData.scHeight = 88;
                        }else if($scope.attendanceData.kqktStatisticsInfo.teachClassList.length > 1){
                            $scope.attendanceData.scHeight = 128;
                        }
                    }
                }
            });
        }

        //根据不需考勤原因码表值获取名称
        function findNoNeedReasonNameByKey(key) {
            var arr = $scope.attendanceData.noNeedReasonKeyList;
            for(var index in arr){
                if(arr[index].dictCode == key){
                    return arr[index].dictName;
                }
            }
        }
        //获取不需考勤码表
        function findNoNeedReasonKeyList() {
            $http.get(basePath + "/findNoNeedReasonKeyList.htm").success(function(data){
                if(data.status==0){
                    $scope.attendanceData.noNeedReasonKeyList = data.result;
                }
            });
        }

        //学生考勤状态操作者
        var userStatusOperator = {
            //复制学生信息副本
            copyDataToTempList:function(item){
                var tempList = $scope.attendanceData.studentListTemp;
                for(var index in tempList){
                    if(tempList[index].id == item.id){
                        tempList[index] = angular.copy(item);
                        break;
                    }
                }
            },
            //设置考勤状态
            setStatus:function (item, status) {
                item.kqStatus = status;
                item.needKq = true;
                item.remark="";
                this.copyDataToTempList(item);
                //刷新班级人数
                refreshRollCallStatisticsNum();
            },
            //设置不需考勤
            setNoReasonStatus:function (noReasonObj) {
                var userList = $scope.attendanceData.kqktInfo.studentList;
                for(var index in userList){
                    if(userList[index].id == $scope.attendanceData.opStudent.id){
                        userList[index].needKq = false;
                        userList[index].kqStatus = null;
                        userList[index].notKqRemark = buildNoNeedReason(noReasonObj.key,noReasonObj.remark);
                        this.copyDataToTempList(userList[index]);
                        //刷新班级人数
                        refreshRollCallStatisticsNum();
                        break;
                    }
                }
            }
        };

        //全部学生
        function allUserList() {
            $scope.attendanceData.kqktInfo.studentList = $scope.attendanceData.studentListTemp;
            $scope.attendanceData.clam = "all";
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTop(false);
        }
        //应到学生
        function shouldComeUserList() {
            $scope.attendanceData.kqktInfo.studentList = $filter("filter")($scope.attendanceData.studentListTemp, {needKq: true});
            $scope.attendanceData.clam = "sd";
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTop(false);
        }

        function filterStatusUserlist(value) {
            $scope.attendanceData.kqktInfo.studentList = $filter("filter")($scope.attendanceData.studentListTemp, {kqStatus:value});
            $scope.attendanceData.clam = value;
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTop(false);
        }
        //过滤学生名单
        function filterUserList(value) {
            if (value == "1") {
                if(!$scope.attendanceData.weidmNumActivated){
                    //需要考勤
                    $scope.attendanceData.kqktInfo.studentList = $filter("filter")($scope.attendanceData.studentListTemp, {needKq: true,kqStatus:null});
                }else{
                    $scope.attendanceData.kqktInfo.studentList = $scope.attendanceData.studentListTemp;
                }
                $scope.attendanceData.clam = 6;
            } else if (value == "2") {
                if(!$scope.attendanceData.notKqNumActivated){
                    //不需要考勤
                    $scope.attendanceData.kqktInfo.studentList = $filter("filter")($scope.attendanceData.studentListTemp, {needKq: false});
                }else{
                    $scope.attendanceData.kqktInfo.studentList = $scope.attendanceData.studentListTemp;
                }
                // $scope.attendanceData.notKqNumActivated = !$scope.attendanceData.notKqNumActivated;
                $scope.attendanceData.clam = 7;
            } else {
                $scope.attendanceData.clam = "-1";
            }
            initSelectAlphabet();
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTop(false);
        }

        function buildNoNoeedReasonStr(reason,remark) {
            var codeName = "";
            if(remark != "" && remark != null){
                codeName =  reason + "("+remark+")";
            }else{
                codeName =  reason;
            }
            return codeName;
        }

        //构建不需要考勤原因
        function buildNoNeedReason(noReasonCode,remark) {
            var codeName = findNoNeedReasonNameByKey(noReasonCode);
            return buildNoNoeedReasonStr(codeName,remark);
        }

        //刷新班级人数
        function refreshRollCallStatisticsNum() {
            $http.get(basePath + "/findRollCallStatisticsNum.htm?rollCallId="+rollCallId).success(function(data){
                if(data.status==0){
                    //设置考勤状态
                    $scope.attendanceData.kqktInfo.totalNum    =data.result.totalNum;
                    $scope.attendanceData.kqktInfo.shouldNum   =data.result.shouldNum;
                    $scope.attendanceData.kqktInfo.actNum      =data.result.actNum;
                    $scope.attendanceData.kqktInfo.leaveNum    =data.result.leaveNum;
                    $scope.attendanceData.kqktInfo.absentNum   =data.result.absentNum;
                    $scope.attendanceData.kqktInfo.lateNum     =data.result.lateNum;
                    $scope.attendanceData.kqktInfo.leaveEarlyNum    =data.result.leaveEarlyNum;
                    $scope.attendanceData.kqktInfo.onTimeNum    =data.result.onTimeNum;
                }
            });
            countKqWdmAndNotKq();
        }

        function retractOpStatus() {
            angular.forEach($scope.attendanceData.kqktInfo.studentList,function (item) {
                item.attendanceStatus = false;
            });
        }

        //修改考勤状态
        function changeKqStatus(item,status) {
            $scope.flag = true;
            var data = {params:{kqktUserId:item.id,kqStatus:status}};
            $http.get(basePath + "/changeKqktStatus.htm",data).success(function(data){
                if(data.status==0){
                    //设置考勤状态
                    userStatusOperator.setStatus(item,status);
                    retractOpStatus();
                    //操作了一个学生之后，将下一个学生的操作展开
                    var studentList = $scope.attendanceData.kqktInfo.studentList;
                    for(var i=0;i<studentList.length;i++){
                        if(studentList[i].id == item.id){
                            studentList[i+1].attendanceStatus = true;
                            break;
                        }
                    }
                }
            });
        }

        //根据考勤ID获取考勤信息
        function findMobileKqktInfo(rollCallId,flag){
            var param = {
                rollCallId:rollCallId,
                sortType:vm.searchInfo.id,
            };
            $http.post(basePath + "/findMobileKqktInfo.htm",param).success(function(data){
                if(data.status==0){
                    $scope.attendanceData.kqktInfo = data.result;
                    if(data.result.hasMoreMajorClass){
                        angular.forEach($scope.attendanceData.kqktInfo.studentList,function (item) {
                            item.attendanceStatus= false;
                            item.attendWayAndClassStr = item.attendWay;
                            if(item.attendWay != null && item.attendWay !='' && item.teachClassName != null && item.teachClassName !='' ){
                                item.attendWayAndClassStr+=",";
                            }
                            item.attendWayAndClassStr+=item.teachClassName;
                        });
                    }else{
                        angular.forEach($scope.attendanceData.kqktInfo.studentList,function (item) {
                            item.attendanceStatus= false;
                            item.attendWayAndClassStr = item.attendWay;
                        });
                    }
                    $scope.attendanceData.studentListTemp = $scope.attendanceData.kqktInfo.studentList;
                    angular.forEach($scope.attendanceData.kqktInfo.studentList,function (item) {
                        if($scope.alphabetList.indexOf(item.firstChar) == -1 && $scope.alphabetListTmp.indexOf(item.firstChar) !=-1 ){
                            $scope.alphabetList.push(item.firstChar);
                        }
                    });
                    initSelectAlphabet();
                    countKqWdmAndNotKq();
                    if (flag){
                        switch ($scope.attendanceData.clam+"") {
                            case "all":allUserList();break;
                            case "sd":shouldComeUserList();break;
                            case "5":filterStatusUserlist(5);break;
                            case "1":filterStatusUserlist(1);break;
                            case "2":filterStatusUserlist(2);break;
                            case "3":filterStatusUserlist(3);break;
                            case "4":filterStatusUserlist(4);break;
                            case "6":filterUserList("1");break;
                            case "7":filterUserList("2");break;
                        }
                    }
                }
            });
        }



        function countKqWdmAndNotKq(){
            var wdmNum = 0;
            var notKqNum = 0;
            angular.forEach($scope.attendanceData.studentListTemp,function (item) {
                if((item.needKq && item.kqStatus == null) || (item.needKq && item.kqStatus == "")){
                    wdmNum ++;
                }
                if(!item.needKq){
                    notKqNum++;
                }
            });
            $scope.attendanceData.weidmNum = wdmNum;
            $scope.attendanceData.notKqNum = notKqNum;
        }


        var notReasonConfig = {
            templateUrl: 'templates/classroom_attendance/common/dialog/notKqReason.html',
            title: '提示',
            scope: $scope,
            buttons: [
                { text: '取消' },
                {
                    text: '<b>确定</b>',
                    type: 'button-positive',
                    onTap: function(e) {
                        if(!$scope.attendanceData.notReasonObj.key){
                            ynuiNotification.error({msg: "请选择不考勤原因！"});
                            e.preventDefault();
                        }else{
                            submitNotKqReason();
                        }
                    }
                }
            ]
        };

        function showSubimtDialog() {
            $scope.submitDialog.show();
            $http.get(basePath + "/hasMajorClass.htm?rollCallId="+rollCallId).success(function(data){
                if(data.status==0){
                    if(data.result){
                        showSendMsgFlag(true);
                    }else{
                        showSendMsgFlag(false);
                    }
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        function showSendMsgFlag(flag) {
            initkqSendMsgStatus();
            var studentList = $scope.attendanceData.kqktInfo.studentList;
            if(flag){
                $scope.attendanceData.showSendMsgFlag = true;
                var showSendMsgFlag = false;
                for(var i=0;i<studentList.length;i++){
                    if(studentList[i].kqStatus == '2' || studentList[i].kqStatus == '3' || studentList[i].kqStatus == '4'){
                        showSendMsgFlag = true;
                        break;
                    }
                }
                $scope.attendanceData.showSendMsgFlag = showSendMsgFlag;
            }else{
                $scope.attendanceData.showSendMsgFlag =  false;
            }
        }


        function showNotKqDialog(item){
            $scope.attendanceData.opStudent = item;
            $scope.attendanceData.notReasonObj.studentId = item.id;
            $scope.attendanceData.notReasonObj = {};
            $ionicPopup.show(notReasonConfig);
        }

        //初始化发送考勤状态
        function initkqSendMsgStatus() {
            $scope.attendanceData.kqSendMsgStatus.absent = true;
            $scope.attendanceData.kqSendMsgStatus.late = false;
            $scope.attendanceData.kqSendMsgStatus.leaveEarly = false;
        }

        function realSubmit() {
            var kqktStatusList = [];
            if($scope.attendanceData.kqSendMsgStatus.absent){
                kqktStatusList.push(2);
            }
            if($scope.attendanceData.kqSendMsgStatus.late){
                kqktStatusList.push(3);
            }
            if($scope.attendanceData.kqSendMsgStatus.leaveEarly){
                kqktStatusList.push(4);
            }
            var kqStatus = 2;
            //如果是班干部，需要老师确认考勤，则班干部提交为待确认
            if($scope.bizType == classleader && $scope.attendanceData.needTeacherComfirm){
                kqStatus = 1;
            }
            var postData = {rollCallId:rollCallId,kqStatus:kqStatus,isSaveOnTime:true,kqktStatusList:kqktStatusList,systemId:'FW-S-019',menuId:'FW-S-019-M-001'};
            $http.post(basePath + "/realSubmit.htm",postData).success(function(data){
                if(data.status==0){
                    ynuiNotification.success({msg: '保存成功'});
                    backPath();
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
            $scope.submitDialog.hide();
        }

        function changeKqktRollCallCommitStatus(status) {
            if(!status){
                status = 0;
            }
            var getData = {rollCallId:rollCallId,kqStatus:status,isSaveOnTime:$scope.attendanceData.isSaveOnTime};
            $http.get(basePath + "/changeKqktRollCallCommitStatus.htm",{params:getData}).success(function(data){
                if(data.status==0){
                    findMobileKqktInfo(rollCallId);
                    $scope.draftDialog.hide();
                    ynuiNotification.success({msg: '保存成功'});
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        function templateInit(){

            $ionicModal.fromTemplateUrl('nearDialog.html',{
                scope:$scope,
                animation:'slide-in-up'
            }).then(function(modal){
                $scope.nearDialog = modal;
            });
            $scope.nearDialogShow = function() {
                //最近一次考勤记录
                findNearestKqktRollCall();
            };

            $ionicModal.fromTemplateUrl('deleteDialog.html',{
                scope:$scope,
                animation:'slide-in-up'
            }).then(function(modal){
                $scope.deleteDialog = modal;
            });

            $ionicModal.fromTemplateUrl('submitDialog.html',{
                scope:$scope,
                animation:'slide-in-up'
            }).then(function(modal){
                $scope.submitDialog = modal;
            });

            $ionicModal.fromTemplateUrl('draftDialog.html',{
                scope:$scope,
                animation:'slide-in-up'
            }).then(function(modal){
                $scope.draftDialog = modal;
            });

            $ionicModal.fromTemplateUrl('notKqDialog.html',{
                scope:$scope,
                animation:'slide-in-up'
            }).then(function(modal){
                $scope.notKqDialog = modal;
            });

            $scope.notKqDialogShow = function (item) {
                $scope.flag = true;
                $scope.attendanceData.opStudent = item;
                $scope.attendanceData.notReasonObj.studentId = item.id;
                $scope.attendanceData.notReasonObj = {};
                initNotReasonTip();
                $scope.notKqDialog.show();
            }

        }
        templateInit();

        function saveOnTimeClick() {
            $scope.attendanceData.isSaveOnTime = !$scope.attendanceData.isSaveOnTime;
        }

        function absentClick() {
            $scope.attendanceData.kqSendMsgStatus.absent = !$scope.attendanceData.kqSendMsgStatus.absent;
        }

        function lateClick() {
            $scope.attendanceData.kqSendMsgStatus.late = !$scope.attendanceData.kqSendMsgStatus.late;
        }

        function leaveEarlyClick() {
            $scope.attendanceData.kqSendMsgStatus.leaveEarly = !$scope.attendanceData.kqSendMsgStatus.leaveEarly;
        }

        //使用最近一次考勤名单
        function submitByNear() {
            if(!$scope.attendanceData.nearestRollCallId){
                ynuiNotification.error({msg: "没有获取到最近一次的点名名单!"});
                return;
            }
            $scope.nearDialog.hide();
            $http.post(basePath + "/submitNearestRollCallById.htm",{rollCallId:rollCallId,nearestRollCallId:$scope.attendanceData.nearestRollCallId}).success(function(data){
                if(data.status == 0){
                    //重新获取列表
                    findMobileKqktInfo(rollCallId);
                    ynuiNotification.success({msg: '使用最近一次考勤的学生名单成功!'});
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        //获取最近一次考勤记录
        function findNearestKqktRollCall() {
            $http.post(basePath + "/findNearestKqktRollCall.htm?rollCallId="+rollCallId).success(function(data){
                if(data.status==0){
                    if(data.result == null){
                        ynuiNotification.error({msg: '该教学班本次为学期第一次点名，还没有最近一次的点名名单！'});
                    }else{
                        $scope.attendanceData.nearMsg = data.result.name;
                        $scope.attendanceData.nearestRollCallId = data.result.id;
                        $scope.nearDialog.show();
                    }
                }
            });
        }

        function deleteConfirm() {
            var confirmPopup = $ionicPopup.confirm({
                title:"提示",
                template: '确定要删除该节课的点名记录吗？',
                cancelText:"取消",
                okText:"确认"
            });
            confirmPopup.then(function(res) {
                if(res) {
                    deleteRollCall();
                }
            });
        }

        function deleteRollCall(){
            $http.get(basePath + "/deleteKqktRollCall.htm?rollCallId="+rollCallId).success(function(data){
                if(data.status==0){
                    ynuiNotification.success({msg: '删除成功'});
                    $scope.deleteDialog.hide();
                    backPath();
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            });
        }

        function backPath() {
            if($scope.bizType == classleader){
                $location.path("/classleader_attendance").search();
            }else if($scope.bizType == teacher){
                $location.path("/attendance").search();
            }
        }

        $scope.selectAlphabet = "";

        function initSelectAlphabet() {
            var studentList = $scope.attendanceData.kqktInfo.studentList;
            if(studentList.length > 0){
                $scope.selectAlphabet = studentList[0].firstChar;
            }
        }

        function toAlphabet(n) {

            $scope.selectAlphabet = n;
            if($scope.selectAlphabet == ""){
                return;
            }
            var studentList = $scope.attendanceData.kqktInfo.studentList;
            var alphabetId ="";
            var index = "";
            for(var i=0;i<studentList.length;i++){
                if(studentList[i].firstChar == $scope.selectAlphabet){
                    alphabetId = studentList[i].firstChar;
                    index = i;
                    break;
                }
            }
            if(alphabetId == ""){
                return;
            }

            var id = "#"+index+"_"+alphabetId;
            // 定位处理
            var selectedTop = $(id).position().top; // 相对父级（list）的位置
            if(selectedTop){
                $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0,selectedTop,true);
            }
        }

        function buildlistId(index, list) {
            return "#"+index+"_"+list[index].firstChar;
        }

        function onScrollComplete() {
            if($scope.flag){
                $scope.flag = false;
                return;
            }
            var minId = null;
            var studentList = $scope.attendanceData.kqktInfo.studentList;
            for(var i=0;i<studentList.length;i++){
                // 获取最小的top
                var newId = "#"+i+"_"+studentList[i].firstChar;
                var offsetTop = $(newId).offset().top;
                if(offsetTop > 0 && studentList.length > 1){
                    minId = buildlistId(i+1,studentList);
                    break;
                }else if(offsetTop > 0){
                    minId = buildlistId(i,studentList);
                    break;
                }
            }
            if(minId){
                // 重新定位
                $scope.selectAlphabet = minId.split("_")[1];
                $scope.$apply($scope.selectAlphabet);
            }
        }

    }

    function selectStudentFromClassService ($ionicModal, $rootScope,$http,$ionicScrollDelegate,ynuiNotification) {
        var $scope = $rootScope.$new();

        var basePath = originBaseUrl + "/third/kqkt/mobile";

        $scope.alphabetListTmp = ['A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];
        $scope.alphabetList = [];

        $scope.gradeList    =[];
        $scope.adminOrgList =[];
        $scope.adminClassList    =[];
        $scope.studentList  =[];
        $scope.selectedOrg  ={};

        $scope.selectedGrade={};
        $scope.selectedGradeTemp = {};

        $scope.selectedAdminClass  = {};

        $scope.selectedArr = {};
        $scope.selectAlphabet = {};

        //年级
        function getNearlyFiveYearsGrades() {
            $http.get(basePath + '/findGradesByNearYearCount.htm').success(function (data) {
                if (data.status == 0) {
                    $scope.gradeList = data.result;
                    $scope.selectedArr = {};
                    if($scope.gradeList && $scope.gradeList.length > 0){
                        getAdminClassOrgs($scope.gradeList[0]);
                    }
                }
            });
        }

        //行政班机构
        function getAdminClassOrgsOnly(gradeObj) {
            $http.get(basePath + '/getAdminClassOrgs.htm?gradeId='+gradeObj.id).success(function (data) {
                if (data.status == 0) {
                    $scope.adminOrgList = data.result;
                    buildGradeAndOrgKey(gradeObj);
                }
            });
        }

        function buildGradeAndOrgKey(gradeObj) {
            //构造一个key，用于区分机构的年级
            angular.forEach($scope.adminOrgList,function (item) {
                item.key = gradeObj.id+"_"+item.id;
            })
        }

        //行政班机构
        function getAdminClassOrgs(gradeObj) {
            $http.get(basePath + '/getAdminClassOrgs.htm?gradeId='+gradeObj.id).success(function (data) {
                if (data.status == 0) {
                    $scope.adminOrgList = data.result;
                    if($scope.adminOrgList && $scope.adminOrgList.length > 0){
                        var orgObj = $scope.adminOrgList[0];
                        getAdminClssList(gradeObj,orgObj);
                        buildGradeAndOrgKey(gradeObj);
                        $scope.selectedOrg = orgObj;
                    }

                }
            });
        }
        //行政班
        function getAdminClssList(gradeObj,orgNoObj) {

            $scope.selectedGrade = gradeObj;
            $scope.selectedGradeTemp = gradeObj;
            $http.get(basePath + '/getAdminClssList.htm?gradeId='+gradeObj.id+"&orgNo="+orgNoObj.id).success(function (data) {
                if (data.status == 0) {
                    $scope.adminClassList = data.result;
                    if($scope.adminClassList && $scope.adminClassList.length > 0){
                        getAdminClassStudentList($scope.adminClassList[0]);
                    }
                }
            });
        }
        //学生
        function getAdminClassStudentList(adminClassObj) {
            $scope.selectedAdminClass = adminClassObj;
            $http.get(basePath + '/getAdminClassStudentList.htm?adminClassId='+adminClassObj.id).success(function (data) {
                if (data.status == 0) {
                    $scope.studentList = data.result;
                    var map = $scope.selectedArr;
                    $scope.alphabetList = [];
                    angular.forEach($scope.studentList,function (student) {
                        student.isSelected = map.hasOwnProperty(student.id);

                        if($scope.alphabetList.indexOf(student.firstChar) == -1 && $scope.alphabetListTmp.indexOf(student.firstChar) !=-1 ){
                            $scope.alphabetList.push(student.firstChar);
                        }
                    });
                    initSelectAlphabet();
                }
            });
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTop();
        }
        //选择学生
        function selectStu(student) {
            student.isSelected = !student.isSelected;
            var map = $scope.selectedArr;
            if(student.isSelected && !map.hasOwnProperty(student.id)){
                map[student.id] = student;
            }else if(!student.isSelected && map.hasOwnProperty(student.id)){
                delete map[student.id];
            }
            $scope.studentArr = convertMapToArr(map);
        }

        function convertMapToArr(map) {
            var arr = [];
            for(var key in map){
                arr.push(map[key]);
            }
            return arr;
        }


        //删除选中的学生
        function removeStu(student) {
            var map = $scope.selectedArr;
            if(map.hasOwnProperty(student.id)){
                var studentList = $scope.studentList;
                for(var i=0;i<studentList.length;i++){
                    if(studentList[i].id == student.id){
                        studentList[i].isSelected = false;
                        break;
                    }
                }
                delete map[student.id];
            }
            $scope.studentArr = convertMapToArr(map);
        }

        function getStudentLength() {
            return Object.keys($scope.selectedArr).length;
        }

        function showDialog() {
            if ($scope.selectStudentFromClassDialog) {
                $scope.selectStudentFromClassDialog.show();
            }
        }
        function hideDialog() {
            if ($scope.selectStudentFromClassDialog) {
                $scope.selectStudentFromClassDialog.hide();
            }
        }
        function initTeamplate() {
            $ionicModal.fromTemplateUrl('templates/classroom_attendance/common/selectStudentFromClass.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                $scope.selectStudentFromClassDialog = modal;
            });
            $ionicModal.fromTemplateUrl('templates/classroom_attendance/common/select_grade.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                $scope.selectGradeDialog = modal;
            });

        }
        initTeamplate();

        function selectGrade(grade) {
            $scope.selectedGradeTemp = grade;
            getAdminClassOrgsOnly(grade);
        }

        function selectAdminClass(adminClass) {
            getAdminClassStudentList(adminClass);
        }

        function selectOrg(orgObj) {
            getAdminClssList($scope.selectedGradeTemp,orgObj);
            $scope.selectedOrg = orgObj;
            $scope.selectGradeDialog.hide();
        }

        function selectGradeShow() {
            if($scope.selectedGradeTemp != $scope.selectedGrade){
                $scope.selectedGradeTemp = $scope.selectedGrade;
                getAdminClassOrgsOnly($scope.selectedGrade);
            }
            $scope.selectGradeDialog.show();
        }
        //初始化数据
        function initDate() {
            $scope.studentArr = [];
            $scope.showSelectedStu = false;
            getNearlyFiveYearsGrades();
        }
        function select(callBack) {
            initDate();
            showDialog();
            $scope.callBackDeal = function (){
                if(getStudentLength() < 1){
                    ynuiNotification.error({msg: "您还没有选择学生！"});
                    return;
                }
                callBack($scope.selectedArr);
                hideDialog();
            };
        }

        function initSelectAlphabet() {
            var studentList = $scope.studentList;
            if(studentList.length > 0){
                $scope.selectAlphabet = studentList[0].firstChar;
            }
        }

        function toAlphabet(n){
            $scope.selectAlphabet = n;
            if($scope.selectAlphabet == ""){
                return;
            }
            var studentList = $scope.studentList;
            var alphabetId ="";
            var index = "";
            for(var i=0;i<studentList.length;i++){
                if(studentList[i].firstChar == $scope.selectAlphabet){
                    alphabetId = studentList[i].firstChar;
                    index = i;
                    break;
                }
            }
            if(alphabetId == ""){
                return;
            }

            var id = "#"+index+"_"+alphabetId;
            // 定位处理
            var selectedTop = $(id).position().top; // 相对父级（list）的位置
            if(selectedTop){
                $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0,selectedTop,true);
            }
        }

        function onScrollComplete() {
            var minId = null;
            var studentList = $scope.studentList;
            for(var i=0;i<studentList.length;i++){
                // 获取最小的top
                var newId = "#"+i+"_"+studentList[i].firstChar;
                var offsetTop = $(newId).offset().top;
                if(offsetTop > 0 && studentList.length > 1){
                    minId = buildlistId(i+1,studentList);
                    break;
                }else if(offsetTop > 0){
                    minId = buildlistId(i,studentList);
                    break;
                }
            }
            if(minId){
                var firstId  = buildlistId(0,studentList);
                if(studentList.length > 1){
                    var secondId = buildlistId(1,studentList);
                    if(minId == secondId){
                        $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0,$(firstId).position().top,true);
                    }else{
                        $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0,$(minId).position().top,true);
                    }
                    // 重新定位
                    $scope.selectAlphabet = minId.split("_")[1];
                    $scope.$apply($scope.selectAlphabet);
                }
            }
        }

        function buildlistId(index, list) {
            return "#"+index+"_"+list[index].firstChar;
        }

        $scope.hideDialog      = hideDialog;
        $scope.selectGradeShow = selectGradeShow;
        $scope.selectGrade     = selectGrade;
        $scope.selectOrg       = selectOrg;
        $scope.selectAdminClass     = selectAdminClass;
        $scope.selectStu       = selectStu;
        $scope.getStudentLength       = getStudentLength;
        $scope.removeStu       = removeStu;
        $scope.toAlphabet       = toAlphabet;
        $scope.onScrollComplete = onScrollComplete;

        return {select: select}
    }
})();
