/**
 * 健康上报
 *
 * @author Jin Tan
 * @date 2017/12/19
 */

(function() {
    'use strict';

    angular.module('starter').config(stateConfig)
        .controller('collectSituationHomeCtrl', collectSituationHomeCtrl)
        .controller('collectSituationCtrl', collectSituationCtrl)
        .controller('collectInfoListCtrl', collectInfoListCtrl)
        .controller('collectDetailCtrl', collectDetailCtrl);

    stateConfig.$inject = ['$stateProvider'];

    /**
     * 路由配置
     *
     * @param $stateProvider
     */
    function stateConfig($stateProvider) {
        $stateProvider
            .state('collectSituation', {
                url: '/collectSituation',
                templateUrl: 'templates/collectSituation/collect_situation.html',
                controller: 'collectSituationHomeCtrl',
                data: {
                    micro: true,
                    title: '健康上报'
                }
            })
            .state('collectDetail', {
                url: '/collectDetail',
                templateUrl: 'templates/collectSituation/collectInfo_detail.html',
                controller: 'collectDetailCtrl',
                controllerAs: 'vm',
                data: {
                    prev: 'collectSituation',
                    title: '健康上报'
                }
            });
    }

    /**
     * 健康上报主页面
     */
    collectSituationHomeCtrl.$inject = ['$scope', 'storageService', 'ynNavigator', '$ionicPopup'];

    function collectSituationHomeCtrl($scope, storageService, ynNavigator, $ionicPopup) {
        //初始化选项卡
        $scope.tabRepeat = [
            { id: "1", name: "填报", active: true },
            { id: "2", name: "查看记录", active: false }
        ];
        //点击选项卡
        $scope.clickTab = function(index) {
            $scope.activeKey = index;
            angular.forEach($scope.tabRepeat, function(value) {
                value.active = false;
                if (value.id == index) {
                    value.active = true;
                }
            })
        };
        //初始化选中效果
        var defActive = "1";
        var type = storageService.getItem("collect_situation_def_select_type");
        if (type) {
            defActive = type;
        }
        $scope.clickTab(defActive);
        //返回事件拦截器
        ynNavigator.registerBackAction(function() {
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                template: '确定要放弃当前编辑内容吗？',
                cancelText: "继续编辑",
                okText: "放弃"
            });
            confirmPopup.then(function(res) {
                if (res) {
                    ynNavigator.pop(true); //强制返回上一级
                }
            });
        }, 101);
    }

    /**
     * 填报选项卡
     */
    collectSituationCtrl.$inject = ['$scope', '$http', '$interval', '$filter', 'ynuiNotification', 'stringsConstant', '$cordovaFileTransfer', '$cordovaFile', '$timeout', '$ionicPopup', '$ionicModal', '$location'];

    function collectSituationCtrl($scope, $http, $interval, $filter, ynuiNotification, stringsConstant, $cordovaFileTransfer, $cordovaFile, $timeout, $ionicPopup, $ionicModal, $location) {

        var vm = this;
        // 保存的打卡点
        vm.dataVO = {
            gpsIsOpen: '1'
        };
        vm.refreshPosition = refreshPosition;
        // 获取数据状态，0失败，1获取中，2获取成功
        vm.dataStatus = '1';
        vm.locationInfo = { tipInfo: '定位中...' };
        $scope.stuRegisterFieldVO = [];
        $scope.isCommit = true;
        $scope.getNowDate = function(Date) {
            var Y = Date.getFullYear();
            var M = Date.getMonth() + 1;
            M = M < 10 ? '0' + M : M; // 不够两位补充0
            var D = Date.getDate();
            D = D < 10 ? '0' + D : D;
            var H = Date.getHours();
            H = H < 10 ? '0' + H : H;
            var Mi = Date.getMinutes();
            Mi = Mi < 10 ? '0' + Mi : Mi;
            var S = Date.getSeconds();
            S = S < 10 ? '0' + S : S;
            return Y + '-' + M + '-' + D + ' ' + H + ':' + Mi + ':' + S;
        }
        document.addEventListener("deviceready", getCollectList, false);

        var gpsTimer;

        //获取位置
        function refreshPosition() {
            var tipsIndex = 0;
            vm.locationType = 0; // 定位类型
            vm.locationInfo.tipInfo = '定位中...';
            vm.dataStatus = '1';
            if (gpsTimer) {
                window.clearInterval(gpsTimer);
            }
            gpsTimer = window.setInterval(function() {
                if (tipsIndex > 2) {
                    tipsIndex = 2;
                }
                vm.locationInfo.tipInfo = ["正在搜索GPS信号...", "GPS信号较弱，请稍等...", "搜索基站或WI-FI信号..."][tipsIndex];
                $scope.$apply();
                tipsIndex++;
            }, 1500);
            console.log("调用refreshPosition!");
            //先清空，在定位
            $scope.stuRegisterFieldVO.province = "";
            $scope.stuRegisterFieldVO.city = "";
            $scope.stuRegisterFieldVO.county = "";
            $scope.stuRegisterFieldVO.location = "";
            $scope.stuRegisterFieldVO.datetime = "";
            // 发起定位，异步
            navigator.geolocation.getCurrentPosition(function(data) {
                console.log('定位结果：' + JSON.stringify(data));
                window.clearInterval(gpsTimer);

                if(data.status === 1 && data.result.address){
                    vm.dataVO.gpsIsOpen = '1';
                    vm.dataStatus = '2';
                    var result = data.result;
                    $timeout(function() {
                        // 处理界面渲染问题
                        $scope.stuRegisterFieldVO.province = result.province;
                        $scope.stuRegisterFieldVO.city = result.city;
                        $scope.stuRegisterFieldVO.county = result.district;
                        $scope.stuRegisterFieldVO.location = result.address;
                        $scope.stuRegisterFieldVO.datetime = moment().format("YYYY-MM-DD HH:mm:ss")
                        $scope.$apply();
                    }, 500)
                }else{
                    vm.dataVO.gpsIsOpen = '0';
                    vm.dataStatus = '0';
                    console.log('errorCode: ' + data.result.errorCode + ', errorInfo: ' + data.result.errorInfo);
                }
            }, function(getCurrentPositionError) {
                vm.dataStatus = '0';
                console.log('定位失败:' + JSON.stringify(getCurrentPositionError));
            });
        }


        $scope.quesFsInfo = [];

        // 查询动态采集条件
        function getCollectList() {
            $http.get(originBaseUrl + '/third/collectController/getCollectList.htm').success(function(data) {
                if (data.status == 0) {
                    $scope.stuRegisterFieldVO = data.result;
                    angular.forEach($scope.stuRegisterFieldVO.questionVOList, function(data) {
                        if (data.controlType == 7 || data.controlType == 8 || data.controlType == 9) {
                            $scope.quesFsInfo.push({ 'quesId': data.id, 'fsIdArr': [] });
                        }
                    });
                    refreshPosition();
                } else {
                    window.clearInterval(gpsTimer);
                };
            });
        }

        //手动处理单选的效果问题
        $scope.selectFun = function(val, list) {
            angular.forEach(list, function(data) {
                data.selected = false;
            })
            val.selected = true;
        }

        // 保存采集数据
        $scope.saveCollectData = function() {
            /********测试信息**********/
            var isSave = true;
            var msg = "";
            angular.forEach($scope.stuRegisterFieldVO.questionVOList, function(data) {
                if (data.notNull) { //判空
                    if ((data.controlType == 1 || data.controlType == 2 || data.controlType == 6) && !data.questionFieldValueVOs[0].word) {
                        if (!msg) { //如果msg为空，才给它赋值
                            msg = data.name + "必填!";
                            isSave = false;
                        }
                    }
                    if ((data.controlType == 3 || data.controlType == 4 || data.controlType == 5)) {
                        var count = 0;
                        angular.forEach(data.questionFieldValueVOs, function(item) {
                            if (item.selected) {
                                count++;
                            }
                        })
                        if (count == 0 && !msg) { //必填却没有选中的，并且msg为空，才给它赋值
                            msg = data.name + "必选一项！";
                            isSave = false;
                        }
                    }
                }
                if ((data.controlType == 7 || data.controlType == 8 || data.controlType == 9)) {
                    angular.forEach($scope.quesFsInfo, function(quesfs) {
                        if (quesfs.quesId == data.id) {
                            data.fsIdArr = quesfs.fsIdArr.join(",");
                        }
                    });
                    if (data.notNull && !data.fsIdArr) {
                        msg = data.name + "必填!";
                        isSave = false;
                    }
                }
            })
            if (!isSave) {
                ynuiNotification.error({ msg: msg });
                return;
            }
            var saveInfo = { jsonData: angular.toJson({ savePersonAnswerVO: $scope.stuRegisterFieldVO }) };
            console.log('保存数据信息saveInfo：' + JSON.stringify(saveInfo));
            $scope.isCommit = false;
            $http.post(originBaseUrl + '/third/collectController/saveCollectionInfo.htm', saveInfo).success(function(data) {
                $scope.isCommit = true;

                if (data.status == 0) {
                    var opts = {
                        // okText:"确定",
                        title: "操作提示",
                        template: '<div class="text-center">上报健康数据成功！</div>',
                        buttons: [{
                            text: '查看填报明细记录',
                            type: 'button-positive',
                            onTap: function() {
                                $location.path("/collectDetail").search({ id: data.result });
                                return false;
                            }
                        }]
                    };
                    $ionicPopup.alert(opts);
                } else {
                    ynuiNotification.error({ msg: "位置获取失败！" });
                }
            }).error(function() {
                $scope.isCommit = true;
                ynuiNotification.error({ msg: "网络异常！" });
            })

        }

        $scope.photos = [];
        //当前操作文件的问题ID
        $scope.nowPicQuesId = '';
        // 选择图片
        $scope.choosePicture = function(quesId, controlType) {
            $scope.controlType = controlType;
            $scope.nowPicQuesId = quesId;
            $ionicModal.fromTemplateUrl('choosePicture.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function(modal) {
                modal.show();
                $scope.choosePictureModal = modal;
            });
        };
        // 得到照片字符串
        $scope.getFsIds = function(picQuesId) {
            var usedPicQues = null;
            angular.forEach($scope.quesFsInfo, function(quesfs) {
                if (quesfs.quesId === picQuesId) {
                    usedPicQues = quesfs;
                }
            });
            if (!usedPicQues) {
                console.error('未找到文件对应的题目！');
                return;
            }
            var photosFsIds = [];
            for (var i = 0; i < $scope.photos.length; i++) {
                if ($scope.photos[i].fsId && $scope.photos[i].quesId === picQuesId) {
                    photosFsIds.push($scope.photos[i].fsId);
                }
            }
            console.error('picQuesId的文件ID信息:' + JSON.stringify(photosFsIds));
            usedPicQues.fsIdArr = photosFsIds;
        };
        // 单个上传
        $scope.upload = function(photo) {
            photo.status = '0';
            // 参数
            var mac = stringsConstant.utils.uuid();
            var userId = JSON.parse(window.localStorage.getItem('authorizationStr')).userId;
            var options = new FileUploadOptions();
            options.fileName = photo.name;
            options.params = {
                name: photo.name,
                userId: userId,
                mac: mac
            };
            options.headers = {
                authorization: JSON.parse(window.localStorage.getItem("authorizationStr")).access_token
            };
            $cordovaFileTransfer.upload(stringsConstant.file.uploadServer(), photo.uri, options)
                .then(function(uploadSuccessData) {
                    console.log(JSON.stringify(uploadSuccessData.response));
                    // 上传完成
                    photo.fsId = JSON.parse(uploadSuccessData.response).result.fileId;
                    if (photo.fsId) {
                        photo.status = '1';
                        $scope.getFsIds(photo.quesId);
                    } else {
                        console.error('上传失败,fsId为空');
                        photo.status = '-1';
                    }
                }, function(uploadError) {
                    console.error('上传失败');
                    console.error(JSON.stringify(uploadError));
                    photo.status = '-1';
                }, function(progress) {
                    $timeout(function() {
                        photo.progress = parseInt((progress.loaded / progress.total) * 100) + '%';
                        console.log('上传进度: ' + photo.progress);
                    });
                });
        };
        // 单个照片失败重试
        $scope.retry = function(photo) {
            console.log('失败文件重试: ' + photo.uri);
            if (photo.status === '-1') {
                $scope.upload(photo);
            }
        };
        // 删除照片
        $scope.deletePhoto = function(photo) {
            $ionicPopup.confirm({
                title: '删除确认',
                template: '确认要删除当前照片吗?',
                cancelText: '取消',
                okText: '删除'
            }).then(function(res) {
                if (res) {
                    if (photo.fsId) {
                        // 删除服务端文件
                        $http({
                                method: 'GET',
                                url: stringsConstant.file.deleteServer() + photo.fsId
                            })
                            .success(function(deletePhotoRes) {
                                console.log(JSON.stringify(deletePhotoRes));
                                if (deletePhotoRes.status === 0) {
                                    // 已从文件服务器删除文件，执行本地删除
                                    $scope.deleteLocalPhoto(photo);
                                }
                            })
                            .error(function(deletePhotoErr) {
                                console.error('从文件服务器删除文件失败');
                                console.error(JSON.stringify(deletePhotoErr));
                            });
                    } else {
                        // 删除本地文件
                        $scope.deleteLocalPhoto(photo);
                    }
                }
            });
        };
        // 删除本地照片
        $scope.deleteLocalPhoto = function(photo) {
            for (var i = 0; i < $scope.photos.length; i++) {
                if ($scope.photos[i].uri === photo.uri) {
                    $scope.photos.splice(i, 1);
                    $scope.getFsIds(photo.quesId);
                }
            }
        };
        /*选择图片或拍照 结束*/
        // 选择照片
        $scope.takePicture = function() {
            $scope.choosePictureModal.hide();
            navigator.camera.getPicture(function(data) {
                console.log(JSON.stringify(data));
                var photo = {
                    uri: data,
                    path: data.substr(0, data.lastIndexOf('/') + 1),
                    name: data.substr(data.lastIndexOf('/') + 1),
                    fsId: '',
                    status: 0,
                    quesId: $scope.nowPicQuesId,
                    progress: 0
                };
                $scope.photos.push(photo);
                // 执行上传
                $scope.upload(photo);
            }, function(error) {
                console.log(JSON.stringify(error))
            }, {
                sourceType: Camera.PictureSourceType.PHOTOLIBRARY
            })
        };
        $scope.takePhoto = function() {
            $scope.choosePictureModal.hide();
            //成功拍照 组装photo对象 push到 photos
            var customcamera = yn.plugin.customcamera;
            var opts = [{
                name: $scope.stuRegisterFieldVO.userName,
                address: $scope.stuRegisterFieldVO.location,
                time: moment().format("YYYY-MM-DD HH:mm:ss")
            }];
            customcamera.startCamera(opts, takeSuccess, takeError);
        };

        // 拍照完成
        function takeSuccess(data) {
            var photo = {
                uri: data,
                path: data.substr(0, data.lastIndexOf('/') + 1),
                name: data.substr(data.lastIndexOf('/') + 1),
                fsId: '',
                status: 0,
                progress: 0,
                quesId: $scope.nowPicQuesId
            };
            // 拍照完成
            $scope.photos.push(photo);
            // 执行上传
            $scope.upload(photo);
        }

        // 拍照失败
        function takeError(data) {
            console.error('拍照失败');
            console.error(JSON.stringify(data));
        }

        $scope.previewPhoto = function(photo) {
            var cordovaFileOpen = cordova.plugins.disusered.open;
            cordovaFileOpen(photo.uri, cordovaFileOpenSuccess, cordovaFileOpenError);

            function cordovaFileOpenSuccess() {
                // 从已安装程序中打开文件完成
            }

            function cordovaFileOpenError(code) {
                if (code === 1) {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '未能在手机已安装APP中找到可预览此文件的程序'
                    });
                } else {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '预览时发生了未知错误 #' + code
                    });
                }
            }
        };
    }

    /**
     * 上报列表选项卡
     */
    collectInfoListCtrl.$inject = ['$scope', '$ionicPopup', '$http', 'ynuiNotification', '$ionicLoading', '$ionicScrollDelegate', '$location', 'storageService'];

    function collectInfoListCtrl($scope, $ionicPopup, $http, ynuiNotification, $ionicLoading, $ionicScrollDelegate, $location, storageService) {
        $scope.collectData = {
            isInitLoad: true,
            dataList: []
        };
        $scope.pageInfo = {
            totalPage: 0,
            pageSize: 7,
            pageNumber: 0,
            itemSize: 0
        };
        $scope.initLoad = function() {
                $ionicLoading.show({
                    template: '正在加载...'
                });
                $http.post(originBaseUrl + "/third/collectController/query7CollectListInfo.htm").success(function(data) {
                    $ionicLoading.hide();
                    if (data.status == 0) {
                        $scope.collectData.isInitLoad = false;
                        $scope.collectData.dataList = data.result;
                        if (!$scope.collectData.dataList || $scope.collectData.dataList.length < 1) {
                            $scope.emptyInfo = true;
                            $scope.dataErrorMsg = '未查询到你的上报记录。';
                        } else {
                            $scope.emptyInfo = false;
                        }
                    } else {
                        $scope.emptyInfo = true;
                        $scope.dataErrorMsg = '加载失败，请重试';
                    }
                }).error(function() {
                    $scope.dataErrorMsg = '加载失败，请重试';
                });
            }
            // $scope.initLoad();

        $scope.loadPageData = function(func) {
            $ionicLoading.show({
                template: '正在加载...'
            });
            $http.post(originBaseUrl + "/third/collectController/queryCollectListInfoPage.htm", {
                pageNumber: $scope.pageInfo.pageNumber,
                pageSize: $scope.pageInfo.pageSize
            }).success(function(data) {
                if (data.status == 0) {
                    $scope.collectData.isInitLoad = false;
                    $scope.collectData.dataList.push.apply($scope.collectData.dataList, data.result.content);
                    $scope.pageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    if (data.result.totalPages > 0) {
                        $scope.pageInfo.pageNumber = data.result.number + 1;
                    }
                    if (!$scope.collectData.dataList || $scope.collectData.dataList.length < 1) {
                        $scope.emptyInfo = true;
                        $scope.dataErrorMsg = '未查询到你的上报记录！';
                    } else {
                        $scope.emptyInfo = false;
                    }
                    if (func) {
                        func();
                    }
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfo = true;
                    $scope.dataErrorMsg = '加载失败，请重试';
                }
            }).error(function() {
                $scope.dataErrorMsg = '加载失败，请重试';
            });
        }

        $scope.loadPageData();

        $scope.moreDataCanBeLoaded = function() {
            return $scope.pageInfo && $scope.pageInfo.pageNumber < $scope.pageInfo.totalPage;
        };
        /**
         * 加载更多
         */
        $scope.loadMore = function() {
            if ($scope.pageInfo.pageNumber >= $scope.pageInfo.totalPage) {
                return false;
            }
            $scope.loadPageData(function() {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };

        //刷新
        $scope.doRefresh = function() {
            $ionicLoading.show({
                template: '正在刷新...'
            });
            //置空数据，在获取时候叠加数据
            $scope.collectData = {
                isInitLoad: true,
                dataList: []
            };
            $scope.pageInfo = {
                totalPage: 0,
                pageSize: 7,
                pageNumber: 0,
                itemSize: 0
            };
            $scope.loadPageData(function() {
                $ionicScrollDelegate.scrollTop();
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };

        $scope.showDetail = function(id) {
            storageService.setItem("collect_situation_def_select_type", "2");
            $location.path("/collectDetail").search({ id: id });
        }
    }

    /**
     * 上报明细
     */
    collectDetailCtrl.$inject = ['$scope', '$http', 'ynuiNotification', '$location', '$ionicModal'];

    function collectDetailCtrl($scope, $http, ynuiNotification, $location, $ionicModal) {
        $scope.id = $location.search().id;
        // 查询动态采集条件
        $scope.getCollectList = function() {
            $http.get(originBaseUrl + '/third/collectController/querySavePersonAnswerById.htm?id=' + $scope.id).success(function(data) {
                if (data.status == 0) {
                    $scope.stuRegisterFieldVO = data.result;
                }
            });
        }
        $scope.getCollectList();
        var bigImgModal;
        $ionicModal.fromTemplateUrl('bigImg.html', {
            scope: $scope,
            animation: 'slide-in-right'
        }).then(function(modal) {
            bigImgModal = modal;
        });
        $scope.showBigImg = function(fsId) {
            $scope.bigImgUrl = originBaseUrl + '/file/downloadStream.htm?view=1&fastDFSId=' + fsId;
            bigImgModal.show();
        }
        $scope.closeBigImgModal = function() {
            bigImgModal.hide();
        };
    }
})();