/**
 * 寝室安排/床位调整
 * @author Wu Juncheng
 * @Date 2021年4月8日16:27:51
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        /**宿舍考核*/
        .controller('dormitoryApplyCtrl', dormitoryApplyCtrl)
    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
             //安排寝室
            .state('dormitory_apply', {
                url: '/dormitory_apply',
                templateUrl: 'templates/dormitory_apply/dormitory_apply.html',
                data: {
                    prev: 'workspaceForTeacher',
                    title: '班级寝室'
                },
                controller: 'dormitoryApplyCtrl'
            })
    }

    dormitoryApplyCtrl.$inject = ['$scope', '$http', '$ionicModal', 'ynuiNotification', '$state', '$location', '$ionicPopup', '$window', '$ionicScrollDelegate'];

    /**
     * 申请调寝
     */
    function dormitoryApplyCtrl ($scope, $http, $ionicModal, ynuiNotification, $state, $location, $ionicPopup, $window, $ionicScrollDelegate) {

        var localUrl = decodeURI($window.location.href);
        var params = localUrl.split(/[?&]/);
        $scope.backClassId = null;
        angular.forEach(params, function(url){
            if(url.indexOf("classId=") > -1){
                $scope.backClassId = url.replace("classId=", "");
            }
        });

        //默认第一页
        $scope.pageNumber = 0;

        //审核状态
        $scope.statusList = [
            {id: 0, name: "审核中"},
            {id: 1, name: "不通过"},
            {id: 2, name: "通过"},
            {id: 3, name: "驳回申请"},
            {id: 4, name: "返回修改"},
            {id: 5, name: "结束"},
            {id: null, name: "全部"},
        ];

        //调寝状态
        $scope.changeStatusList = [
            {id: 0, name: "未调整"},
            {id: 1, name: "调寝成功"},
            {id: 2, name: "调寝失败"},
            {id: null, name: "全部"}
        ];

        //查询条件
        $scope.condition = {
            stuInfo : '',
            status : null,
            changeStatus : null
        };

        //跳转到班级寝室查看
        $scope.toAnother = function(type){
            if(type === 1){
                $state.go('dormitory_modify_teacher');
            }else{
                $state.go('dormitory_list');
            }
        };

        //选前一个班
        $scope.beforeClass = function(index){
            if(index === 0){
                $scope.curryClass = $scope.classList[$scope.classList.length - 1];
            }else{
                $scope.curryClass = $scope.classList[index - 1];
            }
            $scope.searchApplyList();
        };

        //选后一个班
        $scope.afterClass = function(index){
            if(index === $scope.classList.length - 1){
                $scope.curryClass = $scope.classList[0];
            }else{
                $scope.curryClass = $scope.classList[index + 1];
            }
            $scope.searchApplyList();
        };

        //组装查询url
        $scope.getConditionUrl = function(){
            var url = originBaseUrl + "/third/ssap/queryStuChangeRoomLc.htm?classId=" + $scope.curryClass.id + "&pageNumber=" + $scope.pageNumber + "&pageSize=10";
            if($scope.condition.stuInfo){
                url += "&stuInfo=" + $scope.condition.stuInfo;
            }
            if($scope.condition.changeStatus || $scope.condition.changeStatus === 0){
                url += "&changeStatus=" + $scope.condition.changeStatus;
            }
            if($scope.condition.status || $scope.condition.status === 0){
                url += "&status=" + $scope.condition.status;
            }
            return url;
        };

        //查询班级下的调寝信息
        $scope.searchApplyList = function(){
            $scope.pageNumber = 0;
            $http.get($scope.getConditionUrl()).success(function(data){
                if (data.status === 0) {
                    $scope.lcList = data.result;
                    $scope.haveNext = $scope.lcList.length > 9;
                    $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                }
            });
        };

        //加载更多
        $scope.rollSearch = function(){
            $scope.pageNumber += 1;
            $http.get($scope.getConditionUrl()).success(function(data){
                if (data.status === 0) {
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                    $scope.addList = data.result;
                    $scope.haveNext = $scope.addList.length > 9;
                    angular.forEach($scope.addList, function(item){
                        $scope.lcList.push(item);
                    });
                }
            });
        };


        //查询管理班级
        $http.get(originBaseUrl + "/third/ssap/queryTeacherClassList.htm").success(function(data){
            if(data.status === 0){
                $scope.classList = data.result;
                var i = 0;
                angular.forEach($scope.classList, function(item){
                    item.index = i;
                    i++;
                });
                $scope.curryClass = null;
                if($scope.backClassId){
                    angular.forEach($scope.classList, function(item){
                       if($scope.backClassId === item.id){
                           $scope.curryClass = item;
                           $scope.backClassId = null;
                       }
                    });
                }
                if(!$scope.curryClass){
                    $scope.curryClass = $scope.classList[0];
                }
                $scope.searchApplyList();
            }
        });

        //流程明细页面
        $scope.goLcDetail = function(lcId){
            if(lcId){
                $location.path("/dormitoryApplyDeal").search({"fromType": 0, "procInstId": lcId, "fromBusiness": 1,state:"dormitory_apply", classId: $scope.curryClass.id});
            }
        };

        //发起申请
        $scope.goAddLc = function(){
            $location.path("/dormitory_apply_add").search({ableFlag : true});
        };


        /*模态*/
        $ionicModal.fromTemplateUrl('searchInfo.html',{
            scope:$scope,
            animation:'slide-in-left'
        }).then(function(modal){
            $scope.modal = modal;
        });
        $scope.rightModalClick = function() {
            $scope.modal.show();
        };
        $scope.closeName = function() {
            $scope.searchApplyList();
            $scope.modal.hide();
        };

    }


})();
