/**
 * 宿舍考核
 * @author qiucheng Lu
 * @Date 2021年4月8日16:27:51
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        /**宿舍考核*/
        .controller('dormitoryExamineCtrl', dormitoryExamineCtrl)
        .controller('addTaskCtrlDorm', addTaskCtrlDorm)
        .controller('gradeCtrl', gradeCtrl)
        .controller('fromCtrl', fromCtrl)
    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        //任务管理
            .state('dormitory_examine', {
                url: '/dormitory_examine',
                templateUrl: 'templates/dormitory_examine/dormitory_examine.html',
                data: {
                    micro: true,
                    title: '干部工作'
                },
                controller: 'dormitoryExamineCtrl'
            })
            //添加任务
            .state('add_task_dmt', {
                url: '/add_task_dmt',
                templateUrl: 'templates/dormitory_examine/add_task_dmt.html',
                data: {
                    title: '宿舍考核',
                    prev: 'dormitory_examine'
                },
                controller: 'addTaskCtrlDorm'
            })
            //打分 宿舍考核
            .state('grade_dormitory', {
                url: '/grade_dormitory',
                templateUrl: 'templates/dormitory_examine/grade_dormitory.html',
                data: {
                    title: '宿舍考核',
                    prev: 'dormitory_examine'
                },
                controller: 'gradeCtrl'
            })
            //填写表单
            .state('dormitory_form', {
                url: '/dormitory_form',
                templateUrl: 'templates/dormitory_examine/dormitory_form.html',
                data: {
                    title: '宿舍考核',
                    prev: 'dormitory_examine'
                },
                controller: 'fromCtrl'
            })
    }

    dormitoryExamineCtrl.$inject = ['$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', 'ynuiNotification', "$location", "$rootScope"];

    /**
     * 宿舍考核 任务管理
     */
    function dormitoryExamineCtrl ($scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, ynuiNotification, $location, $rootScope) {
        $scope.getData = function (func) {
            $scope.emptyInfo = false;
            $scope.stuList = [];
            $scope.addButtonName = "";
            $scope.dataErrorMsg = '没有可选择的考核任务，请先添加值日当天的考核任务！';
            var basePath = originBaseUrl + "/third/dormitoryExamineTask";
            $http.get(basePath + '/findTaskList.htm?time=' + (new Date()).getTime()).success(function (data) {
                if (data.status == 0) {
                    $scope.scoreTaskList = data.result;
                    if ($scope.scoreTaskList == null || $scope.scoreTaskList.length == 0) {
                        $scope.emptyInfo = true;
                        $scope.addButtonName = "添加";
                    } else {
                        $scope.addButtonName = "新增";
                    }
                } else {
                    ynuiNotification.error({msg: data.message});
                }
                if (func) {
                    func();
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfo = true;
                $scope.addButtonName = "添加";
                $scope.dataErrorMsg = '加载失败，请重试！';
            });
        };

        $scope.addScoreTask = function () {
            $location.path("/add_task_dmt");
        };
        $scope.doRefresh = function () {
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.getData(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        $scope.doRefresh();
        //去考核页面
        $scope.toDormitoryForm = function (item) {
            if (item.checkDate > $scope.sysDate.day) {
                ynuiNotification.error({msg: "还未到考核日期，不能打分！"});
                return false;
            }
            $location.path("/grade_dormitory").search("task", angular.toJson(item));
        }

        //获取当前日期
        $http.post(originBaseUrl + "/third/newss/mobile/getSystemDate.htm").success(function (data) {
            if (data.status == 0) {
                $scope.sysDate = data.result;
            }
        });
    }

    addTaskCtrlDorm.$inject = ['$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', 'ynuiNotification', "$location", "$ionicModal", "$rootScope"];
    //宿舍考核  添加任务
    function addTaskCtrlDorm ($scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, ynuiNotification, $location, $ionicModal, $rootScope) {
        //添加考核任务
        $scope.taskConditions = {
            scoreTable: "",
            checkRegion: "",
            checkNumber: "",
            term: "",
            checkDate: ""
        };
        //添加考核任务显示名称
        $scope.showTask = {
            scoreTableName: "",
            checkRegionName: "",
            checkNumberName: "",
            termName: ""
        };
        var basePath = originBaseUrl + "/third/dormitoryExamineTask";
        //区域类型
        $scope.checkType = 0;
        $scope.selectFrequency = [];
        $scope.selectArea = [];
        $scope.showRegionInfo = "请先选择打分表";
        var date = new Date();
        var currentDate = date.getFullYear() + "-" + (date.getMonth() + 1) + "-" + date.getDate();
        $scope.taskConditions.checkDate = currentDate;
        $scope.getData = function (func) {
            $scope.emptyInfo = false;
            $scope.stuList = [];
            $http.get(basePath + '/findTaskList.htm?time=' + (new Date()).getTime()).success(function (data) {
                if (data.status == 0) {
                    $scope.scoreTaskList = data.result;
                } else {
                    ynuiNotification.error({msg: data.message});
                }
                if (func) {
                    func();
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfo = true;
                $scope.dataErrorMsg = '加载失败，请重试！';
            });

        };

        //打分表浮层
        $ionicModal.fromTemplateUrl('show_score_table.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.tableList = modal;
        });

        //考核区域浮层
        $ionicModal.fromTemplateUrl('show_check_region.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.regionList = modal;
        });

        //考核次数浮层
        $ionicModal.fromTemplateUrl('show_check_number.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.numberList = modal;
        });

        //学期浮层
        $ionicModal.fromTemplateUrl('show_term.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.termList = modal;
        });

        //选择打分表
        $scope.chooseTable = function () {
            //加载打分表
            $http.post(basePath + "/queryUseScoreTable.htm", {}).success(function (data) {
                if (data.status == 0) {
                    $scope.selectScoreTable = data.result;
                    $scope.tableList.show();
                }
            });
        };
        $scope.confirmTable = function (item) {
            $scope.taskConditions.scoreTable = item.id;
            $scope.showTask.scoreTableName = item.name;
            $scope.showRegionInfo = "请选择";
            $scope.getNumber(item.id);
            $scope.hideTable();
            $scope.chooseRegion(item.id);
        };
        //隐藏打分表
        $scope.hideTable = function () {
            $scope.tableList.hide();
        };

        //选择考核区域
        $scope.chooseRegion = function (item) {
            if (item == null || item == "") {
                ynuiNotification.error({msg: '请先选择打分表'});
                return;
            }
            $scope.checkType = 0;
            //加载打分区域(管理员的考核区)
            $http.post(basePath + "/getAreaAndNumber.htm?id=" + item + "&checkType=" + $scope.checkType, {}).success(function (data) {
                if (data.status == 0) {
                    $scope.selectAreaAdmin = data.result;
                    // $scope.regionList.show();
                }
            });
            $scope.checkType = 1;
            //加载打分区域(我的考核区)
            $http.post(basePath + "/getAreaAndNumber.htm?id=" + item + "&checkType=" + $scope.checkType, {}).success(function (data) {
                if (data.status == 0) {
                    $scope.selectAreaMy = data.result;
                    $scope.selectArea = data.result;
                    // $scope.regionList.show();
                }
            });
        };

        $scope.showRegion = function () {
            if ($scope.taskConditions.scoreTable == null || $scope.taskConditions.scoreTable == "") {
                ynuiNotification.error({msg: '请先选择打分表'});
                return;
            }
            $scope.regionList.show();
        };
        $scope.confirmRegion = function (item) {
            $scope.taskConditions.checkRegion = item.id;
            $scope.showTask.checkRegionName = item.name;
            $scope.hideRegion();
        };

        //隐藏考核区域
        $scope.hideRegion = function () {
            $scope.regionList.hide();
        };

        //选择考核次数
        $scope.chooseNember = function (item) {
            if (item == null || item == "") {
                ynuiNotification.error({msg: '请先选择打分表'});
                return;
            }
            $scope.numberList.show();
        };

        $scope.getNumber = function (item) {
            //选择考核次数
            $http.post(basePath + "/queryByScoreTableId.htm?id=" + item, {}).success(function (data) {
                if (data.status == 0) {
                    $scope.selectFrequency = data.result;
                    if ($scope.taskConditions.checkNumber == "" && $scope.selectFrequency.length > 0) {
                        $scope.taskConditions.checkNumber = $scope.selectFrequency[0].id;
                        $scope.showTask.checkNumberName = $scope.selectFrequency[0].name;
                    }
                }
            });
        };

        $scope.confirmFrequency = function (item) {
            $scope.taskConditions.checkNumber = item.id;
            $scope.showTask.checkNumberName = item.name;
            $scope.hideNumber();
        };

        //隐藏考核次数
        $scope.hideNumber = function () {
            $scope.numberList.hide();
        };

        //获取当前学期
        $scope.getCurrentTerm = function () {
            $http.post(basePath + "/getCurrentTerm.htm", {}).success(function (data) {
                if (data.status == 0) {
                    $scope.currentTerm = data.result;
                    $scope.taskConditions.term = $scope.currentTerm.id;
                    $scope.showTask.termName = $scope.currentTerm.name;
                }
            });
        };
        $scope.getCurrentTerm();

        $scope.chooseTerm = function () {
            //选择考核学期
            $scope.termList.show();
        };

        $scope.getTermList = function () {
            //选择考核学期
            $http.post(basePath + "/getSelectPlatformSysTerm.htm", {}).success(function (data) {
                if (data.status == 0 && data.result.length > 0) {
                    $scope.selectPlatformSysTerm = data.result;
                    if ($scope.taskConditions.term == "" && $scope.selectPlatformSysTerm.length > 0) {
                        $scope.taskConditions.term = $scope.selectPlatformSysTerm[0].id;
                        $scope.showTask.termName = $scope.selectPlatformSysTerm[0].name;
                        $scope.taskConditions.checkDate = $scope.selectPlatformSysTerm[0].termEndDateString;
                    }
                }
            });
        };
        $scope.getTermList();
        $scope.getTaskUrl = function () {
            var url = basePath + "/saveAndCreateMoraleduDormitoryCheckTask.htm?";
            if ($scope.taskConditions.term != "" && $scope.taskConditions.term.length > 0) {
                url += "&termId=" + $scope.taskConditions.term;
            }
            if ($scope.taskConditions.scoreTable != "" && $scope.taskConditions.scoreTable.length > 0) {
                url += "&scoreTableId=" + $scope.taskConditions.scoreTable;
                url += "&scoreTableName=" + $scope.showTask.scoreTableName;
            }
            if ($scope.taskConditions.checkRegion != "" && $scope.taskConditions.checkRegion.length > 0) {
                url += "&DormitoryRegionId=" + $scope.taskConditions.checkRegion;
            }
            if ($scope.taskConditions.checkDate != "" && $scope.taskConditions.checkDate.length > 0) {
                url += "&checkDate=" + $scope.taskConditions.checkDate;
            }
            if ($scope.taskConditions.checkNumber != "") {
                url += "&checkMember=" + $scope.taskConditions.checkNumber;
            }
            return url;
        };

        $scope.confirmTerm = function (item) {
            $scope.taskConditions.term = item.id;
            $scope.showTask.termName = item.name;
            $scope.hideTerm();
        };

        //隐藏考核次数
        $scope.hideTerm = function () {
            $scope.termList.hide();
        };

        //切换考核区域
        $scope.chengeArea = function (item) {
            $scope.checkType = item;
            if (item == 1) {
                $scope.selectArea = $scope.selectAreaMy;
            } else if (item == 0) {
                $scope.selectArea = $scope.selectAreaAdmin;
            }
            // $scope.chooseRegion($scope.taskConditions.scoreTable);
        };

        //取消添加任务
        $scope.closeAddTask = function () {
            $location.path("/dormitory_examine");
        };

        //生成考核任务
        $scope.generateTask = function () {
            if ($scope.taskConditions.scoreTable == null || $scope.taskConditions.scoreTable == "") {
                ynuiNotification.error({msg: '请选择打分表！'});
                return;
            }
            if ($scope.taskConditions.checkRegion == null || $scope.taskConditions.checkRegion == "") {
                ynuiNotification.error({msg: '请选择考核区域！'});
                return;
            }
            if ($scope.taskConditions.checkNumber == null || $scope.taskConditions.checkNumber == "") {
                ynuiNotification.error({msg: '请选择考核次数！'});
                return;
            }
            if ($scope.taskConditions.term == null || $scope.taskConditions.term == "") {
                ynuiNotification.error({msg: '请选择学期！'});
                return;
            }
            if ($scope.taskConditions.checkDate == null || $scope.taskConditions.checkDate == "") {
                ynuiNotification.error({msg: '请选择考核日期！'});
                return;
            }
            var url = $scope.getTaskUrl();
            $http.post(url, {}).success(function (data) {
                if (data.status == 0 && data.result == null) {
                    //任务进度
                    ynuiNotification.success({msg: '添加成功！'});
                    $location.path("/dormitory_examine");
                } else {
                    ynuiNotification.error({msg: '添加失败！' + data.result.failedReason});
                    $scope.taskConditions.checkDate = currentDate;
                }
            });
        };

        $scope.cleanData = function () {
            //添加考核任务
            $scope.taskConditions.scoreTable = "";
            $scope.taskConditions.checkRegion = "";
            $scope.taskConditions.checkNumber = "";
            $scope.taskConditions.checkDate = date.getFullYear() + "-" + (date.getMonth() + 1) + "-" + date.getDate();
            $scope.getCurrentTerm();
            //添加考核任务显示名称
            $scope.showTask.scoreTableName = "";
            $scope.showTask.checkRegionName = "";
            $scope.showTask.checkNumberName = "";
            $scope.getCurrentTerm();
        };

        $scope.doRefresh = function () {
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.cleanData();
            $scope.getData(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        $scope.doRefresh();
    }

    gradeCtrl.$inject = ['$scope', '$rootScope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', 'ynuiNotification', "$location", "$ionicModal", "$filter",'ynNavigator'];
    //宿舍考核填写表单
    function gradeCtrl ($scope, $rootScope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, ynuiNotification, $location, $ionicModal, $filter,ynNavigator) {

        /**
         * 当前考核的任务
         */
        var task = angular.fromJson($location.search().task);

        if (task.notOverClassNumber == 0) {
            if ($rootScope.dormitoryPage && $rootScope.dormitoryPage.returnPage == 1) {
                task.notOverClassNumber = 1;
                $rootScope.dormitoryPage.returnPage = null;
            }
        }
        /**
         * 任务ID
         */
        var taskId = task.id;

        /**
         * 一级路径配置
         * @type {string}
         */
        var basePath = originBaseUrl + "/third/dormitoryExamine";

        /**
         * 查询考核项目的选择框
         * @type {string}
         */
        $scope.MoraleduDormitoryChInfoVO = null;

        /**
         *  查询条件 考核项目
         * @type {string}
         */
        $scope.ItemName = "";
        /**
         * 上一条和下一条数据信息
         * @type {{region: string, dormitory: string}}
         */
        $scope.condition = {
            checkMember: task.checkMember,//考核次数
            checkDate: task.checkDate, //考核日期
            region: task.dormitoryRegionId,//区域信息
            regionName: "",
            dormitory: "",//考核寝室
            lastRegion: "",
            nextRegion: "",
            lastDormitory: "",
            nextDormitory: "",
            dormitoryName: ""
        };

        /**
         * 清除条件
         */
        $scope.clearAllDormitoryInfo = function () {
            $scope.condition.nextDormitory = null;
            $scope.condition.nextDormitoryName = null;
            $scope.condition.lastDormitory = null;
        };

        /**
         * 悬浮侧
         */
        $ionicModal.fromTemplateUrl('grouping.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.classList = modal;
        });
        /**
         * 打开选择班级的悬浮
         */
        $scope.openDormiGrouping = function () {
            $scope.doRefreshClass(1);
            $ionicLoading.hide();
            $scope.classList.show();
            ynNavigator.registerBackAction(function () {
                //关闭弹框，返回上一页
                $scope.goBackToItem();
                ynNavigator.pop(true);
            },201);
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $ionicScrollDelegate.scrollTop();
        };
        /**
         * 获取寝室
         * @param type 0  上一个 1 下一个
         * @param index undefined 为正确跳转  ！undefined为非正确跳转 没有了需要显示选择班级的悬浮侧
         */
        $scope.getDormitory = function (type, index) {
            $scope.clearAllDormitoryInfo();
            var currentIndex = 0, lastIndex = 0, nextIndex = 0;
            if ($scope.dormitoryList.length > 0) {
                for (var i = 0; i < $scope.dormitoryList.length; i++) {
                    var item = $scope.dormitoryList[i];
                    if (item.id == $scope.condition.dormitory) {
                        if (type == 0) {
                            lastIndex = i - 2;
                            currentIndex = i - 1;
                            nextIndex = i;
                        } else if (type == 1) {
                            lastIndex = i;
                            currentIndex = i + 1;
                            nextIndex = i + 2;
                        }
                    }
                }
                /*当前为最后一个*/
                if (nextIndex > $scope.dormitoryList.length) {
                    if (angular.isUndefined(index)) {
                        $scope.condition.nextDormitory = null;
                        $scope.condition.nextDormitoryName = null;
                        ynuiNotification.error({msg: '没有了'});
                        return false;
                    } else {
                        $scope.openDormiGrouping();
                        return false;
                    }
                }
                /*当前为第一个*/
                if (lastIndex == -2) {
                    $scope.condition.lastDormitory = null;
                    ynuiNotification.error({msg: '没有了'});
                    return false;
                }
                /*在中间的时候*/
                if (lastIndex >= 0) {
                    $scope.condition.lastDormitory = $scope.dormitoryList[lastIndex].id;
                }
                if (nextIndex < $scope.dormitoryList.length) {
                    $scope.condition.nextDormitory = $scope.dormitoryList[nextIndex].id;
                    $scope.condition.nextDormitoryName = $scope.dormitoryList[nextIndex].name;
                }
                $scope.condition.dormitory = $scope.dormitoryList[currentIndex].id;
                $scope.getDormitoryScoreDetail(taskId);
            }
        };

        /**
         * 获取下一个区域
         * @param type
         */
        $scope.toLastOrNextRegion = function (type) {
            $scope.clearAllDormitoryInfo();
            var currentIndex = 0, lastIndex = 0, nextIndex = 0;
            if ($scope.regionList.length > 0) {
                for (var i = 0; i < $scope.regionList.length; i++) {
                    var item = $scope.regionList[i];
                    if (item.id == $scope.condition.region) {
                        if (type == 0) {
                            lastIndex = i - 2;
                            currentIndex = i - 1;
                            nextIndex = i;
                        } else if (type == 1) {
                            lastIndex = i;
                            currentIndex = i + 1;
                            nextIndex = i + 2;
                        }
                    }
                }
                /*当前为最后一个*/
                if (nextIndex > $scope.regionList.length) {
                    $scope.condition.nextRegion = null;
                    ynuiNotification.error({msg: '已经是最后1个区域或分组！'});
                    return false;
                }
                /*当前为第一个*/
                if (lastIndex == -2) {
                    $scope.condition.lastRegion = null;
                    ynuiNotification.error({msg: '已经是第1个区域或分组！'});
                    return false;
                }
                /*在中间的时候*/
                if (lastIndex >= 0) {
                    $scope.condition.lastRegion = $scope.regionList[lastIndex].id;
                }
                if (nextIndex < $scope.regionList.length) {
                    $scope.condition.nextRegion = $scope.regionList[nextIndex].id;
                }
                $scope.condition.region = $scope.regionList[currentIndex].id;
                $scope.condition.regionName = $scope.regionList[currentIndex].name;
                $scope.getDormitoryList(function () {
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                    $ionicScrollDelegate.scrollTop();
                    $ionicLoading.hide();
                }, 1);
            }
        };

        /**
         * 手机端 查询考核下的考核项目
         * @param taskId
         * @param dormitoryId
         */
        $scope.closeDataClick = function (item) {
            if (item == $scope.condition.dormitoryName) {
                $scope.condition.dormitoryName = "";
            } else if (item == $scope.ItemName) {
                $scope.ItemName = "";
            }
        };
        $scope.getDormitoryScoreDetail = function (taskId) {
            $scope.MoraleduDormitoryChInfoVO = [];
            $ionicLoading.show({
                template: '正在加载...'
            });
            $http.get(basePath + "/querDormitoryCheckItemByTaskAndDormId.htm?taskId=" + taskId +
                "&dormitoryId=" + $scope.condition.dormitory + "&ItemName=" + $scope.ItemName
                + "&checkMember=" + $scope.condition.checkMember + "&checkDate=" + $scope.condition.checkDate + "&_datatime=" + new Date().getTime()).success(function (data) {
                $ionicLoading.hide();
                if (data.status == 0) {
                    $scope.MoraleduDormitoryChInfoVO = data.result;
                    $scope.moraleduDormitoryChItemInfoVOs = angular.copy($scope.MoraleduDormitoryChInfoVO.moraleduDormitoryChItemInfoVOs);
                } else {
                    ynuiNotification.error({msg: '获取宿舍信息失败！'});
                }
            }).error(function (data) {
                ynuiNotification.error({msg: '获取宿舍信息失败！'});
            });
        };

        /**
         * 获取宿舍
         * @param func 回调函数
         * @param index 1 不查询宿舍下的考核的信息  undefined 查询
         */
        $scope.getDormitoryList = function (func, index) {
            $scope.dormitoryList = [];
            $http.get(basePath + "/queryDormitoryByScoreTask.htm?taskId=" + taskId +
                "&dormitoryName=" + (isNotBlank($scope.condition.dormitoryName) ? $scope.condition.dormitoryName : "") + "&regionId=" + $scope.condition.region
                + "&checkNumber=" + $scope.condition.checkMember + "&checkData=" + $scope.condition.checkDate + "&checkUserId=" + $rootScope.authorizationStr.userId + "&usser=" + new Date().getTime()).success(function (data) {
                if (func) {
                    func();
                }
                if (data.status == 0) {
                    $scope.dormitoryList = data.result;
                    $scope.dormitoryListCopy = angular.copy($scope.dormitoryList);
                    $scope.condition.lastDormitory = null;
                    if ($scope.dormitoryList.length > 0) {
                        $scope.emptyDormitory = false;              //展示空数据提示
                        $scope.dataErrorMsgDormitory = "";

                        if ($rootScope.gradeCtrl && $rootScope.gradeCtrl.condition) {
                            $scope.condition = $rootScope.gradeCtrl.condition;
                        } else {
                            for (var i = 0; i < $scope.dormitoryList.length; i++) {
                                var item = $scope.dormitoryList[i];
                                if (item.isCheck == '0') {
                                    $scope.condition.dormitory = item.id;
                                    if ($scope.dormitoryList.length > i + 1) {
                                        $scope.condition.lastDormitory = $scope.dormitoryList[i + 1].id;
                                    }
                                    break;
                                }
                            }
                            if (!$scope.condition.dormitory && $scope.dormitoryList.length > 0) {
                                $scope.condition.dormitory = $scope.dormitoryList[0].id;
                                if ($scope.dormitoryList.length > 1) {
                                    $scope.condition.lastDormitory = $scope.dormitoryList[1].id;
                                }
                            }
                        }
                        if (index == undefined) {
                            $scope.getDormitoryScoreDetail(taskId);
                        }
                    } else {
                        $scope.emptyDormitory = true;              //展示空数据提示
                        $scope.dataErrorMsgDormitory = "没有可选择的宿舍！";
                    }
                } else {
                    ynuiNotification.error({msg: data.message});
                }
            }).error(function (data) {
                if (func) {
                    func();
                }
                ynuiNotification.error({msg: '获取考核区域失败！'});
            });
        };

        /**
         * 获取考核的区域信息
         */
        $scope.getRegionByScoreTaskId = function (func) {
            if (taskId) {
                $ionicLoading.show({
                    template: '正在加载...'
                });
                $scope.regionList = [];
                $http.get(basePath + "/queryRegionByScoreTaskId.htm?taskId=" + taskId + "&dormitoryUserType=2" + "&_datatime=" + new Date().getTime()).success(function (data) {
                    if (func) {
                        func();
                    }
                    if (data.status == 0) {
                        $scope.regionList = data.result;
                        var hasGroup = false;
                        if ($rootScope.gradeCtrl && $rootScope.gradeCtrl.condition) {
                            $scope.condition = $rootScope.gradeCtrl.condition;
                        } else {
                            for (var i = 0; i < $scope.regionList.length; i++) {
                                var region = $scope.regionList[i];
                                if ("1" == region.checkType) {
                                    hasGroup = true;
                                    $scope.condition.region = region.id;
                                    $scope.condition.regionName = region.name;
                                    $scope.getDormitoryList(function () {
                                        $scope.$broadcast('scroll.infiniteScrollComplete');
                                        $ionicScrollDelegate.scrollTop();
                                        $ionicLoading.hide();
                                    });
                                    break;
                                }
                            }
                            if (!hasGroup) {
                                $scope.condition.region = $scope.regionList[0].id;
                                $scope.condition.regionName = $scope.regionList[0].name;
                            }
                        }
                        $scope.getDormitoryList(function () {
                            $scope.$broadcast('scroll.infiniteScrollComplete');
                            $ionicScrollDelegate.scrollTop();
                            $ionicLoading.hide();
                        });
                    } else {
                        ynuiNotification.error({"msg": "获取区域信息失败！"});
                    }
                }).error(function (data) {
                    if (func) {
                        func();
                    }
                    ynuiNotification.error({"msg": "获取区域信息失败！"});
                });
            } else {
                if (func) {
                    func();
                }
            }
        };

        /**
         * 点击宿舍信息
         */
        $scope.searchCheckItem = function (dormitory) {
            $scope.goBackToItem();
            $scope.condition.dormitory = dormitory.id;
            $scope.doRefreshItems();

        };
        /**
         * 刷新宿舍考核项目列表
         */
        $scope.doRefreshItems = function () {
            $scope.getDormitoryScoreDetail(taskId);
        };

        /**
         * 返回项目信息
         */
        $scope.goBackToItem = function () {
            $scope.classList.hide();
            ynNavigator.cancelBackAction(201);
        };

        /**
         * 刷新宿舍考核宿舍信息
         */
        $scope.doRefreshClass = function (index) {
            $scope.condition.dormitoryName = null;
            $scope.getDormitoryList(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            }, index);
        };

        /**
         * 收缩
         */
        $scope.$watch("ItemName", function (newVal, oldVal) {
            if ($scope.ItemName == "") {
                $scope.isItemName = false
            } else {
                $scope.isItemName = true;
            }
            if (isNotBlank(newVal)) {
                $scope.moraleduDormitoryChItemInfoVOs = $filter('filter')($scope.MoraleduDormitoryChInfoVO.moraleduDormitoryChItemInfoVOs, {checkItemName: $scope.ItemName});
                if (!$scope.moraleduDormitoryChItemInfoVOs || $scope.moraleduDormitoryChItemInfoVOs.length < 1) {
                    $scope.emptyChItemIn = true; //展示空数据提示
                    $scope.dataErrorMsgChItemIn = "没有可选择的宿舍！";
                } else {
                    $scope.emptyChItemIn = false;
                }
            } else {
                if ($scope.MoraleduDormitoryChInfoVO != null) {
                    $scope.moraleduDormitoryChItemInfoVOs = angular.copy($scope.MoraleduDormitoryChInfoVO.moraleduDormitoryChItemInfoVOs);
                }
            }
        }, true);

        /**
         * 搜索
         */
        $scope.$watch("condition.dormitoryName", function (newVal, oldVal) {
            if ($scope.condition.dormitoryName == "") {
                $scope.isDormitoryName = false
            } else {
                $scope.isDormitoryName = true;
            }
            if (isNotBlank(newVal)) {
                $scope.dormitoryListCopy = $filter('filter')($scope.dormitoryList, {dormitoryName: $scope.condition.dormitoryName});
                if (!$scope.dormitoryListCopy || $scope.dormitoryListCopy.length < 1) {
                    $scope.emptyDormitory = true;              //展示空数据提示
                    $scope.dataErrorMsgDormitory = "没有可选择的宿舍！";
                } else {
                    $scope.emptyDormitory = false;
                }
            } else {
                $scope.dormitoryListCopy = angular.copy($scope.dormitoryList);
            }
        }, true);

        /**
         * 去打分
         */
        $scope.checkDormitory = function (checkItem) {
            var obj = {
                taskId: taskId,
                checkMember: $scope.condition.checkMember,//考核次数
                checkDate: $scope.condition.checkDate, //考核日期
                region: $scope.condition.region,//区域信息
                dormitory: $scope.condition.dormitory,//考核寝室
                ItemId: checkItem.checkItemId,
                typeId: checkItem.checkTypeId
            };
            $rootScope.gradeCtrl = {
                condition: $scope.condition
            };
            $location.path("/dormitory_form").search("checkItem", angular.toJson(obj));
        };
        /**
         * 字符串处理
         * @param str
         * @returns {boolean}
         */
        var isNotBlank = function (str) {
            if (null == str) {
                return false;
            }
            if (/\S+/.test(str)) {
                return true;
            }
            return false;
        };

        /**
         * 最后的提交
         */
        $scope.sumbitDormitoryScore = function () {
            $http.post(basePath + "/saveMorleduDormitoryCheckTypeByMobile.htm?taskId=" + taskId + "&dormitoryId=" + $scope.condition.dormitory + "&checkMember=" + $scope.condition.checkMember + "&checkUserId=" + $rootScope.authorizationStr.userId).success(function (data) {
                if (data.status == 0) {
                    //任务进度
                    ynuiNotification.success({msg: $scope.MoraleduDormitoryChInfoVO.dormitoryName + '考核完成！'});
                    $scope.getDormitory(1, 1);
                } else {
                    ynuiNotification.error({msg: '添加失败！'});
                }
            })
        };

        /**
         * 如果未打分的数量为0 则显示悬浮层
         */
        if (task.notOverClassNumber == 0) {
            window.setTimeout(function () {
                $scope.openDormiGrouping();
            }, 300);
        }

        $scope.getRegionByScoreTaskId(function () {
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $ionicScrollDelegate.scrollTop();
            $ionicLoading.hide();
        });
    }

    fromCtrl.$inject = ['$scope', '$rootScope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate', 'ynuiNotification', "$location", "$ionicModal", "$ionicPopup", "$cordovaBarcodeScanner", "ynNavigator"];

    /**
     * 宿舍考核填写表单
     */
    function fromCtrl ($scope, $rootScope, $http, $timeout, $ionicLoading, $ionicScrollDelegate, ynuiNotification, $location, $ionicModal, $ionicPopup, $cordovaBarcodeScanner, ynNavigator) {
        /**
         * 考核项目
         */
        var item = angular.fromJson($location.search().checkItem);

        $scope.showInfo = "扣分";
        /**
         * 一级路径配置
         * @type {string}
         */
        var basePath = originBaseUrl + "/third/dormitoryExamine";
        /**
         * 默认不上传
         * @type {boolean}
         */
        $scope.showUploader = false;

        /**
         *
         * @type {Array}
         */
        $scope.selectStudent = [];
        /**
         * 悬浮侧
         */
        $ionicModal.fromTemplateUrl('student.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            $scope.stuList = modal;
        });
        /**
         * 是否在页面上做出编辑
         * @type {boolean}
         */
        $scope.isHaveChange = false;
        /**
         * 已经选择了的学生信息
         * @type {Array}
         */
        $scope.selectStudent = [];

        /**
         * 文件上传选项
         * @type {{}}
         */
        $scope.options = {};
        /**
         * B0029103
         * 全局验证规则
         * @type {RegExp}
         */
        var reg = /^([1-9]\d{0,6}|0)(.[0-9]{1,2})?$/;
        /**
         * 是否可以保存
         * 手机端验证慢的问题
         * @type {boolean}
         */
        $scope.canSave = true;
        /**
         * 文件信息
         * @type {Array}
         */
        $scope.fileIds = [];
        $scope.file = {
            fsIds: []
        };
        /**
         * 获取详情
         * @param taskId
         */
        $scope.getDormitoryScoreDetail = function (func) {
            $ionicLoading.show({
                template: '正在加载...'
            });
            $http.get(basePath + "/queryDormitoryChDetailItem.htm?taskId=" + item.taskId +
                "&dormitoryId=" + item.dormitory + "&typeId=" + item.typeId
                + "&ItemId=" + item.ItemId + "&checkNumber=" + item.checkMember + "&_datatime=" + new Date().getTime()).success(function (data) {
                if (func) {
                    func();
                }
                $scope.showUploader = true;
                if (data.status == 0) {
                    $scope.MoraleduDormitoryCheckDetailVO = data.result;
                    if (!$scope.MoraleduDormitoryCheckDetailVO.score) {
                        $scope.MoraleduDormitoryCheckDetailVO.score = 0;
                    }
                    $scope.scoreTypeName = $scope.MoraleduDormitoryCheckDetailVO.scoreType == 0 ? "总扣分" : "总加分";
                    if ($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs == null) {
                        $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs = [];
                    }
                    if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 0) {
                        $scope.MoraleduDormitoryCheckDetailVO.lastScore = sub(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
                    } else {
                        $scope.MoraleduDormitoryCheckDetailVO.lastScore = add(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
                    }

                    /* 班级信息*/
                    if (null == $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs) {
                        $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs = [];
                    }
                    /*班级的分数*/
                    var avg = div($scope.MoraleduDormitoryCheckDetailVO.score, $scope.MoraleduDormitoryCheckDetailVO.platformSysAdminClassVOs.length);
                    angular.forEach($scope.MoraleduDormitoryCheckDetailVO.platformSysAdminClassVOs, function (clazz) {
                        var has = false;
                        angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs, function (ckeckedClass) {
                            if (ckeckedClass.platformSysAdminClassId == clazz.id) {
                                has = true;
                            }
                        });
                        if (!has) {
                            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs.push({
                                platformSysAdminClassId: clazz.id,
                                platformSysAdminClassName: clazz.name,
                                scoreType: $scope.MoraleduDormitoryCheckDetailVO.scoreType,
                                score: avg.toFixed(2)
                            })
                        }
                    });
                    /*附件信息*/
                    $scope.file.fsIds = [];
                    angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailFileVOs, function (fileInfo) {
                        $scope.file.fsIds.push(fileInfo.fastDfSId);
                    });
                    $scope.$watch(function () {
                        return $scope.MoraleduDormitoryCheckDetailVO.remark;
                    }, function (newValue, oldValue) {
                        if (newValue != oldValue) {
                            $scope.isHaveChange = true;
                        }
                    });
                } else {
                    ynuiNotification.error({msg: '获取宿舍信息失败！'});
                }
            }).error(function (data) {
                if (func) {
                    func();
                }
                ynuiNotification.error({msg: '获取宿舍信息失败！'});
            });
        };

        /**
         * 改变分数类型
         * @param index 1 加分 0 减分
         */
        $scope.changeScoreType = function (index) {
            $scope.isHaveChange = true;
            $scope.MoraleduDormitoryCheckDetailVO.scoreType = index;
            $scope.MoraleduDormitoryCheckDetailVO.score = 0;
            $scope.totalScoreDeductDisable = false;
            $scope.totalScoreAddDisable = false;
            $scope.scoreTypeName = $scope.MoraleduDormitoryCheckDetailVO.scoreType == 0 ? "总扣分" : "总加分";
            angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs, function (clazz) {
                clazz.scoreType = $scope.MoraleduDormitoryCheckDetailVO.scoreType;
                clazz.score = 0;
                clazz.totalScoreDeductDisable = false;
                clazz.totalScoreAddDisable = false;
            });
            /*计算显示的总分*/
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 0) {
                $scope.showInfo = "扣分";
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = sub(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            } else {
                $scope.showInfo = "加分";
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = add(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            }
        };

        /**
         * 扫描二维码 js二维码扫描乱码，但是今后还是会使用，所以不要删除了
         */
        // $scope.scanCode = function () {
        //     $cordovaBarcodeScanner.scan().then(function (barcodeData) {
        //         /*
        //          楼栋：ch女
        //          寝室：ch女101
        //          床位：1
        //          */
        //         $scope.number = barcodeData.text;
        //         var str = $scope.number.split(/\r?\n/); //楼栋  寝室 床位
        //         if($scope.MoraleduDormitoryCheckDetailVO.buildCode == str[0]){
        //             if($scope.MoraleduDormitoryCheckDetailVO.roomCode == str[1]){
        //                 var hasCodeStudent = false;
        //                 angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryStuInfoVOsmoraleduDormitoryStuInfoVOs,function(stu){
        //                     if(stu.bedCode == str[2]){
        //                         hasCodeStudent = true;
        //                         $scope.isHaveChange = true;
        //                         if($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs == null ){
        //                             $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs = [];
        //                         }
        //                         var save = true;
        //                         angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs,function(saveStuden){
        //                             if(saveStuden.id == stu.id){
        //                                 save = false;
        //                             }
        //                         });
        //                         if(save){
        //                             $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs.push(stu);
        //                         }
        //                     }
        //                 });
        //                 if(!hasCodeStudent){
        //                     ynuiNotification.error({msg: "扫描"+ str[2] +"未入住学生！!"});
        //                 }
        //             }else{
        //                 ynuiNotification.error({msg: "扫描"+ str[1] +"不是考核寝室!"});
        //             }
        //         }else{
        //             ynuiNotification.error({msg: " 扫描寝室"+ str[0] + "不是考核寝室楼栋!"});
        //         }
        //
        //     }, function (error) {
        //         ynuiNotification.error({msg: "扫描失败！"});
        //     });
        // };

        $scope.scanCode = function () {
            $cordovaBarcodeScanner.scan().then(function (barcodeData) {
                $scope.number = barcodeData.text;
                if (!$scope.number) {
                    return false;
                }
                $http.get(basePath + "/quertCodeDormitoryById.htm?dormitoryBedId=" + $scope.number + "&_datatime=" + new Date().getTime()).success(function (data) {
                    $ionicLoading.hide();
                    if (data.status == 0) {
                        $scope.moraleduDormitoryBedCodeInfoVO = data.result;
                        if ($scope.MoraleduDormitoryCheckDetailVO.buildCode == $scope.moraleduDormitoryBedCodeInfoVO.buildCode) {
                            if ($scope.MoraleduDormitoryCheckDetailVO.roomCode == $scope.moraleduDormitoryBedCodeInfoVO.roomCode) {
                                var hasCodeStudent = false;
                                angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryStuInfoVOs, function (stu) {
                                    if (stu.bedCode == $scope.moraleduDormitoryBedCodeInfoVO.bedCode) {
                                        hasCodeStudent = true;
                                        $scope.isHaveChange = true;
                                        if ($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs == null) {
                                            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs = [];
                                        }
                                        var save = true;
                                        angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs, function (saveStuden) {
                                            if (saveStuden.id == stu.id) {
                                                save = false;
                                            }
                                        });
                                        if (save) {
                                            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs.push(stu);
                                        }
                                    }
                                });
                                if (!hasCodeStudent) {
                                    ynuiNotification.error({msg: "扫描" + $scope.moraleduDormitoryBedCodeInfoVO.bedCode + "未入住学生！!"});
                                }
                            } else {
                                ynuiNotification.error({msg: "扫描" + $scope.moraleduDormitoryBedCodeInfoVO.roomCode + "不是考核寝室!"});
                            }
                        } else {
                            ynuiNotification.error({msg: " 扫描寝室" + $scope.moraleduDormitoryBedCodeInfoVO.buildCode + "不是考核寝室楼栋!"});
                        }
                    } else {
                        ynuiNotification.error({msg: '获取学生床位信息失败！'});
                    }
                }).error(function (data) {
                    ynuiNotification.error({msg: '获取学生床位信息失败！'});
                });
            }, function (error) {
                ynuiNotification.error({msg: "扫描失败！"});
            });
        };
        /**
         * 总分数
         * 加分或者减分
         * @param index 1 加分 -1 减分
         */
        $scope.addScore = function (index) {
            $scope.isHaveChange = true;
            var score = $scope.MoraleduDormitoryCheckDetailVO.score;
            if (index == 1) {
                score = add($scope.MoraleduDormitoryCheckDetailVO.score, 0.1);
            } else {
                score = sub($scope.MoraleduDormitoryCheckDetailVO.score, 0.1);
            }
            var disableButton = function (index) {
                if (index == 1) {
                    $scope.totalScoreAddDisable = true;
                } else {
                    $scope.totalScoreDeductDisable = true;
                }
            };
            var notification = function (message) {
                if (index == 1) {
                    if (!$scope.totalScoreAddDisable) {
                        ynuiNotification.error({msg: message});
                    }
                }
                if (index == 0) {
                    if (!$scope.totalScoreDeductDisable) {
                        ynuiNotification.error({msg: message});
                    }
                }
            };
            /*验证*/
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 1) {
                if (score < $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin) {
                    notification('不能小于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + '分');
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin;
                    disableButton(index);
                    return false;
                } else if (score > $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd) {
                    notification('不能大于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '分');
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd;
                    disableButton(index);
                    return false;
                }
            } else {
                if (score < $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin) {
                    notification('不能小于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + '分');
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin;
                    disableButton(index);
                    return false;
                } else if (score > $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd) {
                    notification('不能大于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '分');
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd;
                    disableButton(index);
                    return false;
                }
            }
            $scope.totalScoreDeductDisable = false;
            $scope.totalScoreAddDisable = false;
            $scope.MoraleduDormitoryCheckDetailVO.score = score;
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 0) {
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = sub(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            } else {
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = add(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            }
            $scope.getClassScore();

        };

        /**
         *  获取每一个班级的数据
         */
        $scope.getClassScore = function () {
            var avg = div($scope.MoraleduDormitoryCheckDetailVO.score, $scope.MoraleduDormitoryCheckDetailVO.platformSysAdminClassVOs.length);
            angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs, function (clazz) {
                clazz.score = avg.toFixed(2);
                clazz.totalScoreDeductDisable = false;
                clazz.totalScoreAddDisable = false;
            });
            $scope.totalScoreDeductDisable = false;
            $scope.totalScoreAddDisable = false;
        };

        /**
         * 手动输入的时候
         */
        $scope.changeScore = function (index) {
            $scope.isHaveChange = true;

            if (!isNotBlank($scope.MoraleduDormitoryCheckDetailVO.score)) {
                $scope.MoraleduDormitoryCheckDetailVO.score = 0;
                angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs, function (clazz) {
                    clazz.score = 0;
                });
                return false;
            }
            if (isNotBlank($scope.MoraleduDormitoryCheckDetailVO.score) && isNaN(parseFloat($scope.MoraleduDormitoryCheckDetailVO.score)) || !reg.test($scope.MoraleduDormitoryCheckDetailVO.score)) {
                $scope.MoraleduDormitoryCheckDetailVO.score = 0;
                angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs, function (clazz) {
                    clazz.score = 0;
                });
                if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 1) {
                    ynuiNotification.error({msg: '只能输入' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + '至' + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '的分数'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin;
                } else {
                    ynuiNotification.error({msg: '只能输入' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + '至' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '的分数'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin;
                }
                return false;
            }
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 1) {
                if ($scope.MoraleduDormitoryCheckDetailVO.score < $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin) {
                    ynuiNotification.error({msg: '宿舍分数不能小于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + '分'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin;
                } else if ($scope.MoraleduDormitoryCheckDetailVO.score > $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd) {
                    ynuiNotification.error({msg: '宿舍分数不能大于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '分'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd;
                }
            } else {
                if ($scope.MoraleduDormitoryCheckDetailVO.score < $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin) {
                    ynuiNotification.error({msg: '宿舍分数不能小于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + '分'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin;
                } else if ($scope.MoraleduDormitoryCheckDetailVO.score > $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd) {
                    ynuiNotification.error({msg: '宿舍分数不能大于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '分'});
                    $scope.MoraleduDormitoryCheckDetailVO.score = $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd;
                }
            }
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 0) {
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = sub(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            } else {
                $scope.MoraleduDormitoryCheckDetailVO.lastScore = add(parseFloat($scope.MoraleduDormitoryCheckDetailVO.baseScore), parseFloat($scope.MoraleduDormitoryCheckDetailVO.score));
            }
            if (index == undefined) {
                $scope.getClassScore();
            }
        };

        /**
         * 监控显示
         */
        $scope.changeClazzScoreChange = function () {
            $scope.isHaveChange = true;
        };
        /**
         * 手动输入班级的分数验证规则
         * @param clazz
         */
        $scope.changeClazzScore = function (clazz, index) {
            var avg = div($scope.MoraleduDormitoryCheckDetailVO.score, $scope.MoraleduDormitoryCheckDetailVO.platformSysAdminClassVOs.length);
            $scope.isHaveChange = true;
            var isError = false;
            if (isNotBlank(clazz.score) && (isNaN(parseFloat(clazz.score)) || !reg.test(clazz.score))) {
                if (clazz.scoreType == 1) {
                    ynuiNotification.error({msg: '只能输入' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + "至" + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '的分数'});
                } else {
                    ynuiNotification.error({msg: '只能输入' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + "至" + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '的分数'});
                }
                $scope.canSave = false;
                isError = true;
                if (index == undefined) {
                    clazz.score = avg;
                }
            }
            if (isNotBlank(clazz.score) && !isNaN(parseFloat(clazz.score))) {
                if (clazz.scoreType == 1) {
                    if (clazz.score < $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin) {
                        ynuiNotification.error({msg: '班级分数不能小于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + '分'});
                        if (index == undefined) {
                            clazz.score = avg;
                        }
                        $scope.canSave = false;
                        isError = true;
                    } else if (clazz.score > $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd) {
                        ynuiNotification.error({msg: '班级分数不能大于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '分'});
                        isError = true;
                        $scope.canSave = false;
                        if (index == undefined) {
                            clazz.score = avg;
                        }
                    }
                } else {
                    if (clazz.score < $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin) {
                        ynuiNotification.error({msg: '班级分数不能小于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + '分'});
                        if (index == undefined) {
                            clazz.score = avg;
                        }
                        isError = true;
                        $scope.canSave = false;
                    } else if (clazz.score > $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd) {
                        ynuiNotification.error({msg: '班级分数不能大于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '分'});
                        if (index == undefined) {
                            clazz.score = avg;
                        }
                        isError = true;
                        $scope.canSave = false;
                    }
                }
            }
            if (isError) {
                window.setTimeout(function () {
                    $scope.canSave = true;
                }, 400);
            }
            return isError;
        };

        /**
         * 班级分数
         * @param index 0 减分 1 加分
         */
        $scope.addClassScore = function (index, checkItem) {
            $scope.isHaveChange = true;
            var score = 0;
            if (index == 1) {
                score = add(checkItem.score, 0.1);
            } else {
                score = sub(checkItem.score, 0.1);
            }
            /*禁止使用按钮*/
            var disableButton = function (index) {
                if (index == 1) {
                    checkItem.totalScoreAddDisable = true;
                } else {
                    checkItem.totalScoreDeductDisable = true;
                }
            };
            /*提示信息管理*/
            var notification = function (message) {
                if (index == 1) {
                    if (!checkItem.totalScoreAddDisable) {
                        ynuiNotification.error({msg: message});
                    }
                }
                if (index == 0) {
                    if (!checkItem.totalScoreDeductDisable) {
                        ynuiNotification.error({msg: message});
                    }
                }
            };
            if ($scope.MoraleduDormitoryCheckDetailVO.scoreType == 1) {
                if (score < $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin) {
                    notification('不能小于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreBegin + '分');
                    disableButton(index);
                    return false;
                } else if (score > $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd) {
                    notification('不能大于' + $scope.MoraleduDormitoryCheckDetailVO.addScoreEnd + '分');
                    disableButton(index);
                    return false;
                }
            } else {
                if (score < $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin) {
                    notification('不能小于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreBegin + '分');
                    disableButton(index);
                    return false;
                }
                if (score > $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd) {
                    notification('不能大于' + $scope.MoraleduDormitoryCheckDetailVO.deductScoreEnd + '分');
                    disableButton(index);
                    return false;

                }
            }
            checkItem.score = score;
            checkItem.totalScoreDeductDisable = false;
            checkItem.totalScoreAddDisable = false;
        };

        /**
         * 选择学生
         * @param stu
         */
        $scope.selectStu = function (stu) {
            stu.select = !stu.select;
            var index = -1;
            if (stu.select) {
                $scope.selectStudent.push(stu);
            } else {
                angular.forEach($scope.selectStudent, function (student, ind) {
                    if (stu.id == student.id) {
                        index = ind;
                    }
                })
            }
            if (index != -1) {
                $scope.selectStudent.splice(index, 1);
            }
        };

        /**
         * 选择学生调用
         */
        $scope.selectStudentList = function () {
            $scope.selectStudent = [];
            angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryStuInfoVOs, function (stu) {
                stu.select = false;
            });
            angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs, function (student) {
                angular.forEach($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryStuInfoVOs, function (stu) {
                    if (student.id == stu.id) {
                        stu.select = true;
                        $scope.selectStudent.push(stu);
                    }
                })
            });
            $scope.stuList.show();
        };

        /**
         * 完成学生的选择
         */
        $scope.finishSelectSu = function () {
            $scope.isHaveChange = true;
            if ($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs == null) {
                $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs = [];
            }
            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs = [];
            angular.forEach($scope.selectStudent, function (student, ind) {
                $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailStulItemVOs.push(student);
            });
            $scope.closeName();
        };

        /**
         * 关闭选择学生的悬浮侧
         */
        $scope.closeName = function () {
            $scope.stuList.hide();
        };

        /**
         * 返回列表
         */
        $scope.backItemLists = function () {
            if ($scope.isHaveChange) {
                var confirmPopup = $ionicPopup.confirm({
                    title: "提示",
                    template: '已编辑考核内容确定要放弃吗？',
                    cancelText: "取消",
                    okText: "确认"
                });
                confirmPopup.then(function (res) {
                    if (res) {
                        $rootScope.dormitoryPage = {
                            returnPage: 1
                        };
                        history.back(-1);
                    }
                });
            } else {
                $rootScope.dormitoryPage = {
                    returnPage: 1
                };
                history.back(-1);
            }

        };
        ynNavigator.registerBackAction(function () {
            $scope.backItemLists();
        },101);
        /**
         * 文件上传
         * @param data
         */
        $scope.getDfsIds = function (data) {
            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailFileVOs = [];
            if ($scope.fileIds == null || $scope.fileIds == undefined) {
                $scope.fileIds = [];
            }
            angular.forEach(data.data, function (fileId) {
                $scope.fileIds.push(fileId);
                $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailFileVOs.push({
                    fastDfSId: fileId,
                    fileName: ""
                });
            });
        };


        /**
         * 保存
         */
        $scope.saveScoreDetail = function () {
            $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailFileVOs = [];
            angular.forEach($scope.file.fsIds, function (fileId) {
                $scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailFileVOs.push({
                    fastDfSId: fileId,
                    fileName: ""
                });
            });

            var obj = {};
            if ($scope.changeScore(1)) {
                return false;
            }
            var classIsErr = false;
            for (var i in $scope.moraleduDormitoryCheckDetailClassItemVOs) {
                var clazz = $scope.moraleduDormitoryCheckDetailClassItemVOs[i];
                if ($scope.changeClazzScore(clazz, 1)) {
                    classIsErr = true;
                }
            }
            if (classIsErr) {
                return false;
            }
            if (!$scope.canSave) {
                return false;
            }
            obj = angular.copy($scope.MoraleduDormitoryCheckDetailVO);
            /*删除不需要的数据*/
            delete obj.platformSysAdminClassVOs;
            delete obj.moraleduDormitoryStuInfoVOs;
            delete obj.remarks;
            var emptyClassIndex = [];

            angular.forEach(obj.moraleduDormitoryCheckDetailClassItemVOs, function (clazz, index) {
                if (!isNotBlank(clazz.score)) {
                    emptyClassIndex.push(index);
                }
            });
            angular.forEach(emptyClassIndex, function (index) {
                obj.moraleduDormitoryCheckDetailClassItemVOs.splice(index, 1);
            });
            if ($scope.MoraleduDormitoryCheckDetailVO.moraleduDormitoryCheckDetailClassItemVOs.length > 0 && obj.moraleduDormitoryCheckDetailClassItemVOs.length == 0) {
                ynuiNotification.error({msg: '请输入班级的得分！'});
                return false;
            }
            obj.scoreUserId = $rootScope.authorizationStr.userId;
            $http.post(basePath + "/saveMoraleduDormitoryCheckDetailByMobile.htm", parseParamForSpringMVC(obj)).success(function (data) {
                if (data.status == 0) {
                    //任务进度
                    ynuiNotification.success({msg: '添加成功！'});
                    //$location.path("/grade_dormitory");
                    $rootScope.dormitoryPage = {
                        returnPage: 1
                    };
                    history.back(-1);
                } else {
                    ynuiNotification.error({msg: '添加失败！'});
                }
            })
        };

        /**
         * js浮点数计算不准确计算解决
         * @param a
         * @param b
         * @returns {number}
         */
        var mul = function (a, b) {
            var c = 0,
                d = a.toString(),
                e = b.toString();
            try {
                c += d.split(".")[1].length;
            } catch (f) {
            }
            try {
                c += e.split(".")[1].length;
            } catch (f) {
            }
            return Number(d.replace(".", "")) * Number(e.replace(".", "")) / Math.pow(10, c);
        };

        /**
         * 加法
         * @param a
         * @param b
         */
        function add(a, b) {
            var c, d, e;
            try {
                c = a.toString().split(".")[1].length;
            } catch (f) {
                c = 0;
            }
            try {
                d = b.toString().split(".")[1].length;
            } catch (f) {
                d = 0;
            }
            return e = Math.pow(10, Math.max(c, d)), (mul(a, e) + mul(b, e)) / e;
        }

        /**
         * 剪发
         * @param a
         * @param b
         */
        function sub(a, b) {
            var c, d, e;
            try {
                c = a.toString().split(".")[1].length;
            } catch (f) {
                c = 0;
            }
            try {
                d = b.toString().split(".")[1].length;
            } catch (f) {
                d = 0;
            }
            return e = Math.pow(10, Math.max(c, d)), (mul(a, e) - mul(b, e)) / e;
        }

        /**
         * 乘法
         * @param a
         * @param b
         * @returns {number}
         */
        function mul(a, b) {
            var c = 0,
                d = a.toString(),
                e = b.toString();
            try {
                c += d.split(".")[1].length;
            } catch (f) {
            }
            try {
                c += e.split(".")[1].length;
            } catch (f) {
            }
            return Number(d.replace(".", "")) * Number(e.replace(".", "")) / Math.pow(10, c);
        }

        /**
         * 触发
         * @param a
         * @param b
         */
        function div(a, b) {
            var c, d, e = 0,
                f = 0;
            try {
                e = a.toString().split(".")[1].length;
            } catch (g) {
            }
            try {
                f = b.toString().split(".")[1].length;
            } catch (g) {
            }
            return c = Number(a.toString().replace(".", "")), d = Number(b.toString().replace(".", "")), mul(c / d, Math.pow(10, f - e));
        }

        /**
         *  字符
         * @param str
         * @returns {boolean}
         */
        var isNotBlank = function (str) {
            if (null == str) {
                return false;
            }
            if (/\S+/.test(str)) {
                return true;
            }
            return false;
        };

        /**
         * 数据结构改变
         * @param obj
         * @returns {{}}
         */
        var parseParamForSpringMVC = function (obj) {
            //最终组合成功的对象
            var resultObj = {};
            //递归方法，用于深度转换每一个参数
            //key 对象时，是属性名
            //value 属性值
            //prefix（关键），和key进行组合相组合成想要的格式类型如name.age（对象）或name[0].age（数组）
            var deepParseParams = function (key, value, prefix) {
                //先判断是否是数组
                if (value instanceof Array) {
                    for (var i in value) {
                        deepParseParams("", value[i], prefix + key + "[" + i + "]");
                    }
                }
                //再判断是否是对象
                else if (value instanceof Object) {
                    for (var i in value) {
                        deepParseParams("." + i, value[i], prefix + key);
                    }
                }
                //如果不是数组或对象，到了此次递归的最后一次，将完成组合的这条最终数据放在最终组合对象中
                else {
                    resultObj[prefix + key] = value;
                }

            };
            //因为传入的转换参数必须是对象,而且第一次传入和第二次开始组合“.”号是很特殊的地方，所有
            //第一次单独循环
            for (var i in obj) {
                deepParseParams("", obj[i], i);
            }

            //返回转换成功的对象集合
            return resultObj;
        };
        /**
         * 开始
         */
        $scope.getDormitoryScoreDetail(function () {
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $ionicScrollDelegate.scrollTop();
            $ionicLoading.hide();
        });

    }

})();
