/**
 * 寝室安排/床位调整
 * @author Wu Juncheng
 * @Date 2021年4月8日16:27:51
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        /**宿舍考核*/
        .controller('dormitoryModifyTeacherCtrl', dormitoryModifyTeacherCtrl)
    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
             //安排寝室
            .state('dormitory_modify_teacher', {
                url: '/dormitory_modify_teacher',
                templateUrl: 'templates/dormitory_modify_teacher/dormitory_modify_teacher.html',
                data: {
                    prev: 'workspaceForTeacher',
                    title: '班级寝室'
                },
                controller: 'dormitoryModifyTeacherCtrl'
            })
    }

    dormitoryModifyTeacherCtrl.$inject = ['$scope', '$http', '$ionicModal', 'ynuiNotification', '$ionicPopup', '$location', '$state'];

    /**
     * 宿舍考核 任务管理
     */
    function dormitoryModifyTeacherCtrl ($scope, $http, $ionicModal, ynuiNotification, $ionicPopup, $location, $state) {

        $ionicModal.fromTemplateUrl('dormitory_detail.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function (modal) {
            $scope.modal = modal;
        });

        $ionicModal.fromTemplateUrl('dormitory_choose_stu.html',{
            scope:$scope,
            animation:'slide-in-left'
        }).then(function(modal){
            $scope.modal_choose_stu = modal;
        });

        $ionicModal.fromTemplateUrl('dormitory_choose_bed.html',{
            scope:$scope,
            animation:'slide-in-left'
        }).then(function(modal){
            $scope.modal_choose_bed = modal;
        });

        $scope.type = 1;
        //修改类型
        $scope.changeType = function(type){
            $scope.type = type;
            if(type === 1){
                $scope.searchClassInfo();
            } else{
                $scope.queryClassRoomInfo();
            }
        };

        //跳转到班级寝室查看
        $scope.toAnother = function(type){
            if(type === 1){
                $state.go('dormitory_list');
            }else{
                $state.go('dormitory_apply');
            }
        };

        //查询管理班级
        $http.get(originBaseUrl + "/third/ssap/queryTeacherClassList.htm").success(function(data){
            if(data.status === 0){
                $scope.classList = data.result;
                var i = 0;
                angular.forEach($scope.classList, function(item){
                    item.index = i;
                    i++;
                });
                $scope.curryClass = $scope.classList[0];
                if($scope.type === 1){
                    $scope.searchClassInfo();
                } else{
                    $scope.queryClassRoomInfo();
                }
            }
        });

        //选前一个班
        $scope.beforeClass = function(index){
            if(index === 0){
                $scope.curryClass = $scope.classList[$scope.classList.length - 1];
            }else{
                $scope.curryClass = $scope.classList[index - 1];
            }
            if($scope.type === 1){
                $scope.searchClassInfo();
            } else{
                $scope.queryClassRoomInfo();
            }
        };

        //选后一个班
        $scope.afterClass = function(index){
            if(index === $scope.classList.length - 1){
                $scope.curryClass = $scope.classList[0];
            }else{
                $scope.curryClass = $scope.classList[index + 1];
            }
            if($scope.type === 1){
                $scope.searchClassInfo();
            } else{
                $scope.queryClassRoomInfo();
            }
        };

        //获取班级信息
        $scope.queryClassRoomInfo = function(){
            //获取配置
            $http.get(originBaseUrl + "/third/ssap/getOldStuChangeConfigByUserId.htm?classId=" + $scope.curryClass.id).success(function(data){
                if(data.status === 0){
                    $scope.config = data.result;
                    if($scope.config.errorInfo){
                        $scope.config.errorInfo = $scope.config.errorInfo.replace('班干部', '班主任');
                    }
                    $scope.roomList = [];
                    $scope.selectedRoom = null;
                    //获取班级信息
                    $http.get(originBaseUrl + "/third/ssap/findClassBedRoomInfoByClassId.htm?classId=" + $scope.curryClass.id).success(function(data){
                        if(data.status === 0){
                            $scope.classRoomInfo = data.result;
                            var notDealInfo = [];
                            if($scope.classRoomInfo.notDealBoyNumber > 0){
                                notDealInfo.push($scope.classRoomInfo.notDealBoyNumber + "男");
                            }
                            if($scope.classRoomInfo.notDealGirlNumber > 0){
                                notDealInfo.push($scope.classRoomInfo.notDealGirlNumber + "女");
                            }
                            $scope.classRoomInfo.notDealStr = notDealInfo.join(",");
                            //获取班级下的寝室信息
                            $http.get(originBaseUrl + "/third/ssap/getBedRoomInfoListByClassId.htm?isSearchNotGive=false&classId=" + $scope.classRoomInfo.classIds).success(function(data){
                                if(data.status === 0){
                                    $scope.roomList = data.result;
                                    if($scope.roomList.length > 0){
                                        $scope.roomList[0].selected = true;
                                        $scope.chooseInRoom($scope.roomList[0]);
                                    }
                                }
                            });
                        }
                    });
                }
            });
        };

        $scope.notFullOnly = false;
        //仅显示未排满
        $scope.showNotFullOnly = function(){
            $scope.notFullOnly = !$scope.notFullOnly;
            if($scope.notFullOnly){
                $scope.classRoomInfo.bedRoomInfoVOList = $scope.notFullList;
            }else{
                $scope.classRoomInfo.bedRoomInfoVOList = $scope.bedRoomInfoVOList;
            }
        };

        //选择寝室
        $scope.chooseInRoom = function(item){
            angular.forEach($scope.roomList, function(room){
                if(room.bedRoomId !== item.bedRoomId){
                    room.selected = false;
                }else{
                    room.selected = true;
                }
            });
            $http.get(originBaseUrl + "/third/ssap/getBedRoomInfoByRoomIdAndClassIdAndSex.htm?classId=" + $scope.classRoomInfo.classIds + "&roomId=" + item.bedRoomId + "&sex=" + item.sex).success(function(data){
                if(data.status === 0){
                    $scope.selectedRoom = data.result;
                    $scope.selectedRoom.classSurplus = $scope.selectedRoom.giveNumber - $scope.selectedRoom.inRoomNumber;
                    $scope.selectedRoom.classSurplus = $scope.selectedRoom.classSurplus > $scope.selectedRoom.surplus ? $scope.selectedRoom.surplus : $scope.selectedRoom.classSurplus;
                    if($scope.selectedRoom.classSurplus < 0){
                        $scope.selectedRoom.classSurplus = 0;
                    }
                }
            });
        };

        //关闭寝室明细
        $scope.closeDormitory = function () {
            $scope.modal.hide();
        };



        //获取班级信息
        $scope.searchClassInfo = function(){
            $http.get(originBaseUrl + "/third/ssap/findClassBedRoomInfoByClassId.htm?classId=" + $scope.curryClass.id).success(function(data){
                if(data.status === 0){
                    $scope.classRoomInfo = data.result;
                    var notDealInfo = [];
                    if($scope.classRoomInfo.notDealBoyNumber > 0){
                        notDealInfo.push($scope.classRoomInfo.notDealBoyNumber + "男");
                    }
                    if($scope.classRoomInfo.notDealGirlNumber > 0){
                        notDealInfo.push($scope.classRoomInfo.notDealGirlNumber + "女");
                    }
                    $scope.classRoomInfo.notDealStr = notDealInfo.join(",");
                    //获取配置
                    $http.get(originBaseUrl + "/third/ssap/getOldStuChangeConfigByUserId.htm?classId=" + $scope.classRoomInfo.classIds).success(function(data){
                        if(data.status === 0){
                            $scope.config = data.result;
                            if($scope.config.errorInfo){
                                $scope.config.errorInfo = $scope.config.errorInfo.replace('班干部', '班主任');
                            }
                        }
                    });
                    $scope.bedRoomInfoVOList = [];
                    //仅显示为未排满
                    $scope.notFullList = [];
                    angular.forEach($scope.classRoomInfo.bedRoomInfoVOList, function(item){
                        item.classSurplus = item.giveNumber - item.inRoomNumber;
                        item.classSurplus = item.classSurplus > item.surplus ? item.surplus : item.classSurplus;
                        if(item.classSurplus < 0){
                            item.classSurplus = 0;
                        }
                        $scope.bedRoomInfoVOList.push(item);
                        if(item.classSurplus > 0){
                            $scope.notFullList.push(item);
                        }
                    });
                    if($scope.notFullOnly){
                        $scope.classRoomInfo.bedRoomInfoVOList = $scope.notFullList;
                    }else{
                        $scope.classRoomInfo.bedRoomInfoVOList = $scope.bedRoomInfoVOList;
                    }
                }
            });
        };

        //选择学生
        $scope.clickBedInfo = function (item, canEmpty) {
            if (item.stuName || canEmpty ) {
                $scope.setectBedInfo = item;
            }
        };

        //查看寝室
        $scope.showDetail = function(roomId, roomName){
            $scope.selectedRoomName = roomName;
            $http.get(originBaseUrl + "/third/ssap/getBedRoomDetailByRoomIdAndClassId.htm?roomId="+ roomId + "&classId=" + $scope.classRoomInfo.classIds).success(function(data){
                if(data.status === 0){
                    $scope.roomDetail = data.result;
                    $scope.modal.show();
                }
            });
        };

        //选择学生
        $scope.chooseStu = function(sex, room){
            //判断是否超过寝室剩余数量
            if(room.surplus < 1){
                ynuiNotification.error({msg: '剩余预分给本班的床位已被占用，无法安排！'});
                return false;
            }
            $scope.chooseRoom = room;
            $http.get(originBaseUrl + "/third/ssap/getCanInStuBySexAndClassId.htm?sex=" + sex + "&classId=" + $scope.classRoomInfo.classIds).success(function(data){
                if(data.status === 0){
                    $scope.noBedStuList = data.result;
                    angular.forEach($scope.noBedStuList, function(stu){
                        var stuInfo = stu.stuShowName.split("(");
                        stu.name = stuInfo[0];
                        stu.info = '(' + stuInfo[1];
                        stu.selected = false;
                    });
                    var length = $scope.chooseRoom.classSurplus > $scope.noBedStuList.length ? $scope.noBedStuList.length : $scope.chooseRoom.classSurplus;
                    //默认选中剩余的学生
                    for(var i = 0; i < length; i++){
                        $scope.selectStu($scope.noBedStuList[i]);
                    }
                    $scope.modal_choose_stu.show();
                }
            });
        };

        //选中学生
        $scope.selectStu = function(item){
            if(!item){
                return false;
            }
            item.selected = !item.selected;
            $scope.chooseNumber = 0;
            angular.forEach($scope.noBedStuList, function(item){
                if(item.selected){
                    $scope.chooseNumber++;
                }
            });
            $scope.selectAll = $scope.chooseNumber === $scope.noBedStuList.length
        };

        //全选
        $scope.selectAll = false;
        $scope.selectedAll = function(){
            $scope.selectAll = !$scope.selectAll;
            $scope.chooseNumber = 0;
            angular.forEach($scope.noBedStuList, function(item){
                item.selected = $scope.selectAll;
                if(item.selected){
                    $scope.chooseNumber++;
                }
            });
        };

        //刷新学生
        $scope.searchStu = function(sex){
            $http.get(originBaseUrl + "/third/ssap/getCanInStuBySexAndClassId.htm?sex=" + sex + "&classId=" + $scope.classRoomInfo.classIds).success(function(data){
                if(data.status === 0){
                    $scope.noBedStuList = data.result;
                    $scope.modal_choose_stu.show();
                }
            });
        };

        //关闭选择学生
        $scope.closeChoose = function(){
            $scope.modal_choose_stu.hide();
        }

        //提交
        $scope.submit = function(){
            var stuIds = [];
            angular.forEach($scope.noBedStuList, function(item){
                if(item.selected){
                    stuIds.push(item.stuId);
                }
            });
            if(stuIds.length > $scope.chooseRoom.classSurplus){
                ynuiNotification.error({msg: '选中学生人数超过班级剩余床位数，不能提交！'});
                return false;
            }
            if(stuIds.length === 0){
                ynuiNotification.error({msg: '请至少勾选一项！'});
                return false;
            }
            //判断是否超了寝室的实际剩余床位
            if(stuIds.length > $scope.chooseRoom.surplus){
                ynuiNotification.error({msg: '安排学生人数大于寝室实际剩余床位数：' + $scope.chooseRoom.surplus + '！请调整安排学生数量！'});
                return false;
            }
            //发送请求
            $http.post(originBaseUrl + "/third/ssap/submitBedInfo.htm?stuIds=" + stuIds + "&bedRoomId=" + $scope.chooseRoom.bedRoomId).success(function(data){
                if(data.status === 0){
                    ynuiNotification.success({msg: '保存成功'});
                    $scope.modal_choose_stu.hide();
                    $scope.searchClassInfo();
                }else{
                    ynuiNotification.error({msg: data.message});
                }
            })
        };

        //调整床位-调整
        $scope.changeBed = function(sex, stu){
            $scope.changeBedStuInfo = stu;

            //查询待选楼栋寝室信息
            $http.get(originBaseUrl + "/third/ssap/getBuildListByClassIdAndSex.htm?sex=" + sex + "&classId=" + $scope.classRoomInfo.classIds).success(function(data){
                if(data.status === 0){
                    $scope.buildingList = data.result;
                    if($scope.buildingList.length > 0 && $scope.buildingList[0].chooseRoomVOList.length > 0){
                        angular.forEach($scope.buildingList, function(build){
                            angular.forEach(build.chooseRoomVOList, function(room){
                                room.classSurplus = room.classSurplus > room.surplus ? room.surplus : room.classSurplus;
                            });
                        });
                        $scope.chooseTargetBuild($scope.buildingList[0]);
                    }
                    $scope.modal_choose_bed.show();
                }
            });
        };

        //选择楼栋
        $scope.chooseTargetBuild = function(build){
            $scope.selectedBuild = build;
            //缓存目标楼栋的备选房间
            $scope.cacheRoomList = angular.copy(build.chooseRoomVOList);
            angular.forEach($scope.buildingList, function(data){
                if(build.id === data.id){
                    build.selected = true;
                }else{
                    build.selected = false;
                }
            });
            $scope.chooseTargetRoom($scope.selectedBuild.chooseRoomVOList[0]);
        };

        //查询目标寝室信息
        $scope.chooseTargetRoom = function(item){
            angular.forEach($scope.buildingList, function(build){
                angular.forEach(build.chooseRoomVOList, function(room){
                    if(item.bedRoomId === room.bedRoomId){
                        room.selected = true;
                    }else{
                        room.selected = false;
                    }
                });
            });
            $http.get(originBaseUrl + "/third/ssap/getBedRoomInfoByRoomIdAndClassIdAndSex.htm?classId=" + $scope.classRoomInfo.classIds + "&roomId=" + item.bedRoomId + "&sex=" + item.sex).success(function(data){
                if(data.status === 0){
                    $scope.targetRoom = data.result;
                    $scope.targetRoom.classRealSurplus = item.classRealSurplus;
                    angular.forEach($scope.targetRoom.bedInfoVOList, function(item){
                        item.classSurplus = item.giveNumber - item.inRoomNumber;
                        item.classSurplus = item.classSurplus > item.surplus ? item.surplus : item.classSurplus;
                    });
                    $scope.clickBedInfo($scope.targetRoom.bedInfoVOList[0]);
                }
            });
        };

        //关闭选择寝室
        $scope.closeChooseBed = function(){
            $scope.modal_choose_bed.hide();
        };

        //提交对调寝室
        $scope.submitChangeBed = function(){
            console.log($scope.targetRoom);
            if($scope.targetRoom.classRealSurplus < 0 || $scope.targetRoom.classRealSurplus === 0 && !$scope.setectBedInfo.stuId){
                ynuiNotification.error({msg: '选中学生人数超过班级剩余床位数，不能提交！'});
                return false;
            }
            if(!$scope.setectBedInfo.targetClass && $scope.setectBedInfo.stuId){
                ynuiNotification.error({msg: '不能和其他班的学生对调!'});
                return false;
            }
            if($scope.setectBedInfo.stuId === $scope.changeBedStuInfo.stuId){
                ynuiNotification.error({msg: '不能和自己对调!'});
                return false;
            }
            var msg = "";
            //判断是否为对调
            if($scope.setectBedInfo.stuId){
                msg += "您确定要将学生“" + $scope.changeBedStuInfo.stuName + "”" + "和“" + $scope.setectBedInfo.stuName + "”的寝室安排进行对调吗？"
                doCommit(msg);
            }else{
                $http.get(originBaseUrl + "/third/ssap/queryClassStuInfoByStuId.htm?stuId=" + $scope.changeBedStuInfo.stuId).success(function(data){
                    if(data.status === 0){
                        var stuInfoVO = data.result;
                        msg += "您确定将" + stuInfoVO.name + "从“" + stuInfoVO.roomBedInfo + "”更换到当前寝室的床位上吗？";
                        doCommit(msg);
                    }
                });
            }

        };

        //提交调整
        function doCommit(msg){
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                template: msg,
                cancelText: "取消",
                okText: "确认"
            });
            confirmPopup.then(function (res) {
                if(res){
                    $http.post(originBaseUrl + "/third/ssap/setOrSwapStu.htm", {
                        stuId : $scope.changeBedStuInfo.stuId,
                        bedId : $scope.setectBedInfo.id,
                        swapStuId : $scope.setectBedInfo.stuId,
                        swapBedId : $scope.changeBedStuInfo.id
                    }).success(function(data){
                        if(data.status === 0){
                            ynuiNotification.success({msg: '调整成功！'});
                            angular.forEach($scope.roomList, function(room){
                                if(room.selected){
                                    $scope.chooseInRoom(room);
                                }
                            });
                            $scope.modal_choose_bed.hide();
                        }else{
                            ynuiNotification.error({msg: data.message});
                            return false;
                        }
                    });
                }
            });
        }

        //学生单个退寝
        $scope.stuOutRoom = function(stuId){
            $scope.isNeedRoom = {
                flag : false
            };
            $scope.outType = 2;
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                templateUrl: 'templates/dormitory_modify/template/confirmOutRoom.html',
                scope: $scope,
                cancelText: "取消",
                okText: "确认"
            });
            confirmPopup.then(function (res) {
                if (res) {
                    var businessDataIds = [];
                    businessDataIds.push(stuId);
                    $http.post(originBaseUrl + "/third/ssap/setBedEmpty.htm", {
                        isAdmin : false,
                        businessDataType : 0,
                        businessDataIds : businessDataIds,
                        adminClassId : $scope.classRoomInfo.classIds,
                        moveOutReasonType: 1,
                        isStay : $scope.isNeedRoom.flag,
                        gender : $scope.selectedRoom.sex
                    }).success(function(data) {
                            if (data.status === 0) {
                                ynuiNotification.success({msg: '退寝成功！'});
                                angular.forEach($scope.roomList, function(room){
                                    if(room.selected){
                                        $scope.chooseInRoom(room);
                                    }
                                });
                            }else{
                                ynuiNotification.error({msg: data.message});
                                return false;
                            }
                        }
                    )
                }
            });
        };

        $scope.isNeedRoomList = [{id : true, name : "是"},{id : false, name: "否"}];
        //退寝
        $scope.outRoom = function(room){
            $scope.isNeedRoom = {
                flag : false
            };
            $scope.outType = 1;
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                templateUrl: 'templates/dormitory_modify/template/confirmOutRoom.html',
                scope: $scope,
                cancelText: "取消",
                okText: "确认"
            });
            confirmPopup.then(function (res) {
                if (res) {
                    var businessDataIds = [];
                    businessDataIds.push(room.bedRoomId);
                    $http.post(originBaseUrl + "/third/ssap/setBedEmpty.htm", {
                        isAdmin : false,
                        businessDataType : 2,
                        businessDataIds : businessDataIds,
                        moveOutReasonType: 1,
                        adminClassId : $scope.classRoomInfo.classIds,
                        isStay : $scope.isNeedRoom.flag,
                        gender : room.sex
                    }).success(function(data) {
                            if (data.status === 0) {
                                ynuiNotification.success({msg: '退寝成功！'});
                                $scope.searchClassInfo();
                            }else{
                                ynuiNotification.error({msg: data.message});
                                return false;
                            }
                        }
                    )
                }
            });
        };

    }


})();
