/**
 * 我的评教
 *
 * @author qiucheng Lu
 * @date 2021年4月13日11:04:29
 */
(function () {
    'use strict';
    angular.module('starter')
        .config(config)
        .filter('to_wj_fmt', ['$sce', '$filter', to_wj_fmt])
        .factory('wjCommonService', wjCommonService)
        .controller('myEvaluationCtrl', myEvaluationCtrl)
        .controller('myEvaluationPersonCtrl', myEvaluationPersonCtrl)
        .controller('myOnlineEvaluateCtrl', myOnlineEvaluateCtrl);

    config.$inject = ['$stateProvider'];
    function config($stateProvider) {
        $stateProvider
            .state('myEvaluationList', {
                url: '/myEvaluationList',
                templateUrl: 'templates/evaluation/myEvaluation.html',
                controller: 'myEvaluationCtrl',
                cache: false,
                data: {
                    micro: true,
                    title: '评教'
                }
            })
            .state('myEvaluationPerson', {
                url: '/myEvaluationPerson',
                templateUrl: 'templates/evaluation/myEvaluationPerson.html',
                controller: 'myEvaluationPersonCtrl',
                cache: false,
                data: {
                    micro: true,
                    title: '被评人员列表',
                    prev:"myEvaluationList"
                }
            })
            .state('myOnlineEvaluate', {
                url: '/myOnlineEvaluate',
                templateUrl: 'templates/evaluation/myOnlineEvaluate.html',
                controller: 'myOnlineEvaluateCtrl',
                cache: false,
                data: {
                    micro: false,
                    title: '在线评教',
                    prev:"myEvaluationPerson"
                }
            })
    }

    myEvaluationCtrl.$inject = ['$scope', '$http', '$ionicModal', '$interval', '$location','ynuiNotification','wjCommonService'];

    function myEvaluationCtrl($scope, $http, $ionicModal, $interval, $location,ynuiNotification,wjCommonService) {
        var vm = $scope.vm = {
            evaluationList: [],
            pageInfo: {
                pageNumber: 0,
                itemSize: 0
            },
            showEvaluation: {},
            //计时器
            second: 10,
            getEvaluationList: function () {
                $http.get(originBaseUrl + "/third/myEvaluation/getMobileEvaluationPlanByUserId.htm?pageNumber=" + vm.pageInfo.pageNumber).success(function (data) {
                    if(data.status==0 && data.result.content){
                        var currTime=new Date(data.message).getTime();
                        angular.forEach(data.result.content, function (item,_index) {
                            if(item.type==1){
                                item.difftime=new Date(item.endTime).getTime() - currTime;
                            }else{
                                item.difftime=new Date(item.beginTime).getTime()-currTime;
                            }
                            vm.evaluationList.push(item);
                            vm.ynCountDown(item);
                            item.interval=setInterval(function(){vm.ynCountDown(item);},1000);
                        })
                        vm.pageInfo = {
                            pageNumber: data.result.number,
                            itemSize: data.result.totalElements
                        };
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    }
                });
            },
            loadMore: function () {
                if (vm.pageInfo.itemSize > vm.evaluationList.length) {
                    vm.pageInfo.pageNumber = vm.pageInfo.pageNumber + 1;
                    vm.getEvaluationList();
                }
            },
            /**
             * 弹出评教说明
             * @param planId
             */
            openEvaluationRemark: function (planId) {
                //判断评教是否已经结束或未开始
                wjCommonService.getEvaluationPlanRemark(planId).then(function(data){
                    if(data.status==0){
                        vm.showEvaluation=data.result;
                        if (vm.showEvaluation.remark && vm.showEvaluation.remark.length > 0 && data.message=="false") {
                            vm.second = 5;
                            $interval(function () {vm.second--;}, 1000, 5);
                            wjCommonService.openModalRemark($scope).then(function(modal){
                                vm.modal=modal;
                                vm.modal.show();
                            })
                        } else {
                            vm.second=0;
                            vm.clearRemarkOrGoPersonlist();
                        }
                    }else{
                        ynuiNotification.error({msg: data.message});
                    }
                });
            },
            /**
             * 进入被评人列表页面
             */
            clearRemarkOrGoPersonlist: function () {
                if(vm.second>0){
                    return;
                }
                if(vm.modal){
                    vm.modal.hide();
                }
                $location.path("/myEvaluationPerson").search({planId:vm.showEvaluation.id});
            },
            /**
             *
             * @param item
             * @param currTime
             */
            ynCountDown:function(item){
                //得到天数
                var d = Math.floor(item.difftime / 1000 / 60 / 60 / 24);
                //得到小时
                var h = Math.floor(item.difftime / 1000 / 60 / 60 % 24);
                //得到分钟数
                var m = Math.floor(item.difftime / 1000 / 60 % 60);
                //得到秒数
                var s = Math.floor(item.difftime / 1000 % 60);
                //若天数和小时为0 不显示
                var shouwTime = "";
                if (d > 0) {
                    shouwTime += d + "天";
                }
                if (h > 0) {
                    shouwTime += h + "小时";
                }
                if (m > 0) {
                    shouwTime += m + "分";
                }
                if (s > 0) {
                    shouwTime += s + "秒";
                }
                item.difftime = item.difftime - 1000;
                if (shouwTime != "") {
                    item.showTime=item.type==1?"进行中,"+shouwTime+"后结束":"未开始,"+shouwTime+"后开始";
                    $scope.$applyAsync();
                }
                //进行中->结束的评教计划需要隐藏,未开始->进行中需要改变显示效果
                if(d==0 && h==0 && m==0 && s==0){
                    item.type++;
                    if(item.type==2){
                        clearInterval(item.interval);
                    }else{
                        item.difftime=new Date(item.endTime).getTime()-new Date(item.beginTime).getTime();
                    }
                }
                //console.log(item.planName+"  "+item.difftime+" "+item.showTime+"  "+item.type);
            }
        }
        vm.getEvaluationList();
    }

    myEvaluationPersonCtrl.$inject = ['$scope', '$http', '$ionicModal', 'ynuiNotification','$location','$rootScope','storageService','$ionicScrollDelegate','wjCommonService'];

    function myEvaluationPersonCtrl($scope, $http, $ionicModal, ynuiNotification,$location,$rootScope,storageService,$ionicScrollDelegate,wjCommonService) {
        var planId = $location.search().planId;
        var vm = $scope.vm = {
            //展示数据
            evaluationPersonList: [],
            //已评人数
            attendList:[],
            //未评人数
            notAttendList:[],
            showSeach:false,
            isLoading:false,
            second:0,
            condition:{
                evaluatedName:"",
                planId:planId,
                userType:$rootScope.authorizationStr.userType,
                isAttend:2,//0未平，1已评，2全部
            },
            checkTab:function(isAttend){
                vm.condition.isAttend=isAttend;
                vm.evaluationPersonList=[];
                if(isAttend!=1){
                    vm.evaluationPersonList=angular.copy(vm.notAttendList);
                }
                if(isAttend!=0){
                    angular.forEach(vm.attendList, function (item) {
                        vm.evaluationPersonList.push(item);
                    })
                }
                $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0, 1, true);
            },
            getEvaluationPersonList: function () {
                $http.post(originBaseUrl + "/third/myEvaluation/getPersonVOByPlanIdOrUserId.htm",vm.condition).success(function (data) {
                    angular.forEach(data.result.content, function (item) {
                        if(item.isAttend){
                            vm.attendList.push(item);
                        }else{
                            vm.notAttendList.push(item);
                        }
                    })
                    vm.isLoading=true;
                    vm.checkTab(vm.notAttendList.length>0?0:2);
                });
            },
            /**
             * 弹出评教说明
             * @param item
             */
            openEvaluationRemark: function () {
                wjCommonService.openModalRemark($scope).then(function(modal){
                    vm.modal=modal;
                    vm.modal.show();
                    wjCommonService.getEvaluationPlanRemark(planId).then(function(data){
                        vm.showEvaluation={
                            remark:data.result.remark
                        }
                    });
                })
            },
            clearRemarkOrGoPersonlist: function () {
                vm.modal.hide();
            },
            search:function(){
                vm.showSeach=!vm.showSeach;
                if(vm.showSeach){
                    vm.changeSearch();
                }else{
                    vm.condition.evaluatedName="";
                    vm.checkTab(vm.condition.isAttend);
                }
            },
            changeSearch:function(){
                vm.evaluationPersonList=[];
                angular.forEach(vm.attendList, function (item) {
                    if(item.userName.indexOf(vm.condition.evaluatedName)>-1){
                        vm.evaluationPersonList.push(item);
                    }
                })
                angular.forEach(vm.notAttendList, function (item) {
                    if(item.userName.indexOf(vm.condition.evaluatedName)>-1) {
                        vm.evaluationPersonList.push(item);
                    }
                })
            },
            /**
             * 进入问卷调查页面
             */
            goOnlineEvaluate: function (item) {
                if(vm.condition.userType==2&& item.isAttend){
                    return;
                }
                wjCommonService.getEvaluationPlanRemark(planId).then(function(data){
                    if(data.status==0){
                        var param={
                            //1表示重评
                            operateType:(vm.condition.userType==1&& item.isAttend)?1:0,
                            planId:vm.condition.planId,
                            userId:item.userId,
                            personMiddleId:item.personMiddleId,
                            userName:item.userName+(!item.courseName?"":"("+item.courseName+")"),
                        }
                        $location.path("/myOnlineEvaluate").search(param);
                    }else{
                        ynuiNotification.error({msg: data.message});
                    }
                });

            },
        }
        vm.getEvaluationPersonList();
    }

    myOnlineEvaluateCtrl.$inject = ['$scope', '$http', '$ionicModal', '$location','ynNavigator','ynuiNotification','$timeout',"$ionicPopup"];

    function myOnlineEvaluateCtrl($scope, $http, $ionicModal, $location,ynNavigator,ynuiNotification,$timeout,$ionicPopup) {
        var param = $location.search();
        var vm = $scope.vm = {
            condition:param,
            wJQuestionnaireProjectVOList:[],
            //评教时是否不显示分数
            isNotShowScore:false,
            validation:/^[0-9]+(.[0-9]{1})?$/,
            findWJQuestionnaireTeachingEvaluation: function () {
                $http.post(originBaseUrl + "/third/myEvaluation/findWJQuestionnaireTeachingEvaluation.htm",vm.condition).success(function (data) {
                    if(data.status==0 && data.result.wJQuestionnaireProjectVOList.length>0){
                        vm.wJQuestionnaireProjectVOList=data.result.wJQuestionnaireProjectVOList;
                        vm.isNotShowScore=data.result.isNotShowScore;
                        vm.initData();
                    }
                });
            },
            initData:function(){
                //提交下一步需要重新获取参数
                vm.condition=$location.search();
                ynNavigator.setNavTitle(vm.condition.userName);
                vm.showProject={};//显示的项目信息
                vm.showTopic={};//显示的题目信息
                vm._topicIndex=0;//显示第几题
                vm.topicList=new Array();//总试题
                var i=0;
                angular.forEach(vm.wJQuestionnaireProjectVOList,function(project){
                    angular.forEach(project.wJQuestionnaireTopicVOList,function(topic){
                        var score=0,optionIds=[];
                        angular.forEach(topic.wJQuestionnaireOptionVOList,function(option){
                            option.isChecked=option.isDefault==true;
                            if(option.isDefault==true){
                                if(topic.topicAnswerType==3){
                                    score+=parseFloat(option.highScore);
                                }else{
                                    score=parseFloat(option.highScore)>score?parseFloat(option.highScore):score;
                                }
                                optionIds.push(option.id);
                            }
                        })
                        vm.topicList[i]={topicId:topic.id,isSuccess:optionIds.length>0,score:score==0?"":score,optionIds:optionIds,advice:"",isMust:topic.isMust==true};
                        i++;
                    })
                })
                vm.showTopicInfo();
                vm.getTotal();
            },
            /**
             * 保存选项信息
             */
            saveOptions:function(){
                var optionIds=[];
                var topic=vm.showTopic;
                angular.forEach(topic.optionList,function(item){
                    if(item.isChecked==true){
                        optionIds.push(item.id);
                    }
                })
                //1:单选+打分    2：单选+文本输入+打分   3:多选+打分   4：直接打分   5:打分+文本输入  6: 文本输入
                var isSuccess=false;
                if(topic.topicAnswerType<4){
                    isSuccess=optionIds.length>0 &&vm.validation.test(topic.score);
                }else if(topic.topicAnswerType<6){
                    isSuccess=vm.validation.test(topic.score);
                }else {
                    isSuccess=topic.advice!='';
                }
                vm.topicList[vm._topicIndex]={topicId:topic.id,isSuccess:isSuccess,score:topic.score,optionIds:optionIds,advice:topic.advice,isMust:topic.isMust};
            },
            /**
             * 切换题目
             */
            showTopicInfo:function(){
                var _topic=vm.topicList[vm._topicIndex];
                angular.forEach(vm.wJQuestionnaireProjectVOList,function(project){
                    angular.forEach(project.wJQuestionnaireTopicVOList,function(topic,_index){
                        if(_topic.topicId==topic.id){
                            vm.showProject={
                                name:project.name,//问卷项目名称
                                score:project.score,//分数
                                index:_index+1,//第几题
                                topicLength:project.wJQuestionnaireTopicVOList.length,//总题数
                            }
                            var optionList=angular.copy(topic.wJQuestionnaireOptionVOList);
                            angular.forEach(optionList,function(item){
                                item.isChecked=_topic.optionIds.indexOf(item.id)>-1;
                            })
                            vm.showTopic=topic;//问卷题目VO
                            vm.showTopic.score=_topic.score;//默认分数
                            vm.showTopic.optionList=optionList;//选项
                            vm.showTopic.advice=_topic.advice;//意见和建议
                        }
                    })
                })
            },
            /**
             * 统计分数和必填完成情况
             */
            getTotal:function(){
                vm.saveOptions();
                //必填未完成数，未完成总数，总分数
                vm.totalMust=0,vm.total=0,vm.totalScore=0;
                var totalScoreInfo = 0;
                angular.forEach(vm.topicList,function(item){
                    if(!item.isSuccess){
                        if(item.isMust){
                            vm.totalMust++;
                        }
                        vm.total++;
                    }else if(vm.validation.test(item.score)){
                        totalScoreInfo+=parseFloat(item.score);
                    }
                });
                if(parseInt(totalScoreInfo)==totalScoreInfo){
                    vm.totalScore = parseInt(totalScoreInfo);
                }else{
                    vm.totalScore =  parseFloat(totalScoreInfo).toFixed(1);
                }
            },
            /**
             * 验证分数是否正确
             */
            valiScore:function(){
                var optionScore = vm.getOptionScore();
                if ((vm.showTopic.score && !vm.validation.test(vm.showTopic.score)) || vm.showTopic.score > optionScore.hightScore || vm.showTopic.score < optionScore.lowScore) {
                    if(optionScore.hightScore != optionScore.lowScore){
                        ynuiNotification.error({msg: "只能输入" + optionScore.lowScore + "到" + optionScore.hightScore + "分,整数或1位小数！"});
                    }else if(optionScore.hightScore == optionScore.lowScore && optionScore.lowScore>0){
                        ynuiNotification.error({msg: "只能输入" + optionScore.lowScore+ "分"});
                    }else if(optionScore.hightScore == optionScore.lowScore && optionScore.lowScore==0){
                        ynuiNotification.error({msg: "请选择评分项目！"});
                    }
                    return false;
                }
                return true;
            },
            /**
             * 获取该选项最高分和最低分
             * @returns {{hightScore: *, lowScore: *}}
             */
            getOptionScore:function(){
                var hightScore=0,lowScore=0,isChecked=false,topic=vm.showTopic;
                if(topic.topicAnswerType<4){
                    angular.forEach(topic.optionList,function(item){
                        if(item.isChecked==true&&topic.topicAnswerType<3){
                            hightScore=item.highScore?parseFloat(item.highScore):0;
                            lowScore=item.lowScore?parseFloat(item.lowScore):0;
                            isChecked=true;
                        }
                        if(item.isChecked==true&&topic.topicAnswerType==3){
                            hightScore+=item.highScore?parseFloat(item.highScore):0;
                            lowScore+=item.lowScore?parseFloat(item.lowScore):0;
                            isChecked=true;
                        }
                    })
                }else{
                    isChecked=true;
                    hightScore=topic.highScore?parseFloat(topic.highScore):0;
                    lowScore=topic.lowScore?parseFloat(topic.lowScore):0;
                }
                return {hightScore:hightScore,lowScore:lowScore,isChecked:isChecked};
            },
            /**
             * 上一题或下一题
             */
            goTopOrDown:function(_index){
                if((vm._topicIndex+_index)==-1){
                    return;
                }
                if((vm._topicIndex+_index)==vm.topicList.length){
                    ynuiNotification.error({msg: "已经是最后一题了！"});
                    return;
                }
                if(!vm.valiScore()){
                    return false;
                }
                vm.getTotal();
                if(vm.showTopic.isMust && !vm.topicList[vm._topicIndex].isSuccess){
                    if(vm.showTopic.topicAnswerType<6){
                        ynuiNotification.error({msg: "此题为必评题，请为此题打分！"});
                    }else{
                        ynuiNotification.error({msg: "此题为必评题，请输入意见或建议！"});
                    }
                    return;
                }

                vm._topicIndex=vm._topicIndex+_index;
                vm.showTopicInfo();
            },
            /**
             * 添加获取修改分数
             * @param score
             */
            updateScore:function(score){
                var topicScore=vm.showTopic.score+score;
                var optionScore=vm.getOptionScore();
                if(!optionScore.isChecked){
                    ynuiNotification.error({msg: "请选择评分项目！"});
                    return;
                }
                if(topicScore<optionScore.lowScore){
                    topicScore=optionScore.lowScore;
                }else if(!vm.validation.test(topicScore) || topicScore>optionScore.hightScore){
                    topicScore=optionScore.hightScore;
                }
                vm.showTopic.score=parseFloat(topicScore);
                vm.getTotal();
            },
            /**
             * 选中选项
             * @param option
             * @returns {*}
             */
            checkedOption: function (option) {
                //1:单选+打分    2：单选+文本输入+打分   3:多选+打分   4：直接打分   5:打分+文本输入  6: 文本输入
                if(vm.showTopic.topicAnswerType<3){
                    angular.forEach(vm.showTopic.optionList,function(item){
                        item.isChecked=false;
                    });
                    option.isChecked=true;
                }else{
                    option.isChecked=!option.isChecked;
                }
                $timeout(function(){
                    var score=0;
                    angular.forEach(vm.showTopic.optionList,function(item){
                        if(item.isChecked==true&&vm.showTopic.topicAnswerType<3){
                            score=item.highScore?parseFloat(item.highScore):parseFloat(item.lowScore);
                        }
                        if(item.isChecked==true&&vm.showTopic.topicAnswerType==3){
                            score+=item.highScore?parseFloat(item.highScore):parseFloat(item.lowScore);
                        }
                    })
                    vm.showTopic.score=score;
                    vm.getTotal();
                },100);
            },
            /**
             * 显示完成情况
             */
            showExaminationModal:function(){
                $ionicModal.fromTemplateUrl('examinationModal.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.modal = modal;
                    vm.modal.show();
                });
            },
            clearExaminationModal: function (index) {
                vm._topicIndex=index;
                if(!vm.valiScore()){
                    return false;
                }
                vm.showTopicInfo();
                vm.modal.hide();
            },
            /**
             * 提交及验证
             */
            submitVail:function(){
                if(!vm.valiScore()){
                    return false;
                }
                vm.getTotal();
                if(vm.totalMust>0){
                    vm.submitVailModel=$ionicPopup.show({
                        title: '<span class="font-12">你还有<span class="text-danger">'+vm.totalMust+'个</span>必评未评，不能提交！</span>',
                        templateUrl: "submitVail.html",
                        scope: $scope,
                        buttons: [{ text: '取消' }, {text: '确认', type: 'button-positive',}]
                    });
                }else{
                    //获取下一个被评人
                    $http.post(originBaseUrl + "/third/myEvaluation/getDownWJEvaluationPlanVO.htm",{
                        planId:vm.condition.planId,
                        personMiddleId:vm.condition.personMiddleId,
                    }).success(function (data) {
                        //未评总数
                        vm.notAttendTotal=0;
                        if (data.status == 0 && data.result) {
                            vm.downPersonVO=data.result;
                            if(data.message){
                                vm.notAttendTotal=parseFloat(data.message);
                            }
                        }
                        vm.submitMessageModal=true;
                    });
                }
            },
            /**
             * 保存评教结果
             */
            saveOrUpdateOnlineEvaluation:function(toDown){
                var jsonData={
                    wjTeachingEvaluationPlanId:vm.condition.planId,
                    evaluAtedUserId:vm.condition.userId,
                    totalScore:vm.totalScore,
                    operateType:vm.condition.operateType,
                    personMiddleId:vm.condition.personMiddleId,
                    scoreRecordDetailVOList:vm.topicList,
                }
                $http.post(originBaseUrl + "/third/myEvaluation/saveOrUpdateOnlineEvaluation.htm", {
                    jsonData: angular.toJson(jsonData)
                }).success(function (data) {
                    if (data.status == 0) {
                        if (toDown) {
                            var param={
                                operateType:0,
                                planId:vm.condition.planId,
                                userId:vm.downPersonVO.userId,
                                personMiddleId:vm.downPersonVO.personMiddleId,
                                userName:vm.downPersonVO.userName+(!vm.downPersonVO.courseName?"":"("+vm.downPersonVO.courseName+")"),
                            }
                            $location.path("/myOnlineEvaluate").search(param);
                            vm.initData();
                        } else {
                            $location.path("/myEvaluationPerson").search({planId:vm.condition.planId});
                        }
                        vm.submitMessageModal=false;
                    }else{
                        ynuiNotification.error({msg: "发生未知错误，请联系管理员！"});
                    }
                });
            },
            clearSubmitVail:function(index){
                vm._topicIndex=index;
                vm.showTopicInfo();
                vm.submitVailModel.close();
            }
        }
        // 默认关闭微应用
        ynNavigator.registerBackAction(function () {
            var confirmPopup = $ionicPopup.confirm({
                title: "提示",
                template: '您确定要退出当前评教页面吗？',
                cancelText: "取消",
                okText: "确定"
            });
            confirmPopup.then(function (res) {
                if (res) {
                    $location.path("/myEvaluationPerson").search({planId:vm.condition.planId});
                }
            });
        }, 101)
        vm.findWJQuestionnaireTeachingEvaluation();
    }

    function to_wj_fmt($sce, $filter) {
        return function (time) {
            //new Date()的参数严格模式下必须是一个符合 RFC2822 或 ISO 8601 日期格式的字符串
            //正确示范：new Date("2021-12-25T10:30:00")。
            //引发兼容错误：new Date("2021-12-25 10:30:00")。
            time = time.replace(" ","T");
            var dateTime = $filter('date')(new Date(time), "MM/dd HH:mm");
            return $sce.trustAsHtml(dateTime);
        }
    }
    function wjCommonService($http,$q,$ionicModal){
        return {
            /**
             * 获取评教信息
             * @param planId
             * @returns {d}
             */
            getEvaluationPlanRemark : function(planId){
                var deferred = $q.defer();
                var promise = deferred.promise;
                //判断评教是否已经结束
                $http.get(originBaseUrl + "/third/myEvaluation/getEvaluationPlanOver.htm?planId="+planId+"&isApp=true").success(function (data) {
                    deferred.resolve(data);
                });
                return promise;
            },
            /**
             * 打开评教要求
             * @returns {string}
             */
            openModalRemark:function ($scope) {
                return $ionicModal.fromTemplateUrl('templates/evaluation/template/openRemark.html', {scope: $scope, animation: 'slide-in-up'});
            }
        }
    }
})();
