/**
 * 移动学习指令
 * Created by yineng on 2017/11/20 10:37
 *
 */
'use strict';
angular.module("starter")
// 处理上传至文件服务器中的图片显示
    .directive("fileId", function (fileDownloadPath) {
        return {
            restrict: 'A',
            link: function ($scope, element, attrs) {
                if (attrs.fileId) {
                    // 更改图片请求路径
                    element.attr("src", fileDownloadPath + attrs.fileId);
                }
            }
        };
    })
    //onFinishRender
    .directive('onFinishRender', function ($timeout) {
        return {
            restrict: 'A',
            link: function (scope, element, attr) {
                if (scope.$last === true) {
                    $timeout(function () {
                        scope.$emit('ngRepeatFinished');
                    });
                }
            }
        }
    })
    // 资源学习计时器
    .directive("resTimer", function ($ionicModal, $interval, mbStudyCommonService) {
        return {
            restrict: 'A',
            link: function ($scope, element, attrs) {
                // 参数信息
                var param = {
                    learnId: null, // 学习痕迹ID
                    avPlayTime: null // 媒体播放时长
                };

                // 获取资源已学时间
                var loadResLearnedTime = function () {
                    var shareData = mbStudyCommonService.getShareData();
                    // 获取资源已学时间
                    mbStudyCommonService.getResLearnedTime(
                        shareData.tempResType,
                        shareData.tempResId
                    ).then(function (data) {
                        element.html(formatLearnTime(data.hour, data.minute));
                    });
                };

                loadResLearnedTime();

                // 允许提交保存学习时间的限制时长（单位秒）
                var allowSubmitTime = 60;

                // 学习时长（单位秒）
                var studyTime = 0;

                var timer;

                // TODO 处理学习了50多秒，关闭学习页面的情况

                /**
                 * 计时
                 */
                function countTime() {
                    studyTime++;
                    console.log("执行计时 | " + studyTime);
                    if (studyTime == allowSubmitTime) {
                        console.log("提交时间 | " + studyTime);
                        recordLearnTime();
                        studyTime = 0;
                    }
                }

                /**
                 * 提交时间
                 */
                function recordLearnTime() {
                    // 如果为媒体资源，获取播放进度
                    if ($scope.getNowPlayTime != undefined) {
                        param.avPlayTime = parseInt($scope.getNowPlayTime());
                    }
                    var shareData = mbStudyCommonService.getShareData();
                    param.resourcesId = shareData.tempResId;
                    param.type = shareData.tempResType;
                    // 如果为从scorm课件进入学习的知识点
                    if (shareData.currentLearnChapter) {
                        param.scormId = shareData.resId;
                        param.lastChapterId = shareData.currentLearnChapter;
                        mbStudyCommonService.recordKnowleageLearnTime(
                            param
                        ).then(function (data) {
                            // 学习轨迹ID
                            param.learnId = data.learnId;
                            element.html(formatLearnTime(data.hour, data.minute));
                        });
                    } else {
                        mbStudyCommonService.recordLearnTime(
                            param
                        ).then(function (data) {
                            // 学习轨迹ID
                            param.learnId = data.learnId;
                            element.html(formatLearnTime(data.hour, data.minute));
                        });
                    }
                }

                function saveAVPlayTime() {
                    // 为媒体资源，获取播放进度
                    param.avPlayTime = parseInt($scope.getNowPlayTime());
                    var shareData = mbStudyCommonService.getShareData();
                    param.resourcesId = shareData.tempResId;
                    param.type = shareData.tempResType;
                    if (param.avPlayTime) {
                        mbStudyCommonService.saveAVPlayTime(
                            param
                        ).then(function (data) {
                            // 学习轨迹ID
                            if (data) {
                                param.learnId = data;
                            }
                        });
                    }
                }

                /**
                 * 格式化学习时间
                 * @param hour 小时
                 * @param min 分钟
                 * @returns {string}
                 */
                function formatLearnTime(hour, min) {
                    var timeStr = "";
                    if (hour >= 0 && hour < 10) {
                        timeStr += "0" + hour;
                    } else {
                        timeStr += hour;
                    }
                    timeStr += ":";
                    if (min >= 0 && min < 10) {
                        timeStr += "0" + min;
                    } else {
                        timeStr += min;
                    }
                    return timeStr;
                }


                /**
                 * 开始计时
                 */
                $scope.start = function () {
                    if (!timer) {
                        console.log("开始计时");
                        timer = $interval(countTime, 1000);
                    }
                };

                /**
                 * 重新计时
                 */
                $scope.reStart = function () {
                    param.learnId = null;
                    console.log("重新计时");
                    studyTime = 0;
                    $scope.start();
                };

                // 如果设置了默认启动计时
                if ($scope.startTimer != undefined && $scope.startTimer) {
                    $scope.start();
                }

                /**
                 * 暂停计时
                 */
                $scope.pause = function () {
                    if (timer) {
                        console.log("暂停计时");
                        $interval.cancel(timer);
                        timer = null;
                    }
                };

                // 监听开始计时
                var startResTimer = $scope.$on("startResTimer", function () {
                    console.log("监听开始计时");
                    $scope.start();
                });

                // 监听重新开始计时
                var reStartResTimer = $scope.$on("reStartResTimer", function () {
                    console.log("监听重新开始计时");
                    loadResLearnedTime();
                    $scope.reStart();
                });

                // 监听暂停计时
                var pauseResTimer = $scope.$on("pauseResTimer", function () {
                    console.log("监听暂停计时");
                    $scope.pause();
                });
                //暂停播放时保存播放时间
                var pauseSaveAVPlayTime = $scope.$on("saveAVPlayTime", function () {
                    saveAVPlayTime();
                });
                // Cleanup the modal when we're done with it!
                $scope.$on('$destroy', function () {
                    console.log("清除计时器");
                    startResTimer();
                    startResTimer = null;
                    reStartResTimer();
                    reStartResTimer = null;
                    pauseResTimer();
                    pauseResTimer = null;
                    pauseSaveAVPlayTime = null;
                    if ($scope.getNowPlayTime != undefined) {
                        saveAVPlayTime();
                        $scope.clearPlayInfo();
                    }
                    $interval.cancel(timer);
                });
            }
        };
    })
    /*自动获取焦点*/
    .directive('setFocus', function ($timeout) {
        return {
            link: function (scope, element) {
                $timeout(function () {
                    element.focus();
                }, 500);
            }
        }
    })
    // 收藏按钮
    .directive("collect", function (operateType, mbStudyCommonService,$rootScope) {
        var CLASS_ACTIVE = "active";
        // 以attrs属性likeOrCollect值来区分点赞、收藏按钮：like 点赞， collect 收藏
        return {
            scope: {},
            link: function ($scope, element, attrs) {

                /**
                 * 加载已被操作状态
                 */
                var loadOperatedStatus = function () {
                    var shareData = mbStudyCommonService.getShareData();
                    // 初始化按钮是否高亮显示：如果已被点赞或收藏，则高亮显示，否则不高亮显示
                    mbStudyCommonService.isOperatedResource(
                        shareData.tempResType,
                        shareData.tempResId,
                        operateType.COLLECTION
                    ).then(function (isOperated) {
                        if (isOperated) {
                            element.addClass(CLASS_ACTIVE);
                        } else {
                            element.removeClass(CLASS_ACTIVE);
                        }
                    });
                };

                loadOperatedStatus();

                // 绑定点击处理事件：收藏
                element.click(function () {
                    var shareData = mbStudyCommonService.getShareData();
                    mbStudyCommonService.gCollectStatusChanged = true;
                    mbStudyCommonService.operateResource(
                        shareData.tempResType,
                        shareData.tempResId,
                        operateType.COLLECTION
                    ).then(function (isOperated) {
                        if (isOperated) {
                            element.addClass(CLASS_ACTIVE);
                        } else {
                            element.removeClass(CLASS_ACTIVE);
                        }
                        //刷新收藏数据
                        $rootScope.$broadcast("refreshSearchstudyCount");
                    });
                });

                /**
                 * 监听重新加载操作状态信息
                 */
                $scope.$on("reLoadOperatedStatus", function (event, data) {
                    loadOperatedStatus();
                })
            }
        };
    })
    // 点赞按钮
    .directive("like", function (operateType, mbStudyCommonService) {
        var CLASS_ACTIVE = "active";
        // 以attrs属性likeOrCollect值来区分点赞、收藏按钮：like 点赞， collect 收藏
        return {
            scope: {},
            link: function ($scope, element, attrs) {

                /**
                 * 加载已被操作状态
                 */
                var loadOperatedStatus = function () {
                    var shareData = mbStudyCommonService.getShareData();
                    // 初始化按钮是否高亮显示：如果已被点赞或收藏，则高亮显示，否则不高亮显示
                    mbStudyCommonService.isOperatedResource(
                        shareData.tempResType,
                        shareData.tempResId,
                        operateType.LIKE
                    ).then(function (isOperated) {
                        if (isOperated) {
                            element.addClass(CLASS_ACTIVE);
                        } else {
                            element.removeClass(CLASS_ACTIVE);
                        }
                    });
                };

                loadOperatedStatus();

                // 绑定点击处理事件：点赞
                element.click(function () {
                    var shareData = mbStudyCommonService.getShareData();
                    mbStudyCommonService.operateResource(
                        shareData.tempResType,
                        shareData.tempResId,
                        operateType.LIKE
                    ).then(function (isOperated) {
                        if (isOperated) {
                            element.addClass(CLASS_ACTIVE);
                        } else {
                            element.removeClass(CLASS_ACTIVE);
                        }
                    });
                });

                /**
                 * 监听重新加载操作状态信息
                 */
                $scope.$on("reLoadOperatedStatus", function (event, data) {
                    loadOperatedStatus();
                })
            }
        };
    })
    // 学习入口
    .directive("learnEntry", function ($ionicModal, mbStudyCommonService, operateType, modalManager, ynuiNotification,$rootScope,ynNavigator) {
        return {
            scope: {
                onLearned: "&" // 回调函数，退出学习界面时触发
            },
            link: function ($scope, element, attrs) {
                // 绑定点击事件
                element.click(function () {
                    // 设置全局状态值
                    mbStudyCommonService.gStatusChanged = true;

                    var _res = $scope.$eval(attrs.learnEntry);
                    if (_res.delete) {
                        ynuiNotification.error({msg: "已被删除"});
                        return;
                    }

                    // 将共享数据放入服务中统一管理
                    // 先清空共享数据
                    mbStudyCommonService.cleanShareData();
                    mbStudyCommonService.setShareData(
                        _res.resourceTableType,
                        _res.id,
                        _res.documentType,
                        _res.resourceTableType,
                        _res.id
                    );

                    $ionicModal.fromTemplateUrl(
                        'templates/handheldlearn/common-study-res.html',
                        {
                            animation: 'slide-in-right',
                            scope: $scope
                        }
                    ).then(function (modal) {
                        modalManager.put("commonStudyResModal", modal);
                        modal.show();
                        console.log("showcommonStudyResModal");


                    });
                });
                function close(){
                    //刷新历史数据
                    if(modalManager.exist("commonStudyResModal")){
                        $rootScope.$broadcast("refreshSearchstudyCount");
                    }
                    modalManager.remove("commonStudyResModal");
                }
                ynNavigator.registerBackAction(function () {
                    ynNavigator.cancelBackAction(201);
                    close();
                },201);
                // Cleanup the modal when we're done with it!
                $scope.$on('$destroy', function () {
                    close();
                });
            }
        };
    })
    // 写笔记
    .directive("takeNote", function ($rootScope, $ionicModal, ynuiNotification, mbStudyCommonService) {
        var regStr = /[\uD83C|\uD83D|\uD83E][\uDC00-\uDFFF][\u200D|\uFE0F]|[\uD83C|\uD83D|\uD83E][\uDC00-\uDFFF]|[0-9|*|#]\uFE0F\u20E3|[0-9|#]\u20E3|[\u203C-\u3299]\uFE0F\u200D|[\u203C-\u3299]\uFE0F|[\u2122-\u2B55]|\u303D|[\A9|\AE]\u3030|\uA9|\uAE|\u3030/;
        return {
            scope: {// 设置为隔离作用域
                doEvent: "=", // 是否处理笔记模态框关闭事件
                onOperated: "&", // 操作之后的回调
            },
            link: function ($scope, element, attrs, c) {
                // 笔记内容
                $scope.note = {
                    noteId: null,
                    content: null,
                    resType: null,
                    resId: null
                };

                // 保存笔记
                $scope.saveNote = function () {
                    if (!$scope.note.content) {
                        ynuiNotification.warning({msg: '请输入笔记内容！'});
                        return;
                    }
                    // 过滤emoji表情
                    if (regStr.test($scope.note.content)) {
                        $scope.note.content = $scope.note.content.replace(regStr, "");
                    }

                    var shareData = mbStudyCommonService.getShareData();
                    mbStudyCommonService.saveOrUpdateNote(
                        shareData.tempResType,
                        shareData.tempResId,
                        $scope.note.content,
                        $scope.note.noteId
                    ).then(function (data) {
                        $scope.closeModal();
                        clearNote();
                        callBackFn();
                    });
                };

                /**
                 * 回调
                 */
                function callBackFn() {
                    // 如果有回调函数则回调
                    if ($scope.onOperated) {
                        $scope.onOperated();
                    }
                }

                // 清空笔记内容
                function clearNote() {
                    $scope.note.content = null;
                }

                var _modal;
                // 绑定点击处理事件：加载输入笔记文本框并显示
                element.click(function () {
                    if (attrs.takeNote != "") {
                        $scope.note = angular.extend($scope.note, $scope.$eval(attrs.takeNote));
                    }
                    $ionicModal.fromTemplateUrl('templates/handheldlearn/take-note.html', {
                        scope: $scope
                    }).then(function (modal) {
                        _modal = modal;
                        _modal.show();
                    });
                    // 笔记模态框打开
                    $rootScope.$broadcast("noteModal:openStatus", {isOpen: true});
                });

                // 关闭笔记输入框
                $scope.closeModal = function () {
                    if (_modal) {
                        _modal.hide();
                        // 笔记模态框打开
                        $rootScope.$broadcast("noteModal:openStatus", {isOpen: false});
                    }
                };

                // Cleanup the modal when we're done with it!
                $scope.$on('$destroy', function () {
                    if (_modal) {
                        _modal.remove();
                    }
                });

                // Execute action on hide modal
                $scope.$on('modal.hidden', function (event) {
                    if (event.targetScope == event.currentScope) {
                        // 如果要处理事件
                        if (attrs.unDealEvent == undefined) {
                            // 笔记模态框关闭
                            $rootScope.$broadcast("noteModal:openStatus", {isOpen: false});
                        }
                    }
                });
            }
        };
    })
    // 笔记
    .directive("note", function ($ionicModal, $ionicPopup, ynuiNotification, mbStudyCommonService) {
        return {
            // require: 'ngModel', // 依赖ng-model指令
            replace: false,
            templateUrl: "templates/handheldlearn/note.html",
            link: function ($scope, element, attrs) {

                $scope.param = {
                    page: 0, // 第几页
                    size: 10 // 每页几条数据
                };


                // 分页查询结果
                $scope.pageResult = null;

                // 笔记
                $scope.notes = [];

                var shareData = mbStudyCommonService.getShareData();


                /**
                 * 加载笔记
                 */
                $scope.loadNotes = function () {
                    mbStudyCommonService.listAllNotes(
                        shareData.resType,
                        shareData.resId,
                        $scope.param.page,
                        $scope.param.size
                    ).then(function (data) {
                        $scope.pageResult = data;
                        angular.forEach(data.content, function (item) {
                            item.resType = shareData.resType;
                            item.resId = shareData.resId;
                            $scope.notes.push(item);
                        });
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    });
                };

                $scope.loadNotes();


                /**
                 * 重新加载笔记
                 */
                $scope.reLoadNotes = function () {
                    $scope.param.page = 0;
                    $scope.notes = [];
                    // 通知父级组件重新获取资源基本信息
                    $scope.$emit('commonStudyRes: reLoadData');
                    $scope.loadNotes();
                };

                /**
                 * 加载更多
                 */
                $scope.loadMore = function () {
                    $scope.param.page++;
                    if ($scope.param.page >= $scope.pageResult.totalPages) {
                        return false;
                    }
                    $scope.loadNotes();
                };


                /**
                 * 删除笔记
                 * @param noteId
                 */
                $scope.deleteNote = function (noteId) {
                    $ionicPopup.confirm({
                        title: "提示",
                        template: '确定要删除此条笔记吗？',
                        cancelText: "取消",
                        okText: "确定"
                    }).then(function (res) {
                        if (res) {
                            mbStudyCommonService.deleteNote(
                                noteId
                            ).then(function (data) {
                                if (data.status == 0) {
                                    ynuiNotification.success({msg: "已删除！"});
                                    $scope.reLoadNotes();
                                } else {
                                    ynuiNotification.error({msg: data.message});
                                }
                            });
                        }
                    });
                };

                /**
                 * 是否使用加载更多
                 */
                $scope.useLoadMore = function () {
                    return $scope.pageResult && ($scope.pageResult.number + 1) < $scope.pageResult.totalPages;
                };
            }
        };
    })
    // 介绍
    .directive("introduce", function () {
        return {
            templateUrl: "templates/handheldlearn/res-introduce.html",
            link: function ($scope, element, attrs) {
            }
        };
    })
    // 学习资源工具栏组件
    .directive("resToolbar", function ($ionicModal, modalManager, $rootScope) {
        return {
            replace: false,
            templateUrl: "templates/handheldlearn/res-toolbar.html",
            link: function ($scope, element, attrs) {

                // 显示资源公共信息块
                $scope.showCommonInfo = function () {
                    // 通知父级组件重新获取资源基本信息
                    $scope.$emit('reLoadScormCourse');
                    // 暂停计时
                    $scope.$emit("pauseResTimer");
                    $ionicModal.fromTemplateUrl(
                        'res-common-info-modal.html',
                        {
                            scope: $scope
                        }
                    ).then(function (modal) {
                        modalManager.put("resCommonInfoModal", modal);
                        modal.show();

                    });
                };

                // Cleanup the modal when we're done with it!
                $scope.$on('$destroy', function () {
                    modalManager.remove("resCommonInfoModal");
                });

                // Execute action on hide modal
                $scope.$on('modal.hidden', function (event) {
                    if (event.targetScope == event.currentScope) {
                        // 如果要处理事件
                        if (attrs.unDealEvent == undefined) {
                            // 笔记模态框关闭
                            $rootScope.$broadcast("noteModal:openStatus", {isOpen: false});
                        }
                    }
                });
            }
        };
    })
    // 资源公共信息组件
    .directive("resCommonInfo", function ($ionicModal, $timeout, modalManager) {
        return {
            templateUrl: "templates/handheldlearn/res-common-info.html",
            link: function ($scope, element, attrs) {


                $scope.$on('$destroy', function () {
                });
            }
        };
    })
    // 图片资源组件
    .directive("resPicture", function ($rootScope, $ionicSlideBoxDelegate, $document) {
        return {
            scope: true,
            replace: false,
            templateUrl: "templates/handheldlearn/res-picture.html",
            link: function ($scope, element, attrs) {
                $scope.param = {
                    // 是否显示缩略图，默认不显示（）
                    isShowThumbnail: false,
                    // 当前显示图片的索引，默认从第一张开始
                    myActiveSlide: 0
                };

                /**
                 * 选中缩略图
                 * @param index
                 */
                $scope.selectPicture = function (index) {
                    $scope.param.myActiveSlide = index;
                    $scope.param.isShowThumbnail = false;
                };

                // 监听图片是否已经遍历完成
                $scope.$on("ngRepeatFinished", function () {
                    $ionicSlideBoxDelegate.update();
                    angular.element('.box').css('height', $document.innerHeight())
                });

                // 监听笔记弹框打开状态
                var unsubscribe = $rootScope.$on("noteModal:openStatus", function (event, data) {
                    // 如果笔记框打开，暂停计时
                    if (data.isOpen) {
                        $scope.$emit("pauseResTimer");
                    } else { // 否则开启计时
                        $scope.$emit("startResTimer");
                    }
                });

                $scope.$on("$destroy", function () {
                    unsubscribe();
                });

                // 开启计时
                $scope.startTimer = true;
            }
        };
    })
    // 视频资源组件
    .directive("resVideo", function (ynuiNotification,$http,$rootScope) {
        return {
            templateUrl: "templates/handheldlearn/res-video.html",
            link: function ($scope) {
                $scope.showVideo = true;
                $scope.videoInfo = {
                    /*控制显示默认页面或视频*/
                    static: true,
                    /*视频获取src*/
                    fsSrc: "",
                    /*显示提示*/
                    showTitle: "",
                    showTimer: false
                };
                // var videoWidth = document.body.clientWidth;
                // $scope.videoHeight = parseInt((videoWidth * 3)/4);
                /*判断是否能在线播放*/
                var getErrorTitle = function () {
                    var errorTitle = "";
                    var fsId = $scope.resDetail.fastFSIds[0];
                    var suffixName = fsId.substring(fsId.indexOf(".") + 1);
                    if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                        /*ios*/
                        if (suffixName != "mp4") {
                            errorTitle = suffixName + "格式的视频，暂不支持在线播放";
                        }
                    } else if (/(Android)/i.test(navigator.userAgent)) {
                        /*android*/
                        var androidVideo = ["wmv", "webm", "mkv", "mp4", "avi"];
                        if (!$.inArray(suffixName, androidVideo)) {
                            errorTitle = suffixName + "格式的视频，暂不支持在线播放";
                        }
                    }
                    return errorTitle;
                };
                /*获取显示提示字符串*/
                var getShowTitle = function () {
                    var errorTitle = getErrorTitle();
                    if (errorTitle) {
                        $scope.videoInfo.showTitle = errorTitle;
                    } else {
                        $scope.videoInfo.showTitle = "使用移动网络播放，会消耗" + $scope.resDetail.size + $scope.resDetail.unit + "流量";
                    }
                };
                /*监控获取当前视频src 用以加载视频*/
                $scope.$watch(function () {
                    return $scope.resDetail
                }, function () {
                    if ($scope.resDetail && $scope.resDetail.fastFSIds) {
                        $scope.videoInfo.fsId = $scope.resDetail.fastFSIds[0];
                        $scope.videoInfo.fsSrc = $scope.resDetail.fastFSIds[1];
                        getShowTitle();
                        $scope.videoInfo.avPlayTime = $scope.resDetail.avPlayTime;
                    }
                });
                var myVid = null;
                /*加载视频*/
                var openVideo = function () {
                    var flashvars = {
                        f: $scope.videoInfo.fsSrc,//视频地址
                        p: 1,
                        e: 0,
                        i: ""
                        //loaded:'loadedHandler'
                    };

                    /**
                     * 1. swf所在位置
                     * 2. 写死（千万不要改）
                     * 3. 写死<div id="ckplayer_a1"></div> 视屏所在区域位置(千万不要改)
                     * 4. 显示大小(宽度) 可以写成  200
                     * 5. 显示大小(高度) 可以写成  100
                     * 6. 如果为true 默认调用html5 如果为false 则调用 flash
                     * 7. 调用flash播放时的配置
                     * 8. 调用html5属性播放的时候 配置
                     */
                    CKobject.embed("", 'videoDiv', 'videoDom', '100%', 210, true, flashvars, [$scope.videoInfo.fsSrc]);

                    /*当前视频元素*/
                    myVid = document.getElementById("videoDom");
                    /*监控暂停事件*/
                    myVid.addEventListener("pause", function () {
                        $scope.$emit("pauseResTimer");
                        $scope.$emit("saveAVPlayTime");
                        $scope.videoInfo.showTimer = false;
                    });
                    /*监控播放事件*/
                    myVid.addEventListener("play", function () {
                        $scope.$emit("startResTimer");
                        $scope.videoInfo.showTimer = true;
                    });
                    /*监控播放结束事件*/
                    myVid.addEventListener("ended", function () {
                        $scope.$emit("pauseResTimer");
                        $scope.$emit("saveAVPlayTime");
                        $scope.videoInfo.showTimer = false;
                        if (myVid.currentTime < 1) {
                            myVid.play();
                            myVid.currentTime = $scope.resDetail.avPlayTime;
                        }
                    });
                    myVid.addEventListener("canplaythrough", function () {
                        if ($scope.resDetail.avPlayTime && myVid.currentTime < 1) {
                            myVid.currentTime = $scope.resDetail.avPlayTime;
                            if (myVid.paused) {
                                /*处于暂停状态*/
                                myVid.play();
                                $scope.videoInfo.showTimer = true;
                            }
                        }
                    });
                };
                /*点击播放图标*/
                $scope.payVideo = function () {
                    var errorTitle = getErrorTitle();
                    if (errorTitle) {
                        ynuiNotification.error({msg: errorTitle});
                        return;
                    }
                    $http.get(originBaseUrl + "/lmshome/portalHomePage/getAudioOrVideoFilePath.htm?fileKeyId=" + $scope.videoInfo.fsId).success(function (data) {
                        $scope.videoInfo.static = false;
                        //赋值url
                        $scope.videoInfo.fsSrc =  originBaseUrl.replace("/ynedut", "") + data;
                        openVideo();
                        $scope.videoInfo.showTimer = true;
                    });
                };
                /*暂停或者播放视频*/
                $scope.pausedVideo = function () {
                    if (myVid.paused) {
                        /*处于暂停状态*/
                        myVid.play();
                        $scope.videoInfo.showTimer = true;
                    } else {
                        myVid.pause();
                        $scope.videoInfo.showTimer = false;
                    }
                };

                $scope.$on("noteModal:openStatus", function (event, data) {
                    // 如果笔记框打开
                    if (data.isOpen) {
                        myVid.pause();
                        $scope.$emit("pauseResTimer");
                        $scope.showVideo = false;
                        $scope.videoInfo.showTimer = false;
                    } else {
                        myVid.play();
                        $scope.showVideo = true;
                        $scope.videoInfo.showTimer = true;
                    }
                });

                /*获取当前播放时间*/
                $scope.getNowPlayTime = function () {
                    if (myVid) {
                        if (myVid.ended) {
                            return myVid.duration
                        } else {
                            return myVid.currentTime;
                        }
                    } else {
                        return null;
                    }
                };
                /**
                 * 页面销毁时 关闭播放
                 */
                $scope.clearPlayInfo = function () {
                    if (myVid) {
                        myVid.pause();
                        $scope.videoInfo.showTimer = false;
                    }
                };
                $rootScope.$on("refreshSearchstudyCount",function () {
                    $scope.clearPlayInfo();
                });
            }
        };
    })
    // 音频资源组件
    .directive("resAudio", function ($sce, ynuiNotification,$http,$rootScope) {
        return {
            // replace: false,
            templateUrl: "templates/handheldlearn/res-audio.html",
            link: function ($scope, element, attrs) {
                $scope.showVideo = true;
                $scope.audioInfo = {
                    /*控制显示默认页面或音频*/
                    static: true,
                    /*视频获取src*/
                    fsSrc: "",
                    /*显示提示*/
                    showTitle: "",
                    showTimer: false
                };
                /*判断是否能在线播放*/
                var getErrorTitle = function () {
                    var errorTitle = "";
                    var fsId = $scope.resDetail.fastFSIds[0];
                    var suffixName = fsId.substring(fsId.indexOf(".") + 1);
                    if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                        /*ios*/
                        if (suffixName != "mp3" && suffixName != "wav") {
                            errorTitle = suffixName + "格式的音频，暂不支持在线播放";
                        }
                    } else if (/(Android)/i.test(navigator.userAgent)) {
                        /*android*/
                        var androidAudeo = ["wma", "wav", "map"];
                        if (!$.inArray(suffixName, androidAudeo)) {
                            errorTitle = suffixName + "格式的音频，暂不支持在线播放";
                        }
                    }
                    return errorTitle;
                };
                /*获取显示提示字符串*/
                var getShowTitle = function () {
                    var errorTitle = getErrorTitle();
                    if (errorTitle) {
                        $scope.audioInfo.showTitle = errorTitle;
                    } else {
                        $scope.audioInfo.showTitle = "使用移动网络播放，会消耗" + $scope.resDetail.size + $scope.resDetail.unit + "流量";
                    }
                };
                /*监控获取当前音频src 用以加载音频*/
                $scope.$watch(function () {
                    return $scope.resDetail
                }, function () {
                    if ($scope.resDetail && $scope.resDetail.fastFSIds) {
                        $scope.audioInfo.fsId = $scope.resDetail.fastFSIds[0];
                        $scope.audioInfo.fsSrc = $scope.resDetail.fastFSIds[1];
                        getShowTitle();
                    }
                });

                var myAud = null;
                /*加载视频*/
                var openAudio = function () {
                    var flashvars = {
                        f: $scope.audioInfo.fsSrc,//视频地址
                        p: 1,
                        e: 0,
                        i: "templates/handheldlearn/assets/images/audio.png"
                        //loaded:'loadedHandler'
                    };

                    /**
                     * 1. swf所在位置
                     * 2. 写死（千万不要改）
                     * 3. 写死<div id="ckplayer_a1"></div> 视屏所在区域位置(千万不要改)
                     * 4. 显示大小(宽度) 可以写成  200
                     * 5. 显示大小(高度) 可以写成  100
                     * 6. 如果为true 默认调用html5 如果为false 则调用 flash
                     * 7. 调用flash播放时的配置
                     * 8. 调用html5属性播放的时候 配置
                     */
                    CKobject.embed("", 'audioDiv', 'videoDom', '100%', 210, true, flashvars, [$scope.audioInfo.fsSrc]);

                    /*当前视频元素*/
                    myAud = document.getElementById("videoDom");
                    /*监控暂停事件*/
                    myAud.addEventListener("pause", function () {
                        $scope.$emit("pauseResTimer");
                        $scope.$emit("saveAVPlayTime");
                        $scope.audioInfo.showTimer = false;
                    });
                    /*监控播放事件*/
                    myAud.addEventListener("play", function () {
                        $scope.$emit("startResTimer");
                        $scope.audioInfo.showTimer = true;
                    });

                    /*监控播放结束事件*/
                    myAud.addEventListener("ended", function () {
                        $scope.$emit("pauseResTimer");
                        $scope.$emit("saveAVPlayTime");
                        $scope.audioInfo.showTimer = false;
                        if (myAud.currentTime < 1) {
                            myAud.play();
                            myAud.currentTime = $scope.resDetail.avPlayTime;
                        }
                    });
                    //播放准备就绪时
                    myAud.addEventListener("canplaythrough", function () {
                        if ($scope.resDetail.avPlayTime && myAud.currentTime < 1) {
                            myAud.currentTime = $scope.resDetail.avPlayTime;
                            if (myAud.paused) {
                                /*处于暂停状态*/
                                myAud.play();
                                $scope.videoInfo.showTimer = true;
                            }
                        }
                    });
                };
                /*点击播放图标*/
                $scope.payAudio = function () {
                    var errorTitle = getErrorTitle();
                    if (errorTitle) {
                        ynuiNotification.error({msg: errorTitle});
                        return;
                    }
                    $http.get(originBaseUrl + "/lmshome/portalHomePage/getAudioOrVideoFilePath.htm?fileKeyId=" + $scope.audioInfo.fsId).success(function (data) {
                        $scope.audioInfo.static = false;
                        //赋值url
                        $scope.audioInfo.fsSrc =  originBaseUrl.replace("/ynedut", "") + data;
                        openAudio();
                        $scope.audioInfo.showTimer = true;
                    });

                };
                /*暂停或者播放音频*/
                $scope.pausedAudio = function () {
                    if (myAud.paused) {
                        /*处于暂停状态*/
                        myAud.play();
                        $scope.audioInfo.showTimer = true;
                    } else {
                        myAud.pause();
                        $scope.audioInfo.showTimer = false;
                    }
                };

                $scope.$on("noteModal:openStatus", function (event, data) {
                    // 如果笔记框打开
                    if (data.isOpen) {
                        myAud.pause();
                        $scope.$emit("pauseResTimer");
                        $scope.showVideo = false;
                        $scope.audioInfo.showTimer = false;
                    } else {
                        myAud.play();
                        $scope.showVideo = true;
                        $scope.audioInfo.showTimer = true;
                    }
                });

                /*获取当前播放时间*/
                $scope.getNowPlayTime = function () {
                    if (myAud) {
                        if (myAud.ended) {
                            return myAud.duration
                        } else {
                            return myAud.currentTime;
                        }
                    } else {
                        return null;
                    }
                };
                /**
                 * 页面销毁时 关闭播放
                 */
                $scope.clearPlayInfo = function () {
                    if (myAud) {
                        myAud.pause();
                        $scope.audioInfo.showTimer = false;
                    }
                };
                $rootScope.$on("refreshSearchstudyCount",function () {
                    $scope.clearPlayInfo();
                });
            }
        };
    })
    // 文档资源组件
    .directive("resDoc", function ($rootScope, $window, $document,$sce) {
        return {
            // replace: false,
            templateUrl: "templates/handheldlearn/res-doc.html",
            link: function ($scope, element, attrs) {
                // 是否已打开文件
                $scope.isOpenedFile = false;

                // 文件路径
                $scope.fileUrl = null;

                $scope.openFile = function () {
                    $scope.isOpenedFile = true;
                    $scope.fileUrl = $sce.trustAsResourceUrl(originBaseUrl + "/static/yineng/components/22-ynuiPdfViewer/web/viewer.html?fastDFSId=" + $scope.resDetail.fastFSIds[0]);
                    // 开启学习计时器
                    $scope.$emit("startResTimer");
                };


                // 监听笔记弹框打开状态
                $rootScope.$on("noteModal:openStatus", function (event, data) {
                    // 如果笔记框打开，暂停计时
                    if (data.isOpen) {
                        $scope.$emit("pauseResTimer");
                    } else { // 否则开启计时
                        $scope.$emit("startResTimer");
                    }
                });


                changeFrameSize();

                /**
                 * 改变iframe窗体大小
                 */
                function changeFrameSize() {
                    $document.find("#docFrame").prop('height', $window.innerHeight);
                    $document.find("#docFrame").prop('width', $window.innerWidth);
                }

            }
        };
    })
    // SCORM课件资源组件
    .directive("resScormCourse", function (mbStudyCommonService) {
        return {
            templateUrl: "templates/handheldlearn/res-scorm-course.html",
            link: function ($scope, element, attrs) {
                // 重置提供给APP的方法
                window.historyBack = angular.noop;

                var shareData = mbStudyCommonService.getShareData();
                $scope.options = shareData;
            }
        };
    })
    // sco资源（知识点、网站）资源组件
    .directive("resSco", function ($rootScope) {
        return {
            templateUrl: "templates/handheldlearn/res-sco.html",
            link: function ($scope, element, attrs) {
                // 监听笔记弹框打开状态
                $rootScope.$on("noteModal:openStatus", function (event, data) {
                    // 如果笔记框打开，暂停计时
                    if (data.isOpen) {
                        $scope.$emit("pauseResTimer");
                    } else { // 否则开启计时
                        $scope.$emit("startResTimer");
                    }
                });
                $scope.$on('$destroy', function () {
                });
            }
        };
    })
    // 不支持预览资源
    .directive("resUnsupport", function ($rootScope) {
        return {
            templateUrl: "templates/handheldlearn/res-unsupport.html",
            link: function ($scope, element, attrs) {
            }
        };
    })
    // 章节树组件
    .directive("chapterTree", function () {
        return {
            restrict: 'EA',
            replace: true,
            scope: {
                chapters: "=",
                currentLearnChapter: "="
            },
            template: function () {
                var html = '<ul class="tree-customized">' +
                    '<li ng-repeat="item in chapters">' +
                    '<a href="" ng-click="clickChapter(item)" class="link-icon learn-mark" ng-init="item.isUp=true" class="learn-mark" ng-class="{\'learning-mark\': item.id == currentLearnChapter}">' +
                    '<i class="learn-icon active" ng-if="item.learned"></i>' +
                    '<i ng-if="item.haveSubChapters"' +
                    'ng-class="{\'ion-arrow-up-b\': item.isUp, \'ion-arrow-down-b\': !item.isUp}"' +
                    'ng-click="item.isUp = !item.isUp;stopPropagation();" ></i>' +
                    '<i class="ion-link" ng-if="item.haveKPoint" ></i>' +
                    '<span >{{item.name}}</span>' +
                    '<i class="learning" ng-if="item.id == currentLearnChapter">正在学...</i>' +
                    '</a>' +
                    '<div chapter-tree chapters="item.subChapters" ng-show="item.isUp" current-learn-chapter="currentLearnChapter"></div>' +
                    '</li>' +
                    '</ul>';
                return html;
            },
            // templateUrl: "templates/handheldlearn/chapter-tree.html",
            link: function ($scope, element, attrs) {
                /**
                 * 点击章节
                 * @param chapter 章节
                 */
                $scope.clickChapter = function (chapter) {
                    $scope.$emit("chapter:clicked", chapter);
                };
            }
        };
    })
    // sco资源路径处理组件
    .directive("scoPath", function ($document, $window) {
        return {
            restrict: 'A',
            scope: {},
            link: function ($scope, element, attrs) {
                attrs.$observe("scoPath", function (newVal) {
                    if (newVal) {
                        element.attr("src", newVal);
                    }
                });
                element.on("load", function () {
                    // 开启学习计时器
                    $scope.$emit("reStartResTimer");
                });
                // todo 云端资源

                changeFrameSize();

                /**
                 * 改变iframe窗体大小
                 */
                function changeFrameSize() {
                    element.prop('height', $window.innerHeight);
                    element.prop('width', $window.innerWidth);
                }


            }
        };
    })
    // 笔记显示全文组件
    .directive("showMore", function ($compile) {
        return {
            restrict: 'A',
            scope: {},
            link: function ($scope, element, attrs) {
                // 页面宽度
                var _pageWidth = angular.element(document).width(),
                    fontSize = 12, // 字体像素
                    showMoreRow = 3; // 默认设置的显示“查看全文”行数

                // 配置信息
                $scope.options = {
                    show: true // 默认显示“查看全文”，false 显示“收起全文”
                };

                /**
                 * 查看或收起
                 */
                $scope.showOrHide = function () {
                    if ($scope.options.show) {
                        element.addClass("showmore");
                    } else {
                        element.removeClass("showmore");
                    }
                    $scope.options.show = !$scope.options.show;
                };

                var html = '<div class="show-popover" ng-click="showOrHide()">{{options.show ? "查看" : "收起"}}全文</div>';
                html = $compile(html)($scope);
                attrs.$observe("showMore", function (newVal) {
                    if (newVal) {
                        element.html(newVal);
                        // 在以当前页宽度的情况下，会显示几行
                        var row = (newVal.length * fontSize) / _pageWidth; // newVal.length * fontSize 笔记内容文字像素长度
                        // 如果行数大于要显示的最小行数
                        if (row > showMoreRow) {
                            element.append(angular.element(html));
                        }
                    }
                });
            }
        };
    })
    // 底部继续学习处理组件
    .directive("continueLearnAtBottom", function ($rootScope) {
        return {
            restrict: 'E',
            scope: {
                model: "=",
                continueLearn: "&"
            },
            replace: true,
            template: function (tElement, tAttrs) {
                var html = '<div class="" ng-show="options.isShow">';
                html += '<div class="item-customized item-customized-icon-right">';
                html += '<div class="article-title">';
                html += '上次学到:&nbsp;&nbsp;{{learnedInfo.learnedChapterName}}';
                html += '<span class="text-theme" ng-click="continueLearn()">继续</span>';
                html += '</div>';
                html += '<i class="icon ion-close-round" ng-click="closeContinueLearn()" ></i>';
                html += '</div>';
                html += '</div>';
                return html;
            },
            link: function ($scope, element, attrs) {
                $scope.learnedInfo = {
                    learnedChapterId: null, // 已学章节ID
                    learnedChapterName: null, // 已学章节名称
                    learnedKPointId: null, // 已学章节对应知识点ID
                };

                $scope.options = {
                    isShow: false
                };
                $scope.$watch("model.learnedChapterName", function (newVal, oldVal) {
                    if (newVal !== oldVal && newVal) {
                        $scope.learnedInfo.learnedChapterName = $scope.model.learnedChapterName;
                        $scope.options.isShow = true;
                    }
                }, true);

                var show = function () {
                    $scope.options.isShow = true;
                };

                var close = function () {
                    $scope.options.isShow = false;
                };

                /**
                 * 关闭底部继续学习
                 */
                $scope.closeContinueLearn = function () {
                    $rootScope.$broadcast("continueLearnAtTop: isShow", {isShow: true});
                    close();
                };
            }
        };
    })
    // 顶部继续学习处理组件
    .directive("continueLearnAtTop", function ($rootScope) {
        return {
            restrict: 'E',
            scope: {
                model: "=",
                continueLearn: "&"
            },
            template: function (tElement, tAttrs) {
                var html = '<div class="item-customized item-customized-icon-right warning-bg" ng-if="options.isShow">';
                html += '上次学到：&nbsp;&nbsp;{{learnedInfo.learnedChapterName}}';
                html += '<span class="text-only text-theme" ng-click="continueLearn()">继续</span>';
                html += '</div>';

                return html;
            },
            link: function ($scope, element, attrs) {
                $scope.learnedInfo = {
                    learnedChapterId: null, // 已学章节ID
                    learnedChapterName: null, // 已学章节名称
                    learnedKPointId: null, // 已学章节对应知识点ID
                };

                $scope.options = {
                    isShow: false
                };

                $scope.$watch("model.learnedChapterName", function (newVal, oldVal) {
                    if (newVal !== oldVal && newVal) {
                        $scope.learnedInfo.learnedChapterName = $scope.model.learnedChapterName;
                    }
                }, true);

                var show = function () {
                    $scope.options.isShow = true;
                };

                var close = function () {
                    $scope.options.isShow = false;
                };

                $rootScope.$on("continueLearnAtTop: isShow", function (event, data) {
                    if (data.isShow) {
                        show();
                    } else {
                        close();
                    }
                });

            }
        };
    });

