/** 移动学习【远程H5改本地】
 * Created by qiucheng Lu on 2021年5月27日10:41:56
 */

(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        .controller('learnAppCtrl', learnAppCtrl)
        .controller('myLearnCtrl', myLearnCtrl)
        .controller('learnTaskController', learnTaskController)
        .controller('commonStudyResCtrl', commonStudyResCtrl)
        .controller('loveSpecialtyCtrl', loveSpecialtyCtrl)
        .controller('learnResourceCtrl', learnResourceCtrl)
        .controller('searchResourceCtrl', searchResourceCtrl)
        .controller('resourceListCtrl', resourceListCtrl)
        .controller('learnHistoryCtrl', learnHistoryCtrl)
        .controller('learnCollectCtrl', learnCollectCtrl)
        .controller('resScormCourseCtrl', resScormCourseCtrl)
        .controller('learnScormCouseCtrl', learnScormCouseCtrl)

    stateConfig.$inject = ['$stateProvider'];
    learnAppCtrl.$inject = ['$scope', '$ionicModal'];
    myLearnCtrl.$inject = ["$rootScope", "$scope", "$http", "$timeout", "$ionicModal", 'mbStudyCommonService'];
    learnTaskController.$inject = ["$scope", "$http", "$timeout", "$ionicModal"];
    commonStudyResCtrl.$inject = ['$rootScope', '$scope', '$http', '$ionicModal', '$timeout', 'mbStudyCommonService', 'resType', 'operateType', 'modalManager'];
    loveSpecialtyCtrl.$inject = ['$scope', '$http', '$timeout', 'ynuiNotification'];
    learnResourceCtrl.$inject = ["$scope", "$http", "$ionicModal", "$ionicLoading", "$ionicScrollDelegate"];
    searchResourceCtrl.$inject = ["$scope", "$http", "$ionicModal", "$ionicLoading", "$timeout", "$ionicScrollDelegate"];
    resourceListCtrl.$inject = ["$scope", "$http", "$ionicModal", "$ionicLoading", "$timeout", "$ionicScrollDelegate"];
    learnHistoryCtrl.$inject = ["$scope", "$http", "$ionicModal", "$ionicLoading", "$timeout", "$ionicScrollDelegate", "mbStudyCommonService"];
    learnCollectCtrl.$inject = ["$scope", "$http", "$ionicModal", "$ionicLoading", "$timeout", "$ionicScrollDelegate", "$ionicPopup", "ynuiNotification", "mbStudyCommonService"];
    resScormCourseCtrl.$inject = ['$scope', '$http', '$ionicModal', '$timeout', 'mbStudyCommonService', 'resType', 'operateType', 'modalManager', 'ynuiNotification'];
    learnScormCouseCtrl.$inject = ['$rootScope', '$scope', '$http', '$ionicModal', '$timeout', 'mbStudyCommonService', 'resType', 'operateType', 'modalManager'];

    function stateConfig($stateProvider) {
        $stateProvider
        // 一卡通
            .state('learnApp', {
                url: '/learnApp',
                templateUrl: 'templates/handheldlearn/learn-resource.html',
                data: {
                    micro: true,
                    title: '移动学习'
                },
                controller: 'learnAppCtrl',
            });
    }

    function learnAppCtrl($scope, $ionicModal) {
        /*浮层对象*/
        $scope.modelNameVO = {};

        /*初始化学习资源库页面打开搜索弹框方法*/
        $scope.learnOpenSearchModal = function () {
            /**
             * 搜索资源弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/search-resource.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.search_modal = modal;
                $scope.$broadcast('searchResource', {courseId: ""});
                /*打开搜索页面弹框*/
                $scope.modelNameVO.search_modal.show();
            });

        };

        /*页面tab切换*/
        $scope.tabListVO = {
            /*1 我的学习  2 学习资源库*/
            learnTab: 1
        };
        /*页面加载错误提示*/
        $scope.emptyInfoVO = {
            /*学习资源库*/
            studyResourceEmptyInfo: false,
            studyResourceDataErrorMsg: "",
            /*搜索页面*/
            searchEmptyInfo: false,
            searchDataErrorMsg: "",
            /*资源列表*/
            resourceListEmptyInfo: false,
            resourceListDataErrorMsg: ""
        };

        /*获取资源图标显示class值*/
        $scope.getResourceClass = function (item) {
            /*不存在自带图标的就用默认图标*/
            if (item.fsId == null || item.fsId == "") {
                /*文档资源*/
                if (item.documentType != null) {
                    switch (item.documentType) {
                        case 0:
                            /*不支持的格式*/
                            return "file-style-wrap other";
                        case 1:
                            /*web*/
                            return "file-style-wrap web";
                        case 2:
                            /*scorm课件*/
                            return "file-style-wrap scorm-kj";
                        case 3:
                            /*知识点*/
                            return "file-style-wrap scorm-zsd";
                        case 4:
                            /*视频*/
                            return "file-style-wrap video";
                        case 5:
                            /*音频*/
                            return "file-style-wrap music";
                        case 6:
                            /*图*/
                            return "file-style-wrap jpg";
                        case 7:
                            /*文档*/
                            return "file-style-wrap file-total";
                        case 8:
                            /*压缩包*/
                            return "file-style-wrap rar";
                        default:
                            return "file-style-wrap other";
                    }
                } else {
                    return "file-style-wrap";
                }
            } else {
                return "file-style-wrap";
            }
        };
        /*获取资源图标下载src地址*/
        $scope.getResourceImageSrc = function (fsId) {
            if (fsId) {
                return originBaseUrl + '/file/downloadStream.htm?fastDFSId=' + fsId;
            } else {
                return "";
            }
        };
        /*获取头像*/
        $scope.getImageSrc = function (headFsId, gender) {
            if (headFsId) {
                return $scope.getResourceImageSrc($scope.headFsId);
            } else {
                if (gender && gender == 2) {
                    /*女性头像*/
                    return "img/userface_0.png";
                } else {
                    /*男性头像*/
                    return "img/userface_1.png";
                }
            }
        };
        //强制渲染一波操作
        $scope.defaultClick = function () {
            $scope.tabListVO.learnTab = $scope.tabListVO.learnTab;
        };
    }

    function myLearnCtrl($rootScope, $scope, $http, $timeout, $ionicModal, mbStudyCommonService) {

        $scope.common = {
            hasLastTimeStudy: false, //是否有上一次学习记录
            selectTaskObj: {}
        };
        //累计学习时间
        $scope.studyTime = {
            todayTimeStr: "",//今日学习时间
            totalTimeStr: "", //总共学习时间
            todayTotalTime: 0
        };
        $scope.userInfo = {
            name: "",
            gender: "2",
            headFsId: "",
            specialtyList: []
        };
        //学习数量统计
        $scope.studyCount = {
            collectNum: 0,//收藏数量
            historyNum: 0 //浏览历史数量
        };

        $scope.lastTimeStudyResource = {
            title: "", //标题
            resTypeCode: "",  //类型
            subTitle: "", //子标题
            avPlayTimeStr: "", //如果是音视频，音视频的播放时间
            delete: ""//是否被删除
        };

        $scope.specialtyCourseTaskArr = [];
        $scope.maybeLikeResourceArr = [];

        $scope.specialtyCourseTask = {
            name: "",
            classId: "",
            jiaoAnPercent: "0%",
            kewaiCount: 0
        };

        $scope.openLoveSpecialty = function () {
            $ionicModal.fromTemplateUrl('templates/handheldlearn/love-specialty.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {

                $scope.modelNameVO.specialty_modal = modal;
                /*跳转到资源页面*/
                $scope.$broadcast('loveSpecialty', {fromMyLearn: true});
                $scope.modelNameVO.specialty_modal.show();
            });
        };
        /**
         * 第一次进入移动学习
         * 打开选择感兴趣专业弹框
         */
        $scope.firstCommonOn = function () {
            return $http.get( originBaseUrl + '/third/learnResource/isFirstStuInterestedSpecialty.htm', {
                params: {}
            }).then(function (response) {
                return response.data;
            });
        };
        //获取学习时间统计
        $scope.getStudyTime = function () {
            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findMobileStudyTime.htm").success(function (data) {
                if (data.status === 0) {
                    $scope.studyTime.todayTimeStr = data.result.todayTimeStr;
                    $scope.studyTime.totalTimeStr = data.result.totalTimeStr;
                    $scope.studyTime.todayTotalTime = data.result.todayTotalTime;
                }
            });
        };
        //获取上次学习的资源信息
        $scope.getLastStudyResource = function () {
            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findLastStudyResource.htm").success(function (data) {
                if (data.status === 0) {

                    $scope.studyCount.collectNum = data.result.collectNum;
                    $scope.studyCount.historyNum = data.result.historyNum;

                    if (data.result.resId !== "" && data.result.resId !== "null" && data.result.resId !== null) {

                        $scope.common.hasLastTimeStudy = true;
                        $scope.lastTimeStudyResource = data.result;

                        $scope.lastTimeStudyResource.id = data.result.resId;
                        $scope.lastTimeStudyResource.resourceTableType = data.result.resTypeCode;
                        $scope.lastTimeStudyResource.delete = data.result.delete;
                    }
                }
            });
        };

        $scope.getSpecialtyCourseTask = function () {

            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findSpecialtyCourseTask.htm").success(function (data) {
                if (data.status === 0) {

                    $scope.specialtyCourseTaskArr = [];

                    for (var i = 0; i < data.result.length; i++) {

                        $scope.specialtyCourseTaskArr[i] = data.result[i];

                        if (data.result[i].jiaoAnPercent !== null && data.result[i].jiaoAnPercent > 0) {
                            if (data.result[i].jiaoAnPercent >= 1) {
                                $scope.specialtyCourseTaskArr[i].jiaoAnPercent = "100%";
                            } else {
                                $scope.specialtyCourseTaskArr[i].jiaoAnPercent = (data.result[i].jiaoAnPercent * 100) + "%";
                            }
                        } else {
                            $scope.specialtyCourseTaskArr[i].jiaoAnPercent = "0%";
                        }

                        if (data.result[i].jiaoAnCount !== null && data.result[i].jiaoAnCount) {
                            $scope.specialtyCourseTaskArr[i].jiaoAnCount = data.result[i].jiaoAnCount;
                        } else {
                            $scope.specialtyCourseTaskArr[i].jiaoAnCount = 0;
                        }
                    }
                }
            });
        };

        $scope.getMaybeLikeResource = function () {

            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findMaybeLikeResource.htm").success(function (data) {
                if (data.status === 0) {

                    $scope.maybeLikeResourceArr = [];

                    for (var i = 0; i < data.result.length; i++) {
                        $scope.maybeLikeResourceArr[i] = data.result[i];
                        //查看详情需要的参数
                        $scope.maybeLikeResourceArr[i].id = data.result[i].resouceId;
                        if (data.result[i].studyCount !== null) {
                            $scope.maybeLikeResourceArr[i].studyCount = data.result[i].studyCount;
                        } else {
                            $scope.maybeLikeResourceArr[i].studyCount = 0;
                        }
                    }
                }
            });
        };

        $scope.getUserInfo = function () {

            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findUserInfo.htm").success(function (data) {
                if (data.status === 0) {
                    $scope.userInfo.name = data.result.name;
                    $scope.userInfo.gender = data.result.gender;
                    $scope.userInfo.headFsId = data.result.headFsId;
                    $scope.userInfo.specialtyList = data.result.specialtyList;
                }
            });
        };

        /*浮层对象*/
        $scope.model = {};

        /*初始化学习资源库页面打开搜索弹框方法*/
        $scope.openTaskModal = function (item) {

            $scope.common.selectTaskObj = item;
            /**
             * 搜索资源弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/learn-task.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.model.taskModal = modal;
                /*打开搜索页面弹框*/
                $scope.model.taskModal.show();
            });

        };
        $scope.init = function () {
            //第一次进入移动学习的操作
            $scope.firstCommonOn().then(function (data) {
                if (data.status === 0) {
                    if (data.result) {
                        $scope.openLoveSpecialty();
                    } else {
                        //非第一次进入移动学习
                        // $scope.myLearnInit();
                    }
                }
            });
            $scope.getStudyTime();
            $scope.getLastStudyResource();
            $scope.getSpecialtyCourseTask();
            $scope.getMaybeLikeResource();
            $scope.getUserInfo();
        };

        //初始化
        $scope.init();

        /**
         * 学习历史
         */
        $scope.openLearnHistory = function () {
            //历史列表弹框
            $ionicModal.fromTemplateUrl('templates/handheldlearn/learn-history.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.learn_history_modal = modal;
                $scope.modelNameVO.learn_history_modal.show();
            });
        };

        /**
         * 收藏 开始
         */
        $scope.openLearnCollect = function () {
            /**
             * 收藏列表弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/learn-collect.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.learn_collect_modal = modal;
                $scope.modelNameVO.learn_collect_modal.show();
            });
        };

        /**
         * 重新加载数据
         */
        $scope.reLoadData = function () {
            if (mbStudyCommonService.gStatusChanged) {
                $scope.getLastStudyResource();
                $scope.getStudyTime();
                mbStudyCommonService.gStatusChanged = false;
            }

        };
        //刷新收藏、历史记录
        $rootScope.$on("refreshSearchstudyCount",function () {
            $scope.getLastStudyResource();
        });
    }

    function learnTaskController($scope, $http, $timeout, $ionicModal) {

        $scope.taskCommon = {
            isShowWeek: false,
            keWaiTaskArr: [],
            jiaoAnTaskArr: [],
            jiaoAnObj: {},
            selectWeekIndex: "",
            hasPreWeek: false,
            hasNextWeek: false
        };

        $ionicModal.fromTemplateUrl('learn-week-modal.html', {
            scope: $scope
        }).then(function (modal) {
            $scope.model.weekModal = modal;
        });
        $scope.toggleShowWeek = function () {
            $scope.model.weekModal.show();
        };
        $scope.toggleCloseWeek = function () {
            $scope.model.weekModal.hide();
        };
        $scope.close = function () {
            $scope.model.taskModal.remove();
            $scope.model.weekModal.remove();
            $scope.getStudyTime();
            $scope.getSpecialtyCourseTask();
        };

        //课外
        $scope.getKeWaiTaskResource = function () {

            if ($scope.common.selectTaskObj.kewaiCount < 1) {
                return;
            }
            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findKeWaiTaskResource.htm?classId=" + $scope.common.selectTaskObj.classId).success(function (data) {
                if (data.status == 0) {
                    $scope.taskCommon.keWaiTaskArr = data.result;

                    for (var i = 0; i < data.result.length; i++) {
                        //查看详情需要的参数
                        $scope.taskCommon.keWaiTaskArr[i].id = data.result[i].resourceId;
                    }
                }
            });
        };
        //教案
        $scope.getJiaoAnTaskResource = function () {

            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findMobileStudyTeachingPlanInfo.htm?classId=" + $scope.common.selectTaskObj.classId).success(function (data) {
                if (data.status == 0) {
                    $scope.taskCommon.jiaoAnObj = data.result;

                    var nowWeek = data.result.nowWeek;
                    if (nowWeek != '' && nowWeek != null) {

                        var weekSize = data.result.mobileStudyWeekVOList.length;
                        if (nowWeek > 1) {
                            $scope.taskCommon.hasPreWeek = true;
                        }
                        if (nowWeek < weekSize) {
                            $scope.taskCommon.hasNextWeek = true;
                        }
                    }

                    $scope.taskCommon.selectWeekIndex = nowWeek;

                    if ($scope.common.selectTaskObj.jiaoAnCount > 0) {
                        $scope.getMobileStudyTeachingPlanResList(nowWeek);
                    }

                }
            });
        };
        //教案
        $scope.getMobileStudyTeachingPlanResList = function (week) {

            if (week == null) {
                week = "";
            }

            $http.get(originBaseUrl + "/third/mobileStudy/myStudy/findMobileStudyTeachingPlanResList.htm?classId=" + $scope.common.selectTaskObj.classId + "&week=" + week).success(function (data) {
                if (data.status == 0) {
                    $scope.taskCommon.jiaoAnTaskArr = data.result;

                    for (var i = 0; i < data.result.length; i++) {
                        //查看详情需要的参数
                        $scope.taskCommon.jiaoAnTaskArr[i].id = data.result[i].resourceId;
                    }
                }
            });
        };

        $scope.goWeek = function (week) {
            $scope.taskCommon.selectWeekIndex = week;
            $scope.getMobileStudyTeachingPlanResList(week);
        };

        $scope.clickWeekEnable = function (week) {

            var weekSize = $scope.taskCommon.jiaoAnObj.mobileStudyWeekVOList.length;
            $scope.taskCommon.hasPreWeek = week >= 2;
            $scope.taskCommon.hasNextWeek = week < weekSize;
        };

        $scope.clickWeek = function (item) {

            $scope.clickWeekEnable(item.week);

            $scope.taskCommon.selectWeekIndex = item.week;
            $scope.getMobileStudyTeachingPlanResList(item.week);
            $scope.toggleCloseWeek();
        };

        $scope.preWeek = function () {

            var nowWeek = $scope.taskCommon.selectWeekIndex;
            if (nowWeek == '' || nowWeek == null) {
                return;
            }

            var preWeek = nowWeek - 1;
            $scope.clickWeekEnable(preWeek);

            if (nowWeek >= 2) {
                $scope.goWeek(preWeek);
            }

        };

        $scope.nextWeek = function () {

            var weekSize = $scope.taskCommon.jiaoAnObj.mobileStudyWeekVOList.length;
            var nowWeek = $scope.taskCommon.selectWeekIndex;

            if (nowWeek == '' || nowWeek == null) {
                return;
            }

            var nextWeek = nowWeek + 1;
            $scope.clickWeekEnable(nextWeek);

            if (nowWeek < weekSize) {
                $scope.goWeek(nextWeek);
            }
        };


        $scope.init = function () {
            //第一次进入移动学习的操作
            // $scope.getUserInfo();
            $scope.getKeWaiTaskResource();
            $scope.getJiaoAnTaskResource();
        };

        //初始化
        $scope.init();


    }

    function commonStudyResCtrl($rootScope, $scope, $http, $ionicModal, $timeout, mbStudyCommonService, resType, operateType, modalManager) {
        console.log("commonStudyResCtrl 初始化！");
        // 资源基本信息
        $scope.rescourseBaseInfo = {
            resType: 0, // 资源类型
            resId: null,   // 资源ID
            documentType: null,  // 资源格式
            isScormCourse: false, // 是否是SCORM课件
        };

        $scope.rescourseBaseInfo = angular.copy(mbStudyCommonService.getShareData(), $scope.rescourseBaseInfo);
        console.log($scope.rescourseBaseInfo);

        //
        $scope.resDetail = null;
        // 加载资源详情是否完成
        $scope.loadDetailFinished = false;
        /**
         * 加载资源基本信息
         */
        $scope.loadResourceBaseInfo = function () {
            mbStudyCommonService.getResourceBaseInfo(
                $scope.rescourseBaseInfo.resType,
                $scope.rescourseBaseInfo.resId
            ).then(function (data) {
                $scope.resDetail = data;
                $scope.loadDetailFinished = true;
            });
        };


        $scope.loadResourceBaseInfo();

        // 记录阅读笔记
        (function () {
            mbStudyCommonService.operateResource(
                $scope.rescourseBaseInfo.resType,
                $scope.rescourseBaseInfo.resId,
                operateType.READ
            );
        })();


        // 如果为sco类资源
        if (resType.K_POINT == $scope.rescourseBaseInfo.resType
            || resType.WEBSITE == $scope.rescourseBaseInfo.resType) {
            $scope.$watch("resDetail.homePageName", function (newVal, oldVal) {
                if (newVal !== oldVal && newVal) {
                    $scope.sco = {
                        path: mbStudyCommonService.getPreviewPath() + $scope.rescourseBaseInfo.resId + "/" + newVal
                    };
                }
            });
        }


        /**
         * 判断是否是SCORM课件
         */
        $scope.isScormCourse = function () {
            return $scope.rescourseBaseInfo.resType == resType.SCORM;
        };

        $scope.tab = {
            currentTab: "chapter"
        };

        /**
         * 初始化
         */
        function init() {
            initTab();
        }

        init();

        /**
         * 初始化Tab
         */
        function initTab() {
            // 如果为SCORM课件，则显示章节tab，否则显示介绍tab
            $scope.tab = {currentTab: ($scope.isScormCourse() ? "chapter" : "introduce")};
        }

        /**
         * 监听重新加载数据事件
         */
        $scope.$on("reLoadScormCourse", function () {
            $scope.loadResourceBaseInfo();
        });
        /**
         * 监听重新加载数据事件
         */
        $scope.$on("commonStudyRes: reLoadData", function () {
            $scope.loadResourceBaseInfo();
        });

        /**
         * 关闭
         */
        $scope.closeResModal = function () {
            // 如果回调函数存在
            if ($scope.onLearned != undefined && typeof $scope.onLearned === "function") {
                console.log("调用回调函数");
                $scope.onLearned();
            }
            modalManager.remove("commonStudyResModal");
        };
        console.log("commonStudyResCtrl");
        console.log($scope.$$listenerCount);
    }

    function loveSpecialtyCtrl($scope, $http, $timeout, ynuiNotification) {
        $scope.$on("loveSpecialty", function (event, learnInfo) {
            $scope.fromMyLearn = angular.copy(learnInfo.fromMyLearn);
            getSpecialtyCode();
        });
        /*获取弹框显示信息*/
        var getSpecialtyCode = function () {
            /*弹框 主修专业*/
            $scope.modelMajorSpecialtyList = [];
            /*自定义头像fsId*/
            $scope.headFsId = "";
            /*用户性别*/
            $scope.gender = 1;
            $http.get(originBaseUrl + "/third/learnResource/findUserSpecialtyCode.htm?").success(function (data) {
                if (data.status == 0) {
                    $scope.modelMajorSpecialtyList = data.result.specialtyList;
                    $scope.headFsId = data.result.headFsId;
                    $scope.gender = data.result.gender;
                }
            });
            /*弹框 感兴趣专业*/
            $scope.modelLoveSpecialtyList = [];
            /*选中的感兴趣专业*/
            $scope.loveSpecialtyIdList = [];
            /*未修改前选中的感兴趣专业*/
            $scope.oldLoveSpecialtyIdList = [];
            $http.get(originBaseUrl + "/third/learnResource/findSpecialtyCode.htm?").success(function (data) {
                if (data.status == 0) {
                    $scope.modelLoveSpecialtyList = data.result;
                    angular.forEach($scope.modelLoveSpecialtyList, function (item) {
                        if (item.isSelect) {
                            $scope.loveSpecialtyIdList.push(item.id);
                            $scope.oldLoveSpecialtyIdList.push(item.id);
                        }
                    })
                }
            });
        };
        /*选择感兴趣专业*/
        $scope.loveSpecialtyIdList = [];
        $scope.oldLoveSpecialtyIdList = [];
        $scope.selectLoveSpecialty = function (item) {
            if (item.isSelect) {
                /*取消选择*/
                for (var i in $scope.loveSpecialtyIdList) {
                    if ($scope.loveSpecialtyIdList[i] == item.id) {
                        $scope.loveSpecialtyIdList.splice(i, 1);
                        break;
                    }
                }
                item.isSelect = false;
            } else {
                /*选中专业*/
                /*已选择专业>=3，则冒泡提示：最多选择3个兴趣专业*/
                if ($scope.loveSpecialtyIdList.length >= 3) {
                    ynuiNotification.warning({msg: '最多选择3个兴趣专业'});
                } else {
                    $scope.loveSpecialtyIdList.push(item.id);
                    item.isSelect = true;
                }
            }
        };
        /*确定保存感兴趣的专业*/
        $scope.submitLoveSpecialty = function (isSubmit) {
            var loveSpecialtyIdList = [];
            if (isSubmit) {
                /*确认按钮*/
                loveSpecialtyIdList = $scope.loveSpecialtyIdList;
            } else {
                /*关闭按钮 使用修改前的数据*/
                loveSpecialtyIdList = $scope.oldLoveSpecialtyIdList;
            }
            $http.post(originBaseUrl + "/third/learnResource/saveOrUpdateStuInterestedSpecialty.htm?", {specialtyCodeIds: loveSpecialtyIdList}).success(function (data) {
                if (data.status == 0) {
                    closeLoveSpecialty();
                }
            });
            /*关闭按钮 不管是否提交成功都关闭当前浮层*/
            if (!isSubmit) {
                closeLoveSpecialty();
            }
        };
        /*关闭页面*/
        var closeLoveSpecialty = function () {
            if ($scope.fromMyLearn) {

                $scope.getMaybeLikeResource();
                /*初始化页面确定就进入我的学习*/
                // if($scope.myLearnInit){
                //     $scope.myLearnInit();
                // }
            } else {
                /*非初始化页面就进入 学习资源库*/
                if ($scope.resourceInit) {
                    $scope.nowSelectSpecialty.init = true;
                    $scope.resourceInit();
                }
            }
            /*每次关闭浮层都销毁*/
            $scope.modelNameVO.specialty_modal.remove();
        }
    }

    function learnResourceCtrl($scope, $http, $ionicModal, $ionicLoading, $ionicScrollDelegate) {
        var nowSelectSpecialtyInit = function () {
            $scope.nowSelectSpecialty = {
                /*是否是公共基础*/
                isCommonBase: false,
                /*是否是主修专业*/
                isMajorSpecialty: false,
                /*当前选中专业id*/
                specialtyId: null,
                /*当前选中专业名称*/
                specialtyName: "",
                /*是否是初始化状态*/
                init: true
            };
        };
        nowSelectSpecialtyInit();
        /*学习资源库初始化*/
        $scope.resourceInit = function () {
            /*只有点击学习资源库才查询*/
            /*专业分组*/
            $ionicLoading.show();
            $scope.getSpecialtyData(function () {
                $ionicLoading.hide();
            });
        };

        /*查询专业分类信息*/
        $scope.getSpecialtyData = function (func) {
            $scope.MobileSpecialtyClassifyVOList = [];
            $http.get(originBaseUrl + "/third/learnResource/querySpecialtyClassifyInfo.htm?").success(function (data) {
                if (data.status == 0) {
                    $scope.MobileSpecialtyClassifyVOList = data.result;
                    if ($scope.MobileSpecialtyClassifyVOList && $scope.MobileSpecialtyClassifyVOList.length > 0) {
                        var classify = 1;
                        if ($scope.nowSelectSpecialty.init) {
                            /*存在公共基础则首先查公共基础*/
                            if ($scope.MobileSpecialtyClassifyVOList[0].classify == 1) {
                                $scope.nowSelectSpecialty.isCommonBase = true;
                                $scope.nowSelectSpecialty.specialtyName = "公共基础";
                            } else {
                                if ($scope.MobileSpecialtyClassifyVOList[0].classify == 2) {
                                    /*没有公共基础有主修专业 查主修专业*/
                                    $scope.nowSelectSpecialty.isMajorSpecialty = true;
                                }
                                if ($scope.MobileSpecialtyClassifyVOList[0].specialtyInfoList.length > 0) {
                                    $scope.nowSelectSpecialty.specialtyId = $scope.MobileSpecialtyClassifyVOList[0].specialtyInfoList[0].id;
                                    $scope.nowSelectSpecialty.specialtyName = $scope.MobileSpecialtyClassifyVOList[0].specialtyInfoList[0].name;
                                }
                                classify = $scope.MobileSpecialtyClassifyVOList[0].classify;
                            }
                        }
                        /*查询课程*/
                        getCourseListHtm(classify);
                    }
                    if (!$scope.MobileSpecialtyClassifyVOList || $scope.MobileSpecialtyClassifyVOList.length < 1) {
                        $scope.emptyInfoVO.studyResourceEmptyInfo = true;
                        $scope.emptyInfoVO.studyResourceDataErrorMsg = '没有专业';
                    } else {
                        $scope.emptyInfoVO.studyResourceEmptyInfo = false;
                    }
                    if (func) {
                        func();
                    }
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.studyResourceEmptyInfo = true;
                    $scope.emptyInfoVO.studyResourceDataErrorMsg = '加载专业失败，请重试';
                }

            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.studyResourceEmptyInfo = true;
                $scope.emptyInfoVO.studyResourceDataErrorMsg = '加载专业失败，请重试';
            });
        };
        $scope.resourceInit();
        /*专业分类样式*/
        $scope.getClass = function (item) {
            switch (item.classify) {
                case 1:
                    return "classify-list";
                case 2:
                    return "classify-list classify-list-title";
                case 3:
                    return "classify-list classify-list-title setting";
                case 4:
                    return "classify-list classify-list-title";
            }
        };
        //刷新
        $scope.doRefresh = function () {
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.getSpecialtyData(function () {
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };

        /*点击公共基础 查询课程*/
        $scope.getCommonCourseList = function (item) {
            if (item.classify != 1) {
                /*不是公共基础 就不生效*/
                return;
            }
            if ($scope.nowSelectSpecialty.isCommonBase) {
                /*如果课程是公共基础下的就不再查*/
                return;
            }
            nowSelectSpecialtyInit();
            $scope.nowSelectSpecialty.isCommonBase = true;
            $scope.nowSelectSpecialty.specialtyName = "公共基础";
            $scope.nowSelectSpecialty.init = false;
            getCourseListHtm(item.classify);
        };
        /*点击专业 查询课程*/
        $scope.getCourseList = function (item, it) {
            if (it.id == $scope.nowSelectSpecialty.specialtyId) {
                /*点击的是当前专业就不再查*/
                return;
            }
            nowSelectSpecialtyInit();
            if (item.classify == 2) {
                /*是主修专业*/
                $scope.nowSelectSpecialty.isMajorSpecialty = true;
            }
            $scope.nowSelectSpecialty.specialtyId = it.id;
            $scope.nowSelectSpecialty.specialtyName = it.name;
            $scope.nowSelectSpecialty.init = false;
            getCourseListHtm(item.classify);
        };
        /*查询课程列表数据*/
        $scope.MobileSpecialtyCourseVOList = [];
        var getCourseListHtm = function (classify) {
            $scope.MobileSpecialtyCourseVOList = [];
            $http.post(originBaseUrl + "/third/learnResource/queryCourseInfoBySpecialtyId.htm?", {
                classify: classify,
                specialtyId: $scope.nowSelectSpecialty.specialtyId
            }).success(function (data) {
                if (data.status == 0) {
                    $scope.MobileSpecialtyCourseVOList = data.result;
                    /*没有选中的课程就默认选中第一个*/
                    if ($scope.MobileSpecialtyCourseVOList && $scope.MobileSpecialtyCourseVOList.length > 0) {
                        $scope.MobileSpecialtyCourseVO = $scope.MobileSpecialtyCourseVOList[0];
                    }
                }
            });
        };
        /*当前课程信息*/
        $scope.MobileSpecialtyCourseVO = {
            id: null,
            courseName: "",
            courseNum: ""
        };

        /*打开感兴趣专业选择弹框*/
        $scope.openModalZeroByResource = function () {
            /**
             * 感兴趣专业弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/love-specialty.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.specialty_modal = modal;
                $scope.$broadcast('loveSpecialty', {fromMyLearn: false});
                $scope.modelNameVO.specialty_modal.show();
            });

        };

        /*点击课程 进入资源显示界面*/
        $scope.clickCourse = function (item) {
            /**
             * 课程资源列表弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/resource-list.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.resource_list_modal = modal;
                $scope.MobileSpecialtyCourseVO = item;
                /*跳转到资源页面*/
                $scope.$broadcast('resourceList', {
                    fromHome: true,
                    isMajorSpecialty: $scope.nowSelectSpecialty.isMajorSpecialty,
                    courseId: item.id != null ? item.id : "",
                    courseName: item.courseName
                });
                $scope.modelNameVO.resource_list_modal.show();
            });
        };
    }

    function searchResourceCtrl($scope, $http, $ionicModal, $ionicLoading, $timeout, $ionicScrollDelegate) {
        $scope.$on("searchResource", function (event, lastInfo) {
            $scope.courseId = angular.copy(lastInfo.courseId);
            $scope.searchInfo = {
                /*1 显示资源 2 显示课程 */
                tab: 1,
                /*搜索关键字*/
                keywordStr: null
            };
            initSearchInfoVO();
        });
        $scope.searchInfo = {
            /*1 显示资源 2 显示课程 */
            tab: 1,
            /*搜索关键字*/
            keywordStr: null
        };
        /*切换tab*/
        $scope.changeTab = function (tab) {
            $scope.searchInfo.tab = tab;
            /*将滚动条回到顶部*/
            $ionicScrollDelegate.scrollTop();
        };
        var initSearchInfoVO = function () {
            $scope.MobileSearchInfoVO = {
                /*搜索的资源列表*/
                resourceVOPageList: [],
                /*分页信息*/
                resourcePageInfo: {
                    totalPage: 0,
                    pageSize: 20,
                    pageNumber: 0,
                    itemSize: 0
                },
                /*搜索的课程列表*/
                courseVOPageList: [],
                coursePageInfo: {
                    totalPage: 0,
                    pageSize: 20,
                    pageNumber: 0,
                    itemSize: 0
                }
            };
            $scope.isFirstSearch = true;
            $scope.emptyInfoVO.searchEmptyInfo = false;
        };
        initSearchInfoVO();
        $scope.getResourceData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryInfoByCondition.htm?",
                {
                    keywordStr: $scope.searchInfo.keywordStr,
                    nowCourseId: $scope.courseId,
                    pageNumber: $scope.searchInfo.tab == 1 ? $scope.MobileSearchInfoVO.resourcePageInfo.pageNumber : $scope.MobileSearchInfoVO.coursePageInfo.pageNumber,
                    pageSize: $scope.searchInfo.tab == 1 ? $scope.MobileSearchInfoVO.resourcePageInfo.pageSize : $scope.MobileSearchInfoVO.coursePageInfo.pageSize
                }).success(function (data) {
                if (data.status == 0) {
                    $scope.MobileSearchInfoVO.resourceVOPageList.push.apply($scope.MobileSearchInfoVO.resourceVOPageList, data.result.resourceVOPage.content);
                    $scope.MobileSearchInfoVO.courseVOPageList.push.apply($scope.MobileSearchInfoVO.courseVOPageList, data.result.courseVOPage.content);
                    $scope.MobileSearchInfoVO.resourcePageInfo = {
                        totalPage: data.result.resourceVOPage.totalPages,
                        pageSize: data.result.resourceVOPage.size,
                        pageNumber: data.result.resourceVOPage.number,
                        itemSize: data.result.resourceVOPage.totalElements
                    };
                    $scope.MobileSearchInfoVO.coursePageInfo = {
                        totalPage: data.result.courseVOPage.totalPages,
                        pageSize: data.result.courseVOPage.size,
                        pageNumber: data.result.courseVOPage.number,
                        itemSize: data.result.courseVOPage.totalElements
                    };
                    if (data.result.resourceVOPage.totalPages > 0) {
                        $scope.MobileSearchInfoVO.resourcePageInfo.pageNumber = data.result.resourceVOPage.number + 1;
                    }
                    if (data.result.courseVOPage.totalPages > 0) {
                        $scope.MobileSearchInfoVO.coursePageInfo.pageNumber = data.result.courseVOPage.number + 1;
                    }
                    ;
                    $scope.isFirstSearch = false;
                    $scope.emptyInfoVO.searchEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.searchEmptyInfo = true;
                    $scope.emptyInfoVO.searchDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.searchEmptyInfo = true;
                $scope.emptyInfoVO.searchDataErrorMsg = '加载失败，请重试';
            });
        };
        /*点击搜索*/
        $scope.searchKeyWord = function () {
            if ($scope.searchInfo.keywordStr != null && $scope.searchInfo.keywordStr != "") {
                initSearchInfoVO();
                $ionicLoading.show({
                    template: '正在查找...'
                });
                $scope.getResourceData(function () {
                    /*将滚动条回到顶部*/
                    $ionicScrollDelegate.scrollTop();
                    /*隐藏上拉刷新图标*/
                    $scope.$broadcast('scroll.refreshComplete');
                    $ionicLoading.hide();
                });
            } else {
                initSearchInfoVO();
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新图标*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            }
        };
        /*监控搜索 间隔一秒*/
        $scope.$watch(function () {
            return $scope.searchInfo.keywordStr;
        }, function (newVal, oldVal) {
            setTimeout(function () {
                if (newVal != oldVal && $scope.searchInfo.keywordStr == newVal) {
                    $scope.searchKeyWord();
                }
            }, 1000);
        });
        //刷新
        $scope.resourceDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.searchKeyWord();
        };
        /**
         * 加载更多
         */
        $scope.loadMore = function () {
            if (($scope.MobileSearchInfoVO.resourcePageInfo.pageNumber >= $scope.MobileSearchInfoVO.resourcePageInfo.totalPage) && ($scope.MobileSearchInfoVO.coursePageInfo.pageNumber >= $scope.MobileSearchInfoVO.coursePageInfo.totalPage)) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            $scope.getResourceData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };

        /*关闭搜索弹框*/
        $scope.closeSearchResource = function () {

            /*隐藏搜索弹框*/
            $scope.modelNameVO.search_modal.hide();
            /*销毁*/
            $timeout(function () {
                $scope.modelNameVO.search_modal.remove();
            }, 500);
        };
        /*控制下拉更多 隐藏显示*/
        $scope.showInfinite = function () {
            if ($scope.searchInfo.tab == 1) {
                return $scope.MobileSearchInfoVO.resourcePageInfo.pageNumber < $scope.MobileSearchInfoVO.resourcePageInfo.totalPage;
            } else {
                return $scope.MobileSearchInfoVO.coursePageInfo.pageNumber < $scope.MobileSearchInfoVO.coursePageInfo.totalPage;
            }
        };
        /*点击课程 进入资源显示界面*/
        $scope.clickCourse = function (item) {
            /*跳转到资源页面*/
            /**
             * 课程资源列表弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/resource-list.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.search_resource_list_modal = modal;
                $scope.$broadcast('resourceList', {
                    fromHome: false,
                    isMajorSpecialty: item.isMajorSpecialty,
                    courseId: item.id,
                    courseName: item.courseName
                });
                $scope.modelNameVO.search_resource_list_modal.show();
            });
        };
    }

    function resourceListCtrl($scope, $http, $ionicModal, $ionicLoading, $timeout, $ionicScrollDelegate) {
        $scope.$on("resourceList", function (event, lastInfo) {
            /*true  来自资源库页面 显示搜索按键   false 来自搜索页面 不显示搜索按钮*/
            $scope.fromHome = angular.copy(lastInfo.fromHome);
            /*是否主修专业*/
            $scope.isMajorSpecialty = angular.copy(lastInfo.isMajorSpecialty);
            /*课程id*/
            $scope.nowCourseId = angular.copy(lastInfo.courseId);
            /*课程名称*/
            $scope.courseName = angular.copy(lastInfo.courseName);

            /*初始化数据*/
            $scope.studyNumSort = 1;
            $scope.timeSort = 3;
            $scope.nowSort = 1;
            $scope.firstResourceList(1);
        });
        /*根据上一页面 分别调用关闭方法*/
        $scope.closeModalByLast = function () {
            if ($scope.fromHome) {
                /*父级页面是 学习资源库*/
                $scope.modelNameVO.resource_list_modal.hide();
                $timeout(function () {
                    $scope.modelNameVO.resource_list_modal.remove();
                }, 500);
            } else {
                /*父级页面是 搜索页面*/
                $scope.modelNameVO.search_resource_list_modal.hide();
                $timeout(function () {
                    $scope.modelNameVO.search_resource_list_modal.remove();
                }, 500);
            }
            ;
        };
        /*打开搜索资源页面*/
        $scope.openSearchModal = function () {
            /**
             * 搜索资源弹框
             */
            $ionicModal.fromTemplateUrl('templates/handheldlearn/search-resource.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.search_modal = modal;
                $scope.$broadcast('searchResource', {courseId: $scope.nowCourseId != null ? $scope.nowCourseId : ""});
                $scope.modelNameVO.search_modal.show();
            });
        };
        $scope.studyNumSort = 1;
        $scope.timeSort = 3;
        $scope.nowSort = 1;

        /**
         * 资源列表开始
         */

        $scope.initResourceList = function () {
            $scope.resourceListPageInfo = {
                totalPage: 0,
                pageSize: 20,
                pageNumber: 0,
                itemSize: 0
            };
            $scope.MobileCourseResourceVOList = [];
            $scope.scormNum = 0;
        };
        $scope.resourceListGetData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryCourseResourceInfoPage.htm?", {
                courseId: $scope.nowCourseId,
                isMajorSpecialty: $scope.isMajorSpecialty,
                sort: $scope.nowSort,
                pageNumber: $scope.resourceListPageInfo.pageNumber,
                pageSize: $scope.resourceListPageInfo.pageSize
            }).success(function (data) {
                if (data.status == 0) {
                    if (data.result.content && data.result.content.length > 0) {
                        angular.forEach(data.result.content, function (item) {
                            if (item.resourceTableType == 2) {
                                $scope.scormNum += 1;
                            }
                        });
                        $scope.MobileCourseResourceVOList.push.apply($scope.MobileCourseResourceVOList, data.result.content);
                    }

                    $scope.resourceListPageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    if (data.result.totalPages > 0) {
                        $scope.resourceListPageInfo.pageNumber = data.result.number + 1;
                    }
                    $scope.emptyInfoVO.resourceListEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.resourceListEmptyInfo = true;
                    $scope.emptyInfoVO.resourceListDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.resourceListEmptyInfo = true;
                $scope.emptyInfoVO.resourceListDataErrorMsg = '加载失败，请重试';
            });

        };
        /*第一次查询列表*/
        $scope.firstResourceList = function (sort) {
            $scope.nowSort = sort;
            if (sort < 3) {
                $scope.studyNumSort = sort;
            } else {
                $scope.timeSort = sort;
            }
            $scope.initResourceList();
            $ionicLoading.show();
            $scope.resourceListGetData(function () {
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            });
        };


        //刷新
        $scope.resourceDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.firstResourceList($scope.nowSort);
        };
        /**
         * 加载更多
         */
        $scope.resourceListLoadMore = function () {
            if ($scope.resourceListPageInfo.pageNumber >= $scope.resourceListPageInfo.totalPage) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            $scope.resourceListGetData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };
    }

    function learnHistoryCtrl($scope, $http, $ionicModal, $ionicLoading, $timeout, $ionicScrollDelegate, mbStudyCommonService) {
        /*日期*/
        $scope.checkDate = null;

        /*清除选择的日期*/
        $scope.deleteCheckDate = function () {
            $scope.checkDate = null;
            $ionicLoading.show();
            $scope.firstHistoryList(function () {
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        /*是否仅查询已学习过的*/
        $scope.onlyHasLearn = false;
        /*排序 1 时间倒序  2 升序*/
        $scope.sort = 1;
        /*初始化历史页面数据*/
        var historyInit = function () {
            /*历史数据*/
            $scope.MobileHistoryResourceVOList = [];
            /*分页数据*/
            $scope.historyPageInfo = {
                totalPage: 0,
                pageSize: 20,
                pageNumber: 0,
                itemSize: 0
            };
            $scope.isFirstQuery = true;
            /*错误提示*/
            $scope.emptyInfoVO.historyEmptyInfo = false;
        };
        historyInit();

        var historyListGetData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryHistoryShowPage.htm?", {
                checkDate: $scope.checkDate,
                onlyHasLearn: $scope.onlyHasLearn,
                sort: $scope.sort,
                pageNumber: $scope.historyPageInfo.pageNumber,
                pageSize: $scope.historyPageInfo.pageSize
            }).success(function (data) {
                if (data.status == 0) {
                    if (data.result.content && data.result.content.length > 0) {
                        $scope.MobileHistoryResourceVOList.push.apply($scope.MobileHistoryResourceVOList, data.result.content);
                    }
                    $scope.historyPageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    if (data.result.totalPages > 0) {
                        $scope.historyPageInfo.pageNumber = data.result.number + 1;
                    }
                    $scope.isFirstQuery = false;
                    $scope.emptyInfoVO.resourceListEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.resourceListEmptyInfo = true;
                    $scope.emptyInfoVO.resourceListDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.historyEmptyInfo = true;
                $scope.emptyInfoVO.historyDataErrorMsg = '加载失败，请重试';
            });
        };
        /*第一次查询*/
        $scope.firstHistoryList = function (func) {
            /*初始化*/
            historyInit();
            /*查询*/
            historyListGetData(func);
        };
        $ionicLoading.show();
        $scope.firstHistoryList(function () {
            $ionicLoading.hide();
        });
        /*关闭学习界面调用的方法*/
        $scope.changeHistoryList = function () {
            if (mbStudyCommonService.gStatusChanged) {
                $scope.firstHistoryList(function () {
                    /*将滚动条回到顶部*/
                    $ionicScrollDelegate.scrollTop();
                    $ionicLoading.hide();
                });
                if ($scope.searchInfo.keywordStr) {
                    $scope.searchKeyWord();
                }
            }
        };

        /*页面点击事件*/
        $scope.htmlClickFirstHistoryList = function () {
            $ionicLoading.show();
            $scope.firstHistoryList(function () {
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };
        /*改变排序方式*/
        $scope.newSort = function () {
            if ($scope.sort == 1) {
                $scope.sort = 2;
            } else {
                $scope.sort = 1;
            }
            $ionicLoading.show();
            $scope.firstHistoryList(function () {
                $ionicLoading.hide();
            });
        };
        //刷新
        $scope.historyDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.firstHistoryList(function () {
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新图标*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            });
        };
        //加载更多
        $scope.loadMore = function () {
            if ($scope.historyPageInfo.pageNumber >= $scope.historyPageInfo.totalPage) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            ;
            historyListGetData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };


        /*关闭历史页面*/
        $scope.closeHistory = function () {
            if (mbStudyCommonService.gStatusChanged) {
                $scope.getLastStudyResource();
                $scope.getStudyTime();
            }
            $scope.modelNameVO.learn_history_modal.hide();
            $timeout(function () {
                $scope.modelNameVO.learn_history_modal.remove();
            }, 500);
        };
        /**
         * 历史搜索弹框开始
         */
        /*打开历史搜索浮层*/
        $scope.openHistorySearch = function () {

            $ionicModal.fromTemplateUrl('learn-history-search.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.learn_history_search_modal = modal;
                /*初始化搜索页面*/
                $scope.searchInfo = {keywordStr: null};
                searchInit();
                /*打开搜索弹框*/
                modal.show();
            });
        };
        /*初始化搜索页面*/
        /*搜索关键字*/
        $scope.searchInfo = {keywordStr: null};
        var searchInit = function () {
            /*分页*/
            $scope.searchPageInfo = {
                totalPage: 0,
                pageSize: 20,
                pageNumber: 0,
                itemSize: 0
            };
            /*搜索结果*/
            $scope.searchHistoryVOList = [];
            $scope.isFirstSearch = true;
            /*搜索异常显示*/
            $scope.emptyInfoVO.historySearchEmptyInfo = false;
        };
        /*搜索*/
        var getSearchData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryHistoryInfoByCondition.htm?", {
                keywordStr: $scope.searchInfo.keywordStr,
                pageNumber: $scope.searchPageInfo.pageNumber,
                pageSize: $scope.searchPageInfo.pageSize
            }).success(function (data) {
                if (data.status == 0) {
                    if (data.result.content && data.result.content.length > 0) {
                        $scope.searchHistoryVOList.push.apply($scope.searchHistoryVOList, data.result.content);
                    }
                    $scope.searchPageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    if (data.result.totalPages > 0) {
                        $scope.searchPageInfo.pageNumber = data.result.number + 1;
                    }
                    ;
                    $scope.emptyInfoVO.historySearchEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                    $scope.isFirstSearch = false;
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.historySearchEmptyInfo = true;
                    $scope.emptyInfoVO.historySearchDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.historySearchEmptyInfo = true;
                $scope.emptyInfoVO.historySearchDataErrorMsg = '加载失败，请重试';
            });
        };
        /*点击搜索*/
        $scope.searchKeyWord = function () {
            if ($scope.searchInfo.keywordStr != null && $scope.searchInfo.keywordStr != "") {
                searchInit();
                $ionicLoading.show({
                    template: '正在查找...'
                });
                getSearchData(function () {
                    /*将滚动条回到顶部*/
                    $ionicScrollDelegate.scrollTop();
                    /*隐藏上拉刷新*/
                    $scope.$broadcast('scroll.refreshComplete');
                    $ionicLoading.hide();

                });
            } else {
                searchInit();
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            }
        };
        /*监控搜索 间隔一秒*/
        $scope.$watch(function () {
            return $scope.searchInfo.keywordStr;
        }, function (newVal, oldVal) {
            setTimeout(function () {
                if (newVal != oldVal && $scope.searchInfo.keywordStr == newVal) {
                    $scope.searchKeyWord();
                }
            }, 1000);
        });

        //刷新
        $scope.searchDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.searchKeyWord();
        };

        //加载更多
        $scope.searchLoadMore = function () {
            if ($scope.searchPageInfo.pageNumber >= $scope.searchPageInfo.totalPage) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            getSearchData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };

        /*关闭搜索弹框*/
        $scope.closeHistorySearch = function () {
            $scope.searchInfo = {keywordStr: null};
            searchInit();
            $scope.modelNameVO.learn_history_search_modal.hide();
            $timeout(function () {
                $scope.modelNameVO.learn_history_search_modal.remove();
            }, 500);
        };
    }

    function learnCollectCtrl($scope, $http, $ionicModal, $ionicLoading, $timeout, $ionicScrollDelegate, $ionicPopup, ynuiNotification, mbStudyCommonService) {
        /*初始化收藏页面数据*/
        var collectInit = function () {
            /*收藏数据*/
            $scope.MobileCourseResourceVOList = [];
            /*分页数据*/
            $scope.collectPageInfo = {
                totalPage: 0,
                pageSize: 20,
                pageNumber: 0,
                itemSize: 0
            };
            /*存在值 就代表只查这页后面的条数和下一页*/
            $scope.otherSize = null;
            /*判断是否是第一次正在查询状态*/
            $scope.isFirstQuery = true;
            /*错误提示*/
            $scope.emptyInfoVO.collectEmptyInfo = false;
        };
        collectInit();

        var collectListGetData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryCollectShowPage.htm?", {
                otherSize: $scope.otherSize,
                pageNumber: $scope.collectPageInfo.pageNumber,
                pageSize: $scope.collectPageInfo.pageSize
            }).success(function (data) {
                if (data.status == 0) {
                    if (data.result.content && data.result.content.length > 0) {
                        $scope.MobileCourseResourceVOList.push.apply($scope.MobileCourseResourceVOList, data.result.content);
                        /*收藏 页面全选按钮*/
                        $scope.selectedAll = false;
                    }
                    ;
                    $scope.collectPageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    $scope.otherSize = null;
                    if (data.result.totalPages > 0) {
                        $scope.collectPageInfo.pageNumber = data.result.number + 1;
                    }
                    ;
                    $scope.isFirstQuery = false;
                    $scope.emptyInfoVO.collectEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.collectEmptyInfo = true;
                    $scope.emptyInfoVO.collectDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.collectEmptyInfo = true;
                $scope.emptyInfoVO.collectDataErrorMsg = '加载失败，请重试';
            });
        };

        /*第一次查询*/
        $scope.firstCollectList = function () {
            /*初始化*/
            collectInit();
            /*查询*/
            collectListGetData(function () {
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新图标*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            });
        };
        $ionicLoading.show();
        $scope.firstCollectList();

        /*关闭学习界面调用的方法*/
        $scope.changeCollectList = function () {
            /*收藏数据存在修改*/
            if (mbStudyCommonService.gCollectStatusChanged) {
                $scope.firstCollectList();
                if ($scope.searchInfo.keywordStr) {
                    $scope.searchKeyWord();
                }
                ;
                /*更新我的学习界面收藏总数*/
                $scope.getLastStudyResource();
                mbStudyCommonService.gCollectStatusChanged = false;
            }
        };


        //刷新
        $scope.collectDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.firstCollectList();
        };

        //加载更多
        $scope.loadMore = function () {
            if ($scope.collectPageInfo.pageNumber >= $scope.collectPageInfo.totalPage) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            ;
            collectListGetData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };


        /*关闭收藏页面*/
        $scope.closeCollect = function () {
            if (mbStudyCommonService.gStatusChanged) {
                $scope.getLastStudyResource();
            }
            ;
            $scope.modelNameVO.learn_collect_modal.hide();
            $timeout(function () {
                $scope.modelNameVO.learn_collect_modal.remove();
            }, 500);
        };


        /**
         * 搜索收藏 开始
         */
        /*打开收藏搜索浮层*/
        $scope.openCollectSearch = function () {
            $ionicModal.fromTemplateUrl('learn-collect-search.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.learn_collect_search_modal = modal;
                /*初始化搜索页面*/
                $scope.searchInfo = {keywordStr: null};
                searchInit();
                /*打开搜索弹框*/
                modal.show();
            });
        };

        /*初始化搜索页面*/
        /*搜索关键字*/
        $scope.searchInfo = {keywordStr: null};
        var searchInit = function () {
            /*分页*/
            $scope.serachPageInfo = {
                totalPage: 0,
                pageSize: 20,
                pageNumber: 0,
                itemSize: 0
            };
            /*搜索结果*/
            $scope.searchCollectVOList = [];
            $scope.isFirstSearch = true;
            /*搜索异常显示*/
            $scope.emptyInfoVO.collectSearchEmptyInfo = false;
        };

        /*搜索*/
        var getSearchData = function (func) {
            $http.post(originBaseUrl + "/third/learnResource/queryCollectInfoByCondition.htm?", {
                keywordStr: $scope.searchInfo.keywordStr,
                pageNumber: $scope.serachPageInfo.pageNumber,
                pageSize: $scope.serachPageInfo.pageSize
            }).success(function (data) {
                if (data.status == 0) {
                    if (data.result.content && data.result.content.length > 0) {
                        $scope.searchCollectVOList.push.apply($scope.searchCollectVOList, data.result.content);
                    }
                    $scope.serachPageInfo = {
                        totalPage: data.result.totalPages,
                        pageSize: data.result.size,
                        pageNumber: data.result.number,
                        itemSize: data.result.totalElements
                    };
                    if (data.result.totalPages > 0) {
                        $scope.serachPageInfo.pageNumber = data.result.number + 1;
                    }
                    ;
                    $scope.isFirstSearch = false;
                    $scope.emptyInfoVO.collectSearchEmptyInfo = false;
                    $timeout(function () {
                        if (func) {
                            func();
                        }
                    }, 500);
                } else {
                    if (func) {
                        func();
                    }
                    $scope.emptyInfoVO.collectSearchEmptyInfo = true;
                    $scope.emptyInfoVO.collectSearchDataErrorMsg = '加载失败，请重试';
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.emptyInfoVO.collectSearchEmptyInfo = true;
                $scope.emptyInfoVO.collectSearchDataErrorMsg = '加载失败，请重试';
            });
        };
        /*点击搜索*/
        $scope.searchKeyWord = function () {
            if ($scope.searchInfo.keywordStr != null && $scope.searchInfo.keywordStr != "") {
                searchInit();
                $ionicLoading.show({
                    template: '正在查找...'
                });
                getSearchData(function () {
                    /*将滚动条回到顶部*/
                    $ionicScrollDelegate.scrollTop();
                    /*隐藏上拉刷新*/
                    $scope.$broadcast('scroll.refreshComplete');
                    $ionicLoading.hide();
                });
            } else {
                searchInit();
                /*将滚动条回到顶部*/
                $ionicScrollDelegate.scrollTop();
                /*隐藏上拉刷新*/
                $scope.$broadcast('scroll.refreshComplete');
                $ionicLoading.hide();
            }
        };
        /*监控搜索 间隔一秒*/
        $scope.$watch(function () {
            return $scope.searchInfo.keywordStr;
        }, function (newVal, oldVal) {
            setTimeout(function () {
                if (newVal != oldVal && $scope.searchInfo.keywordStr == newVal) {
                    $scope.searchKeyWord();
                }
            }, 1000);
        });

        //刷新
        $scope.searchDoRefresh = function (doRefresh) {
            if (doRefresh) {
                $ionicLoading.show({
                    template: '正在刷新...'
                });
            }
            ;
            $scope.searchKeyWord();
        };

        $scope.$on('stateChangeSuccess', function () {
            $scope.searchLoadMore();
        });

        //加载更多
        $scope.searchLoadMore = function () {
            if ($scope.serachPageInfo.pageNumber >= $scope.serachPageInfo.totalPage) {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
                return false;
            }
            getSearchData(function () {
                /*隐藏下拉更多*/
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicLoading.hide();
            });
        };

        /*关闭搜索弹框*/
        $scope.closeCollectSearch = function () {
            searchInit();
            $scope.modelNameVO.learn_collect_search_modal.hide();
            $timeout(function () {
                $scope.modelNameVO.learn_collect_search_modal.remove();
            }, 500);
        };
        /**
         * 搜索收藏 结束
         */


        /**
         * 编辑收藏 开始
         */
        /*打开收藏搜索浮层*/
        $scope.openCollectEdit = function () {
            var scrollPosition = $ionicScrollDelegate.$getByHandle('collectScroll').getScrollPosition();
            $ionicModal.fromTemplateUrl('learn-collect-edit.html', {
                scope: $scope,
                animation: 'slide-in-right'
            }).then(function (modal) {
                $scope.modelNameVO.learn_collect_edit_modal = modal;
                modal.show();
                $ionicScrollDelegate.$getByHandle('collectEditScroll').scrollBy(scrollPosition.left, scrollPosition.top);
            });
            $scope.selectedAll = false;
            $scope.selectAll(false);
        };
        $scope.selectedAll = false;
        /*设置是否全部选中*/
        $scope.selectAll = function (status) {
            $scope.selectedAll = status;
            if (status) {
                $scope.collectSelectNum = $scope.MobileCourseResourceVOList.length;
            } else {
                $scope.collectSelectNum = 0;
            }
            angular.forEach($scope.MobileCourseResourceVOList, function (item) {
                item.isSelect = status;
            });
        };
        /*单个选中*/
        $scope.changeSelect = function (item) {
            if (item.isSelect) {
                $scope.collectSelectNum += 1;
            } else {
                $scope.collectSelectNum -= 1;
            }
            if ($scope.collectSelectNum == $scope.MobileCourseResourceVOList.length) {
                $scope.selectedAll = true;
            } else {
                $scope.selectedAll = false;
            }
        };
        /*修改查询更多时的页数查询值*/
        var updatePageNumber = function (deletNum) {
            if ($scope.collectPageInfo.pageNumber < $scope.collectPageInfo.itemSize) {
                $scope.otherSize = $scope.MobileCourseResourceVOList.length % $scope.collectPageInfo.pageSize;
                var nowPage = ($scope.MobileCourseResourceVOList.length - $scope.otherSize) / $scope.collectPageInfo.pageSize;
                $scope.collectPageInfo.pageNumber = nowPage;
                $scope.collectPageInfo.itemSize -= deletNum;
            }
            ;
        };
        /*删除所选*/
        $scope.batchAbolishCollect = function () {
            var collectIdList = [];
            angular.forEach($scope.MobileCourseResourceVOList, function (item) {
                if (item.isSelect) {
                    collectIdList.push(item.myTracesId);
                }
            });
            if (collectIdList.length < 1) {
                ynuiNotification.error({msg: "请至少勾选一项"});
                return;
            }
            $ionicPopup.show({
                title: '提示',
                template: '<span class="help-block text-left">确定要删除收藏的资源吗？</span>',
                buttons: [
                    {
                        text: '取消', type: 'button-default', onTap: function () {
                        }
                    },
                    {
                        text: "确定删除", type: 'button-positive', onTap: function () {
                            $http.post(originBaseUrl + "/third/learnResource/batchAbolishCollect.htm?", {myTracesIds: collectIdList}).success(function (data) {
                                if (data.status == 0) {
                                    ynuiNotification.success({msg: "已删除"});
                                    for (var i = 0; i < $scope.MobileCourseResourceVOList.length; i++) {
                                        if ($scope.MobileCourseResourceVOList[i].isSelect) {
                                            $scope.MobileCourseResourceVOList.splice(i, 1);
                                            i--;
                                        }
                                    }
                                    ;
                                    updatePageNumber(collectIdList.length);
                                    /*更新总收藏数*/
                                    $scope.getLastStudyResource();
                                    /*关闭编辑浮层*/
                                    $scope.closeCollectEdit();
                                } else {
                                    ynuiNotification.error({msg: "删除失败"});
                                }
                            });
                        }
                    }
                ]
            });
        };
        /*一键清空*/
        $scope.allAbolishCollect = function () {
            $ionicPopup.show({
                title: '提示',
                template: '<span class="help-block text-left">确定清空所有收藏的资源吗？</span>',
                buttons: [
                    {
                        text: '取消', type: 'button-default', onTap: function () {
                        }
                    },
                    {
                        text: "确定删除", type: 'button-positive', onTap: function () {
                            $http.post(originBaseUrl + "/third/learnResource/allAbolishCollect.htm?").success(function (data) {
                                if (data.status == 0) {
                                    ynuiNotification.success({msg: "已删除"});
                                    /*更新总收藏数*/
                                    $scope.getLastStudyResource();
                                    /*初始化*/
                                    collectInit();
                                    $scope.closeCollectEdit();
                                } else {
                                    ynuiNotification.error({msg: "删除失败"});
                                }
                            })
                        }
                    }
                ]
            });
        };

        /*关闭编辑弹框*/
        $scope.closeCollectEdit = function () {
            $scope.modelNameVO.learn_collect_edit_modal.hide();
            $timeout(function () {
                $scope.modelNameVO.learn_collect_edit_modal.remove();
            }, 500);
        };
        /**
         * 编辑收藏 结束
         */
    }

    function resScormCourseCtrl($scope, $http, $ionicModal, $timeout, mbStudyCommonService, resType, operateType, modalManager, ynuiNotification) {
        $scope.chapter = null;
        console.log("resScormCourseCtrl 被初始化");
        /**
         * 第一个可学章节
         */
        $scope.firstAbleLearnChapter = {
            id: null,
            kPointId: null,
            indexPage: null,
            chapterName: null
        };


        // 加载章节
        $scope.loadChapter = function () {
            mbStudyCommonService.getChapterDetail(
                $scope.rescourseBaseInfo.resId
            ).then(function (data) {
                $scope.chapter = data;
                if ($scope.chapter && $scope.chapter.chapters) {
                    angular.forEach($scope.chapter.chapters, function (item) {
                        if (!$scope.firstAbleLearnChapter.id) {
                            if (item.haveKPoint) {
                                $scope.firstAbleLearnChapter.id = item.id;
                                $scope.firstAbleLearnChapter.kPointId = item.kPointId;
                                $scope.firstAbleLearnChapter.indexPage = item.indexPage;
                                $scope.firstAbleLearnChapter.chapterName = item.name;
                            } else if (item.haveSubChapters) {
                                recursionData(item.subChapters);
                            }
                        }

                    });
                }
            });
        };


        $scope.loadChapter();


        /**
         * 继续学习
         */
        $scope.continueLearn = function () {
            mbStudyCommonService.setShareTempData(
                resType.K_POINT,
                $scope.chapter.learnedKPointId,
                $scope.chapter.learnedChapterId,
                $scope.chapter.learnedKPointIndexPage,
                $scope.chapter.learnedChapterName
            );
            $ionicModal.fromTemplateUrl(
                'templates/handheldlearn/learn-scorm-course.html',
                {
                    animation: 'slide-in-right',
                    scope: $scope
                }
            ).then(function (modal) {
                modalManager.put("learnScormCourseModal", modal);
                modal.show();
            });
        };

        /**
         * 开始学习
         */
        $scope.startLearn = function () {
            if (!$scope.firstAbleLearnChapter.id) {
                ynuiNotification.warning({msg: "没有可以学习的章节！"});
                return;
            }
            mbStudyCommonService.setShareTempData(
                resType.K_POINT,
                $scope.firstAbleLearnChapter.kPointId,
                $scope.firstAbleLearnChapter.id,
                $scope.firstAbleLearnChapter.indexPage,
                $scope.firstAbleLearnChapter.chapterName
            );
            $ionicModal.fromTemplateUrl(
                'templates/handheldlearn/learn-scorm-course.html',
                {
                    animation: 'slide-in-right',
                    scope: $scope
                }
            ).then(function (modal) {
                modalManager.put("learnScormCourseModal", modal);
                modal.show();
            });
        };


        /**
         * 递归数据
         * @param datas
         */
        function recursionData(datas) {
            angular.forEach(datas, function (item) {
                if (!$scope.firstAbleLearnChapter.id) {
                    if (item.haveKPoint) {
                        $scope.firstAbleLearnChapter.id = item.id;
                        $scope.firstAbleLearnChapter.kPointId = item.kPointId;
                        $scope.firstAbleLearnChapter.indexPage = item.indexPage;
                        $scope.firstAbleLearnChapter.chapterName = item.name;
                    } else if (item.haveSubChapters) {
                        recursionData(item.subChapters);
                    }
                }
            });
        }

        /**
         * 监听章节被点击
         */
        $scope.$on("chapter:clicked", function (event, data) {
            // 如果章节没有挂载知识点
            if (!data.haveKPoint) {
                return;
            }
            mbStudyCommonService.setShareTempData(
                resType.K_POINT,
                data.kPointId,
                data.id,
                data.indexPage,
                data.name
            );
            $ionicModal.fromTemplateUrl(
                'templates/handheldlearn/learn-scorm-course.html',
                {
                    animation: 'slide-in-right',
                    scope: $scope
                }
            ).then(function (modal) {
                modalManager.put("learnScormCourseModal", modal);
                modal.show();
            });
        });

        $scope.$on('$destroy', function () {
        });

        /**
         * 监听重新加载数据事件
         */
        $scope.$on("reLoadScormCourse", function () {
            $scope.loadChapter();
        });

    }

    function learnScormCouseCtrl($rootScope, $scope, $http, $ionicModal, $timeout, mbStudyCommonService, resType, operateType, modalManager) {
        window.setTimeout(function () {
            try {
                if (!!navigator.userAgent.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/)) {
                    window.webkit.messageHandlers.showHeader.postMessage(null);
                } else {
                    window.native.disableBackButton();
                    window.native.showHeader();
                }
            } catch (e) {
                // 不影响正常流程
            }
        }, 0);
        console.log("learnScormCouseCtrl 被初始化");
        // 资源基本信息
        $scope.rescourseBaseInfo = {
            resType: 0, // 资源类型
            resId: null,   // 资源ID
            documentType: null  // 资源格式
        };
        $scope.shareData = mbStudyCommonService.getShareData();
        $scope.rescourseBaseInfo = angular.copy($scope.shareData, $scope.rescourseBaseInfo);

        $scope.resDetail = null;

        $scope.customParam = {
            currentLearnChapter: $scope.shareData.currentLearnChapter // 当前所学章节ID
        };


        $scope.sco = {
            path: null
        };

        $scope.sco.path = mbStudyCommonService.getPreviewPath() + $scope.shareData.tempResId + "/" + $scope.shareData.indexPage;

        /**
         * 加载资源基本信息
         */
        $scope.loadResourceBaseInfo = function () {
            mbStudyCommonService.getResourceBaseInfo(
                $scope.rescourseBaseInfo.resType,
                $scope.rescourseBaseInfo.resId
            ).then(function (data) {
                $scope.resDetail = data;
            });
        };


        $scope.loadResourceBaseInfo();


        $scope.tab = {
            currentTab: "chapter"
        };


        /**
         * 显示scorm课件的基本信息
         */
        $scope.showScormCourseBaseInfo = function () {
            // 暂停计时
            $scope.$emit("pauseResTimer");
            var isExsits = modalManager.exist("resScormCourseModal");
            if (isExsits) {
                modalManager.show("resScormCourseModal");
            } else {
                $ionicModal.fromTemplateUrl(
                    'templates/handheldlearn/res-scorm-course-modal.html',
                    {
                        scope: $scope
                    }
                ).then(function (modal) {
                    modalManager.put("resScormCourseModal", modal);
                    modal.show();
                });
            }
            $scope.loadResourceBaseInfo();
        };

        // 章节信息
        $scope.chapter = null;

        // 加载章节
        $scope.loadChapter = function () {
            mbStudyCommonService.getChapterDetail(
                $scope.rescourseBaseInfo.resId
            ).then(function (data) {
                $scope.chapter = data;
            });
        };

        $scope.loadChapter();


        /**
         * 监听章节被点击
         */
        $scope.$on("chapter:clicked", function (event, data) {
            // 如果章节没有挂载知识点
            if (!data.haveKPoint) {
                return;
            }
            var current = $scope.customParam.currentLearnChapter === data.id;
            // 设置新的sco信息
            mbStudyCommonService.setShareTempData(
                resType.K_POINT,
                data.kPointId,
                data.id,
                data.indexPage,
                data.name
            );
            // 设置当前正在学的章节
            $scope.customParam.currentLearnChapter = data.id;
            // 通知重新查询点赞收藏状态
            $scope.$broadcast("reLoadOperatedStatus");
            // 关闭信息模态框
            var modal = modalManager.get("resScormCourseModal");
            if (modal) {
                modal.hide().then(function () {
                    if (current) {
                        // 重新开始计时
                        $scope.$emit('startResTimer');
                    }
                });
            }
            // 装载新的sco
            $scope.sco.path = mbStudyCommonService.getPreviewPath() + data.kPointId + "/" + data.indexPage;
            // 终止事件
            event.stopPropagation();
        });

        /**
         * 关闭模态框
         */
        $scope.closeModal = function () {
            modalManager.remove("learnScormCourseModal");
            modalManager.remove("resScormCourseModal");
            $scope.$emit("reLoadScormCourse");
            // 重置提供给APP的方法
            window.historyBack = angular.noop;
        };
        // 提供给APP的方法
        window.historyBack = $scope.closeModal;

        // 监听笔记弹框打开状态
        var unsubscribe = $rootScope.$on("noteModal:openStatus", function (event, data) {
            // 如果笔记框打开，暂停计时
            if (data.isOpen) {
                $scope.$emit("pauseResTimer");
            } else { // 否则开启计时
                console.log("监听笔记弹框打开状态");
                $scope.$emit("startResTimer");
            }
        });

        $scope.$on("$destroy", function () {
            unsubscribe();
        });

        /**
         * 监听重新获取数据事件
         */
        $scope.$on("commonStudyRes: reLoadData", function (event, data) {

            $scope.loadResourceBaseInfo();
            // $scope.loadChapter();
            // 终止事件继续传播
            // event.stopPropagation();
        });

    }
})();




