/**
 * Created by yineng on 2017/11/20 12:52
 *
 */
angular.module("starter")
    .service("mbStudyCommonService", function ($http, $q) {
        /**
         * 用于存放组件之间共享的数据
         */
        var shareData = {
            resType: null,  // 资源类型
            resId: null,  // 资源ID
            documentType: null, // 资源文件类型
            tempResType: null, // 临时变量，如果为sco课件此值存放点击的知识点类型，其他情况都与resType值一致
            tempResId: null, // 临时变量，如果为sco课件此值存放点击的知识点ID，其他情况都与resId值一致
            currentLearnChapter: null, // 临时变量，如果为sco课件此值存放点击的章节ID，其他情况值为null
            indexPage: null, // 临时变量，如果为sco课件此值存放点击的章节的知识点所对应首页名称，其他情况值为null
            chapterName: null // 临时变量，如果为sco课件此值存放点击的章节的名称，其他情况值为null
        };

        /**
         * 清空共享数据
         */
        function cleanShareData() {
            shareData.resType = null;
            shareData.resId = null;
            shareData.documentType = null;
            shareData.tempResType = null;
            shareData.tempResId = null;
            shareData.currentLearnChapter = null;
            shareData.indexPage = null;
            shareData.chapterName = null;
        }

        var previewPath;

        (function getPreviewPath() {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $http.get(originBaseUrl + "/third/mobileStudyCommon/getPreviewPath.htm").success(function (data) {
                deferred.resolve(data);
            });
            promise.then(function (path) {
                previewPath = path;
            })
        })();

        // 全局变量，监控资源是否已被操作(用于重新加载数据页面判断)
        var _gStatusChanged = false;

        // 全局变量，监控资源是否已改变收藏状态(用于重新加载收藏页面数据)
        var _gCollectStatusChanged = false;

        return {
            /**
             * 设置共享数据
             */
            setShareData: function (resType, resId, documentType, tempResType, tempResId) {
                shareData.resType = resType;
                shareData.resId = resId;
                shareData.documentType = documentType;
                shareData.tempResType = tempResType;
                shareData.tempResId = tempResId;
            },
            /**
             * 设置共享数据
             */
            setShareTempData: function (tempResType, tempResId, currentLearnChapter, indexPage, chapterName) {
                shareData.tempResType = tempResType;
                shareData.tempResId = tempResId;
                shareData.currentLearnChapter = currentLearnChapter;
                shareData.indexPage = indexPage;
                shareData.chapterName = chapterName;
            },
            /**
             * 获取共享数据
             */
            getShareData: function () {
                return shareData;
            },
            cleanShareData: function () {
                cleanShareData();
            },
            /**
             * 全局变量，监控资源是否已被操作(用于重新加载数据页面判断)
             */
            gStatusChanged: _gStatusChanged,
            /**
             * 全局变量，监控资源是否已改变收藏状态(用于重新加载收藏页面数据)
             */
            gCollectStatusChanged: _gCollectStatusChanged,
            /**
             * 判断资源是否已被操作过
             * @param resType 资源类型
             * @param resId 资源ID
             * @param operateType 操作类型
             * @returns {boolean}
             */
            isOperatedResource: function (resType, resId, operateType) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/isOperatedResource.htm", {
                    resType: resType,
                    resId: resId,
                    operateType: operateType
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             *  操作某个资源
             * @param resType 资源类型
             * @param resId 资源ID
             * @param operateType 操作类型
             */
            operateResource: function (resType, resId, operateType) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/operateResource.htm", {
                    resType: resType,
                    resId: resId,
                    operateType: operateType
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 新增或修改笔记
             * @param resType 资源类型 必传
             * @param resId 资源ID 必传
             * @param content 笔记内容 必传
             * @param noteId 笔记ID
             */
            saveOrUpdateNote: function (resType, resId, content, noteId) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/saveOrUpdateNote.htm", {
                    resType: resType,
                    resId: resId,
                    content: content,
                    noteId: noteId
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             *  分页查询操作人对应资源的所有笔记
             * @param resType
             * @param resId
             * @param page
             * @param size
             */
            listAllNotes: function (resType, resId, page, size) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/listAllNotes.htm", {
                    resType: resType,
                    resId: resId,
                    page: page,
                    size: size
                }).success(function (data) {
                    var result = [];
                    if (data.status == 0) {
                        result = data.result;
                    }
                    deferred.resolve(result);
                });
                return promise;
            },
            /**
             * 删除笔记
             * @param noteId
             */
            deleteNote: function (noteId) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/deleteNote.htm", {
                    noteId: noteId
                }).success(function (data) {
                    deferred.resolve(data);
                });
                return promise;
            },
            /**
             *  获取资源基本信息
             * @param resType
             * @param resId
             */
            getResourceBaseInfo: function (resType, resId) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/getResourceBaseInfo.htm", {
                    resType: resType,
                    resId: resId
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 获取章节详情
             * @param scormCourseId scorm课件ID 必传
             * @param operatorId 操作人ID 必传
             */
            getChapterDetail: function (scormCourseId) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/getChapterDetail.htm", {
                    scormCourseId: scormCourseId,
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 获取sco资源本地路径
             */
            getPreviewPath: function () {
                return originBaseUrl.replace("/ynedut", "") + previewPath;
            },
            /**
             * 获取某个资源的已学时间
             * @param resType
             * @param resId
             */
            getResLearnedTime: function (resType, resId) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/getResLearnedTime.htm", {
                    resType: resType,
                    resId: resId
                }).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 记录学习某个资源的时间-非知识点的学习
             * @param learnInfoVO
             */
            recordLearnTime: function (learnInfoVO) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/recordLearnTime.htm", learnInfoVO).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 记录学习某个资源的时间-知识点的学习
             * @param learnInfoVO
             */
            recordKnowleageLearnTime: function (learnInfoVO) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/recordKnowleageLearnTime.htm", learnInfoVO).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            },
            /**
             * 暂停或播放结束时保存上次播放时间
             * @param learnInfoVO
             */
            saveAVPlayTime:function (learnInfoVO) {
                var deferred = $q.defer();
                var promise = deferred.promise;
                $http.post(originBaseUrl + "/third/mobileStudyCommon/saveAVPlayTime.htm", learnInfoVO).success(function (data) {
                    deferred.resolve(data.result);
                });
                return promise;
            }
        };
    });
