/**
 * 健康检查
 *
 * @author Gin
 */
(function () {
  'use strict';

  angular.module('starter').config(config)
    .controller('healthCheckCtrl', ctrl);

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      .state('health_check', {
        url: '/health_check',
        templateUrl: 'templates/healthcheck/healthCheck.html',
        data: {
          micro: true,
          title: '健康检查'
        },
        controller: 'healthCheckCtrl',
        controllerAs: 'vm'
      });
  }

  ctrl.$inject = ['$scope', '$http', '$ionicModal', '$ionicScrollDelegate', '$timeout', '$ionicPopup'];

  /**
   * 列表 ctrl
   */
  function ctrl($scope, $http, $ionicModal, $ionicScrollDelegate, $timeout, $ionicPopup) {
    var vm = this;

    vm.onSelectDate = onSelectDate;
    vm.onSelectParams = onSelectParams;
    vm.onSingleSelectParams = onSingleSelectParams;
    vm.showMoreConditions = showMoreConditions;
    vm.closeModal = closeModal;
    vm.resetParams = resetParams;
    vm.loadMoreData = loadMoreData;
    vm.formatCountInfo = formatCountInfo;
    vm.listTeacher = listTeacher;
    vm.callTeacher = callTeacher;
    vm.doCallTeacher = doCallTeacher;

    vm.pageInfo = {
      pageSize: 20,
      pageNumber: -1
    };
    vm.date = null;
    vm.paramsDate = null;
    vm.settingList = [];
    vm.settingId = null;
    // 更多筛选条件
    vm.schoolList = [];
    vm.schoolOrgNos = [];
    vm.gradeList = [];
    vm.gradeIds = [];
    vm.checkStatusList = [];
    vm.checkStatusIds = [];
    vm.healthTypeList = [];
    vm.healthTypeIds = [];
    // 更多筛选条件弹框
    vm.moreConditionsModal = null;
    vm.callTeacherModal = null;

    vm.countData = null;
    vm.dataList = null;

    // 初始化今天的日期
    onSelectDate();

    $timeout(function () {
      getHealthCheck().success(function (data) {
        if (data.status === 0 && data.result.length > 0) {
          angular.forEach(data.result, function (d) {
            if (d.userNumber === '1') {
              vm.settingId = d.id;
            }
          });
          if (null == vm.settingId) {
            vm.settingId = data.result[0].id;
          }
        }
        // 第一次进入页面 ion-infinite-scroll 去加载数据
        vm.moreDataCanBeLoaded = true;
      }).error(function () {
        vm.moreDataCanBeLoaded = true;
      });
    }, 500);

    /**
     * 选择日期后格式化为【YYYY 年 MM 月 DD】
     * @param item 选择的日期
     */
    function onSelectDate(item) {
      var format = 'YYYY 年 MM 月 DD 日';
      var cm = moment();
      var value;
      if (null == item) {
        value = cm;
      } else {
        value = moment(item);
      }
      if (cm.isSame(value, 'day')) {
        vm.date = value.format(format) + '（今天）';
        vm.paramsDate = value.format("YYYY-MM-DD");
      } else {
        var weeks = ['周日', '周一', '周二', '周三', '周四', '周五', '周六'];
        vm.date = value.format(format) + '（' + weeks[value.format('d')] + '）';
        vm.paramsDate = value.format("YYYY-MM-DD");
      }
      if (null != item) {
        $scope.$apply();
        loadMoreData(true);
      }
    }

    function getHealthCheck() {
      return $http.get(originBaseUrl + '/third/health/settings/list.htm').success(function (data) {
        if (data.status === 0) {
          vm.settingList = data.result;
        }
      });
    }

    function getSchoolList() {
      return $http.get(originBaseUrl + '/third/platformSysOrg/queryAllSchoolOrg.htm').success(function (data) {
        if (data.status === 0) {
          vm.schoolList = data.result;
        }
      });
    }

    function getGradeList() {
      return $http.get(originBaseUrl + '/third/grade/list.htm').success(function (data) {
        if (data.status === 0) {
          vm.gradeList = data.result;
        }
      });
    }

    function getStaticParams() {
      vm.checkStatusList = [
        {id: '1', name: '未完成检查'},
        {id: '2', name: '完成检查'}
      ];
      vm.healthTypeList = [
        {id: '2', name: '有发热'},
        {id: '1', name: '正常'}
      ];
    }

    /**
     * 选择多选的筛选条件
     *
     * @param value            选中的值，选全部值为 null
     * @param valueArrayKey    选中值要存放的数组的key
     * @param resourceArrayKey 数据源list
     * @param resourceKey      数据对象的key
     */
    function onSelectParams(value, valueArrayKey, resourceArrayKey, resourceKey) {
      var valueIdArray = vm[valueArrayKey];
      // 选择全部的情况
      if (null == value) {
        var resourceArray = vm[resourceArrayKey];
        if (null == value && valueIdArray.length === resourceArray.length) {
          vm[valueIdArray] = [];
        } else if (null == value && valueIdArray.length !== resourceArray.length) {
          angular.forEach(resourceArray, function (obj) {
            if (valueIdArray.indexOf(obj[resourceKey]) === -1) {
              valueIdArray.push(obj[resourceKey]);
            }
          });
          vm[valueArrayKey] = valueIdArray;
        }
        return;
      }
      // 单选的情况
      var index = valueIdArray.indexOf(value);
      if (index === -1) {
        valueIdArray.push(value);
      } else {
        valueIdArray.splice(index, 1);
      }
      vm[valueArrayKey] = valueIdArray;
    }

    /**
     * 选择单选的筛选条件
     *
     * @param value         选中的值
     * @param valueArrayKey 选中值要存放的数组的key
     */
    function onSingleSelectParams(value, valueArrayKey) {
      if (null == value) {
        vm[valueArrayKey] = [];
      } else {
        var index = vm[valueArrayKey].indexOf(value);
        if (index === -1) {
          vm[valueArrayKey] = [value];
        } else {
          vm[valueArrayKey] = [];
        }
      }
    }

    /**
     * 显示更多弹框
     */
    function showMoreConditions() {
      if (null == vm.moreConditionsModal) {
        $ionicModal.fromTemplateUrl('more-conditions.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function (modal) {
          vm.moreConditionsModal = modal;
          modal.show();
        });
      } else {
        vm.moreConditionsModal.show();
      }
      getSchoolList();
      getGradeList();
      getStaticParams();
    }

    function closeModal() {
      vm.moreConditionsModal.hide().then(function () {
        // 关闭弹框查询列表数据
        loadMoreData(true);
      });
    }

    function resetParams() {
      vm.schoolOrgNos = [];
      vm.gradeIds = [];
      vm.checkStatusIds = [];
      vm.healthTypeIds = [];
    }

    function countDataByConditions(obj) {
      return $http.post(
        originBaseUrl + '/third/health/class/count.htm', obj
      ).success(function (data) {
        if (0 === data.status) {
          vm.countData = data.result;
        }
        return data;
      });
    }

    function findByConditions(obj) {
      return $http.post(
        originBaseUrl + '/third/health/class/page.htm', obj
      ).success(function (data) {
        if (0 === data.status) {
          // 判断是否最后一页数据，最后一页隐藏 ion-infinite-scroll
          vm.moreDataCanBeLoaded = !data.result.lastPage;
        }
        return data;
      });
    }

    function getConditions() {
      return {
        date: vm.paramsDate,
        checkTypeId: vm.settingId,
        schoolOrgNos: vm.schoolOrgNos,
        gradeIds: vm.gradeIds,
        checkStatus: vm.checkStatusIds,
        healthStatus: vm.healthTypeIds
      };
    }

    function loadMoreData(init) {
      // 获取数据
      var obj = getConditions();
      countDataByConditions(obj);
      if (init) {
        obj.pageNumber = vm.pageInfo.pageNumber = -1;
      }
      obj.pageNumber = vm.pageInfo.pageNumber += 1;
      obj.pageSize = vm.pageInfo.pageSize;
      findByConditions(obj).success(function (data) {
        if (data.status === 0) {
          if (init || null == vm.dataList) {
            vm.dataList = data.result.content;
            $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
          } else {
            vm.dataList = vm.dataList.concat(data.result.content);
          }
        } else {
          // 报错，不能拉数据
          vm.moreDataCanBeLoaded = false;
          vm.dataList = [];
          vm.countData = null;
        }
      }).error(function () {
        // 报错，不能拉数据
        vm.moreDataCanBeLoaded = false;
        vm.dataList = [];
        vm.countData = null;
      }).finally(function () {
        $scope.$broadcast('scroll.refreshComplete');
        $scope.$broadcast('scroll.infiniteScrollComplete');
      });
    }

    function formatCountInfo() {
      var strings = [];
      var first = "共<strong>" + vm.countData.classCount + "</strong>个班";
      if (null == vm.checkStatusIds || 0 === vm.checkStatusIds.length) {
        first += "（" + vm.countData.notCheckClassCount + "个未完成）";
      }
      strings.push(first);
      strings.push("病假<strong>" + vm.countData.sickLeaveStuCount + "</strong>人");
      strings.push("发热<strong>" + vm.countData.warningStuCount + "</strong>人。");
      return strings.join("，");
    }

    function listTeacher(list) {
      var names = [];
      angular.forEach(list, function (obj) {
        names.push(obj.name);
      });
      return names.join("、");
    }

    function callTeacher(data) {
      var list = data.classTeacherMapList;
      if (list.length > 1) {
        // 弹框
        showCallTeacherModal(data);
      } else {
        // 否则直接取第一个提示
        var obj = list[0];
        doCallTeacher(obj);
      }
    }

    /**
     * 给班主任打电话
     * 涉及到多个班主任的要弹框显示班主任列表
     */
    function showCallTeacherModal(data) {
      vm.selectData = data;
      if (null == vm.callTeacherModal) {
        $ionicModal.fromTemplateUrl('call-teacher.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function (modal) {
          vm.callTeacherModal = modal;
          modal.show();
        });
      } else {
        vm.callTeacherModal.show();
      }
    }

    function doCallTeacher(obj) {
      if (null == obj) {
        return;
      }
      $ionicPopup.confirm({
        title: '提示',
        template: '您将拨打<strong>' + obj.name + '</strong>老师手机号：<strong style="color: #886aea">' + obj.mobile + '</strong>，请确认！',
        cancelText: '取消',
        okText: '确定'
      }).then(function (res) {
        if (res) {
          // 拨打电话
          window.location.href = 'tel:' + obj.mobile;
        }
      });
    }

  }
})();
