(function () {
    'use strict';

    angular
        .module('starter')
        .config(stateConfig)
        /**
         * 名称格式化
         */
        .factory("nameFormatStr", function () {
            var modals = {};

            return {
                //格式化节次
                getKnobs:function(knobs){
                    if(!knobs|| knobs.length==0){
                        return null;
                    }
                    knobs.sort(function(a,b){
                        return a-b;
                    });
                    var knobStr=knobs[0];
                    for(var i=1;i<knobs.length;){
                        if(knobs[i]-knobs[i-1]==1){
                            var endKnob=0;
                            for(;i<knobs.length;i++){
                                if(knobs[i]-knobs[i-1]==1==1){
                                    endKnob=knobs[i];
                                    continue;
                                }
                                break;
                            }
                            knobStr+="~"+endKnob;
                        }else{
                            knobStr+=","+knobs[i];
                            i++;
                        }
                    }
                    return knobStr;
                },
                //格式化ID
                getId:function(itemList){
                    var ids=[];
                    angular.forEach(itemList,function(item){
                        ids.push(item.id);
                    })
                    return ids;
                },
                getName:function(data){
                    var name="";
                    if(data && data.length>0){
                        angular.forEach(data,function(item){
                            name+=item.name+",";
                        })
                    }
                    if(name.length>0){
                        return name.substring(0,name.length-1);
                    }
                    return name;
                }
            };
        })
        .controller('jxrzResultCourseController', jxrzResultCourseController)
        .controller('jxrzResultDetailedController', jxrzResultDetailedController);

    stateConfig.$inject = ['$stateProvider'];
    function stateConfig($stateProvider) {
        $stateProvider
            //按课次汇总教学日志提交情况
            .state('jxrz_resultCourse', {
                firstPage: true,
                url: '/jxrz_resultCourse',
                templateUrl: 'templates/jxrz/jxrz_resultCourse.html',
                controller: 'jxrzResultCourseController',
                data:{
                    micro: true,//是否显示table
                    title: '日志检查意见',
                    prev: null
                }
            })
            //教学日志详细页面
            .state('jxrz_resultDetailed', {
                firstPage: true,
                url: '/jxrz_resultDetailed',
                templateUrl: 'templates/jxrz/jxrz_resultDetailed.html',
                controller: 'jxrzResultDetailedController',
                data:{
                    micro: false,//是否显示table
                    title: '日志检查意见',
                    prev: "jxrz_resultCourse"
                }
            })
    }

    jxrzResultCourseController.$inject = ['$scope', '$http', '$sce', '$location',"ynuiNotification"];
    function jxrzResultCourseController($scope, $http, $sce, $location,ynuiNotification) {
        var vm=$scope.vm={
            resultCoureList:[],
            errorStatus:"",
            termName:"",
            getTeacherTimeTableSummaryList:function(){
                $http.post(originBaseUrl + "/third/jxrzResultKnob/getTeacherTimeTableSummaryList.htm").success(function(data){
                    if(data.status!=-1){
                        vm.resultCoureList = data.result;
                        vm.errorStatus=data.status;
                        vm.termName=data.message;
                    }else{
                        ynuiNotification.error({msg: "获取数据失败！"});
                    }
                });
            },
            goDetailedGrid:function(item){
                $location.path("/jxrz_resultDetailed").search({teachClassId:item.teachClassId,courseName:item.courseName,hourUnit:item.hourUnit});
            }
        };
        vm.getTeacherTimeTableSummaryList();


    }
    jxrzResultDetailedController.$inject = ['$scope', '$http', '$sce', '$location','ynuiNotification'];
    function jxrzResultDetailedController($scope, $http, $sce, $location,ynuiNotification) {
        var teachClassId = $location.search().teachClassId;
        var courseName = $location.search().courseName;
        var hourUnit = $location.search().hourUnit;
        var vm=$scope.vm={
            resultCoureList:[],
            courseName:courseName,
            status:0,//0本周，1上周，2本月，3按日期查询
            beginDate:"",
            endDate:"",
            hourUnit:hourUnit,//1学时，2周
            getTeachClassSummaryList:function(status){
                vm.updStatus(status);
                var url="getTeachClassSummaryList.htm";
                if(hourUnit==2){
                    url="getTeachClassWeekSummaryList.htm";
                }
                if(status==3 && vm.beginDate && vm.endDate && vm.beginDate>vm.endDate){
                    ynuiNotification.error({msg: "开始时间不能大于结束时间！"});
                    return;
                }
                $http.post(originBaseUrl + "/third/jxrzResultKnob/"+url,{
                    teachClassId:teachClassId,
                    status:vm.status,
                    beginDate:vm.beginDate,
                    endDate:vm.endDate
                }).success(function(data){
                    if(data.status==0){
                        vm.resultCoureList = data.result;
                        vm.isShow=false;//设置特殊节次
                        angular.forEach(vm.resultCoureList,function(item){
                            if(item.checkType==1){
                                vm.isShow=true;
                            }
                        })
                    }else{
                        ynuiNotification.error({msg: "获取数据失败！"});
                    }
                });
            },
            updStatus:function(status){
                if(status!=3){
                    vm.beginDate='';
                    vm.endDate='';
                }
                vm.status=status;
                vm.resultCoureList=[];
            },
            goScanInfo:function(id){
                var goBack="jxrz_resultCourse";
                if(hourUnit==1){
                    $location.path("/jxrz_scanInfo").search({knobInfo:angular.toJson({pkTeachClassId:teachClassId,id:id}),goBack:goBack});
                }else{
                    $location.path("/submitWeekCourse").search({weekCourseInfo:angular.toJson({id:id}),isLook:true,goBack:goBack});
                }
            }
        };
        vm.getTeachClassSummaryList(0);
    }
})();
