/**
 * 一卡通
 * @author qiucheng Lu
 * @Date 2021年4月7日15:57:19
 */
(function () {
    'use strict';

    angular.module('starter')
        .config(stateConfig)
        .controller('oneCardCtrl', oneCardCtrl)

    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        // 一卡通
            .state('onecard', {
                url: '/onecard',
                templateUrl: 'templates/onecard/onecard.html',
                data: {
                    micro: true,
                    title: '一卡通'
                },
                controller: 'oneCardCtrl',
            });
    }

    oneCardCtrl.$inject = ['$scope', '$http', '$timeout', '$ionicLoading', '$ionicScrollDelegate'];

    function oneCardCtrl($scope, $http, $timeout, $ionicLoading, $ionicScrollDelegate) {
        $scope.balanceDetailToggle = false;
        $scope.isBack = false;
        $scope.loadECardInfoError = false;
        //查询
        $scope.queryOneCard = function () {
            $http.post(originBaseUrl + '/third/onecard/queryEcardInfo.htm').success(function (data) {
                if (data.status == 0) {
                    $scope.eCardInfo = data.result;
                    $scope.eCardInfo.totalBalance = formatNumber($scope.eCardInfo.totalBalance, 2, 1);
                    $scope.eCardInfo.accountBalance = formatNumber($scope.eCardInfo.accountBalance, 2, 1);
                    $scope.eCardInfo.allowanceBalance = formatNumber($scope.eCardInfo.allowanceBalance, 2, 1);
                    $scope.eCardInfo.todayTotalMoney = formatNumber($scope.eCardInfo.todayTotalMoney, 2, 1);
                    $scope.eCardInfo.weekTotalMoney = formatNumber($scope.eCardInfo.weekTotalMoney, 2, 1);
                    $scope.eCardInfo.monthTotalMoney = formatNumber($scope.eCardInfo.monthTotalMoney, 2, 1);
                }
            }).error(function () {
                $scope.loadECardInfoError = true;
                $scope.loadErrorMsg = '加载失败，请重试！';
            });
        };
        $scope.queryOneCard();

        //数字处理
        function formatNumber(num, cent, isThousand) {
            if (num != null) {
                num = num.toString().replace(/\$|\,/g, '');

                // 检查传入数值为数值类型
                if (isNaN(num))
                    num = "0";
                // 获取符号(正/负数)
                var sign = (num == (num = Math.abs(num)));

                num = Math.floor(num * Math.pow(10, cent) + 0.50000000001);  // 把指定的小数位先转换成整数.多余的小数位四舍五入
                var cents = num % Math.pow(10, cent);              // 求出小数位数值
                num = Math.floor(num / Math.pow(10, cent)).toString();   // 求出整数位数值
                cents = cents.toString();               // 把小数位转换成字符串,以便求小数位长度

                // 补足小数位到指定的位数
                while (cents.length < cent)
                    cents = "0" + cents;

                if (isThousand) {
                    // 对整数部分进行千分位格式化.
                    for (var i = 0; i < Math.floor((num.length - (1 + i)) / 3); i++)
                        num = num.substring(0, num.length - (4 * i + 3)) + ',' + num.substring(num.length - (4 * i + 3));
                }

                if (cent > 0)
                    return (((sign) ? '' : '-') + num + '.' + cents);
                else
                    return (((sign) ? '' : '-') + num);
            }
        }

        var pageNumber = 0;
        var pageSize = 40;
        var currentData = new Date();
        //详细的一卡通数据的重新拼装以便遍历
        var list = [];
        $scope.assembleData = function (data) {
            var dataDetail;
            var consumeList = [];    //当天消费记录
            var year = currentData.getFullYear();
            var month = currentData.getMonth() + 1;
            var day = currentData.getDate();
            for (var a = 0; a < data.length; a++) {
                if (data[a].time.getFullYear() == year) {
                    if (data[a].time.getMonth() == month) {
                        if (data[a].time.getDate() == day) {
                            consumeList.push({address: data[a].address, money: data[a].money});
                        }
                    }
                }
                dataDetail = {
                    day: data[a].time.getMonth() + "-" + data[a].time.getDate(),
                    week: week(data[a].time),
                    detail: consumeList
                };
            }
            currentData = new Date(new Date().getTime() - 24 * 60 * 60 * 1000);
            list.push(dataDetail);
        };
        $scope.getShowData = function (arr) {
            if (arr instanceof Array) {
                var finalResult = [],
                    dayDatas,//同一天的消费记录
                    year,
                    month,
                    day;
                for (var i = 0, len = arr.length; i < len; i++) {
                    var itemDate = arr[i].time,
                        _year = itemDate.getFullYear(),
                        _month = itemDate.getMonth(),
                        _day = itemDate.getDate();
                    if (_year == year && _month == month && day == _day) {//同一天
                        dayDatas.arr.push({
                            address: arr[i].address,
                            time: arr[i].time.getHours() + ":" + (arr[i].time.getMinutes() >= 10 ? arr[i].time.getMinutes() : "0" + arr[i].time.getMinutes()),
                            money: arr[i].money > 0 ? "+" + arr[i].money.toFixed(2) : arr[i].money.toFixed(2)
                        });
                    } else {
                        if (i == arr.length - 1) {
                            var doPush = true;
                        }
                        if (dayDatas) {
                            finalResult.push(dayDatas);
                        }
                        dayDatas = {
                            name: $scope.isSameDayOrPre(arr[i].time, new Date(), false) ? "今天" : ($scope.isSameDayOrPre(arr[i].time, new Date(), true) ? "昨天" : _month + 1 + "-" + _day),
                            arr: [],
                            weekDay: week(arr[i].time)
                        };
                        dayDatas.arr.push({
                            address: arr[i].address,
                            time: arr[i].time.getHours() + ":" + (arr[i].time.getMinutes() >= 10 ? arr[i].time.getMinutes() : "0" + arr[i].time.getMinutes()),
                            money: arr[i].money > 0 ? "+" + arr[i].money.toFixed(2) : arr[i].money.toFixed(2)
                        });
                    }
                    year = _year;
                    month = _month;
                    day = _day

                }
                finalResult.push(dayDatas);
                return finalResult;
            } else {
                return [];
            }
        };
        /**
         * 判断当前日期是当天或者前一天
         * @returns {boolean}
         */
        $scope.isSameDayOrPre = function (item, sysDate, isPre) {
            if (isPre) {
                return !$scope.isSameDayOrPre(item, sysDate, false) && Math.abs(item - sysDate) < 24 * 60 * 60 * 1000;
            } else {//同一天
                return item.getFullYear() == sysDate.getFullYear() && item.getMonth() == sysDate.getMonth() && item.getDate() == sysDate.getDate();
            }
        };
        $scope.items = [];
        $scope.items_copy = [];
        $scope.eCardInfoDetail = [];
        ($scope.getData = function (func) {
            $http.post(originBaseUrl + '/third/onecard/queryConsumptionScores.htm?pageNumber=' + pageNumber + "&pageSize=" + pageSize).success(function (data) {
                if (data.status == 0) {
                    $scope.page = data.result;
                    if ($scope.page.content && $scope.page.content.length > 0) {
                        var arr = $scope.items_copy.concat($scope.page.content);
                        $scope.items_copy = arr;
                        $scope.items = arr;
                        $scope.eCardInfoDetail = data.result.content;
                        angular.forEach($scope.eCardInfoDetail, function (item) {
                            var a = item.time.replace(/-/g, "/");
                            item.time = new Date(a);
                        });
                        $scope.items = $scope.getShowData($scope.items);
                    }
                    $scope.moreDataCanBeLoaded = function () {
                        return data.result.content.length;
                    };
                    $scope.dataError = $scope.items.length < 1;
                    if ($scope.loadECardInfoError) {
                        $scope.dataErrorMsg = '加载失败，请重试！';
                    } else {
                        $scope.dataErrorMsg = '没有消费/充值记录！';
                    }
                    if (func) {
                        func();
                    }
                }
            }).error(function () {
                if (func) {
                    func();
                }
                $scope.dataError = true;
                if ($scope.loadECardInfoError) {
                    $scope.dataErrorMsg = '加载失败，请重试！';
                } else {
                    $scope.dataErrorMsg = '加载消费/充值记录失败，请重试！';
                }
            });

        })(0);

        function week(day) {
            var week;
            if (day.getDay() == 0) {
                week = "星期日";
            }
            if (day.getDay() == 1) {
                week = "星期一"
            }
            if (day.getDay() == 2) {
                week = "星期二"
            }
            if (day.getDay() == 3) {
                week = "星期三"
            }
            if (day.getDay() == 4) {
                week = "星期四"
            }
            if (day.getDay() == 5) {
                week = "星期五"
            }
            if (day.getDay() == 6) {
                week = "星期六"
            }
            return week;
        }

        $scope.doRefresh = function () {
            $ionicLoading.show({
                template: '正在刷新...'
            });
            $scope.page = null;//重新获取page对象
            $scope.items_copy = [];
            $scope.items = [];
            pageNumber = 0;
            $scope.queryOneCard();
            $scope.getData(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };

        $scope.loadMore = function () {
            //模拟请求数据
            pageNumber += 1;
            $scope.getData(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        };

        $scope.$on('stateChangeSuccess', function () {
            $scope.loadMore();
        });
    }
})();
