/**
 * 选择课程
 */
(function () {
    'use strict';

    angular
      .module('starter')
      .controller('tkChooseCoursesController', tkChooseCoursesController);

    tkChooseCoursesController.$inject = ['$scope', '$http', '$ionicModal', '$ionicLoading', '$ionicScrollDelegate', '$location', "ynuiNotification",
        "tkStorageService"];

    function tkChooseCoursesController(
      $scope, $http, $ionicModal, $ionicLoading, $ionicScrollDelegate, $location, ynuiNotification, tkStorageService
    ) {
        /**
         * 路由信息
         * @type {string}
         */
        var basePath = originBaseUrl + "/third/tkOutsideTaskRegisterApp";
        var targetRoute = $location.search().targetRoute;

        /**
         * 查询条件
         * @type {{gradeId: string, name: string}}
         */
        $scope.condition = {
            isQuery: false,
            pageNumber: 0,
            pageSize: 20,
            name: "",
            title: ""
        };

        $scope.courseList = [];

        var condition = tkStorageService.getItemNoDel("tkBasicInfo");

        /**
         * 查询课程
         */
        $scope.queryTeachCourse = function (fun) {
            $scope.condition.isQuery = true;
            $http.get(basePath + "/findAllCourse.htm", {
                params: {
                    name: $scope.condition.name,
                    pageSize: $scope.condition.pageSize,
                    pageNumber: $scope.condition.pageNumber,
                    _timestamp: new Date().getTime()
                }
            }).success(function (data) {
                if (data.status == 0) {
                    var arrs = data.result;
                    if (!arrs || !arrs.content || arrs.content.length == 0) {
                        $scope.condition.title = "没有可选课程";
                        $scope.condition.error = false;
                    } else {
                        angular.forEach(arrs.content, function (item) {
                            $scope.courseList.push(item);
                        });
                        $scope.condition.pageSize = data.result.size;
                        $scope.condition.pageNumber = data.result.number;
                        $scope.condition.itemSize = data.result.totalElements;
                        $scope.condition.totalPage = data.result.totalPages;
                        initMore();
                    }
                } else {
                    $scope.condition.title = "获取课程失败";
                    $scope.condition.error = true;
                }
                if (arrs) {
                    $scope.courseList = arrs.content;
                    $scope.condition.isQuery = false;
                }
            }).error(function () {
                $scope.condition.title = "获取课程失败";
                $scope.condition.error = true;
                $scope.condition.isQuery = false;
                if (fun && angular.isFunction(fun)) {
                    fun();
                }
            })
        };

        /**
         * 清除查询条件
         */
        $scope.clearCondition = function () {
            $scope.condition.pageNumber = 0;
            $scope.condition.pageSize = 20;
            $scope.condition.name = "";
        };

        /**
         * 刷新数据
         */
        $scope.doRefresh = function () {
            $scope.condition.pageNumber = 0;
            $scope.condition.pageSize = 20;
            $scope.courseList = [];
            $scope.queryTeachCourse(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };

        /**
         * 加载更多
         */
        function initMore() {
            if (!$scope.loadMore) {
                $scope.loadMore = function () {
                    if ($scope.condition.pageNumber >= $scope.condition.totalPage) {
                        return false;
                    }
                    $scope.condition.pageNumber = $scope.condition.pageNumber + 1;
                    $scope.queryTeachCourse(function () {
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        // $ionicScrollDelegate.scrollTop();
                        $ionicLoading.hide();
                    });
                };
            }
        }

        /**
         * 消息填写
         */
        $scope.intCourseWatch = function () {
            $scope.condition.pageNumber = 0;
            $scope.condition.pageSize = 20;
            $scope.queryTeachCourse(function () {
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $ionicScrollDelegate.scrollTop();
                $ionicLoading.hide();
            });
        };

        /**
         * 选中
         * @param item
         */
        $scope.selectCourse = function (item) {
            condition.courseName = item.courseName;
            condition.courseId = item.courseId;
            tkStorageService.setItem("tkBasicInfo", condition);
            if(targetRoute){
                $location.path("/"+targetRoute).search({isChangeTeacher: false});
            }else{
                $location.path("/basic_msg").search({isChangeTeacher: false});
            }
        };

        /**
         * 取消
         */
        $scope.cancelCourse = function () {
            if(targetRoute){
                $location.path("/"+targetRoute).search({isChangeTeacher: false});
            }else{
                $location.path("/basic_msg").search({isChangeTeacher: false});
            }
        };

        $scope.intCourseWatch();
    }

})();
