/**
 * 学期报到
 *
 * @author qiucheng Lu
 * @date 2021年4月15日13:41:41
 */

(function () {
    angular.module('starter')
        .config(config)
        .controller("termReportController", termReportController);

    config.$inject = ['$stateProvider'];

    function config($stateProvider) {
        $stateProvider
        /*学期报到*/
            .state('term_report', {
                url: '/term_report',
                templateUrl: 'templates/report/semester_report.html',
                cache: false,
                data: {
                    prev: 'workspaceForTeacher',
                    title: '学期报到'
                }
            })
    }

    termReportController.$inject = ['$scope', '$http', '$location', 'ynuiNotification', 'storageService', '$ionicModal', '$ionicPopup', '$ionicScrollDelegate'];

    function termReportController($scope, $http, $location, ynuiNotification, storageService, $ionicModal, $ionicPopup, $ionicScrollDelegate) {
        // 路由信息
        var basePath = originBaseUrl + "/third/bdglMobileReport";

        var classId = $location.search().classId;

        $scope.showDetailInfo = null;
        $scope.showFlagInfo = null;
        // 默认选中全部
        $scope.tableView = null;
        // 班级搜索 默认否
        $scope.searchFlag = false;
        // 学生搜索条件
        $scope.stuSearch = {name: ""};

        $scope.sortList = [
            {name: 'A', selected: false}, {name: 'B', selected: false}, {name: 'C', selected: false},
            {name: 'D', selected: false}, {name: 'E', selected: false}, {name: 'F', selected: false},
            {name: 'G', selected: false}, {name: 'H', selected: false}, {name: 'I', selected: false},
            {name: 'J', selected: false}, {name: 'K', selected: false}, {name: 'L', selected: false},
            {name: 'M', selected: false}, {name: 'N', selected: false}, {name: 'O', selected: false},
            {name: 'P', selected: false}, {name: 'Q', selected: false}, {name: 'R', selected: false},
            {name: 'S', selected: false}, {name: 'T', selected: false}, {name: 'U', selected: false},
            {name: 'V', selected: false}, {name: 'W', selected: false}, {name: 'X', selected: false},
            {name: 'Y', selected: false}, {name: 'Z', selected: false}
        ];

        $scope.showAllSortList = [];

        // 首字母定位
        $scope.goSort = function (info) {
            // 选中
            angular.forEach($scope.showAllSortList, function (val) {
                if (val.name == info.name) {
                    val.selected = true;
                } else {
                    val.selected = false;
                }
            });

            // 获取定位id
            if ($scope.showDetailList && $scope.showDetailList.length > 0) {
                var id = info.name, flag = false;
                angular.forEach($scope.showDetailList, function (value, index) {
                    if (value.sortName == info.name) {
                        if (!flag) {
                            id += index;
                            flag = true;
                        }
                    }
                });
                // 定位处理
                var selectedTop = $("#" + id).position().top; // 相对父级（list）的位置
                if (selectedTop) {
                    $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0, selectedTop, true);
                }


            }

        };

        // 列表滚动完成事件
        $scope.onScrollComplete = function () {
            var minTop = null, minId = null;
            angular.forEach($scope.showDetailList, function (value, index) {
                // 获取最小的top
                var newId = "#" + value.sortName + index;
                var offsetTop = $(newId).offset().top;
                if (offsetTop > 0) {
                    if (minTop != null) {
                        // 减去绝对位置（顶部距离）84
                        if ((offsetTop - 84) < minTop) {
                            minTop = offsetTop - 84;
                            minId = newId;
                        }
                    } else {
                        minTop = offsetTop - 84;
                        minId = newId;
                    }

                }

            });

            if (minId) {
                // 重新定位
                $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0, $(minId).position().top, true);
                // 重新选择 首字母
                angular.forEach($scope.showAllSortList, function (val) {
                    if (minId.indexOf(val.name) > -1) {
                        val.selected = true;
                    } else {
                        val.selected = false;
                    }
                });
                $scope.$apply($scope.showAllSortList);
            }

        };

        $scope.toSearch = function () {
            $scope.searchFlag = true;
            $scope.showDetailInfo = null;
        };

        // 通知家长 1已报到 2未报到 3全部
        $scope.notifyParents = function (notifyType, reportStatus, classId) {

            var param = {
                setType: 1,
                queryValueType: 5,
                queryValue: $scope.stuSearch.name,
                reportStatus: reportStatus,
                adminClassIds: [classId]
            };
            param.notifyType = notifyType;
            // param.systemId = $yuiLocation.stateParams.systemId;
            // param.menuId = $yuiLocation.stateParams.menuId;
            $http.post(basePath + "/notifyParents.htm", param).success(function (data) {
                if (data.status == 0) {
                    $scope.isInformPatriarch = false;
                    ynuiNotification.success({msg: "操作成功！"});
                    // 刷新数据
                    // $scope.getReportInfo($scope.tableView,$scope.showClass.id);
                } else if (data.status == -1) {
                    ynuiNotification.error({msg: data.message});
                } else {
                    ynuiNotification.error({msg: "操作失败！"});
                }
            });
        };

        // 调整住宿意向为不住宿时是否清空学生床位
        function findSystemPublicConfig() {
            return $http.post(basePath + "/findSystemPublicConfig.htm").success(function (data) {
                if (data.status == 0) {
                    $scope.isStay = data.result.flag;
                    $scope.voList = angular.copy(data.result.voList);
                    if ($scope.voList && $scope.voList.length > 0) {
                        $scope.voList.unshift({name: "请选择住宿意向", id: ""});
                    } else {
                        $scope.voList = [{name: "请选择住宿意向", id: ""}];
                    }
                    return data;
                }
            });
        }

        // 修改住宿意向
        $scope.dormitoryChoose = function (info) {
            storageService.setItem("stuId", info.platformSysUserId);
            $scope.dormitoryInfo = {
                isStay: false,
                stuId: info.platformSysUserId,
                dormitoryType: "",
                dormitoryTypeName: "请选择住宿意向"
            };
            $scope.isStay = false;
            findSystemPublicConfig().then(function () {
                // 获取学生住宿意向
                $http.post(basePath + "/findStudentAccommodation.htm", {stuId: info.platformSysUserId}).success(function (data) {
                    if (data.status == 0) {
                        $scope.dormitoryInfo.isStay = data.result.isStay;
                        if (data.result.id) {
                            $scope.dormitoryInfo.dormitoryType = data.result.id;
                            angular.forEach($scope.voList, function (val) {
                                if (val.id == $scope.dormitoryInfo.dormitoryType) {
                                    $scope.dormitoryInfo.dormitoryTypeName = val.name;
                                }
                            });
                        }
                        $scope.dormitoryInfo.showInfo = data.result.showInfo;
                        $scope.dormitoryInfo.showName = data.result.showName;
                    }
                });
            });

            $ionicPopup.show(studentAccommodationConfig);
        };


        // 未报到弹窗
        var submitPopupConfig = {
            templateUrl: 'templates/report/dialog/noReportReasons.html',
            title: '未报到',
            scope: $scope,
            buttons: [
                {text: '取消'},
                {
                    text: '<b>确定</b>',
                    type: 'button-positive',
                    onTap: function (e) {
                        //
                        $scope.noReport(e);
                    }
                }
            ]
        };

        // 住宿意向弹窗
        var studentAccommodationConfig = {
            templateUrl: 'templates/report/dialog/studentAccommodation.html',
            cssClass:'popup-head-none',
            title: '',
            scope: $scope,
            buttons: [
                {text: '取消'},
                {
                    text: '<b>已报到</b>',
                    type: 'button-positive',
                    onTap: function (e) {

                        var saveInfo = {
                            stuId: storageService.getItemNoDel("stuId"),
                            flag: $scope.isStay,
                            isStay: $scope.dormitoryInfo.isStay,
                            dormitoryType: $scope.dormitoryInfo.dormitoryType
                        };
                        $http.post(basePath + "/updateStudentAccommodation.htm", saveInfo).success(function (data) {
                            if (data.status == 0) {
                                // 修改为已报到
                                $scope.report(saveInfo);
                            } else {
                                e.preventDefault();
                                ynuiNotification.error({msg: "操作失败！"});
                                return false;
                            }
                        });

                    }
                }
            ]
        };

        // 住宿类型样式选中处理
        $scope.getDormitoryInfoActive = function (info) {
            if (info.id == $scope.dormitoryInfo.dormitoryType) {
                return 'active';
            }
        };

        // 住宿类型选中处理
        $scope.getDormitoryInfoSelect = function (info) {
            $scope.dormitoryInfo.dormitoryType = info.id;
            $scope.dormitoryInfo.dormitoryTypeName = info.name;
        };

        // 未报到类型样式选中处理
        $scope.getNoReportReasonsActive = function (info) {
            if (info.id == $scope.reason.noReportCode) {
                return 'active';
            }
        };

        // 未报到类型选中处理
        $scope.getNoReportReasonsSelect = function (info) {
            $scope.reason.noReportCode = info.id;
            $scope.reason.noReportName = info.name;
        };

        // 获取未报到原因
        $scope.getNoReportReasons = function (info) {
            // 批量则初始默认值：不来了
            var userIds = [];
            $scope.reason = {
                customNoReportReason: "",
                noReportCode: "",
                noReportName: "请选择",
                remark: ""
            };
            if (info) {
                userIds.push(info.platformSysUserId);
                if (info.noReportCode) {
                    if ($scope.noReportReasonsList) {
                        angular.forEach($scope.noReportReasonsList, function (re) {
                            if (re.id == info.noReportCode) {
                                $scope.reason.noReportName = re.name;
                                $scope.reason.noReportCode = re.id;
                            }
                        });
                    }
                }
                $scope.reason.remark = info.remark;
            } else {
                // 只获取待确认的
                angular.forEach($scope.showDetailList, function (item) {
                    if (item.reportStatus == 2) {
                        userIds.push(item.platformSysUserId);
                    }
                });
            }
            storageService.setItem("userIds", userIds);
            $http.post(basePath + "/getNoReportReasons.htm").success(function (data) {
                if (data.status == 0) {
                    $ionicPopup.show(submitPopupConfig);
                    $scope.noReportReasonsList = angular.copy(data.result);
                }
            });
        };


        // 报到
        $scope.report = function (info) {

            if (!info) {
                var confirmPopup = $ionicPopup.confirm({
                    title: "提示",
                    template: "确定将所有待确认的学生设为已报到？",
                    cancelText: "取消",
                    okText: "确定"
                });
                confirmPopup.then(function (flag) {
                    if (flag) {

                        var userIds = [];

                        // 只获取待确认的
                        angular.forEach($scope.showDetailList, function (item) {
                            if (item.reportStatus == 2) {
                                userIds.push(item.platformSysUserId);
                            }
                        });

                        if (userIds.length > 0) {
                            var param = {
                                stuIds: userIds,
                                reportType: 1
                            };
                            $http.post(basePath + "/dealReportRecord.htm", param).success(function (data) {
                                if (data.status == 0) {
                                    $scope.isAffirmReport = false;
                                    ynuiNotification.success({msg: "操作成功！"});
                                    // 刷新数据
                                    $scope.getReportInfo($scope.tableView, $scope.showClass.id);
                                } else {
                                    ynuiNotification.error({msg: "操作失败！"});
                                }
                            });
                        } else {
                            $scope.isAffirmReport = false;
                            ynuiNotification.success({msg: "操作成功！"});
                        }

                    }
                });

            } else {
                var userIds = [];
                // 单个报到
                if (info) {
                    userIds.push(info.stuId);
                }

                if (userIds.length > 0) {
                    var param = {
                        stuIds: userIds,
                        reportType: 1
                    };
                    $http.post(basePath + "/dealReportRecord.htm", param).success(function (data) {
                        if (data.status == 0) {
                            $scope.isAffirmReport = false;
                            ynuiNotification.success({msg: "操作成功！"});
                            // 刷新数据
                            $scope.getReportInfo($scope.tableView, $scope.showClass.id);
                        } else {
                            ynuiNotification.error({msg: "操作失败！"});
                        }
                    });
                } else {
                    $scope.isAffirmReport = false;
                    ynuiNotification.success({msg: "操作成功！"});
                }
            }


        };

        // 未报到
        $scope.noReport = function (e) {
            var userIds = storageService.getItemNoDel("userIds");
            if (userIds && userIds.length > 0) {
                var param = {
                    stuIds: userIds,
                    customNoReportReason: $scope.reason.customNoReportReason,
                    noReportCode: $scope.reason.noReportCode,
                    remark: $scope.reason.remark,
                    reportType: 1
                };
                if (!param.noReportCode) {
                    e.preventDefault();
                    ynuiNotification.error({msg: "请选择未报到原因！"});
                    return false;
                }
                $http.post(basePath + "/dealNotReportRecord.htm", param).success(function (data) {
                    if (data.status == 0) {
                        $scope.isAffirmReport = false;
                        ynuiNotification.success({msg: "操作成功！"});
                        // 刷新数据
                        $scope.getReportInfo($scope.tableView, $scope.showClass.id);
                    } else {
                        e.preventDefault();
                        ynuiNotification.error({msg: "操作失败！"});
                        return false;
                    }
                });
            }

        };


        // 取消搜索
        $scope.cancelSearch = function (reportStatus, classId) {
            $scope.searchFlag = false;
            $scope.stuSearch = {name: ""};
            $scope.showAllSortList = [];
            $scope.getReportInfo(reportStatus, classId);
        };

        // 清除搜索条件
        $scope.clearSearch = function (reportStatus, classId) {
            $scope.stuSearch = {name: ""};
            $scope.getReportInfo(reportStatus, classId)
        };

        // 获取班主任负责的报到任务的状态
        $scope.getReportTaskStateWithHeadmaster = function () {
            $http.post(basePath + "/getReportTaskStateWithHeadmaster.htm", {reportType: 1}).success(function (data) {
                if (data.status == 0) {
                    $scope.showFlagInfo = angular.copy(data.result);
                    $scope.termTipFlag = true;
                    if ($scope.showFlagInfo.isAllowReport && $scope.showFlagInfo.isExistsCurrentTerm) {
                        $scope.getDropDownOptions();
                    }

                } else {
                    ynuiNotification.error({msg: "获取班主任负责的报到任务的状态失败！"});
                }
            });
        };

        // 获取班级下拉值
        $scope.getDropDownOptions = function () {
            $http.post(basePath + "/getDropDownOptions.htm", {bdglReportType: 1}).success(function (data) {
                if (data.status == 0) {
                    $scope.showClassList = angular.copy(data.result.reportClass);
                    // 默认第一个班级
                    if ($scope.showClassList && $scope.showClassList.length > 0) {
                        angular.forEach($scope.showClassList, function (vo) {
                            vo.name = (vo.name + "(" + vo.studentNumber + "人)");
                        });
                        $scope.showDetailList = [];
                        if (null != classId) {
                          angular.forEach($scope.showClassList, function (vo) {
                              if (vo.id === classId) {
                                  $scope.showClass = vo;
                              }
                          });
                        } else {
                            $scope.showClass = $scope.showClassList[0];
                        }
                        $scope.getReportInfo(null, $scope.showClass.id);
                    }
                    window.setTimeout(function () {
                        $scope.classTipFlag = true;
                    }, 150);
                } else {
                    ynuiNotification.error({msg: "获取班级失败！"});
                }
            });
        };

        // 获取列表数据
        $scope.getReportInfo = function (reportStatus, classId, flag) {
            var searchInfo = {
                setType: 1,
                queryValueType: 5,
                queryValue: $scope.stuSearch.name,
                reportStatus: reportStatus,
                adminClassIds: [classId]
            };
            $http.post(basePath + "/getReportInfo.htm", searchInfo).success(function (data) {
                if (data.status == 0) {
                    $scope.showDetailInfo = angular.copy(data.result);
                    $scope.showDetailList = angular.copy(data.result.reportStuInfoVOList);
                    $scope.showDetailInfo.notReportNum = $scope.showDetailInfo.notReportNum - $scope.showDetailInfo.waitConfirmReportNum;
                    if ($scope.showDetailList && $scope.showDetailList.length > 0) {
                        var allSortList = [], allSort = [];
                        angular.forEach($scope.showDetailList, function (info) {
                            // 姓名显示 姓名+学号
                            var showName = info.stuName;
                            if (info.number) {
                                showName += "(" + info.number + ")";
                            }
                            info.showName = showName;

                            if (info.headUrl) {
                                info.headUrl = originBaseUrl + "/file/downloadStream.htm?fastDFSId=" + info.headUrl;
                            }

                            if (allSort.indexOf(info.sortName) == -1) {
                                allSort.push(info.sortName);
                                allSortList.push({name: info.sortName, selected: false});
                            }

                            // 统计人数
                            if (info.reportStatus == 2) {
                                info.reportStatusDesc = '待确认';
                            }
                        });
                        if (allSortList.length > 0) {
                            $scope.showAllSortList = allSortList;
                            // 切换处理
                            if (flag) {
                                window.setTimeout(function () {
                                    $scope.goSort($scope.showAllSortList[0]);
                                }, 500);
                            }
                        } else {
                            $scope.showAllSortList = [];
                        }
                    } else {
                        $scope.showAllSortList = [];
                    }


                } else {
                    ynuiNotification.error({msg: "获取数据失败！"});
                }
            });
        };

        // 获取班级选中样式
        $scope.getActive = function (info) {
            if (info.id === $scope.showClass.id) {
                return 'active';
            }
        };

        // 获取选中班级
        $scope.getSelect = function (info) {
            $scope.showClass = info;
            $scope.getReportInfo($scope.tableView, $scope.showClass.id);
        };

        //table切换
        $scope.getActiveTable = function (type) {
            $scope.tableView = type;
            $scope.getReportInfo(type, $scope.showClass.id, true);
            $scope.isInformPatriarch = false;
            $scope.isAffirmReport = false;
        };

        //获取table选中样式
        $scope.getClassTable = function (type) {
            if (type == $scope.tableView) {
                return 'tab-item active';
            } else {
                return 'tab-item'
            }
        };

        $scope.getStatusClass = function (status) {
            if (status == 0) {
                return 'button-label margin-left-10';
            } else if (status == 1) {
                return 'label-orange button-label margin-left-10';
            } else if (status == 2) {
                return 'label-yellow button-label margin-left-10';
            }
        };


        // 初始化数据
        $scope.initData = function () {
            $scope.getReportTaskStateWithHeadmaster();
        };

        $scope.initData();


        $scope.informPatriarchClick = function () {
            $scope.isInformPatriarch = !$scope.isInformPatriarch;
            $scope.isAffirmReport = false;
        };

        $scope.affirmReportClick = function () {
            $scope.isAffirmReport = !$scope.isAffirmReport;
            $scope.isInformPatriarch = false;
        };


    }
})();










