(function () {
    'use strict';

    angular
        .module('starter')
        .config(config)
        .controller('stuInfoCtrl', stuInfoCtrl)
        .controller('stuInfoModifyCtrl', stuInfoModifyCtrl);

    config.$inject = ['$stateProvider'];

    function config($stateProvider) {

        $stateProvider
            // 学籍信息查看
            .state('stuInfo', {
                firstPage: true,
                url: '/stu/info',
                templateUrl: 'templates/stuInfo/stuInfo.html',
                data: {
                    micro: true,
                    title: '学籍信息'
                },
                controller: 'stuInfoCtrl',
                controllerAs: 'vm'
            })
            // 修改
            .state('modify', {
                url: '/stu/info/modify?taskId&headUrl',
                templateUrl: 'templates/stuInfo/stuInfoModify.html',
                data: {
                    title: '学籍信息',
                    prev: 'stuInfo'
                },
                controller: 'stuInfoModifyCtrl',
                controllerAs: 'vm'
            });
    }

    stuInfoCtrl.$inject = ['$scope', '$http', '$ionicPopup', '$state', '$ionicScrollDelegate', '$sce', '$ionicModal',
        'storageService', '$filter'];

    /**
     * 学籍信息
     */
    function stuInfoCtrl($scope, $http, $ionicPopup, $state, $ionicScrollDelegate, $sce, $ionicModal, storageService, $filter) {

        var vm = this;

        vm.originBaseUrl = originBaseUrl;
        vm.tab = '1';

        vm.switchTab = switchTab;
        vm.familyPropertiesShow = familyPropertiesShow;
        vm.toModify = toModify;
        vm.toCollect = toCollect;
        vm.showTaskModal = showTaskModal;
        vm.revoke = revoke;

        vm.previewPhoto = previewPhoto;
        vm.showData = showData;

        vm.toTop = false;
        vm.onScroll = onScroll;
        vm.scrollMainToTop = scrollMainToTop;

        findStuTask().success(function (data) {
            var contentTop = 110;
            var isShowTaskModal = false;
            if (null != data.result) {
                vm.tasks = data.result;
                if (vm.tasks.length > 0) {
                    contentTop += 49;
                }
                angular.forEach(vm.tasks, function (t) {
                    if (t.checkStatus === 2 || t.checkStatus === 3) {
                        isShowTaskModal = true;
                    }
                });
            }
            vm.contentStyle = {'margin-top': contentTop + 'px'};
            findStuInfo(0).then(function () {
                if (isShowTaskModal) {
                    setTimeout(function () {
                        showTaskModal();
                    }, 100);
                }
                // 处理问题
                angular.forEach(vm.stuFamilyMemberVOList, function (member) {
                    // 自定义字段
                    if (member.stuCustomFieldVOList && member.stuCustomFieldVOList.length > 0) {
                        angular.forEach(member.stuCustomFieldVOList, function(f) {
                            if (f.platformCommonDictionaryVOList && f.platformCommonDictionaryVOList.length > 0) {
                                var v = member[f.memberName];
                                angular.forEach(f.platformCommonDictionaryVOList, function (dict) {
                                    if (dict.dictCode === v) {
                                        v = dict.dictName;
                                    }
                                });
                                member[f.memberName] = v;
                            }
                        });
                    }
                });
            });
        });

        findFamilyProperties().success(function (data) {
            vm.familyProperties = data.result;
        });

        function switchTab(tab) {
            if (tab === vm.tab) {
                return false;
            }
            if ('3' === tab && null == vm.files) {
                // 查询照片/附件
                findStuFile().success(function () {
                    $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                });
            }
            else if ('4' === tab && null == vm.changeList) {
                // 查询学籍异动信息
                findStuChange().success(function () {
                    $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                });
            }
            else {
                $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
            }
            vm.tab = tab;
        }

        function onScroll() {
            var obj = $ionicScrollDelegate.$getByHandle('mainScroll').getScrollPosition();
            var scrollHeight = angular.element('.scroll .row .col .examine-list-wrap').height();
            var contentHeight = angular.element('.content-top-70').height();
            vm.toTop = scrollHeight - contentHeight - obj.top < 50;
            $scope.$apply();
        }

        function scrollMainToTop() {
            if (vm.toTop) {
                $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
            } else {
                $ionicScrollDelegate.$getByHandle('mainScroll').scrollBottom(true);
            }
        }

        function findStuInfo(type) {
            return $http.get(originBaseUrl + '/third/xj/stu/info.htm', {
                params: {
                    userStatus: type
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.platformSysUserVO = data.result.platformSysUserVO;
                    vm.baseInfo = data.result.stuBaseInfoVO;
                    vm.archivesInfo = data.result.stuArchivesInfoVO;
                    vm.zsAdmissionInfoVO = data.result.zsAdmissionInfoVO;
                    vm.stuSubsidizeInfoVO = data.result.stuSubsidizeInfoVO;
                    vm.stuContactWayInfoVO = data.result.stuContactWayInfoVO;
                    vm.stuFamilyInfoVO = data.result.stuFamilyInfoVO;
                    vm.stuFamilyMemberVOList = data.result.stuFamilyMemberVOList;
                    vm.platformSysAdminClassVO = data.result.platformSysAdminClassVO;
                    // 经历信息
                    vm.stuLearnExperienceUncheckVOList = data.result.stuLearnExperienceUncheckVOList;
                    vm.stuWorkExperienceUncheckVOList = data.result.stuWorkExperienceUncheckVOList;
                    vm.stuProjectExperienceUncheckVOList = data.result.stuProjectExperienceUncheckVOList;
                    vm.stuInternshipExperienceUncheckVOList = data.result.stuInternshipExperienceUncheckVOList;
                }
            });
        }

        function findStuChange() {
            return $http.get(originBaseUrl + '/third/xj/stu/info/change.htm').success(function (data) {
                if (0 === data.status) {
                    vm.changeList = data.result;
                }
            });
        }

        function findStuFile() {
            return $http.get(originBaseUrl + '/third/xj/stu/info/file.htm', {
                params: {
                    code: 1,
                    operType: 1,
                    businessKeyType: 0
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.files = data.result.materialStuInClassifyList;
                    vm.filesShow = true;
                    angular.forEach(vm.files, function (file) {
                        if (null != file.dictClassifyList) {
                            file.fsIdList = [];
                            angular.forEach(file.dictClassifyList, function (d) {
                                if (null != d.fsId) {
                                    file.fsIdList.push(d.fsId);
                                }
                            });
                            if (0 === file.fsIdList.length) {
                                file.fsIdList = null;
                            }
                        }
                        if (null != file.fsIdList && vm.filesShow) {
                            vm.filesShow = false;
                        }
                    });
                }
            });
        }

        function findStuTask() {
            return $http.get(originBaseUrl + '/third/xj/stu/task.htm')
              .success(function (data) {
                  return data.result;
              });
        }

        function taskRevoke(taskId, userId) {
            return $http.post(originBaseUrl + '/third/xj/stu/task/revoke.htm', {
                taskId: taskId,
                platformSysUserId: userId
            }).success(function (data) {
                return data.result;
            });
        }

        function findFamilyProperties() {
            return $http.get(originBaseUrl + '/third/xj/stu/findFamilyProperties.htm')
              .success(function (data) {
                  if (data.status === 0) {
                      return data.result;
                  }
              });
        }

        function familyPropertiesShow(item) {
            if (null != vm.familyProperties) {
                return $filter('filter')(vm.familyProperties, {memberName: item}).length > 0;
            }
            return true;
        }

        function showTips(template) {
            $ionicPopup.confirm({
                title: '提示',
                template: template,
                buttons: [
                    {text: '忽略'},
                    {
                        text: '立即前往', type: 'button-positive', onTap: function () {
                            toModify();
                        }
                    }
                ]
            });
        }

        function toModify(taskId) {
            vm.taskModal.hide().then(function () {
                var obj = {
                    baseInfoId: vm.baseInfo.id,
                    platformSysUserId: vm.baseInfo.platformSysUserId,
                    headUrl: vm.baseInfo.headUrl,
                    name: vm.baseInfo.name,
                    gender: vm.baseInfo.gender,
                    genderName: vm.baseInfo.genderName,
                    platformAdminClassName: vm.archivesInfo.platformSysAdminClassVO ? vm.archivesInfo.platformSysAdminClassVO.name : '未分班'
                };
                storageService.setItem('xj_stuShowObj', obj);
                $state.go('modify', {
                    taskId: taskId,
                    headUrl: vm.baseInfo.headUrl
                });
            });
        }

        function toCollect() {
          // 跳转人脸照片采集
          yn.plugin.yncordova.nativeStart({
              target: '210'
          });
        }

        vm.taskModal = null;

        function showTaskModal() {
            if (null == vm.taskModal) {
                $ionicModal.fromTemplateUrl('tasks-modal.html', {
                    scope: $scope,
                    animation: 'slide-in-left'
                }).then(function (modal) {
                    vm.taskModal = modal;
                    vm.taskModal.show();
                });
            } else {
                vm.taskModal.show();
            }
        }

        function revoke(taskId) {
            var callback = function() {
                taskRevoke(taskId, vm.platformSysUserVO.id)
                  .success(function (data) {
                      if (data.status === 0) {
                          $ionicPopup.confirm({
                              title: '提示',
                              template: '操作成功！是否需要立即修改？',
                              buttons: [{
                                  text: '取消',
                                  onTap: function () {
                                      findStuTask()
                                        .success(function (data) {
                                            if (data.status === 0) {
                                                vm.tasks = data.result;
                                            }
                                        });
                                  }
                              }, {
                                  text: '确定', type: 'button-positive',
                                  onTap: function () {
                                      toModify(taskId);
                                  },
                              }]
                          });
                      }
                  });
            };
            $ionicPopup.confirm({
                title: '提示',
                template: '确定要撤回已提交审核的数据吗？',
                buttons: [{
                    text: '取消'
                }, {
                    text: '确定', type: 'button-positive',
                    onTap: function () {
                        callback();
                    }
                }]
            });
        }

        function previewPhoto(fsId) {
            var url = vm.originBaseUrl + '/third/file/download.htm?fileId=' + fsId;
            var cordovaFileOpen = cordova.plugins.disusered.open;
            cordovaFileOpen(url, cordovaFileOpenSuccess, cordovaFileOpenError);

            function cordovaFileOpenSuccess() {
                // 从已安装程序中打开文件完成
            }

            function cordovaFileOpenError(code) {
                if (1 === code) {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '未能在手机已安装APP中找到可预览此文件的程序',
                        okText: '确定'
                    });
                } else {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '预览时发生了未知错误 #' + code,
                        okText: '确定'
                    });
                }
            }
        }

        function showData(obj, property) {
            if (obj) {
                var properties = property.split('.');
                var value = angular.copy(obj);
                var spe = false;
                if (property.indexOf('reserveCol') === 0) {
                    angular.forEach(value.stuCustomFieldVOList, function (v) {
                        if (v.belongType === 2 && v.controlType === 4 && v.referenceType === 1) {
                            var dictCodes = value[property].split(',');
                            var names = [];
                            angular.forEach(dictCodes, function (code) {
                                angular.forEach(v.platformCommonDictionaryVOList, function (d) {
                                    if (d.dictCode === code) {
                                        names.push(d.dictName);
                                    }
                                });
                            });
                            if (names.length > 0) {
                                spe = true;
                                value = names.join('、');
                            }
                        }
                    });
                }
                if (!spe) {
                    angular.forEach(properties, function (p) {
                        value = value[p];
                    });
                }
                // 特殊处理推荐人
                if ('outerPresenter' === property && null == value) {
                    value = obj.innerPresenterName;
                }
                if (null != value && '' !== value) {
                    return $sce.trustAsHtml('<p style="white-space: normal">' + value + '</p>');
                } else {
                    return $sce.trustAsHtml('<p style="white-space: normal; color: lightgrey;">未录入</p>');
                }
            }
        }
    }

    stuInfoModifyCtrl.$inject = ['$scope', '$http', '$ionicPopup', '$rootScope', '$ionicModal', '$timeout',
        '$interval', 'stringsConstant', '$cordovaFileTransfer', '$ionicScrollDelegate', '$state', '$stateParams',
        'ynuiNotification', '$sce', '$filter', 'ynNavigator', 'storageService', '$ionicLoading'];
    //学籍修改
    function stuInfoModifyCtrl(
        $scope, $http, $ionicPopup, $rootScope, $ionicModal, $timeout, $interval, stringsConstant,
        $cordovaFileTransfer, $ionicScrollDelegate, $state, $stateParams, ynuiNotification, $sce, $filter,
        ynNavigator, storageService, $ionicLoading) {

        var vm = this;

        vm.removeModal = removeModal;

        vm.areaSelector = areaSelector;
        vm.customCheckBoxSelect = customCheckBoxSelect;
        vm.doSave = doSave;
        vm.nextStep = nextStep;
        vm.editFamily = editFamily;
        vm.deleteFamily = deleteFamily;
        vm.saveFamily = saveFamily;
        vm.changeRelationship = changeRelationship;

        vm.showSubmitFileModal = showSubmitFileModal;
        vm.takePhoto = takePhoto;
        vm.takePicture = takePicture;
        vm.deletePhoto = deletePhoto;

        vm.rotate = rotate;
        vm.confirmCropper = confirmCropper;
        vm.cancelCropper = cancelCropper;

        vm.showPrevStep = showPrevStep;
        vm.showNextStep = showNextStep;
        vm.showSubmitButton = showSubmitButton;

        vm.originBaseUrl = originBaseUrl;
        vm.tab = 1;
        vm.showTabOne = false;
        vm.showTabTwo = false;
        vm.showTabThree = false;
        vm.showTabFour = false;

        // 学生信息
        vm.stuShowObj = storageService.getItemNoDel('xj_stuShowObj');
        vm.headUrl = $stateParams.headUrl;
        // 走查看页面传进来
        vm.taskId = $stateParams.taskId;

        initModal('modal', 'edit-family.html');
        initModal('fileModal', 'submit-file.html');
        initModal('cropperModal', 'cropper.html');
        initModal('markModal', 'mark.html');

        // 个人经历
        initModal('learnModal', 'learn.html');
        initModal('workModal', 'work.html');
        initModal('projectModal', 'project.html');
        initModal('internshipModal', 'internship.html');

        function initModal(obj, url) {
            return $ionicModal.fromTemplateUrl(url, {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                vm[obj] = modal;
            });
        }

        function removeModal(obj, url) {
            vm[obj].remove().then(function () {
                initModal(obj, url);
            });
        }

        vm.timeOnSelect = timeOnSelect;

        function timeOnSelect(item, obj, key) {
            setTimeout(function () {
                obj[key] = item + ':00';
                $scope.$apply();
            });
        }

        vm.familyPropertiesShow = familyPropertiesShow;

        // *  1：基本信息
        // *  2：学籍信息
        // *  3：招生信息
        // *  4：联系方式
        // *  5：附件信息
        // *  6：家庭信息
        // *  7：资助信息
        // *  8：家庭成员信息
        // *  9：学习经历
        // * 10：工作经历
        vm.propertyTypes = [
            {name: '基本信息', id: 1, value: 'baseInfo', properties: []},
            {name: '学籍信息', id: 2, value: 'archivesInfo', properties: []},
            {name: '招生信息', id: 3, value: 'zsAdmissionInfoVO', properties: []},
            {name: '联系方式', id: 4, value: 'stuContactWayInfoVO', properties: []},
            {name: '附件信息', id: 5, value: 'baseInfo', properties: []},
            {name: '家庭信息', id: 6, value: 'stuFamilyInfoVO', properties: []},
            {name: '资助信息', id: 7, value: 'stuSubsidizeInfoVO', properties: []},
            {name: '家庭成员信息', id: 8, value: 'stuFamilyMemberVOList', properties: []},
            {name: '学习经历', id: 9, value: 'baseInfo', properties: []},
            {name: '工作经历', id: 10, value: 'baseInfo', properties: []},
            {name: '自定义', id: 11, value: 'custom', properties: []}
        ];

        vm.birthTypes = [{id: 0, value: '公历'}, {id: 1, value: '农历'}];
        vm.options = [{id: true, name: "是"}, {id: false, name: "否"}];

        init();

        function init() {
            // 如果没有数据，后台重新查询学生信息
            if (null == vm.stuShowObj) {
                $http.get(originBaseUrl + '/third/xj/stu/simple/info.htm')
                  .success(function (data) {
                      if (data.status === 0) {
                          vm.stuShowObj = data.result;
                      }
                  });
            }
            findStuTask().success(function (data) {
                if ((data.status === -1 || 0 === data.status) && null == data.result) {
                    // 没有任务或者任务关闭超时了，回到查看页面
                    $ionicPopup.alert({
                        title: '提示',
                        template: '任务已关闭，不能修改学籍信息',
                        okText: '确定',
                    }).then(function () {
                        $state.go('stuInfo');
                    });
                } else {
                    // 需要修改的字段
                    getStuProperties(vm.taskVO.id).success(function () {
                        // 空对象代表没有基本信息字段需要修改，所以不显示“修改基本资料”tab
                        if ('{}' === angular.toJson(vm.modifyProperties)) {
                            if (vm.showTabTwo) {
                                vm.tab = 2;
                                findFamilyMember(vm.taskVO.id).then(function () {
                                    // 字典
                                    getDictionary();
                                });
                            } else if (vm.showTabThree) {
                                vm.tab = 3;
                                findStuFiles(vm.taskVO.id);
                            } else {
                                vm.tab = 4;
                                findStuExperience(vm.taskVO.id);
                            }
                        } else {
                            vm.showTabOne = true;
                            // 不是空的代表需要修改基本资料
                            findStuBaseInfo(vm.taskVO.id).then(function () {
                                setTimeout(function () {
                                    // 字典
                                    getDictionary();
                                    // 需要修改生源地，才去查询
                                    if (vm.modifyProperties && vm.modifyProperties.hasOwnProperty('zsStudentSourceId')) {
                                        getStudentSources();
                                    }
                                }, 500);
                            });
                        }
                    });
                }
            });
            findFamilyProperties().success(function (data) {
                if (data.status === 0) {
                    vm.familyProperties = data.result;
                }
            });
        }

        function findStuTask() {
            return $http.get(originBaseUrl + '/third/xj/stu/info/task.htm', {
                params: {
                    taskId: vm.taskId
                }
            }).success(function (data) {
                if (0 === data.status && null != data.result) {
                    vm.taskVO = angular.fromJson(data.result.taskVO);
                    console.log(vm.taskVO);
                    vm.checkStatus = data.result.checkStatus;
                    if ('0' === vm.taskVO.isAdd || '0' === vm.taskVO.isUpdate || '0' === vm.taskVO.isDelete) {
                        vm.showTabTwo = true;
                    }
                    // 采集资料
                    if (vm.taskVO.materialAddVO && null != vm.taskVO.materialAddVO.needMaterial) {
                        vm.showTabThree = vm.taskVO.materialAddVO.needMaterial;
                    }
                    // 经历
                    if (vm.taskVO.internshipAdd || vm.taskVO.internshipDel || vm.taskVO.internshipEdit) {
                        vm.showTabFour = true;
                    }
                    if (vm.taskVO.projectAdd || vm.taskVO.projectDel || vm.taskVO.projectEdit) {
                        vm.showTabFour = true;
                    }
                    if (vm.taskVO.studyAdd || vm.taskVO.studyDel || vm.taskVO.studyEdit) {
                        vm.showTabFour = true;
                    }
                    if (vm.taskVO.workAdd || vm.taskVO.workDel || vm.taskVO.workEdit) {
                        vm.showTabFour = true;
                    }
                }
                return data;
            });
        }

        function findStuBaseInfo(taskId) {
            return $http.get(originBaseUrl + '/third/xj/stu/modify/base_info.htm', {
                params: {
                    taskId: taskId
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.platformSysUserVO = data.result.platformSysUserVO;
                    vm.baseInfo = data.result.stuBaseInfoVO;
                    vm.archivesInfo = data.result.stuArchivesInfoVO;
                    vm.zsAdmissionInfoVO = data.result.zsAdmissionInfoVO;
                    vm.stuSubsidizeInfoVO = data.result.stuSubsidizeInfoVO;
                    vm.stuContactWayInfoVO = data.result.stuContactWayInfoVO;
                    vm.stuFamilyInfoVO = data.result.stuFamilyInfoVO;
                    // vm.platformSysAdminClassVO = data.result.platformSysAdminClassVO;
                    // 学生自定义字段
                    if (null != vm.baseInfo.stuCustomFieldVOList) {
                        vm.stuCustomFiled = vm.baseInfo.stuCustomFieldVOList;
                    }
                    // 处理手机号
                    if (vm.stuContactWayInfoVO.mobile) {
                        vm.baseInfo.mobile = vm.stuContactWayInfoVO.mobile;
                    }
                }
                return data;
            });
        }

        function findFamilyMember(taskId) {
            return $http.get(originBaseUrl + '/third/xj/stu/modify/member.htm', {
                params: {
                    taskId: taskId
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.stuFamilyMemberVOList = data.result.stuFamilyMemberVOList;
                    vm.stuCustomFieldVOList = data.result.stuCustomFieldVOList;
                    // 处理家庭成员的自定义字段
                    angular.forEach(vm.stuCustomFieldVOList, function (value) {
                        if (value.notNull) {
                            vm.notNullPropertiesFamily[value.memberName] = true;
                        }
                    });
                }
                return data;
            });
        }

        function findFamilyProperties() {
            return $http.get(originBaseUrl + '/third/xj/stu/findFamilyProperties.htm')
              .success(function (data) {
                  if (data.status === 0) {
                      return data.result;
                  }
              });
        }

        function familyPropertiesShow(item) {
            if (null != vm.familyProperties) {
                return $filter('filter')(vm.familyProperties, {memberName: item}).length > 0;
            }
            return true;
        }

        function findStuFiles(taskId) {
            return $http.get(originBaseUrl + '/third/xj/stu/modify/files.htm', {
                params: {
                    taskId: taskId
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.stuFiles = data.result.platformBusinessMaterialShowVO.materialStuInClassifyList;
                    // 不再处理没fs_id的数据
                    // angular.forEach(vm.stuFiles, function (f) {
                    //     if (null == f.dictClassifyList || 0 === f.dictClassifyList.length) {
                    //         var i;
                    //         for (i = 0; i < f.fsIdList.length; i++) {
                    //             if (null == f.fsIdList[i]) {
                    //                 f.fsIdList.splice(i, 1);
                    //                 i -= 1;
                    //             }
                    //         }
                    //         for (i = 0; i < f.picStuInfo.length; i++) {
                    //             if (null == f.picStuInfo[i].fsId) {
                    //                 f.picStuInfo.splice(i, 1);
                    //             }
                    //         }
                    //     }
                    // });
                    if (null == vm.stuFiles) {
                        vm.showTabThree = false;
                    }
                }
                return data;
            });
        }

        function findStuExperience(taskId) {
            return $http.get(originBaseUrl + '/third/xj/stu/modify/experience.htm', {
                params: {
                    taskId: taskId
                }
            }).success(function(data) {
                if (0 === data.status) {
                    // 经历信息
                    if (null == vm.stuLearnExperienceUncheckVOList) {
                        vm.stuLearnExperienceUncheckVOList = data.result.stuLearnExperienceUncheckVOList;
                    }
                    if (null == vm.stuWorkExperienceUncheckVOList) {
                        vm.stuWorkExperienceUncheckVOList = data.result.stuWorkExperienceUncheckVOList;
                    }
                    if (null == vm.stuProjectExperienceUncheckVOList) {
                        vm.stuProjectExperienceUncheckVOList = data.result.stuProjectExperienceUncheckVOList;
                    }
                    if (null == vm.stuInternshipExperienceUncheckVOList) {
                        vm.stuInternshipExperienceUncheckVOList = data.result.stuInternshipExperienceUncheckVOList;
                    }
                }
            });
        }

        function getStuProperties(taskId) {
            return $http.get(originBaseUrl + '/third/xj/stu/info/properties.htm', {
                params: {
                    taskId: taskId
                }
            }).success(function (data) {
                if (0 === data.status) {
                    // 处理字段
                    vm.allProperties = {};
                    vm.allPropertiesFamily = {};
                    vm.modifyProperties = {};
                    vm.modifyPropertiesFamily = {};
                    vm.notNullProperties = {};
                    vm.notNullPropertiesFamily = {};
                    vm.notNullPropertiesArr = [];
                    angular.forEach(data.result.collection, function (value) {
                        if (!value.stuFieldControl) {
                            value.stuFieldControl = null;
                        }
                        if (value.stuFieldControl && value.stuFieldControl.isShow) {
                            // belongType * 1：基本信息字段 * 2：家庭成员字段
                            if (2 !== value.stuFieldControl.belongType) {
                                vm.allProperties[value.stuFieldControl.memberName] = value.stuFieldControl;
                                vm.modifyProperties[value.stuFieldControl.memberName] = true;
                                if (value.stuFieldControl.notNull) {
                                    vm.notNullPropertiesArr.push(value.stuFieldControl);
                                    vm.notNullProperties[value.stuFieldControl.memberName] = true;
                                    // 特殊处理
                                    if ('credentialType' === value.stuFieldControl.memberName) {
                                        vm.notNullProperties.credentialNumber = true;
                                    }
                                }
                                if (value.stuFieldControl.isDefault) {
                                    vm.propertyTypes[value.stuFieldControl.belongModule - 1].properties.push(value.stuFieldControl);
                                } else {
                                    vm.propertyTypes[vm.propertyTypes.length - 1].properties.push(value.stuFieldControl);
                                }
                            } else {
                                vm.allPropertiesFamily[value.stuFieldControl.memberName] = value.stuFieldControl;
                                vm.modifyPropertiesFamily[value.stuFieldControl.memberName] = true;
                                if (value.stuFieldControl.notNull) {
                                    vm.notNullPropertiesFamily[value.stuFieldControl.memberName] = true;
                                }
                            }
                        }
                    });
                }
                return data;
            });
        }

        function getDictionary() {
            return $http.get(originBaseUrl + '/third/xj/stu/dictionary.htm').success(function (data) {
                if (0 === data.status) {
                    // 基本信息
                    vm.genderList = data.result[0];            // 性别
                    vm.nationList = data.result[1];            // 民族
                    vm.bloodTypeList = data.result[2];         // 血型
                    vm.healthList = data.result[3];            // 健康状况
                    vm.maritalStatusList = data.result[4];     // 婚姻状况
                    vm.politicalStatusList = data.result[5];   // 政治面貌
                    vm.religion = data.result[6];              // 信仰宗教
                    vm.nationalityList = data.result[7];       // 国籍地区
                    vm.chineseTypeList = data.result[8];       // 港澳台地区
                    vm.houseHoldTypeList = data.result[9];     // 户口性质
                    vm.studentLiveType = data.result[10];      // 学生居住地类型
                    vm.credentialTypeList = data.result[11];   // 证件类型
                    // 学籍
                    vm.entranceWay = data.result[12];          // 入学方式
                    vm.admissionsType = data.result[13];       // 招生类型
                    vm.studentSource = data.result[14];        // 学生来源
                    vm.shcoolRoll = data.result[15];           // 学籍状态
                    vm.studentType = data.result[16];          // 学生类别
                    vm.studyingWay = data.result[17];          // 就读方式
                    vm.learnForm = data.result[18];            // 学习形式
                    vm.piecewiseTrainingWay = data.result[19]; // 分段培养方式
                    vm.admissionsWay = data.result[20];        // 招生方式
                    vm.admissionObj = data.result[21];         // 招生对象
                    vm.highestEducation = data.result[22];     // 入学前最高学历
                    vm.jointAdmissionType = data.result[23];   // 联招合作类型
                    vm.jointSchoolForm = data.result[24];      // 联招合作办学形式
                    vm.jointSchoolType = data.result[25];      // 联招合作学校办学类型
                    // 家庭成员信息
                    vm.relationshipList = data.result[26];     // 与本人关系
                    vm.regChannelList = data.result[27];       // 报名渠道
                }
            });
        }

        function getStudentSources() {
            return $http.get(originBaseUrl + '/third/xj/stu/sources.htm').success(function (data) {
                if (0 === data.status) {
                    vm.studentSources = data.result;
                }
            });
        }

        function getAddress(id, tId) {
            return $http.get(originBaseUrl + '/third/xj/stu/address.htm', {
                params: {
                    id: id,
                    tId: tId
                }
            }).success(function (data) {
                return data.result;
            });
        }

        /**
         * 临时保存到 redis，解决字段过多可能丢数据的问题
         */
        function saveTemp(obj) {
            return $http.post(originBaseUrl + '/third/xj/stu/save/temp.htm', parseParamForSpringMVC(obj)).success(function (data) {
                return data;
            });
        }

        function save(obj, successMsg, url, notParseParams) {
            if (null == url) {
                url = 'save'
            }
            return $http.post(
              originBaseUrl + '/third/xj/stu/' + url + '.htm',
              notParseParams ? obj : parseParamForSpringMVC(obj)
            ).success(function (data) {
                if (0 === data.status && data.result && 0 < data.result.length) {
                    var s = "";
                    angular.forEach(data.result, function (value, key) {
                        s += '<li>' + (key + 1) + '、' + value.failedReason + '</li>';
                    });
                    var message = '<ul class="list-unstyled">' + s + '</ul>';
                    $ionicPopup.alert({
                        title: '提示',
                        template: message,
                        okText: '确定'
                    });
                } else if (0 === data.status && null != successMsg) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: successMsg ? successMsg : '操作成功',
                        okText: '确定'
                    });
                } else if (0 !== data.status) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.message,
                        okText: '确定'
                    });
                }
                return data;
            });
        }

        function saveFamilyMember(obj, successMsg) {
            return $http.post(originBaseUrl + '/third/xj/stu/save/member.htm?', parseParamForSpringMVC(obj))
              .success(function (data) {
                  if (data.status === 0) {
                      $ionicPopup.alert({
                          title: '提示',
                          template: successMsg ? successMsg : '操作成功',
                          okText: '确定'
                      });
                  } else {
                      $ionicPopup.alert({
                          title: '提示',
                          template: data.message,
                          okText: '确定'
                      });
                  }
              });
        }

        function provinceData(callback) {
            getAddress().success(function (data) {
                if (0 === data.status && angular.isFunction(callback)) {
                    callback(data.result);
                }
            });
        }

        function cityData(province, callback) {
            getAddress(province).success(function (data) {
                if (0 === data.status && angular.isFunction(callback)) {
                    callback(data.result);
                }
            });
        }

        function districtData(province, city, callback) {
            getAddress(province, city).success(function (data) {
                if (0 === data.status && angular.isFunction(callback)) {
                    callback(data.result);
                }
            });
        }

        function areaSelector(property, obj) {
            new IosSelect(
                3, [provinceData, cityData, districtData], {
                    title: '地区',
                    itemHeight: 50,
                    itemShowCount: 5,
                    showAnimate: true,
                    callback: function (selectOneObj, selectTwoObj, selectThreeObj) {
                        var array = [];
                        array.push(selectOneObj.value);
                        if (-1 === array.indexOf(selectTwoObj.value)) {
                            array.push(selectTwoObj.value);
                        }
                        if (-1 === array.indexOf(selectThreeObj.value)) {
                            array.push(selectThreeObj.value);
                        }
                        obj[property] = array.join("");
                        if (property === "familyHouseholdProvince") {
                            obj[property + "VO"] = {
                                id: selectThreeObj.id
                            }
                        } else {
                            obj[property + 'Id'] = selectThreeObj.id;
                        }
                        $scope.$apply();
                    }
                });
        }

        function customCheckBoxSelect(value, property, obj) {
            var values = [];
            if (vm[obj][property]) {
                values = vm[obj][property].split(',');
            }
            // 不存在添加，存在删除
            if (-1 === values.indexOf(value)) {
                values.push(value);
            } else {
                values.splice(values.indexOf(value), 1);
            }
            vm[obj][property] = values.join(',');
        }

        function getSaveObj(temp, type) {
            // 处理微信号
            if (vm.baseInfo && vm.stuContactWayInfoVO) {
                // vm.platformSysUserVO.wechat = vm.stuContactWayInfoVO.wechat;
                vm.baseInfo.wechat = vm.stuContactWayInfoVO.wechat;
            }
            // 提交的对象
            var obj = {
                platformSysUserVO: type.indexOf(1) >= 0 ? angular.copy(vm.platformSysUserVO) : null,
                // 基本信息(包含自定义信息)
                stuBaseInfoVO: type.indexOf(1) >= 0 ? angular.copy(vm.baseInfo) : null,
                // 学籍信息
                stuArchivesInfoVO: type.indexOf(1) >= 0 ? angular.copy(vm.archivesInfo) : null,
                // 资助信息
                stuSubsidizeInfoVO: type.indexOf(1) >= 0 ? angular.copy(vm.stuSubsidizeInfoVO) : null,
                // 联系信息
                stuContactWayInfoVO: type.indexOf(1) >= 0 ? angular.copy(vm.stuContactWayInfoVO) : null,
                // 家庭信息
                stuFamilyInfoVO: type.indexOf(1) >= 0 ? angular.copy(vm.stuFamilyInfoVO) : null,
                // 家庭成员信息
                stuFamilyMemberVOList: type.indexOf(2) >= 0 ? angular.copy(vm.stuFamilyMemberVOList) : null,
                // 附件信息
                platformBusinessMaterialShowVO: type.indexOf(3) >= 0 ? {
                    businessKey: vm.baseInfo ? vm.baseInfo.id : null,
                    classifyList: vm.stuFiles ? angular.copy(vm.stuFiles) : [],
                    materialTheme: 2
                } : null,
                // 个人经历
                stuLearnExperienceUncheckVOList: type.indexOf(4) >= 0 ? vm.stuLearnExperienceUncheckVOList : null,
                stuWorkExperienceUncheckVOList: type.indexOf(4) >= 0 ? vm.stuWorkExperienceUncheckVOList : null,
                stuProjectExperienceUncheckVOList: type.indexOf(4) >= 0 ? vm.stuProjectExperienceUncheckVOList : null,
                stuInternshipExperienceUncheckVOList: type.indexOf(4) >= 0 ? vm.stuInternshipExperienceUncheckVOList : null,
            }
            // 需要传入状态
            if (!temp) {
                if (type.indexOf(1) >= 0) {
                    if (obj.platformSysUserVO && null == obj.platformSysUserVO.checkStatus) {
                        obj.platformSysUserVO.checkStatus = 3;
                    }
                    if (obj.stuBaseInfoVO && null == obj.stuBaseInfoVO.checkStatus) {
                        obj.stuBaseInfoVO.checkStatus = 3;
                    }
                    if (obj.stuArchivesInfoVO && null == obj.stuArchivesInfoVO.checkStatus) {
                        obj.stuArchivesInfoVO.checkStatus = 3;
                    }
                    if (obj.stuContactWayInfoVO && null == obj.stuContactWayInfoVO.checkStatus) {
                        obj.stuContactWayInfoVO.checkStatus = 3;
                    }
                    if (obj.stuFamilyInfoVO && null == obj.stuFamilyInfoVO.checkStatus) {
                        obj.stuFamilyInfoVO.checkStatus = 3;
                    }
                    if (type.length === 1) {
                        if (obj.stuBaseInfoVO && obj.stuBaseInfoVO.stuCustomFieldVOList) {
                            delete obj.stuBaseInfoVO.stuCustomFieldVOList;
                        }
                        if (obj.stuFamilyMemberVOList) {
                            delete obj.stuFamilyMemberVOList;
                        }
                        if (obj.platformBusinessMaterialShowVO) {
                            delete obj.platformBusinessMaterialShowVO;
                        }
                    }
                }
                if (type.indexOf(2) >= 0) {
                    if (type.length === 1) {
                        delete obj.platformBusinessMaterialShowVO;
                    }
                    angular.forEach(obj.stuFamilyMemberVOList, function (value) {
                        if (1 !== parseInt(value.checkStatus) || 2 !== parseInt(value.checkStatus)) {
                            value.checkStatus = 3;
                        }
                    });
                }
                if (type.indexOf(3) >= 0) {
                    if (type.length === 1) {
                        delete obj.stuFamilyMemberVOList;
                    }
                    // 去掉
                    // if (null != obj.platformBusinessMaterialShowVO) {
                    //     angular.forEach(obj.platformBusinessMaterialShowVO.classifyList, function (c) {
                            // delete c.picStuInfo;
                            // if (null != c.dictClassifyList) {
                            //     angular.forEach(c.dictClassifyList, function (d) {
                            //         delete d.ifPass;
                            //         delete d.noPassReson;
                            //         delete d.massage;
                            //     });
                            // }
                        // });
                    // }
                }
                if (type.indexOf(2) >= 0 || type.indexOf(3) >= 0) {
                    if (type.length === 1) {
                        obj.platformSysUserVO = {
                            id: vm.stuShowObj.platformSysUserId
                        }
                        delete obj.stuArchivesInfoVO;
                        delete obj.stuContactWayInfoVO;
                        delete obj.stuFamilyInfoVO;
                    }
                }
            }
            if (null == obj.stuBaseInfoVO) {
                obj.stuBaseInfoVO = {
                    // id: vm.stuShowObj.baseInfoId,
                    platformSysUserId: vm.stuShowObj.platformSysUserId
                };
            } else {
                // 处理地区
                obj.stuBaseInfoVO.homeTownProvince = obj.stuBaseInfoVO.homeTownProvinceId;
                obj.stuBaseInfoVO.houseHoldProvince = obj.stuBaseInfoVO.houseHoldProvinceId;
                obj.stuBaseInfoVO.birthPlace = obj.stuBaseInfoVO.birthPlaceId;
                // 居住地类型
                obj.stuBaseInfoVO.residenceType = obj.stuBaseInfoVO.residenceCode;
            }
            if (null != obj.stuSubsidizeInfoVO) {
                obj.stuSubsidizeInfoVO.stipendStandard = obj.stuSubsidizeInfoVO.stipendStand;
            }
            return obj;
        }

        function checkNotNull() {
            var objs = ['baseInfo', 'archivesInfo', 'zsAdmissionInfoVO', 'stuContactWayInfoVO', null, 'stuFamilyInfoVO',
                'stuSubsidizeInfoVO'];
            var error = [];
            angular.forEach(objs, function (obj, index) {
                if (null != obj) {
                    var arr = $filter('filter')(vm.notNullPropertiesArr, {belongModule: index + 1});
                    angular.forEach(arr, function (o) {
                        angular.forEach(vm[obj], function (value, key) {
                            var validKey = o.memberName;
                            if (index + 1 === 1) {
                                // 学生居住地类型
                                if (validKey === 'residenceType') {
                                    validKey = 'residenceCode';
                                }
                                // 判断身份证
                                if (validKey === 'credentialType') {
                                    if (null == vm[obj]['credentialNumber'] || '' === vm[obj]['credentialNumber']) {
                                        error.push('credentialNumber');
                                    }
                                }
                            }
                            if (key === validKey && (null == value || '' === value)) {
                                error.push(o.memberName);
                            }
                        });
                    });
                }
            });
            if (0 < error.length) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请填写必填字段，带“*”号的为必填项',
                    okText: '确定'
                });
            }
            return error;
        }

        function saveByStep() {
            // 先保存具体的数据，再修改审核状态
            if (1 === vm.tab) {
                // 保存基本信息
                var obj = getSaveObj(false, [1]);
                obj.taskId = vm.taskVO.id;
                // 存 baseInfo 到 uncheck 表
                return save(obj, null, 'save/base_info', true);
            }
            if (2 === vm.tab) {
                // 保存家庭成员
                var membersObj = getSaveObj(false, [2]);
                membersObj.taskId = vm.taskVO.id;
                return save(membersObj, null, 'save/member');
            }
            if (3 === vm.tab) {
                // 保存附件资料
                var filesObj = getSaveObj(false, [3]);
                filesObj.taskId = vm.taskVO.id;
                return save(filesObj, null, 'save/files');
            }
            if (4 === vm.tab) {
                var experienceObj = getSaveObj(false, [4]);
                experienceObj.taskId = vm.taskVO.id;
                return save(experienceObj, null, 'save/experience');
            }
        }

        function doSave(url) {
            // 判断任务时间
            if (moment(vm.taskVO.endTime).isBefore(moment().now)) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '已错过最后提交时间，系统已自动为你保存当前修改的信息，建议您联系管理员重新提交审核。',
                    okText: '确定'
                });
                return;
            }
            if (1 === vm.tab) {
                if (!checkBaseInfo()) {
                    return;
                }
            }
            if (2 === vm.tab) {
                if (!checkFamilyMember()) {
                    return;
                }
            }
            if (3 === vm.tab) {
                if (!checkFiles()) {
                    return;
                }
            }
            if (4 === vm.tab) {
                if (!checkExperience()) {
                    return;
                }
            }
            function callback(data) {
                if (null != data && data.status === 0) {
                    // 提交为待审核
                    // 清除定时器
                    $interval.cancel(vm.interval);
                    save({taskId: vm.taskVO.id}, null, url).success(function (data) {
                        if (0 === data.status && (null == data.result || 0 === data.result.length)) {
                            $ionicPopup.alert({
                                title: '提示',
                                template: '保存成功！',
                                okText: '确定'
                            }).then(function () {
                                // 提交审核，到上一个页面
                                if ('submit' === url) {
                                    $state.go('stuInfo');
                                }
                            });
                        }
                    });
                }
            }
            saveByStep().success(function (data) {
                if (null == data.result || data.result.length === 0) {
                    callback(data);
                }
            });
        }

        function checkBaseInfo() {
            var error = checkNotNull();
            if (0 < error.length) {
                return false;
            }
            var arr = [
                {
                    show: vm.modifyProperties.height,
                    key: 'vision',
                    value: vm.baseInfo ? vm.baseInfo.height : null
                },
                {
                    show: vm.modifyProperties.weight,
                    key: 'vision',
                    value: vm.baseInfo ? vm.baseInfo.weight : null
                },
                {
                    show: vm.modifyProperties.vision,
                    key: 'vision',
                    value: vm.baseInfo ? vm.baseInfo.vision : null
                },
                {
                    show: vm.modifyProperties.graduatedScore,
                    key: 'graduatedScore',
                    value: vm.archivesInfo ? vm.archivesInfo.graduatedScore : null
                },
                {
                    show: vm.modifyProperties.admissionScores,
                    key: 'vision',
                    value: vm.archivesInfo ? vm.archivesInfo.admissionScores : null
                },
                {
                    show: vm.modifyProperties.stipendStandard,
                    key: 'stipendStandard',
                    value: vm.stuSubsidizeInfoVO ? vm.stuSubsidizeInfoVO.stipendStand : null
                },
                {
                    show: vm.modifyProperties.email,
                    key: 'email',
                    value: vm.stuContactWayInfoVO ? vm.stuContactWayInfoVO.email : null
                },
                {
                    show: vm.modifyProperties.familyMail,
                    key: 'familyMail',
                    value: vm.stuFamilyInfoVO ? vm.stuFamilyInfoVO.familyMail : null
                },
                {
                    show: vm.modifyProperties.credentialType,
                    key: 'credentialNumber',
                    value: vm.baseInfo ? vm.baseInfo.credentialNumber : null
                },
                {
                    show: vm.modifyProperties.mobile,
                    key: 'mobile',
                    value: vm.baseInfo ? vm.baseInfo.mobile : null
                }
            ];
            for (var i = 0; i < arr.length; i++) {
                if (!validProperty(null, arr[i].show, arr[i].key, arr[i].value)) {
                    return false;
                }
            }
            var customFieldCheckObj = {
                // ip
                '1': {
                    reg: new RegExp('^((2(5[0-5]|[0-4]\\d))|[0-1]?\\d{1,2})(\\.((2(5[0-5]|[0-4]\\d))|[0-1]?\\d{1,2})){3}$'),
                    msg: '不是正确的IP地址'
                },
                // 英文字母
                '2': {
                    reg: new RegExp('^[a-zA-Z]+$'),
                    msg: '只能由字母组成'
                },
                // 英文数字
                '3': {
                    reg: new RegExp('^[a-zA-Z0-9]+$'),
                    msg: '只能由数字、字母组成'
                },
                // 汉字
                '4': {
                    reg: new RegExp('^[\u4e00-\u9fa5]*$'),
                    msg: '只能由汉字组成'
                },
                // email
                '5': {
                    reg: new RegExp('\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*'),
                    msg: '不是正确的Email地址'
                },
                // 负整数
                '6': {
                    reg: new RegExp('^-[1-9]\\d*$'),
                    msg: '只能由负整数组成'
                },
                // 正整数
                '7': {
                    reg: new RegExp('^\\+?[1-9][0-9]*$'),
                    msg: '只能由正整数组成'
                },
                // 整数
                '8': {
                    reg: new RegExp('^-?\\d+$'),
                    msg: '只能由整数组成'
                },
                // yyyy-MM-dd
                '9': {
                    reg: new RegExp('^\\d{4}-\\d{1,2}-\\d{1,2}$'),
                    msg: '只支持yyyy-MM-dd格式的日期'
                },
                // yyyy-MM-dd HH:mm:ss,
                '10': {
                    reg: new RegExp('^\\d{4}-\\d{1,2}-\\d{1,2} (([01]\\d)|(2[0-3])):[0-5]\\d:[0-5]\\d$'),
                    msg: '只支持yyyy-MM-dd HH:mm:ss格式的日期时间'
                },
                // HH:mm:ss
                '11': {
                    reg: new RegExp('^(([01]\\d)|(2[0-3])):[0-5]\\d:[0-5]\\d$'),
                    msg: '只支持HH:mm:ss格式的时间'
                },
            };
            // 验证自定义字段的规则
            for (var allPropertiesKey in vm.allProperties) {
                if (vm.allProperties.hasOwnProperty(allPropertiesKey)) {
                    var p = vm.allProperties[allPropertiesKey];
                    if (!p.isDefault && p.checkRule > 0 && vm.baseInfo[p.memberName]) {
                        var r = customFieldCheckObj[p.checkRule].reg.test(vm.baseInfo[p.memberName]);
                        if (!r) {
                            ynuiNotification.error({msg: p.name + customFieldCheckObj[p.checkRule].msg});
                            return false;
                        }
                    }
                }
            }
            return true;
        }

        function checkFamilyMember() {
            // 如果要添加家庭成员，必须要添加
            if ('0' === vm.taskVO.isAdd + '') {
                if (vm.stuFamilyMemberVOList.length === 0) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '请添加家庭成员！',
                        okText: '确定'
                    });
                    return false;
                }
            }
            return true;
        }

        function checkFiles() {
            var filesError = [];
            var notNullError = [];
            angular.forEach(vm.stuFiles, function (f) {
                if (null == f.dictClassifyList || 0 === f.dictClassifyList.length) {
                    if (0 < f.leastNum && 0 === f.fsIdList.length) {
                        notNullError.push(f.name);
                    }
                    angular.forEach(f.picStuInfo, function (p) {
                        if (2 === parseInt(p.ifPass) && -1 === filesError.indexOf(f.name)) {
                            filesError.push(f.name);
                        }
                    });
                } else {
                    angular.forEach(f.dictClassifyList, function (d) {
                        if (d.mustUpload && null == d.fsId) {
                            notNullError.push(d.dictName);
                        }
                        if (2 === parseInt(d.ifPass)) {
                            filesError.push(d.dictName);
                        }
                    });
                }
            });
            if (0 < notNullError.length) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请上传必填资料，带“*”号的为必须上传',
                    okText: '确定'
                });
                return false;
            }
            if (0 < filesError.length) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请重新上传' + filesError.join("、"),
                    okText: '确定'
                });
                return false;
            }
            return true;
        }

        function checkExperience() {
            var errorNames = [];
            angular.forEach(vm.stuLearnExperienceUncheckVOList, function (l) {
                if (l.failedReason) {
                    errorNames.push(l.attendSchool);
                }
            });
            angular.forEach(vm.stuWorkExperienceUncheckVOList, function (w) {
                if (w.failedReason) {
                    errorNames.push(w.workUnit);
                }
            });
            angular.forEach(vm.stuProjectExperienceUncheckVOList, function (p) {
                if (p.failedReason) {
                    errorNames.push(p.projectName);
                }
            });
            angular.forEach(vm.stuInternshipExperienceUncheckVOList, function (i) {
                if (i.failedReason) {
                    errorNames.push(i.practiceCompany);
                }
            });
            if (errorNames.length > 0) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '“' + errorNames.join("”、“") + '”不符合要求，请修改后再提交',
                    okText: '确定'
                });
                return false;
            }
            return true;
        }

        function showPrevStep() {
            var show = false;
            if (vm.tab === 2 && vm.showTabOne) {
                show = true;
            } else if (vm.tab === 3 && (vm.showTabOne || vm.showTabTwo)) {
                show = true;
            } else if (vm.tab === 4 && (vm.showTabOne || vm.showTabTwo || vm.showTabThree)) {
                show = true;
            }
            return show;
        }

        function showNextStep() {
            var show = false;
            if (vm.tab === 1 && (vm.showTabTwo || vm.showTabThree || vm.showTabFour)) {
                show = true;
            } else if (vm.tab === 2 && (vm.showTabThree || vm.showTabFour)) {
                show = true;
            } else if (vm.tab === 3 && vm.showTabFour) {
                show = true;
            }
            return show;
        }

        function showSubmitButton() {
            return !showNextStep();
        }

        // 用于提交之后缓存该对象
        // 下次提交如果没有变不再去保存
        vm.tempSaveObj = {
            baseInfo: null,
            member: null,
            file: null,
            experience: null,
        };

        // 第一步到下一步的回调方法
        function oneToNext() {
            if (vm.showTabTwo) {
                // 获取家庭成员
                findFamilyMember(vm.taskVO.id);
            } else if (vm.showTabThree) {
                // 获取照片/附件
                findStuFiles(vm.taskVO.id);
            } else if (vm.showTabFour) {
                // 获取经历
                findStuExperience(vm.taskVO.id);
            }
        }

        function nextStep(step) {
            if (1 === vm.tab) {
                if (0 < vm.tab) {
                    if (!checkBaseInfo()) {
                        return false;
                    }
                }
            }
            if (2 === vm.tab) {
                if (0 < step) {
                    if (!checkFamilyMember()) {
                        return false;
                    }
                }
            }
            if (3 === vm.tab) {
                if (0 < step) {
                    if (!checkFiles()) {
                        return false;
                    }
                }
            }
            if (4 === vm.tab) {
                if (0 < step) {
                    if (!checkExperience()) {
                        return false;
                    }
                }
            }

            // 下一步
            if (0 < step) {
                if (1 === vm.tab && vm.showTabTwo) {
                    step = 1;
                } else if (1 === vm.tab && vm.showTabThree) {
                    step = 2;
                } else if (1 === vm.tab && vm.showTabFour) {
                    step = 3;
                }
                if (2 === vm.tab && vm.showTabThree) {
                    step = 1;
                } else if (2 === vm.tab && vm.showTabFour) {
                    step = 2;
                }
                if (vm.tab === 1) {
                    // 如果是在第一步下一步需要保存数据
                    var obj = getSaveObj(false, [1]);
                    obj.taskId = vm.taskVO.id;
                    // 和上一次保存的值相同，不再去保存了
                    if (null != vm.tempSaveObj.baseInfo && vm.tempSaveObj.baseInfo === angular.toJson(obj)) {
                        oneToNext();
                        vm.tab += step;
                    } else {
                        // 存 baseInfo 到 uncheck 表
                        save(obj, null, 'save/base_info', true).success(function (data) {
                            if (data.status === 0 && data.result.length === 0) {
                                // 缓存一下保存对象的值，用于下次判断没有修改不再
                                vm.tempSaveObj.baseInfo = angular.toJson(obj);
                                oneToNext();
                                vm.tab += step;
                            }
                        });
                    }
                } else if (vm.tab === 2) {
                    if (vm.showTabThree) {
                        // 获取照片/附件
                        findStuFiles(vm.taskVO.id).success(function () {
                            vm.tab += step;
                        });
                    } else if (vm.showTabFour) {
                        // 获取经历
                        findStuExperience(vm.taskVO.id).success(function () {
                            vm.tab += step;
                        });
                    }
                } else if (vm.tab === 3) {
                    // 在第三步要保存照片/附件
                    var filesObj = getSaveObj(false, [3]);
                    filesObj.taskId = vm.taskVO.id;
                    // 和上一次保存的值相同，不再去保存了
                    if (null != vm.tempSaveObj.file && vm.tempSaveObj.file === angular.toJson(filesObj)) {
                        // 如果有下一步
                        if (vm.showTabFour) {
                            // 获取经历
                            findStuExperience(vm.taskVO.id).success(function () {
                              vm.tab += step;
                            });
                        }
                    } else {
                        save(filesObj, null, 'save/files').success(function (data) {
                            if (data.status === 0 && data.result.length === 0) {
                                // 缓存一下保存对象的值，用于下次判断没有修改不再
                                vm.tempSaveObj.file = angular.toJson(filesObj);
                                if (vm.showTabFour) {
                                    // 获取经历
                                    findStuExperience(vm.taskVO.id).success(function () {
                                        vm.tab += step;
                                    });
                                }
                            }
                        });
                    }
                }
            }
            // 上一步
            else if (0 > step) {
                if (4 === vm.tab) {
                    if (!vm.showTabThree) {
                        step = -2;
                        if (!vm.showTabTwo) {
                            step = -3;
                        }
                    }
                } else if (3 === vm.tab) {
                    if (!vm.showTabTwo) {
                        step = -2;
                    }
                }
                vm.tab += step;
            }
            // 滚到顶部
            scrollMainToTop();
        }

        function editFamily(data) {
            if (null == data) {
                // 添加
                vm.modifyFamilyData = {
                    isGuardian: false,
                    gender: null,
                };
            } else {
                // 修改
                vm.modifyFamilyData = angular.copy(data);
            }
            $ionicScrollDelegate.$getByHandle('familyScroll').scrollTop();
            vm.modal.show();
        }

        function deleteFamily(index) {
            // 删除数组中的数据，然后保存，再重新查询
            $ionicPopup.confirm({
                title: '提示',
                template: "确定要删除所选吗？",
                buttons: [
                    {text: '取消'},
                    {
                        text: '确定', type: 'button-positive', onTap: function () {
                            vm.stuFamilyMemberVOList.splice(index, 1);
                            // 保存
                            var obj = getSaveObj(false, [2]);
                            obj.taskId = vm.taskVO.id;
                            saveFamilyMember(obj, '删除成功').success(function (data) {
                                if (0 === data.status && (null == data.result || 0 === data.result.length)) {
                                    findFamilyMember(vm.taskVO.id);
                                }
                            });
                        }
                    }
                ]
            });
        }

        function saveFamily() {
            // 验证必填项
            var error = [];
            angular.forEach(vm.notNullPropertiesFamily, function (value, key) {
                if (null == vm.modifyFamilyData[key] || '' === vm.modifyFamilyData[key]) {
                    error.push(key);
                }
            });
            angular.forEach(vm.stuCustomFieldVOList, function (f) {
                if (f.notNull && !vm.modifyFamilyData[f.memberName]) {
                    error.push(f.memberName);
                }
            });
            if (0 < error.length ||
                ('{}' === angular.toJson(vm.modifyFamilyData) && '{}' !== angular.toJson(vm.notNullPropertiesFamily))) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请填写必填字段，带“*”号的为必填项',
                    okText: '确定'
                });
                return false;
            }
            var arr = [
                {show: true, key: 'familyMail', value: vm.modifyFamilyData.familyMail},
                {show: true, key: 'familyDocumentNumber', value: vm.modifyFamilyData.familyDocumentNumber},
                {show: true, key: 'familyMobile', value:vm.modifyFamilyData.mobile}
            ];
            var i;
            for (i = 0; i < arr.length; i++) {
                if (!validProperty(null, arr[i].show, arr[i].key, arr[i].value)) {
                    return false;
                }
            }
            // 没有id就是添加
            var msg = "修改成功";
            if (null == vm.modifyFamilyData.id) {
                vm.stuFamilyMemberVOList.push(vm.modifyFamilyData);
                msg = "添加成功";
            } else {
                i = null;
                angular.forEach(vm.stuFamilyMemberVOList, function (f, index) {
                    if (f.id === vm.modifyFamilyData.id) {
                        i = index;
                    }
                });
                vm.modifyFamilyData.checkStatus = 3;
                vm.modifyFamilyData.failedReason = "";
                vm.stuFamilyMemberVOList.splice(i, 1, vm.modifyFamilyData);
            }
            // 保存，并且重新查询
            var obj = getSaveObj(false, [2]);
            obj.taskId = vm.taskVO.id;
            return saveFamilyMember(obj, msg).success(function (data) {
                findFamilyMember(vm.taskVO.id);
                // 关闭
                removeModal('modal', 'edit-family.html');
                return data;
            });
        }

        function changeRelationship(key) {
            var obj = $filter('filter')(vm.relationshipList, {dictCode: key});
            var male = ['父', '兄', '弟'];
            var female = ['母', '姐', '妹'];
            if (obj.length > 0) {
                for (var i = 0; i < male.length; i++) {
                    if (obj[0].dictName.indexOf(male[i]) >= 0) {
                        vm.modifyFamilyData.gender = '1';
                        return;
                    }
                }
                for (var i = 0; i < female.length; i++) {
                    if (obj[0].dictName.indexOf(female[i]) >= 0) {
                        vm.modifyFamilyData.gender = '2';
                        return;
                    }
                }
            }
        }

        function showSubmitFileModal(obj) {
            vm['fileModal'].show();
            vm.fileObj = obj;
            // 计算裁剪框的高度
            vm.cropperImageStyle = {'height': window.outerHeight - 55 + 'px', 'width': '100%'};
        }

        /**
         * 拍照
         */
        function takePhoto() {
            vm['fileModal'].hide();
            if (vm.fileObj.id === '1' || vm.fileObj.id === '2') {
                yn.plugin.yncordova.startUserIDPhotoCamera(
                  {ratio: vm.fileObj.width / vm.fileObj.height},
                  function (data) {
                      console.log('----------------------------' + angular.toJson(data));
                      vm.cropperImageData = {
                          data: data,
                          name: data.substr(data.lastIndexOf('/') + 1)
                      };
                      // showCropper(vm.fileObj.width, vm.fileObj.height);
                      // 通过 canvas 自动裁剪
                      autoCropper(vm.cropperImageData, {width: vm.fileObj.width, height: vm.fileObj.height});
                  },
                  function (error) {
                      console.log(angular.toJson(error));
                  });
            } else if (vm.fileObj.dictCode === '3_1') {
                yn.plugin.yncordova.startUserIDCardCamera(
                  {"cameraModel": 1},
                  function (data) {
                      console.log('----------------------------' + angular.toJson(data));
                      vm.cropperImageData = {
                          data: data,
                          name: data.substr(data.lastIndexOf('/') + 1)
                      };
                      // showCropper(vm.fileObj.width, vm.fileObj.height);
                      autoCropper(vm.cropperImageData, {width: vm.fileObj.width, height: vm.fileObj.height});
                  },
                  function (error) {
                      console.log(angular.toJson(error));
                  });
            } else if (vm.fileObj.dictCode === '3_2') {
                yn.plugin.yncordova.startUserIDCardCamera(
                  {"cameraModel": 2},
                  function (data) {
                      console.log('----------------------------' + angular.toJson(data));
                      vm.cropperImageData = {
                          data: data,
                          name: data.substr(data.lastIndexOf('/') + 1)
                      };
                      // showCropper(vm.fileObj.width, vm.fileObj.height);
                      autoCropper(vm.cropperImageData, {width: vm.fileObj.width, height: vm.fileObj.height});
                  },
                  function (error) {
                      console.log(angular.toJson(error));
                  });
            } else {
                navigator.camera.getPicture(function (data) {
                    console.log(JSON.stringify(data));
                    // 裁剪
                    if (null != vm.fileObj.width && null != vm.fileObj.height) {
                        vm.cropperImageData = {
                            data: data,
                            name: data.substr(data.lastIndexOf('/') + 1)
                        };
                        showCropper(vm.fileObj.width, vm.fileObj.height);
                    } else {
                        $ionicLoading.show();
                        // 执行上传
                        upload(data.substr(data.lastIndexOf('/') + 1), data);
                    }
                }, function (error) {
                    console.log(JSON.stringify(error))
                }, {
                    sourceType: Camera.PictureSourceType.CAMERA
                });
            }
        }

        /**
         * 选择照片
         */
        function takePicture() {
            vm['fileModal'].hide();
            navigator.camera.getPicture(function (data) {
                console.log(JSON.stringify(data));
                // 裁剪
                if (null != vm.fileObj.width && null != vm.fileObj.height) {
                    vm.cropperImageData = {
                        data: data,
                        name: data.substr(data.lastIndexOf('/') + 1)
                    };
                    showCropper(vm.fileObj.width, vm.fileObj.height);
                } else {
                    // 执行上传
                    upload(data.substr(data.lastIndexOf('/') + 1), data);
                }
            }, function (error) {
                console.log(JSON.stringify(error))
            }, {
                sourceType: Camera.PictureSourceType.PHOTOLIBRARY
            });
        }

        /**
         * 文件上传
         * @param name 文件名称
         * @param uri  文件
         * @param uploadUrl 特殊的上传地址
         * @param width 限制宽
         * @param height 限制高
         */
        function upload(name, uri, uploadUrl, width, height) {
            // 参数
            var mac = stringsConstant.utils.uuid();
            var userId = JSON.parse(window.localStorage.getItem('authorizationStr')).userId;
            var options = new FileUploadOptions();
            options.fileName = name;
            options.params = {
                name: name,
                userId: userId,
                mac: mac,
                width: width,
                height: height,
            };
            options.headers = {
                authorization: JSON.parse(window.localStorage.getItem("authorizationStr")).access_token
            };
            $cordovaFileTransfer
                .upload(uploadUrl || stringsConstant.file.uploadServer(), uri, options)
                .then(
                    function (uploadSuccessData) {
                        $ionicLoading.hide();
                        console.log(JSON.stringify(uploadSuccessData.response));
                        // 上传完成
                        var fsId = JSON.parse(uploadSuccessData.response).result.fileId;
                        // 没有定义 fsId 字段，说明是批量的
                        if (angular.isUndefined(vm.fileObj.fsId)) {
                            if (null == vm.fileObj.fsIdList) {
                                vm.fileObj.fsIdList = [];
                            }
                            if (vm.fileObj.mostNum >= vm.fileObj.fsIdList.length + 1) {
                                vm.fileObj.fsIdList.push(fsId);
                                // 覆盖第一个fs_id为空，但是有错误消息的数据
                                var index = null;
                                angular.forEach(vm.fileObj.picStuInfo, function (p, i) {
                                    if (p.ifPass === 2 && null == p.fsId) {
                                        index = i;
                                        p.fsId = fsId;
                                        p.noPassReson = null;
                                        p.ifPass = null;
                                    }
                                });
                                if (null == index) {
                                    vm.fileObj.picStuInfo.push({
                                        fsId: fsId,
                                        noPassReson: null,
                                        ifPass: null
                                    });
                                }
                            }
                        } else {
                            vm.fileObj.fsId = fsId;
                            vm.fileObj.ifPass = null;
                            vm.fileObj.noPassReson = null;
                        }
                    },
                    function (uploadError) {
                        $ionicLoading.hide();
                        console.error('上传失败');
                        console.error(JSON.stringify(uploadError));
                    },
                    function (progress) {
                        $ionicLoading.hide();
                        $timeout(function () {
                            console.log('上传进度: ' + (progress.loaded / progress.total) * 100);
                        });
                    }
                );
        }

        vm.deleteFsIds = [];

        /**
         * 删除照片
         *
         * @param fsId fsId
         * @param obj  删除照片的对象
         */
        function deletePhoto(fsId, obj) {
            $ionicPopup.confirm({
                title: '删除确认',
                template: '确认要删除当前照片吗?',
                cancelText: '取消',
                okText: '删除'
            }).then(function (res) {
                if (res) {
                    // 把需要删除的文件放在一起，提交审核统一删除
                    if (-1 === vm.deleteFsIds.indexOf(fsId)) {
                        vm.deleteFsIds.push(fsId);
                    }
                    // 从数组移除，或者字段设置为 null
                    if (obj.fsIdList) {
                        obj.fsIdList.splice(obj.fsIdList.indexOf(fsId), 1);
                        var index = null;
                        angular.forEach(obj.picStuInfo, function (s, i) {
                            if (s.fsId === fsId) {
                                index = i;
                            }
                        });
                        obj.picStuInfo.splice(index, 1);
                    } else {
                        obj.fsId = null;
                        obj.ifPass = null;
                    }
                }
            });
        }

        function getPixelRatio() {
            return window.devicePixelRatio || 1;
        }

        function autoCropper(data, limit) {
            $ionicLoading.show();
            var img = new Image();
            // 缩放图片需要的canvas
            var canvas = document.createElement('canvas');
            var context = canvas.getContext('2d');
            var ratio = getPixelRatio();
            img.onload = function () {
                // 最大尺寸限制
                var maxWidth = limit.width, maxHeight = limit.height;
                // canvas对图片进行缩放
                canvas.style.width = maxWidth + 'px';
                canvas.style.height = maxHeight + 'px';
                canvas.width = maxWidth * ratio;
                canvas.height = maxHeight * ratio;
                // 清除画布
                context.clearRect(0, 0, maxWidth, maxHeight);
                // 画图
                context.scale(ratio, ratio);
                context.drawImage(img, 0, 0, maxWidth, maxHeight);
                // to base64
                var base64 = canvas.toDataURL('image/jpeg', 1);
                // 上传
                upload(data.name, base64, originBaseUrl + '/third/file/scale/upload.htm', maxWidth, maxHeight);
            }
            img.src = data.data;
        }

        function showCropper(width, height) {
            vm['cropperModal'].show().then(function () {
                $('#image').cropper({
                    dragMode: 'move',
                    aspectRatio: width / height,
                    viewMode: 1,
                    cropBoxResizable: false,
                    cropBoxMovable: false,
                });
            });
        }

        function cropper() {
            var img = $('#image');
            var ratio = getPixelRatio();
            var canvas = img.cropper("getCroppedCanvas", {
                width: vm.fileObj.width * ratio,
                height: vm.fileObj.height * ratio,
                minWidth: 100,
                minHeight: 100,
                maxWidth: 1024,
                maxHeight: 1024,
                imageSmoothingEnabled: false,
                imageSmoothingQuality: 'high',
            });
            // 设置裁剪过后的图片
            var imgData = canvas.toDataURL('image/jpeg', 1);
            // 销毁
            img.cropper('destroy');
            // base64 编码上传文件
            upload(vm.cropperImageData.name, imgData, originBaseUrl + '/third/file/scale/upload.htm', vm.fileObj.width, vm.fileObj.height);
        }

        function rotate(value) {
            $('#image').cropper('rotate', value);
        }

        function confirmCropper() {
            $ionicPopup.confirm({
                title: '提示',
                template: "确认完成裁剪？",
                buttons: [
                    {text: '取消'},
                    {
                        text: '确定', type: 'button-positive', onTap: function () {
                            cropper();
                            vm['cropperModal'].remove().then(function () {
                                initModal('cropperModal', 'cropper.html');
                            });
                        }
                    }
                ]
            });
        }

        function cancelCropper() {
            $ionicPopup.confirm({
                title: '提示',
                template: "确认取消裁剪？",
                buttons: [
                    {text: '取消'},
                    {
                        text: '确定', type: 'button-positive', onTap: function () {
                            vm['cropperModal'].hide();
                            // 销毁
                            $('#image').cropper('destroy');
                        }
                    }
                ]
            });
        }

        ynNavigator.registerBackAction(function () {
            if (vm['modal'].isShown()) {
                vm['modal'].hide();
            } else if (vm['fileModal'].isShown()) {
                vm['fileModal'].hide();
            } else if (vm['cropperModal'].isShown()) {
                cancelCropper();
            } else if (vm['markModal'].isShown()) {
                vm['markModal'].hide();
            } else if (vm['learnModal'].isShown()) {
                vm['learnModal'].hide();
            } else if (vm['workModal'].isShown()) {
                vm['workModal'].hide();
            } else if (vm['projectModal'].isShown()) {
                vm['projectModal'].hide();
            } else if (vm['internshipModal'].isShown()) {
                vm['internshipModal'].hide();
            } else {
                $ionicPopup.confirm({
                    title: '提示',
                    template: '确定要返回吗？',
                    buttons: [
                        {text: '取消'},
                        {
                            text: '确定', type: 'button-positive', onTap: function () {
                                ynNavigator.pop(true);
                            }
                        }
                    ]
                });
            }
        }, 201);

        function scrollMainToTop() {
            $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        }

        vm.previewPhoto = previewPhoto;

        function previewPhoto(fsId) {
            var url = vm.originBaseUrl + '/third/file/download.htm?fileId=' + fsId;
            var cordovaFileOpen = cordova.plugins.disusered.open;
            cordovaFileOpen(url, cordovaFileOpenSuccess, cordovaFileOpenError);

            function cordovaFileOpenSuccess() {
                // 从已安装程序中打开文件完成
            }

            function cordovaFileOpenError(code) {
                if (1 === code) {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '未能在手机已安装APP中找到可预览此文件的程序',
                        okText: '确定'
                    });
                } else {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '预览时发生了未知错误 #' + code,
                        okText: '确定'
                    });
                }
            }
        }

        vm.regExpObj = {
            vision: {
                reg: new RegExp('^[1-9][0-9]*(\.[0-9])?$|^0\.[1-9]$'),
                msg: '只能输入大于0的数字，支持1位小数'
            },
            stipendStandard: {
                reg: new RegExp('^[1-9][0-9]*(\.[0-9]{1,2})?$|^0.[0-9][1-9]$'),
                msg: '只能输入大于0的数字，支持2位小数'
            },
            email: {
                reg: new RegExp('\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*'),
                msg: '邮箱格式不正确'
            },
            familyMail: {
                reg: new RegExp('\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*'),
                msg: '邮箱格式不正确'
            },
            mobile: {
                reg: new RegExp('^(\\+\\d{2}[-\\s])?(0\\d{2,3}-)?(\\d{7,})$'),
                msg: '手机号格式不正确'
            },
            familyMobile: {
                reg: new RegExp('^(\\+\\d{2}[-\\s])?(0\\d{2,3}-)?(\\d{7,})$'),
                msg: '联系电话格式不正确'
            },
            graduatedScore:{
                reg: new RegExp('^(\\d{1,4}(\\.\\d{1,1})?)$|^([A-Z]((\\+){0,2}|(-){0,2}))$'),
                msg: '分数制：最多只能输入4位正整数和1位小数！ 等级制：只能输入“大写字母和加号”或“大写字母和减号”！'
            }
        }

        vm.validProperty = validProperty;

        function validProperty(e, show, key, value) {
            var idCards = ['credentialNumber', 'familyDocumentNumber'];
            var idIndex = idCards.indexOf(key);
            // 字段验证
            if (show && value) {
                if (-1 === idIndex && !vm.regExpObj[key].reg.test(value)) {
                    ynuiNotification.error({msg: vm.regExpObj[key].msg});
                    if (e && e.target) {
                        angular.element(e.target).focus();
                    }
                    return false;
                } else if (-1 !== idIndex) {
                    var code;
                    if (0 === idIndex) {
                        code = vm.baseInfo.credentialType;
                    } else {
                        code = vm.modifyFamilyData.familyDocumentType;
                    }
                    if ('01' === code) {
                        // 验证身份证
                        var pass = checkIdCard(value);
                        if (!pass) {
                            ynuiNotification.error({msg: '请输入正确的身份证号码'});
                            if (e && e.target) {
                                angular.element(e.target).focus();
                            }
                            return false;
                        }
                    }
                }
            }
            return true;
        }

        vm.showTips = showTips;

        function showTips() {
            if (vm.taskVO.mark) {
                $sce.trustAsHtml(vm.taskVO.mark);
                vm['markModal'].show();
            }
        }

        // 15秒暂存一次
        // vm.interval = $interval(function () {
        //     doSaveTemp();
        // }, 15000);

        vm.oldObj = null;

        function doSaveTemp() {
            // 之前的对象和之后的对象不一样再去处理保存
            var obj = getSaveObj(null, true);
            // 字段
            // obj.zsAdmissionInfoVO = angular.copy(vm.zsAdmissionInfoVO);
            // obj.platformSysAdminClassVO = angular.copy(vm.platformSysAdminClassVO);
            // obj.stuCustomFieldVOList = angular.copy(vm.stuCustomFieldVOList);
            // 附件
            obj.platformBusinessMaterialShowVO = {
                materialStuInClassifyList: vm.stuFiles
            };
            if (null == vm.oldObj) {
                vm.oldObj = angular.copy(obj);
                return false;
            }
            else if (angular.toJson(vm.oldObj) !== angular.toJson(obj)) {
                vm.oldObj = angular.copy(obj);
            } else {
                return false;
            }
            // 处理为空的情况
            if (angular.toJson(vm.oldObj) === '{}') {
                return false;
            }
            saveTemp(vm.oldObj);
        }

        function checkProv(val) {
            var pattern = /^[1-9][0-9]/;
            var provs = {
                11: "北京",
                12: "天津",
                13: "河北",
                14: "山西",
                15: "内蒙古",
                21: "辽宁",
                22: "吉林",
                23: "黑龙江 ",
                31: "上海",
                32: "江苏",
                33: "浙江",
                34: "安徽",
                35: "福建",
                36: "江西",
                37: "山东",
                41: "河南",
                42: "湖北 ",
                43: "湖南",
                44: "广东",
                45: "广西",
                46: "海南",
                50: "重庆",
                51: "四川",
                52: "贵州",
                53: "云南",
                54: "西藏 ",
                61: "陕西",
                62: "甘肃",
                63: "青海",
                64: "宁夏",
                65: "新疆",
                71: "台湾",
                81: "香港",
                82: "澳门"
            };
            if (pattern.test(val)) {
                if (provs[val]) {
                    return true;
                }
            }
            return false;
        }

        function checkDate(val) {
            var pattern = /^(18|19|20)\d{2}((0[1-9])|(1[0-2]))(([0-2][1-9])|10|20|30|31)$/;
            if (pattern.test(val)) {
                var year = val.substring(0, 4);
                var month = val.substring(4, 6);
                var date = val.substring(6, 8);
                // var date2 = new Date(year + "-" + month + "-" + date);
                var date2 = moment(year + "-" + month + "-" + date);
                if (date2 && date2.month() === (parseInt(month) - 1)) {
                    return true;
                }
            }
            return false;
        }

        // 校验码校验
        function checkCode(val) {
            var p = /^[1-9]\d{5}(18|19|20)\d{2}((0[1-9])|(1[0-2]))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$/;
            var factor = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
            var parity = [1, 0, 'X', 9, 8, 7, 6, 5, 4, 3, 2];
            var code = val.substring(17);
            if (p.test(val)) {
                var sum = 0;
                for (var i = 0; i < 17; i++) {
                    sum += val[i] * factor[i];
                }
                if (parity[sum % 11] + '' === code.toUpperCase()) {
                    return true;
                }
            }
            return false;
        }

        function checkIdCard(val) {
            if (18 === val.length) {
                if (checkCode(val)) {
                    var date = val.substring(6, 14);
                    if (checkDate(date)) {
                        if (checkProv(val.substring(0, 2))) {
                            return true;
                        }
                    }
                }
            }
            return false;
        }

        /**
         * 数据结构改变
         * @param obj
         * @returns {{}}
         */
        function parseParamForSpringMVC(obj) {
            //最终组合成功的对象
            var resultObj = {};
            //递归方法，用于深度转换每一个参数
            //key 对象时，是属性名
            //value 属性值
            //prefix（关键），和key进行组合相组合成想要的格式类型如name.age（对象）或name[0].age（数组）
            var deepParseParams = function (key, value, prefix) {
                //先判断是否是数组
                if (value instanceof Array) {
                    for (var i in value) {
                        deepParseParams("", value[i], prefix + key + "[" + i + "]");
                    }
                }
                //再判断是否是对象
                else if (value instanceof Object) {
                    for (var i in value) {
                        deepParseParams("." + i, value[i], prefix + key);
                    }
                }
                //如果不是数组或对象，到了此次递归的最后一次，将完成组合的这条最终数据放在最终组合对象中
                else {
                    resultObj[prefix + key] = value;
                }

            };
            //因为传入的转换参数必须是对象,而且第一次传入和第二次开始组合“.”号是很特殊的地方，所有
            //第一次单独循环
            for (var i in obj) {
                deepParseParams("", obj[i], i);
            }

            //返回转换成功的对象集合
            return resultObj;
        }

        vm.beginDateOptions = {dateOrder: 'yyyymm', dateFormat: 'yyyy-mm'};
        vm.endDateOptions = {dateOrder: 'yyyymm', dateFormat: 'yyyy-mm'};
        vm.learnNotNullKeys = ['attendSchool', 'beginTimeString', 'endTimeString', 'reterence'];
        vm.workNotNullKeys = ['workUnit', 'beginTimeString', 'endTimeString', 'workContent'];
        vm.projectNotNullKeys = ['projectName', 'beginTimeString', 'endTimeString', 'responsibilities'];
        vm.internshipNotNullKeys = ['platformSysTermId', 'beginTimeString', 'practiceCompany', 'practiceContent'];

        vm.editExperience = editExperience;
        vm.saveExperience = saveExperience;
        vm.delExperience = delExperience;
        vm.internshipChangeTerm = internshipChangeTerm;
        vm.changeExperienceData = changeExperienceData;

        function editExperience(obj, key) {
            if (obj) {
                vm[key + 'Obj'] = obj;
                vm[key + 'Modify'] = true;
            } else {
                vm[key + 'Obj'] = initExperienceObj(key);
                vm[key + 'Modify'] = false;
            }
            if (vm.hasOwnProperty(key + 'Modal')) {
                vm[key + 'Modal'].show();
            }
            if (key === 'internship') {
                // 获取学期
                findTermList();
            }
            // 初始化日期限制
            vm.beginDateOptions = {
                dateOrder: 'yyyymm',
                dateFormat: 'yyyy-mm',
                maxDate: vm[key + 'Obj'].endTimeString ? moment(vm[key + 'Obj'].endTimeString, 'YYYY-MM').toDate() : null
            };
            vm.endDateOptions = {
                dateOrder: 'yyyymm',
                dateFormat: 'yyyy-mm',
                minDate: vm[key + 'Obj'].beginTimeString ? moment(vm[key + 'Obj'].beginTimeString, 'YYYY-MM').toDate() : null
            };
        }

        function initExperienceObj(key) {
            if (key === 'learn') {
                return {
                    attendSchool: null,
                    reterence: null,
                    beginTimeString: null,
                    endTimeString: null
                };
            } else if (key === 'work') {
                return {
                    workUnit: null,
                    workContent: null,
                    beginTimeString: null,
                    endTimeString: null
                };
            } else if (key === 'project') {
                return {
                    projectName: null,
                    responsibilities: null,
                    beginTimeString: null,
                    endTimeString: null
                };
            } else if (key === 'internship') {
                return {
                    platformSysTermId: null,
                    platformSysTermName: null,
                    beginTimeString: null,
                    endTimeString: null,
                    practiceCompany: null,
                    practiceAddress: null,
                    companyNature: null,
                    practiceContent: null
                };
            }
        }

        function changeExperienceData(type, date) {
            var baseOption = {dateOrder: 'yyyymm', dateFormat: 'yyyy-mm'};
            if (type === 1) {
                // 开始日期
                $timeout(function () {
                    vm.endDateOptions = {
                        dateOrder: baseOption.dateOrder,
                        dateFormat: baseOption.dateFormat,
                        minDate: moment(date, 'YYYY-MM').toDate()
                    }
                });
            } else if (type === 2) {
                // 结束日期
                $timeout(function () {
                    vm.beginDateOptions = {
                        dateOrder: baseOption.dateOrder,
                        dateFormat: baseOption.dateFormat,
                        maxDate: moment(date, 'YYYY-MM').toDate()
                    }
                });
            }
        }

        function saveExperience(key, array) {
            var notNull = false;
            angular.forEach(vm[key + 'Obj'], function (v, k) {
                if (vm[key + 'NotNullKeys'].indexOf(k) >= 0 && (null == v || '' === v)) {
                    notNull = true;
                }
            });
            if (notNull) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请填写必填字段，带“*”号的为必填项',
                    okText: '确定'
                });
                return;
            }
            var begin = moment(vm[key + 'Obj'].beginTimeString, 'YYYY-MM');
            var end = moment(vm[key + 'Obj'].endTimeString, 'YYYY-MM')
            // 判断开始结束时间
            if (begin.isAfter(end)) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '开始日期不能大于结束日期',
                    okText: '确定'
                });
                return;
            }
            if (vm[key + 'Modify']) {
                var index = null;
                angular.forEach(array, function (v, i) {
                    if (v.id === vm[key + 'Obj'].id) {
                      index = i;
                    }
                });
                // 修改状态为待审核
                vm[key + 'Obj'].failedReason = null;
                if (null != index) {
                    array.splice(index, 1, vm[key + 'Obj']);
                }
            } else {
                array.push(vm[key + 'Obj']);
            }
            ynuiNotification.success({'msg': '保存成功！'});
            vm.removeModal(key + 'Modal', key + '.html');
        }

        function delExperience(array, index) {
            $ionicPopup.alert({
                title: '提示',
                template: '确定要删除所选吗？',
                buttons: [
                    {text: '取消'},
                    {
                        text: '确定',
                        type: 'button-positive',
                        onTap: function () {
                            array.splice(index, 1);
                        }
                }]
            });
        }

        function findTermList() {
            return $http.get(originBaseUrl + '/third/xj/stu/term/list.htm')
              .success(function (data) {
                  if (data.status === 0) {
                      vm.termList = data.result;
                  }
                  return data;
              });
        }

        function internshipChangeTerm(termId) {
            angular.forEach(vm.termList, function (term) {
                if (term.id === termId) {
                    vm['internshipObj'].platformsystermName = term.name;
                }
            })
        }
    }
})();
