/**
 * 教学班花名册
 */
(function () {
  'use strict';
  angular.module('starter')
    .config(config)
    .controller("teachClassStudentCtrl", ctrl);

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      /*按班级报到登记*/
      .state('teach_class_student', {
        url: '/teach_class_student',
        templateUrl: 'templates/teach_class_student/index.html',
        cache: false,
        data: {
          title: '花名册'
        },
        controller: 'teachClassStudentCtrl'
      });
  }

  ctrl.$inject = ['$scope', '$http', 'ynuiNotification', '$ionicModal', '$ionicScrollDelegate', "$timeout", "$location"];

  function ctrl($scope, $http, ynuiNotification, $ionicModal, $ionicScrollDelegate, $timeout, $location) {
    var vm = $scope.vm = {
      searchFlag: false,
      defaultClassId: null,
      originBaseUrl: originBaseUrl,
      showClass: {},//显示班级
      showClassList: [],//所有班级
      stuSearch: {
        name: ""//学生姓名查询条件
      },
      tableView: 0,
      dataResult: [],//查询数据
      showDetailInfo: [],//展示数据
      showStudentInfo: {},//显示学生详细信息
      showAllSortList: [],//显示字母排序
      modal: "",//弹出框
      manNum: 0,//男生人数
      bedNum: 0,//住宿人数
      totalNum: 0//总人数
    }

    var classId = $location.search().classId;
    if ($location.search().item) {
      vm.defaultClassId = JSON.parse($location.search().item).classId;
    }
    // vm.defaultClassId ='ccdfe8e5-c194-4c2c-8b28-5fb59e8a6665';

    //展开搜索
    $scope.toSearch = function () {
      vm.showDetailInfo = [];
      vm.searchFlag = true;
    };
    // 隐藏搜索
    $scope.cancelSearch = function () {
      vm.searchFlag = false;
      $scope.clearSearch();
      $scope.getReportInfo();
    };
    // 清除搜索条件
    $scope.clearSearch = function () {
      vm.showDetailInfo = [];
      vm.stuSearch.name = "";
    };
    // 获取班级选中样式
    $scope.getActive = function (info) {
      if (info.id === vm.showClass.id) {
        return 'active';
      }
    };
    //获取table选中样式
    $scope.getClassTable = function (type) {
      if (type == vm.tableView) {
        return 'tab-item active';
      } else {
        return 'tab-item'
      }
    };
    //table切换
    $scope.getActiveTable = function (type) {
      vm.tableView = type;
      vm.showDetailInfo = [];
      angular.forEach(vm.dataResult, function (item) {
        if (type == 0) {
          vm.showDetailInfo.push(item);
        } else if (type == 1 && item.gender == 1) {
          vm.showDetailInfo.push(item);
        } else if (type == 2 && item.gender == 2) {
          vm.showDetailInfo.push(item);
        } else if (type == 3 && item.bedName) {
          vm.showDetailInfo.push(item);
        } else if (type == 4 && !item.bedName) {
          vm.showDetailInfo.push(item);
        }
      });
      $scope.getShowSortList();
    };
    // 获取选中班级
    $scope.getSelect = function (item) {
      vm.showClass = item;
      vm.showMainClass = null;
      $scope.getReportInfo();
    };
    //获取班级下拉值
    $scope.getDropDownOptions = function () {
      $http.get(
        // vm.originBaseUrl + "/third/studentInfo/queryPlatformAdminClassByUserId.htm", {
        vm.originBaseUrl + "/third/teachclass/teacher.htm").success(function (data) {
        if (data.status == 0) {
          vm.showClassList = data.result;
          // 默认第一个班级
          if (vm.showClassList && vm.showClassList.length > 0) {
            var index = 0;
            if (vm.defaultClassId) {
              angular.forEach(vm.showClassList, function (item, _index) {
                if (item.id == vm.defaultClassId) {
                  index = _index;
                }
              })
            } else if (classId) {
              angular.forEach(vm.showClassList, function (item, _index) {
                if (item.id == classId) {
                  index = _index;
                }
              })
            }
            vm.showClass = vm.showClassList[index];
            vm.showMainClass = null;
            $scope.getReportInfo();
          }
        } else {
          ynuiNotification.error({msg: "获取班级失败！"});
        }
      });
    };
    /**
     * 排序
     */
    $scope.getShowSortList = function () {
      var sortNameList = [];
      vm.showAllSortList = [];
      angular.forEach(vm.showDetailInfo, function (item) {
        if (sortNameList.indexOf(item.sortName) == -1) {
          sortNameList.push(item.sortName);
          vm.showAllSortList.push({name: item.sortName, selected: false});
        }
      });
      $timeout(function () {
        $scope.goSort(vm.showAllSortList[0]);
      }, 100);
    }

    var searchTimeout = null;

    $scope.searchChange = function () {
      if (searchTimeout) {
        clearTimeout(searchTimeout);
      }
      if (null == vm.stuSearch.name || vm.stuSearch.name === '') {
        return false;
      }
      searchTimeout = setTimeout(function () {
        $scope.getReportInfo();
      }, 500);
    }

    // 获取列表数据
    $scope.getReportInfo = function () {
      var searchInfo = {
        adminClassIds: []
      };
      if (vm.searchFlag) {
        angular.forEach(vm.showClassList, function (item) {
          searchInfo.adminClassIds.push(item.id);
        });
        searchInfo.queryValue = vm.stuSearch.name;
      } else {
        searchInfo.adminClassIds.push(vm.showClass.id);
      }
      $http.post(vm.originBaseUrl + "/third/teachclass/stu/" + vm.showClass.id + '.htm', searchInfo).success(function (data) {
        if (data.status == 0) {
          vm.dataResult = data.result;
          vm.showDetailInfo = vm.dataResult;
          vm.manNum = 0;
          vm.bedNum = 0;
          vm.totalNum = 0;
          if (vm.showDetailInfo && vm.showDetailInfo.length > 0) {
            vm.totalNum = vm.showDetailInfo.length;
            angular.forEach(vm.showDetailInfo, function (item) {
              if (item.gender == 1) {
                vm.manNum++;
              }
              if (item.bedName) {
                vm.bedNum++;
              }
            });
            $scope.getActiveTable(vm.tableView);
            // $scope.getShowSortList();
          }
        } else {
          ynuiNotification.error({msg: "获取数据失败！"});
        }
      });
    };
    $scope.openStudentInfo = function (info) {
      vm.showStudentInfo = info;
      vm.modal.show();
    }
    $scope.closeHead = function () {
      vm.modal.hide();
    }
    $ionicModal.fromTemplateUrl('studentInfo.html', {
      scope: $scope,
      animation: 'slide-in-up'
    }).then(function (modal) {
      vm.modal = modal;
    });

    // 首字母定位
    $scope.goSort = function (info) {
      // 选中
      angular.forEach(vm.showAllSortList, function (val) {
        if (val.name == info.name) {
          val.selected = true;
        } else {
          val.selected = false;
        }
      });
      // 获取定位id
      if (vm.showDetailInfo && vm.showDetailInfo.length > 0) {
        var id = info.name, flag = false;
        angular.forEach(vm.showDetailInfo, function (value, index) {
          if (value.sortName == info.name) {
            if (!flag) {
              id += index;
              flag = true;
            }
          }
        });
        // 定位处理
        if ($("#" + id).position()) {
          var selectedTop = $("#" + id).position().top; // 相对父级（list）的位置
          if (selectedTop) {
            $ionicScrollDelegate.$getByHandle('listScroll').scrollTo(0, selectedTop, true);
          }
        }
      }
    };
    $scope.getDropDownOptions();
    $scope.doBack = function () {
      history.back(-1);
    };

  }
})();
