/**
 * 特征照片审核列表 ctrl
 */
(function () {
  'use strict';

  angular
    .module('starter')
    .config(config)
    .factory('facePhotoCheckParameter', facePhotoCheckParameter)
    .controller('facePhotoCheckListCtrl', listCtrl)
    .controller('facePhotoCheckCtrl', checkCtrl)
  ;

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      .state('face_photo_check_list', {
        url: '/face_photo_check_list',
        templateUrl: 'templates/workspaceforteacher/facephotocheck/index.html',
        data: {
          prev: 'workspaceForTeacher',
          title: '特征照片审核'
        },
        controller: 'facePhotoCheckListCtrl',
        controllerAs: 'vm'
      })
      .state('face_photo_check', {
        url: '/face_photo_check?id',
        templateUrl: 'templates/workspaceforteacher/facephotocheck/checkPage.html',
        data: {
          prev: 'face_photo_check_list',
          title: '特征照片审核'
        },
        controller: 'facePhotoCheckCtrl',
        controllerAs: 'vm'
      })
    ;
  }

  function facePhotoCheckParameter() {
    var paramObj = {};

    function setter(obj) {
      angular.forEach(obj, function (value, key) {
        paramObj[key] = value;
      });
    }

    function getter() {
      return paramObj;
    }

    return {
      getter: getter,
      setter: setter
    };
  }

  listCtrl.$inject = ['$scope', '$http', '$ionicScrollDelegate', '$filter', '$state', 'facePhotoCheckParameter'];

  function listCtrl($scope, $http, $ionicScrollDelegate, $filter, $state, facePhotoCheckParameter) {
    var vm = this;

    vm.showName = showName;
    vm.onScroll = onScroll;
    vm.onScrollComplete = onScrollComplete;
    vm.toTarget = toTarget;
    vm.changeClass = changeClass;
    vm.changeName = changeName;
    vm.changeCheckStatus = changeCheckStatus;
    vm.goNameSearch = goNameSearch;
    vm.nameSearchBack = nameSearchBack;
    vm.refresh = refresh;
    vm.goCamera = goCamera;
    vm.goCheckPage = goCheckPage;

    vm.conditions = {
      searchFlag: false,
      checkStatus: null,
      name: '',
      classId: null
    };

    vm.currentTargetKey = null;
    vm.onScrollTimeout = null;

    vm.classList = [];
    vm.selectedClass = null;

    vm.userList = [];

    // 首字母
    vm.charArr = [];

    vm.headerHeight = 90;

    // 获取缓存的查询条件
    var _conditions = facePhotoCheckParameter.getter().conditions;
    if (null != _conditions) {
      vm.conditions = _conditions;
    }

    // 获取班级
    findClassInfoByTeacherId().then(function () {
      // 默认第一个班级
      if (vm.classList.length > 0 && null == vm.conditions.classId) {
        vm.selectedClass = vm.classList[0];
        vm.conditions.classId = vm.selectedClass.id;
      } else if (vm.classList.length > 0) {
        angular.forEach(vm.classList, function (c) {
          if (c.id === vm.conditions.classId) {
            vm.selectedClass = c;
          }
        });
      }
      // 查询列表数据
      if (vm.conditions.searchFlag) {
        vm.headerHeight = 45;
        findCheckListByClassId(null, vm.conditions.name);
      } else {
        vm.headerHeight = 90;
        findCheckListByClassId(vm.selectedClass.id);
      }
    });

    function showName(u) {
      var show = u.name;
      if (u.gender) {
        show += "(" + u.gender + ")";
      }
      return show;
    }

    function onScroll() {
      calculateTargetKey();
    }

    function calculateTargetKey() {
      console.log('calculate...');
      var items = angular.element('#ion-list .list').children();
      for (var i = 0; i < items.length; i++) {
        var item = items[i];
        var itemTop = angular.element(item).offset().top;
        var id = null;
        if (itemTop > 0) {
          id = angular.element(item).attr("id");
        } else {
          continue;
        }
        var arr = $filter('filter')(vm.userList, {id: id});
        if (null != arr && arr.length > 0) {
          vm.currentTargetKey = arr[0].firstChar;
          $scope.$apply();
          return;
        }
      }
    }

    function onScrollComplete() {
      console.log("complete...");
    }

    function toTarget(target) {
      var id = null;
      angular.forEach(vm.userList, function (d) {
        if (null == id && d.firstChar === target) {
          id = d.id;
        }
      });
      if (null == id) {
        return;
      }
      // 获取元素距离顶部的距离，减去头部的高度
      var top = angular.element('#' + id).offset().top - vm.headerHeight;
      $ionicScrollDelegate.$getByHandle('mainScroll').scrollBy(0, top, true);
    }

    function findClassInfoByTeacherId() {
      return $http.get(originBaseUrl + '/third/face/check/class/list.htm')
        .success(function (data) {
          if (data.status === 0) {
            vm.classList = data.result;
          }
          return data;
        });
    }

    function findCheckListByClassId(classId, name) {
      return $http.get(originBaseUrl + '/third/face/check/list.htm', {
        params: {
          classId: classId,
          name: name,
          checkStatus: vm.conditions.checkStatus
        }
      }).success(function (data) {
        // 滚到顶部
        $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        if (data.status === 0) {
          vm.userList = data.result;
          vm.charArr = [];
          // 处理首字母
          angular.forEach(vm.userList, function (u) {
            if (vm.charArr.indexOf(u.firstChar) === -1) {
              vm.charArr.push(u.firstChar);
            }
          });
        }
      });
    }

    function changeClass(c) {
      if (vm.selectedClass.id !== c.id) {
        vm.selectedClass = c;
        vm.conditions.classId = c.id;
        findCheckListByClassId(c.id);
      }
    }

    function changeName() {
      if (vm.changeNameTimeout) {
        window.clearTimeout(vm.changeNameTimeout);
      }
      if (null == vm.conditions.name || '' === vm.conditions.name) {
        return;
      }
      vm.changeNameTimeout = window.setTimeout(function () {
        findCheckListByClassId(null, vm.conditions.name);
      }, 1000);
    }

    function changeCheckStatus(checkStatus) {
      if (vm.conditions.checkStatus === checkStatus) {
        return;
      }
      vm.conditions.checkStatus = checkStatus;
      findCheckListByClassId(vm.selectedClass.id);
    }

    function goNameSearch() {
      vm.conditions.searchFlag = true;
      vm.conditions.checkStatus = null;
      vm.headerHeight -= 45;
      vm.userList = [];
      vm.charArr = [];
    }

    function nameSearchBack() {
      vm.conditions.name = '';
      vm.conditions.searchFlag = false;
      vm.headerHeight += 45;
      findCheckListByClassId(vm.selectedClass.id);
    }

    function refresh() {
      if (vm.conditions.searchFlag) {
        findCheckListByClassId(null, vm.conditions.name);
      } else {
        findCheckListByClassId(vm.selectedClass.id);
      }
    }

    function goCamera(stu) {
      // 给学生采集
      yn.plugin.yncordova.nativeStart({
        target: '106',
        params: {
          userId: stu.id,
          checkStatus:1
        }
      },function () {
        findCheckListByClassId(vm.selectedClass.id);
      });
    }

    function goCheckPage(stu) {
      // 保存当前页面的参数
      var ids = [];
      angular.forEach(vm.userList, function (stu) {
        if (stu.checkStatus !== 4) {
          ids.push(stu.id);
        }
      });
      facePhotoCheckParameter.setter({ids: ids, currentId: stu.id, conditions: vm.conditions});
      // 跳转到审核页面
      $state.go('face_photo_check', {id: stu.id});
    }
  }

  checkCtrl.$inject = ['$scope', '$http', '$stateParams', '$ionicPopup', '$state', 'facePhotoCheckParameter'];

  function checkCtrl($scope, $http, $stateParams, $ionicPopup, $state, facePhotoCheckParameter) {
    var vm = this;

    vm.showGenderAndNumber = showGenderAndNumber;
    vm.changeCheckStatus = changeCheckStatus;
    vm.changeNotFaceReason = changeNotFaceReason;
    vm.checkFaceFeature = checkFaceFeature;

    vm.originBaseUrl = originBaseUrl;

    vm.showParam = {};

    vm.saveParam = {
      id: $stateParams.id,
      checkStatus: 1,
      fsId: null,
      notFaceReason: null,
      customReason: null
    };

    getStuInfoById();

    // 获取页面显示的数据
    function getStuInfoById() {
      return $http.get(originBaseUrl + '/third/face/check/stu/info.htm', {
        params: {
          ids: [$stateParams.id]
        }
      }).success(function (data) {
        if (data.status === 0) {
          vm.showParam = data.result[0];
          return data;
        }
      });
    }

    function showGenderAndNumber() {
      var strArr = [];
      if (vm.showParam.gender) {
        strArr.push(vm.showParam.gender);
      }
      if (vm.showParam.userNumber) {
        strArr.push(vm.showParam.userNumber);
      }
      if (strArr.length > 0) {
        return '（' + strArr.join("，") + '）';
      }
      return '';
    }

    function changeCheckStatus(checkStatus) {
      if (checkStatus === vm.saveParam.checkStatus) {
        return;
      }
      vm.saveParam.checkStatus = checkStatus;
      if (checkStatus + '' === '1') {
        vm.saveParam.notFaceReason = '';
      } else if (checkStatus + '' === '2') {
        vm.saveParam.notFaceReason = '照片模糊不清';
      }
    }

    function changeNotFaceReason(reason) {
      vm.saveParam.notFaceReason = reason;
    }

    function getNextStuId(currentId) {
      var obj = facePhotoCheckParameter.getter();
      console.log(obj);
      var index = obj.ids.indexOf(currentId);
      if (index + 1 === obj.ids.length) {
        // 返回-1表示最后一条
        showTips('已经是最后一条！', function () {
          $state.go('face_photo_check_list');
        });
        return '-1';
      } else {
        return obj.ids[index + 1];
      }
    }

    function showTips(msg, callback) {
      $ionicPopup.show({
        template: msg,
        title: '提示',
        scope: $scope,
        buttons: [{
          text: '确定',
          type: 'button-positive',
          onTap: function () {
            if (null != callback && angular.isFunction(callback)) {
              callback();
            }
          }
        }]
      });
    }

    function checkFaceFeature(next) {
      var param = {
        checkStatus: vm.saveParam.checkStatus,
        notFaceReason: vm.saveParam.notFaceReason,
        id: vm.showParam.id,
        fsId: vm.showParam.fsId
      };
      if (vm.saveParam.notFaceReason === '自定义') {
        if (null == vm.saveParam.customReason || '' === vm.saveParam.customReason) {
          showTips('请输入打回修改的原因！');
          return;
        }
        param.notFaceReason = vm.saveParam.customReason;
      }
      // 调用保存
      doCheckFaceFeature(param, next)
    }

    function doCheckFaceFeature(obj, next) {
      return $http.post(originBaseUrl + '/third/face/check.htm', obj)
        .success(function (data) {
          if (data.status === 0) {
            showTips('审核成功！', function () {
              if (next) {
                // 获取下一条
                var id = getNextStuId(obj.id);
                if (id !== '-1') {
                  // 下一条
                  $state.go('face_photo_check', {id: id});
                }
              } else {
                // 返回上一级
                $state.go('face_photo_check_list');
              }
            })
          }
          return data;
        });
    }

  }
})();
