/**
 * 班主任工作台
 *
 * @author Jin
 */
(function () {
  'use strict';

  angular
    .module('starter')
    .config(config)
    .controller('workspaceForTeacherCtrl', ctrl);

  config.$inject = ['$stateProvider'];

  function config($stateProvider) {
    $stateProvider
      // 工作台
      .state('workspaceForTeacher', {
        firstPage: true,
        url: '/teacher/workspace',
        templateUrl: 'templates/workspaceforteacher/index.html',
        data: {
          title: '班主任工作'
        },
        controller: 'workspaceForTeacherCtrl',
        controllerAs: 'vm'
      });
  }

  ctrl.$inject = ['$http', '$state', '$location', 'storageService']

  function ctrl($http, $state, $location, storageService) {
    var vm = this;

    vm.preAdminClass = preAdminClass;
    vm.nextAdminClass = nextAdminClass;
    vm.gotoSubApp = gotoSubApp;

    vm.adminClasses = null;
    vm.showIndex = null;
    vm.statistics = {
      goBackToSchool: null,
      checkOnAttendance: null,
      stuLeave: null,
      stayOnSchoolRoom: null,
      dailyPoint: null,
      classPoint: null,
      stuPunish: null
    };

    var storageKey = 'teacher_workspace_class_id';

    // 获取班主任的行政班
    getAdminClassByTeacher().success(function () {
      if (null != vm.adminClasses && vm.adminClasses.length > 0) {
        var adminClassId = storageService.getItemNoDel(storageKey);
        if (adminClassId) {
          angular.forEach(vm.adminClasses, function (adminClass, index) {
            if (adminClass.id === adminClassId) {
              vm.showIndex = index;
            }
          });
          if (null == vm.showIndex) {
            vm.showIndex = 0;
            storageService.clearKey(storageKey);
          }
        } else {
          vm.showIndex = 0;
        }
        // 获取第一个行政班的统计数据
        getWorkSpaceStatistics(vm.adminClasses[vm.showIndex].id);
      }
    });

    function preAdminClass () {
      if (vm.adminClasses.length > 0) {
        if (vm.showIndex > 0) {
          vm.showIndex--;
          getWorkSpaceStatistics(vm.adminClasses[vm.showIndex].id);
        }
      }
    }

    function nextAdminClass () {
      if (vm.adminClasses.length > 0) {
        if (vm.showIndex < vm.adminClasses.length - 1) {
          vm.showIndex++;
          getWorkSpaceStatistics(vm.adminClasses[vm.showIndex].id);
        }
      }
    }

    function getAdminClassByTeacher() {
      return $http.get(originBaseUrl + '/third/work/space/list.htm', {
        params: {
          version: 'V1.0'
        }
      }).success(function (data) {
          if (data.status === 0) {
            vm.adminClasses = data.result;
          }
          return data;
        });
    }

    function getWorkSpaceStatistics(adminClassId) {
      return $http.get(originBaseUrl + '/third/work/space/statistics.htm', {
        params: {
          version: 'V1.0',
          adminClassId: adminClassId
        }
      }).success(function (data) {
        if (data.status === 0) {
          saveSelectedClassId(adminClassId);
          angular.forEach(vm.statistics, function (v, k) {
            vm.statistics[k] = data.result[k];
          });
        }
        return data;
      });
    }

    function gotoSubApp(state) {
      var obj = $state.get(state);
      $location.path(obj.url).search({classId: vm.adminClasses[vm.showIndex].id});
    }

    function saveSelectedClassId(classId) {
      storageService.setItem(storageKey, classId);
    }
  }
})();
