(function () {
    'use strict';
    angular.module('starter')
        .config(stateConfig)
        .controller('attAbnormalController', attAbnormalController)
        .controller('showAttDialogController', showAttDialogController)
        .controller('addAttDialogController', addAttDialogController)
        .controller('viewAttDialogController', viewAttDialogController)
        .controller('leaveRecordController', leaveRecordController)
        .controller('attendanceUserRecordCtrl', attendanceUserRecordCtrl)
        .controller('userAttViewController', userAttViewController)
        .controller('toDealWithDialogController', toDealWithDialogController)
        .controller('signInCtrl', signInCtrl)
        /**
         * 模态框管理器
         * 管理模态框的生命周期
         */
        .factory("attModalManager", function () {
            var modals = {};

            return {
                /**
                 * 判断是否存在
                 * @param modalName
                 * @returns {boolean}
                 */
                exist: function (modalName) {
                    var modal = modals[modalName];
                    if (modal) {
                        return true;
                    }
                    return false;
                },
                put: function (modalName, modal) {
                    if (!this.exist(modalName)) {
                        modals[modalName] = modal;
                    }
                },
                /**
                 * 获取
                 * @param modalName
                 * @returns {*}
                 */
                get: function (modalName) {
                    if (this.exist(modalName)) {
                        return modals[modalName];
                    }
                    return null;
                },
                /**
                 * 显示
                 * @param modalName
                 */
                show: function (modalName) {
                    if (this.exist(modalName)) {
                        modals[modalName].show();
                        this.showModals();
                    }
                },
                /**
                 * 关闭
                 * @param modalName
                 */
                close: function (modalName) {
                    if (this.exist(modalName)) {
                        modals[modalName].hide();
                        this.showModals();
                    }
                },
                /**
                 * 移除
                 * @param modalName
                 */
                remove: function (modalName) {
                    if (this.exist(modalName)) {
                        modals[modalName].remove();
                        delete modals[modalName];
                        this.showModals();
                    }
                },
                showModals: function () {
                    console.log(modals);
                }
            };
        })
        /***
         * 本地数据缓存
         */
        .factory("attStorageService", function () {
            /**
             * 可以插入undefined  null 或者是对象
             * 对key值的保护，只返回string
             * @param key
             */
            var translateKeyToStr = function (key) {
                if (angular.isUndefined(key)) {
                    return $rootScope.DEFAULT_KEY;
                } else if (angular.isObject(key) || angular.isArray(key) || angular.isNumber(+key || key)) {
                    return angular.toJson(key) + $rootScope.path;
                }
                /*增加对空字符串的支持*/
                else if (angular.isString(key)) {
                    if (key.length > 0) {
                        return key;
                    } else {
                        return $rootScope.DEFAULT_KEY;
                    }
                }
                /*增加对布尔值的支持*/
                else if (angular.isBoolean(key)) {
                    return key + "";
                }
                return $rootScope.DEFAULT_KEY;
            };
            /**
             * 根据 key删除缓存的数据
             * @param key
             */
            var removeValue = function (key) {
                if (window && window.localStorage) {
                    window.localStorage.removeItem(translateKeyToStr(key));
                }
            };
            /***
             * 保存数据和删除数据
             */
            return {
                getItem: function (key) {
                    if (window && window.localStorage) {
                        var _$ = window.localStorage.getItem(translateKeyToStr(key));
                        removeValue(translateKeyToStr(key));
                        if (_$) {
                            return angular.copy(JSON.parse(_$));
                        }
                        return null;
                    }
                },
                getItemNoDel: function (key) {
                    if (window && window.localStorage) {
                        var _$ = window.localStorage.getItem(translateKeyToStr(key));
                        if (_$) {
                            return angular.copy(JSON.parse(_$));
                        }
                        return null;
                    }
                },
                clearKey: function (key) {
                    removeValue(translateKeyToStr(key));
                },
                setItem: function (key, value) {
                    if (window && window.localStorage) {
                        if (value) {
                            window.localStorage.setItem(translateKeyToStr(key), JSON.stringify(value));
                        }
                    }
                }
            }
        });
    stateConfig.$inject = ['$stateProvider'];

    function stateConfig($stateProvider) {
        $stateProvider
        //按人员坐班考勤确认
            .state('attAbnormal', {
                url: '/attAbnormal',
                templateUrl: 'templates/zbkq/attAbnormal.html',
                data: {
                    micro: true,
                    title: '考勤结果管理',
                    prev: null
                },
                cache: false
            })
            //按班次坐班考勤确认
            .state('userAttView', {
                url: '/userAttView',
                templateUrl: 'templates/zbkq/time_attendance.html',
                data: {
                    title: '坐班考勤确认',
                    prev: 'attAbnormal'
                },
                cache: false
            })
            //坐班打卡结果
            .state('attendance_user_record', {
                firstPage: true,
                url: '/attendance_user_record',
                templateUrl: 'templates/zbkq/attendance_user_record.html',
                data: {
                    micro: true,
                    title: '考勤结果管理',
                    prev: null
                },
                controller: 'attendanceUserRecordCtrl',
                controllerAs: 'vm'
            })
            //活动打卡
            .state('sign_in', {
                firstPage: true,
                url: '/sign_in',
                templateUrl: 'templates/sign_in/sign_in.html',
                data: {
                    micro: true,
                    title: '考勤结果管理',
                    prev: null
                },
                controller: 'signInCtrl',
                controllerAs: 'vm'
            });

    }

    // 考勤异常确认列表
    attAbnormalController.$inject = ['$http', '$scope', 'ynuiNotification',
        "$ionicModal", "$timeout", "attStorageService", "$ionicPopup", "$ionicScrollDelegate", "$location", "ynNavigator", "$state"];

    function attAbnormalController($http, $scope, ynuiNotification, $ionicModal, $timeout, attStorageService, $ionicPopup,
                                   $ionicScrollDelegate, $location, ynNavigator, $state) {
        var oldSearchInfoData = $location.search();
        if (oldSearchInfoData && oldSearchInfoData.showDate && oldSearchInfoData.searchInfo) {
            $scope.oldData = JSON.parse(oldSearchInfoData.searchInfo);
            $scope.oldDataShowDate = JSON.parse(oldSearchInfoData.showDate);
        }


        var basePath = originBaseUrl + "/third/zbkqAtt";
        var vm = $scope.vm = {
            datetimeSettings: {
                buttons: ['set', 'cancel'],
                maxDate: new Date(),
            },
            // 考勤组是排班制且排班表用的是不在系统中排班的才显示这个按钮
            addFlag: false,
            // 是否默认展开第一个
            defaultFirstSpread: false,
            // 搜索
            searchFlag: false,
            // 默认 不显示
            showStatus: null,
            // 加载失败
            errorFlag: false,
            // 需管理的被考勤人员
            manageFlag: false,
            // 列表提示信息
            emptyInfo: null,
            // 考勤组
            ruleList: [],
            // 列表数据
            infoList: [],
            typeList: null,
            statusMapList: null,
            searchInfo: {
                ruleName: null,
                ruleId: null,
                name: null,
                type: null,
                date: null
            },
            // 日期显示
            showDate: {
                today: false,
                todayDate: null,
                week: "",
                showName: null
            },
            // 周
            arr: ["周日", "周一", "周二", "周三", "周四", "周五", "周六"],
            clickStatus: function (type) {
                vm.searchInfo.type = type;
                // vm.defaultFirstSpread = true;
                vm.getListInfo(null, null, type != null);
            },
            // 搜索
            searchUser: function () {
                $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                vm.searchFlag = true;
                vm.searchInfo.name = null;
                // vm.defaultFirstSpread = true;
                vm.infoList = [];
                if(!vm.searchInfo.name && vm.searchInfo.name !== '0'){
                    return false;
                }
                vm.getListInfo();
            },
            // 取消
            clearSearchName: function () {
                vm.searchFlag = false;
                vm.searchInfo.name = null;
                // vm.defaultFirstSpread = true;
                vm.getListInfo();
            },
            changeName: function () {
                // vm.defaultFirstSpread = true;
                vm.infoList = [];
                if(!vm.searchInfo.name && vm.searchInfo.name !== '0'){
                    return false;
                }
                vm.getListInfo();
            },
            // 获取列表数据
            getListInfo: function (first, oldValue, tabFlag) {
                vm.emptyInfo = null;
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    weekDay: vm.searchInfo.date,
                    type: vm.searchInfo.type,
                    first: first,
                    tabFlag: tabFlag,
                    name: vm.searchInfo.name
                };

                if (vm.searchFlag) {
                    param.type = null;
                    param.first = false;
                }

                $http.post(basePath + "/findTeacher.htm", param).success(function (data) {
                    if (data.status == 0) {
                        if (first || tabFlag) {
                            vm.searchInfo.type = data.result.defaultStatus;
                        }
                        vm.infoList = angular.copy(data.result.voList);
                        $timeout(function () {
                            vm.typeList = angular.copy(data.result.statusMap);
                            vm.notEnd = angular.copy(data.result.notEnd);
                            vm.statusMapList = angular.copy(data.result.statusMapList);
                        });
                        if (vm.infoList && vm.infoList.length > 0) {
                            vm.manageFlag = false;
                            if (oldValue) {
                                angular.forEach(vm.infoList, function (val) {
                                    if (val.id == oldValue.id) {
                                        val.up = false;
                                        vm.getAttDetail(val);
                                        // vm.defaultFirstSpread = false;
                                    }
                                });
                            } else
                            // 默认展开第一个
                            if (vm.defaultFirstSpread) {
                                vm.getAttDetail(vm.infoList[0]);
                                // vm.defaultFirstSpread = false;
                            }
                        } else {
                            if (!vm.searchFlag) {
                                vm.manageFlag = true;
                                vm.emptyInfo = "无考勤结果数据！";
                            }

                        }
                        // 是否确认
                        vm.showStatus = data.result.showStatus;


                    } else if (data.status == 10) {
                        vm.infoList = [];
                        vm.showStatus = null;
                        vm.manageFlag = true;
                        vm.emptyInfo = data.message;
                    } else {
                        vm.infoList = [];
                        vm.showStatus = null;
                        vm.manageFlag = true;
                        vm.emptyInfo = "加载失败！";
                    }
                });
            },
            // 人员打卡记录
            getAttDetail: function (info) {
                info.shiftVOList = [];
                if (info.up) {
                    info.up = false;
                    return false;
                } else {
                    info.up = true;
                }
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    weekDay: vm.searchInfo.date,
                    sysUserId: info.id,
                    type: vm.searchInfo.type,
                    resultIds: info.resultIds,
                };

                $http.post(basePath + "/findShift.htm", param).success(function (data) {
                    if (data.status == 0) {
                        info.shiftVOList = angular.copy(data.result);
                        info.up = true;
                    } else {
                        ynuiNotification.error({'msg': "获取数据失败！"});
                    }
                });
            },
            delResult: function (item) {
                $http.post(basePath + "/delResult.htm", {id: item.id}).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': "删除成功！"});
                        vm.getListInfo();
                        // vm.defaultFirstSpread = true;
                    } else {
                        ynuiNotification.error({'msg': "删除失败！"});
                    }
                });
            },
            // 获取考勤组
            findRuleByUser: function () {
                $http.post(basePath + "/findRuleByUser.htm").success(function (data) {
                    if (data.status == 0) {
                        vm.ruleList = angular.copy(data.result);
                        if (vm.ruleList && vm.ruleList.length > 0) {
                            if ($scope.oldData) {
                                angular.forEach(vm.ruleList, function (val) {
                                    if (val.id === $scope.oldData.ruleId) {
                                        vm.searchInfo.ruleName = val.name;
                                        vm.searchInfo.ruleId = val.id;
                                        vm.addFlag = val.userNumber == 'true';
                                    }
                                });
                            } else {
                                // 默认第一个
                                vm.searchInfo.ruleName = vm.ruleList[0].name;
                                vm.searchInfo.ruleId = vm.ruleList[0].id;
                                vm.addFlag = vm.ruleList[0].userNumber == 'true';
                            }
                            // 获取列表数据
                            vm.getListInfo();
                            vm.manageFlag = false;
                            vm.errorFlag = false;
                        } else {
                            vm.errorFlag = true;
                            vm.emptyInfo = "您没有需管理的被考勤人员！";
                        }

                    } else {
                        vm.ruleList = [];
                        vm.errorFlag = true;

                    }
                });
            },
            // 选择考勤组
            clickRule: function (item) {
                vm.searchInfo.ruleName = item.name;
                vm.searchInfo.ruleId = item.id;
                vm.addFlag = item.userNumber == 'true';
                // vm.defaultFirstSpread = true;
                vm.getListInfo();
            },
            // 修改考勤状态弹出框
            showAttDialog: function (info, par) {
                // 是否结束
                if (!info.endFlag) {
                    ynuiNotification.error({'msg': "该出勤时间的考勤还未结束，请结束后再确认！"});
                    return false;
                }
                var param = {
                    id: info.id
                };
                attStorageService.setItem("show_att_dialog", param);
                $scope.$on("show_att_dialog", function (event, data, flag) {
                    vm.affirmStatusModal.remove();
                    if (data) {
                        // 状态被修改
                        if (flag && par.shiftVOList.length == 1) {
                            vm.getListInfo();
                        } else {
                            vm.getListInfo(false, par);
                        }

                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/affirm_status.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.affirmStatusModal = modal;
                    vm.affirmStatusModal.show();
                });
            },
            // 添加异常结果数据
            addAttDialog: function () {
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    date: vm.searchInfo.date
                };
                attStorageService.setItem("add_att_dialog", param);
                $scope.$on("add_att_dialog", function (event, data) {
                    vm.addAttDialogModal.remove();
                    if (data) {
                        vm.getListInfo();
                        // vm.defaultFirstSpread = true;
                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/addAttDialog.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.addAttDialogModal = modal;
                    vm.addAttDialogModal.show();
                });
            },
            // 查看打卡记录
            viewAttDialog: function (info) {
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    date: vm.searchInfo.date,
                    sysUserId: info.teacherId
                };
                attStorageService.setItem("view_att_dialog", param);
                $scope.$on("view_att_dialog", function (event, data) {
                    vm.clockRecordModal.remove();
                    if (data) {
                        vm.getListInfo();
                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/clock_record.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.clockRecordModal = modal;
                    vm.clockRecordModal.show();
                    //修改title
                    vm.currentTitle = angular.copy($state.current.data && $state.current.data.title ? $state.current.data.title : null);
                    ynNavigator.setNavTitle("查看打卡记录");
                    ynNavigator.registerBackAction(function () {
                        $scope.$emit("view_att_dialog", false);
                        //还原title
                        if(vm.currentTitle){
                            ynNavigator.setNavTitle(vm.currentTitle);
                        }
                        //取消拦截注册
                        ynNavigator.cancelBackAction(201);
                    }, 201);
                });
            },
            // 正式提交效果：存在缺卡状态未处理，无法提交
            showMeg: function () {
                // 提交验证
                if (vm.emptyInfo) {
                    return false;
                } else if (vm.notEnd == false || (vm.typeList && vm.typeList.status_4 && vm.typeList.status_4.length > 0)) {
                    $ionicPopup.alert({
                        title: '提交失败！',
                        template: "存在考勤状态为“缺卡”的被考勤人，还未处理，请处理后再提交！",
                        okText: '关闭',
                    });
                } else if (vm.statusMapList && vm.statusMapList.allIds) {
                    $http.post(basePath + "/batchVerificationUser.htm", {ids: vm.statusMapList.allIds}).success(function (data) {
                        if (data.status == 0) {
                            vm.batchSubmit(vm.statusMapList.allIds);
                            // vm.defaultFirstSpread = true;
                        } else if (data.status == 10 || data.status == 11) {
                            $ionicPopup.alert({
                                title: '提示',
                                template: data.message,
                                okText: '关闭',
                            });
                        } else {
                            ynuiNotification.error({'msg': "操作失败！"});
                        }
                    });
                } else {
                    $ionicPopup.alert({
                        title: '提示',
                        template: "无考勤结果数据需要确认！",
                        okText: '关闭',
                    });
                }

            },
            // 一键处理
            batchSubmit: function (ids) {
                var param = {
                    ids: ids,
                    resultFlag: true
                };
                $http.post(basePath + "/batchAddUser.htm", param).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': "确认成功！"});
                        vm.getListInfo();
                        // vm.defaultFirstSpread = true;
                    } else {
                        ynuiNotification.error({'msg': "确认失败！"});
                    }
                });

            },
            // 获取当前日期
            getSystemDate: function () {
                $http.post(basePath + "/getSystemDate.htm").success(function (data) {
                    if (data.status == 0) {
                        vm.searchInfo.date = data.result.day;
                        vm.searchInfo.todayDate = data.result.day;
                        vm.showDate.today = true;
                        vm.showDate.week = vm.arr[data.result.week];
                        vm.showDate.showName = "[今天]" + vm.searchInfo.date + " " + vm.showDate.week;
                        vm.findRuleByUser();
                    }
                });
            },
            selectDateTime: function (item, inst) {
                var info = inst.getVal().toDateString();
                if (info.indexOf("Wed") > -1) {
                    vm.showDate.week = "周三";
                } else if (info.indexOf("Tue") > -1) {
                    vm.showDate.week = "周二";
                } else if (info.indexOf("Mon") > -1) {
                    vm.showDate.week = "周一";
                } else if (info.indexOf("Sun") > -1) {
                    vm.showDate.week = "周日";
                } else if (info.indexOf("Sat") > -1) {
                    vm.showDate.week = "周六";
                } else if (info.indexOf("Fri") > -1) {
                    vm.showDate.week = "周五";
                } else if (info.indexOf("Thu") > -1) {
                    vm.showDate.week = "周四";
                }
                vm.searchInfo.date = item;
                vm.showDate.showName = vm.searchInfo.date + " " + vm.showDate.week;
                if (item == vm.searchInfo.todayDate) {
                    vm.showDate.showName = "[今天]" + vm.showDate.showName;
                }
                // 强制渲染
                $timeout(function () {
                    vm.showDate.showName;
                });
                // vm.defaultFirstSpread = true;
                // 获取数据
                vm.getListInfo();
            },
            // true 上一天 下一天
            goToDay: function (flag) {
                var param = {
                    date: vm.searchInfo.date,
                    flag: flag
                }
                $http.post(basePath + "/getDate.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.searchInfo.date = data.result.day;
                        vm.searchInfo.todayDate = data.result.day;
                        vm.showDate.today = false;
                        vm.showDate.week = vm.arr[data.result.week];
                        vm.showDate.showName = (data.result.today ? "[今天]" : "") + vm.searchInfo.date + " " + vm.showDate.week;
                        // 获取数据
                        vm.getListInfo();
                    } else {
                        ynuiNotification.error({'msg': data.message});
                    }
                });
            },
            // 切换
            switchShift: function () {
                $location.path("/userAttView").search({
                    "searchInfo": JSON.stringify(vm.searchInfo),
                    "showDate": JSON.stringify(vm.showDate)
                });
            }

        };


        // 初始化
        function init() {
            // 按人员跳转时
            if ($scope.oldData) {
                vm.searchInfo = angular.copy($scope.oldData);
                vm.showDate = angular.copy($scope.oldDataShowDate);
                vm.findRuleByUser();
            } else {
                vm.getSystemDate();
            }

        }

        init();

    }

    // 修改考勤状态
    showAttDialogController.$inject = ['$http', '$scope', 'ynuiNotification',
        "attStorageService", "$ionicModal"];

    function showAttDialogController($http, $scope, ynuiNotification, attStorageService, $ionicModal) {
        var basePath = originBaseUrl + "/third/zbkqAtt";

        var oldValue = attStorageService.getItem("show_att_dialog");

        var vm = $scope.vm = {
            datetimeSettings: {
                buttons: ['set', 'cancel', 'clear']
            },
            detailInfo: null,
            // 查看请假或出差
            leaveRecordClick: function () {
                var param = {
                    sysUserId: vm.detailInfo.teacherId,
                    locateTime: vm.detailInfo.kqDatetime,
                    userName: vm.detailInfo.name
                };
                attStorageService.setItem("view_att_leave", param);
                $scope.$on("view_att_leave", function (event, data) {
                    vm.leaveRecordModal.remove();
                    if (data) {
                        vm.getListInfo();
                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/leaveRecord.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.leaveRecordModal = modal;
                    vm.leaveRecordModal.show();
                });
            },
            // 状态选中样式
            getStatusClass: function (type) {
                if (vm.detailInfo && vm.detailInfo.status) {
                    return {'active': type == vm.detailInfo.status};
                }
                return "";
            },
            clickStatus: function (type) {
                vm.detailInfo.status = type;
                if (type == 1) {
                    vm.detailInfo.clockTime = vm.detailInfo.time.replace("(", "").replace(")", "");
                } else {
                    vm.detailInfo.clockTime = null;
                }
            },
            selectDateTime: function (item) {
                vm.detailInfo.clockTime = item;
            },
            // 获取 详情
            findDetailById: function () {
                var param = {
                    id: oldValue.id
                };
                $http.post(basePath + "/findDetailById.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.detailInfo = angular.copy(data.result);
                        oldValue.status = vm.detailInfo.status;
                        // 缺卡默认 正常
                        if (vm.detailInfo.status == 4) {
                            vm.clickStatus(1);
                        }
                    }
                });
            },
            // 确认
            saveInfo: function () {
                var param = {
                    id: vm.detailInfo.id,
                    remarks: vm.detailInfo.remarks,
                    status: vm.detailInfo.status
                };
                if (vm.detailInfo.status == 2 || vm.detailInfo.status == 3) {
                    if (vm.detailInfo.minutes) {
                        // 格式验证
                        var reg = new RegExp(/^[0-9]+$/);
                        if (reg.test(vm.detailInfo.minutes) && Number(vm.detailInfo.minutes) > 0 && Number(vm.detailInfo.minutes) <= 1440) {
                            param.minutes = vm.detailInfo.minutes;
                        } else {
                            ynuiNotification.error({'msg': "分钟数请输入1-1440的整数！"});
                            return false;
                        }
                    } else if (vm.detailInfo.minutes == '0') {
                        ynuiNotification.error({'msg': "分钟数请输入1-1440的整数！"});
                        return false;
                    } else {
                        ynuiNotification.error({'msg': "请填写分钟数！"});
                        return false;
                    }
                }
                if (vm.detailInfo.status == 1) {
                    if (vm.detailInfo.clockTime) {
                        param.clockTime = vm.detailInfo.clockTime;
                    } else {
                        ynuiNotification.error({'msg': "请填写打卡时间！"});
                        return false;
                    }
                }
                if (vm.detailInfo.status == 5) {
                    if (vm.detailInfo.clockTime) {
                        param.clockTime = vm.detailInfo.clockTime;
                    }
                }
                $http.post(basePath + "/updateStatus.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.clickAttDialog(true, oldValue.status != vm.detailInfo.status);
                    } else {
                        ynuiNotification.error({'msg': '保存失败！'});
                    }
                });
            },

            // 取消
            clickAttDialog: function (flag, fff) {
                $scope.$emit("show_att_dialog", flag, fff);
            }
        };

        vm.findDetailById();

    }

    // 新增考勤异常结果数据
    addAttDialogController.$inject = ['$http', '$scope', 'ynuiNotification', "attStorageService",
        "$ionicPopup", "$timeout"];

    function addAttDialogController($http, $scope, ynuiNotification, attStorageService, $ionicPopup, $timeout) {
        var basePath = originBaseUrl + "/third/zbkqAtt";

        var oldValue = attStorageService.getItem("add_att_dialog");

        var vm = $scope.vm = {
            datetimeSettings: {
                buttons: ['set', 'cancel', 'clear'],
                maxDate: new Date(),
            },
            userList: [],
            shiftList: [],
            timeList: [],
            statusList: [],
            saveInfo: {
                currentUserId: "",
                shiftId: "",
                punchRequirementsId: "",
                status: ""
            },
            selectDateTime: function (item) {
                vm.saveInfo.clockTime = item;
            },
            // 选择班次
            changeShift: function (id) {
                angular.forEach(vm.shiftList, function (shift) {
                    if (shift.id === id) {
                        vm.timeList = angular.copy(shift.children);
                        vm.saveInfo.punchRequirementsId = "";
                        vm.saveInfo.status = "";
                        vm.statusList = [];
                        vm.saveInfo.clockTime = "";
                        vm.saveInfo.minutes = "";
                    }
                });
            },
            // 选择出勤时间
            changePunch: function (id) {
                angular.forEach(vm.timeList, function (punch) {
                    if (punch.id === id) {
                        vm.saveInfo.status = "";
                        vm.saveInfo.clockTime = "";
                        vm.saveInfo.minutes = "";
                        // 上班
                        if (punch.name.indexOf("上班") > -1) {
                            vm.statusList = [
                                {name: "正常", id: 1},
                                {name: "迟到", id: 2},
                                {name: "请假", id: 6},
                                {name: "出差", id: 7},
                                {name: "旷工", id: 5},
                                {name: "无需打卡", id: 8}
                            ];
                        } else {
                            vm.statusList = [
                                {name: "正常", id: 1},
                                {name: "早退", id: 3},
                                {name: "请假", id: 6},
                                {name: "出差", id: 7},
                                {name: "旷工", id: 5},
                                {name: "无需打卡", id: 8}
                            ];
                        }
                    }
                });
            },
            // 设置状态
            changeStatus: function (status) {
                if (status === 1 || status === 5) {
                    vm.saveInfo.minutes = "";
                } else if (status === 2 || status === 3) {
                    vm.saveInfo.clockTime = "";
                } else {
                    vm.saveInfo.minutes = "";
                    vm.saveInfo.clockTime = "";
                }
                // 正常 设置默认时间
                if (status == 1) {
                    angular.forEach(vm.timeList, function (value) {
                        if (vm.saveInfo.punchRequirementsId == value.id) {
                            vm.saveInfo.clockTime = value.userNumber;
                        }
                    });
                } else {
                    vm.saveInfo.clockTime = null;
                }


            },
            // 获取 人员、班次、出勤时间点
            findUserShiftTime: function () {
                var param = {
                    userFlag: 1,
                    ruleId: oldValue.ruleId,
                    weekDay: oldValue.date,
                };
                $http.post(basePath + "/findUserShiftTime.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.userList = angular.copy(data.result.user);
                        vm.shiftList = angular.copy(data.result.information);
                    } else {
                        ynuiNotification.error({'msg': '添加失败！'});
                    }
                });
            },
            // 保存
            addInfo: function () {
                var param = angular.copy(vm.saveInfo);
                // 判断必填
                if (!param.currentUserId) {
                    ynuiNotification.error({'msg': "请选择人员！"});
                    return false;
                }
                if (!param.shiftId) {
                    ynuiNotification.error({'msg': "请选择班次！"});
                    return false;
                }
                if (!param.punchRequirementsId) {
                    ynuiNotification.error({'msg': "请选择出勤时间！"});
                    return false;
                }
                if (!param.status) {
                    ynuiNotification.error({'msg': "请设置考勤状态！"});
                    return false;
                }
                if (vm.saveInfo.status == 2 || vm.saveInfo.status == 3) {
                    if (vm.saveInfo.minutes) {
                        // 格式验证
                        var reg = new RegExp(/^[0-9]+$/);
                        if (reg.test(vm.saveInfo.minutes) && Number(vm.saveInfo.minutes) > 0 && Number(vm.saveInfo.minutes) <= 1440) {
                            param.minutes = vm.saveInfo.minutes;
                        } else if (vm.saveInfo.minutes == '0') {
                            ynuiNotification.error({'msg': "分钟数请输入1-1440的整数！"});
                            return false;
                        } else {
                            ynuiNotification.error({'msg': "分钟数请输入1-1440的整数！"});
                            return false;
                        }
                    } else {
                        ynuiNotification.error({'msg': '请填写分钟数！'});
                        return false;
                    }

                }
                if (vm.saveInfo.status == 1) {
                    if (vm.saveInfo.clockTime) {
                    } else {
                        ynuiNotification.error({'msg': '请填写打卡时间！'});
                        return false;
                    }
                }
                param.ruleId = oldValue.ruleId;
                param.kqDatetime = oldValue.date;
                $http.post(basePath + "/addAttUser.htm", param).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': '添加成功！'});
                        $timeout(function () {
                            vm.clickAttDialog(true);
                        });
                    } else if (data.status == 10) {
                        var name = "";
                        angular.forEach(vm.userList, function (u) {
                            if (u.id === param.currentUserId) {
                                name = u.name;
                            }
                        });
                        $ionicPopup.confirm({
                            title: '提交失败！',
                            template: name + "已存在该班次出勤时间的考勤结果，您确定要修改原有考勤结果吗？",
                            cancelText: '取消',
                            okText: '确认'
                        }).then(function (res) {
                            if (res && data.status == 10) {
                                param.id = data.message;
                                vm.updateStatus(param);
                            }
                        });
                    } else if (data.status == 11) {
                        ynuiNotification.error({'msg': data.message});
                        return false;
                    } else {
                        ynuiNotification.error({'msg': '添加失败！'});
                    }
                });
            },
            // 确认
            updateStatus: function (param) {
                $http.post(basePath + "/updateStatus.htm", param).success(function (data) {
                    if (data.status == 0) {
                        $timeout(function () {
                            vm.clickAttDialog(true);
                        });
                    } else {
                        ynuiNotification.error({'msg': '保存失败！'});
                    }
                });
            },
            // 修改考勤状态
            clickAttDialog: function (flag) {
                $scope.$emit("add_att_dialog", flag);
            }
        };


        vm.findUserShiftTime();


    }

    // 打卡记录
    viewAttDialogController.$inject = ['$http', '$scope', "attStorageService", "$ionicModal"];

    function viewAttDialogController($http, $scope, attStorageService, $ionicModal) {

        var basePath = originBaseUrl + "/third/zbkqAtt";

        var oldValue = attStorageService.getItem("view_att_dialog");

        var vm = $scope.vm = {
            searchInfoDate: angular.copy(oldValue.date),
            // 今天
            today: angular.copy(oldValue.date),
            // 昨天
            yesterday: null,
            // 明天
            tomorrow: null,
            userRecordList: [],
            // 获取打卡记录
            findUserRecord: function (info) {
                var param = angular.copy(oldValue);
                param.locateTime = info;
                vm.searchInfoDate = angular.copy(info);
                vm.userRecordList = [];
                $http.post(basePath + "/findUserRecord.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.userRecordList = angular.copy(data.result);
                    }
                });
            },
            getDays: function () {
                $http.post(basePath + "/getDays.htm", {day: oldValue.date}).success(function (data) {
                    if (data.status == 0) {
                        vm.yesterday = data.result.yesterday;
                        vm.tomorrow = data.result.tomorrow;
                    }
                });
            },
            getClass: function (item) {
                if (!vm.searchInfoDate) {
                    vm.searchInfoDate = oldValue.date;
                }
                return {'active': item == vm.searchInfoDate};
            },
            // 取消
            clickAttDialog: function (flag) {
                $scope.$emit("view_att_dialog", flag);
            },
            // 查看图片
            previewPhoto: function (value) {
                var list = [];
                angular.forEach(value, function (val, index) {
                    list.push({id: index + 1, url: originBaseUrl + "/file/downloadStream.htm?fastDFSId=" + val});
                    // list.push();
                });

                $scope.photoShowList = angular.copy(list);
                // 默认第一张
                $scope.photoInfo = $scope.photoShowList[0];

                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/showPhoto.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.showPhotoModal = modal;
                    vm.showPhotoModal.show();
                });
            },
            next: function (info, type) {
                angular.forEach($scope.photoShowList, function (value) {
                    if ((info.id + type) === value.id) {
                        $scope.photoInfo = angular.copy(value);
                    }
                });
            }
        };


        vm.getDays();
        vm.findUserRecord(oldValue.date);

        $scope.hideShowModal = function () {
            if (vm.showPhotoModal) {
                vm.showPhotoModal.remove();
            }
        }

    }

    // 请假记录
    leaveRecordController.$inject = ['$http', '$scope', "attStorageService"];

    function leaveRecordController($http, $scope, attStorageService) {
        var basePath = originBaseUrl + "/third/zbkqAtt";

        var oldValue = attStorageService.getItem("view_att_leave");

        var vm = $scope.vm = {
            leaveRecordList: [],
            userName: oldValue.userName,
            // 获取请假记录
            findUserLeave: function () {
                vm.leaveRecordList = [];
                $http.post(basePath + "/findUserLeave.htm", oldValue).success(function (data) {
                    if (data.status == 0) {
                        vm.leaveRecordList = angular.copy(data.result);
                    }
                });
            },
            // 取消
            clickAttDialog: function (flag) {
                $scope.$emit("view_att_leave", flag);
            }
        };


        vm.findUserLeave();
    }

    //坐班打卡结果
    attendanceUserRecordCtrl.$inject = ['$scope', '$http', '$ionicScrollDelegate', '$timeout', '$ionicPopup', 'stringsConstant'];

    function attendanceUserRecordCtrl($scope, $http, $ionicScrollDelegate, $timeout, $ionicPopup, stringsConstant) {

        var vm = this;
        var basePath = originBaseUrl + "/third/zbkqAtt";


        vm.findRuleByUser = findRuleByUser;
        vm.clickRule = clickRule;
        vm.findAttUserRecord = findAttUserRecord;
        vm.getStatusStr = getStatusStr;
        vm.getColor = getColor;

        vm.monthList = [];
        vm.ruleList = [];
        vm.dateList = [];
        vm.pageSize = 0;
        vm.pageNumber = 0;
        vm.signInStatus = 1;
        vm.rule = {id: null, name: null};

        /**
         * 获取系统时间和当前的登陆人员
         */
        function findRuleByUser() {
            $http.post(basePath + '/findRuleByUser.htm', {viewSearch: true}).then(function (response) {
                if (response.status === 200 && response.data.status === 0) {
                    vm.ruleList = angular.copy(response.data.result);
                    if (vm.ruleList && vm.ruleList.length > 0) {
                        vm.rule = response.data.result[0];
                        vm.findAttUserRecord();
                    } else {
                        vm.signInStatus = 0;
                    }

                } else {
                    vm.signInStatus = 0;
                }

            });
        }


        //初始化人员信息
        vm.findRuleByUser();


        /**
         * 查询一个人的打卡记录
         */
        function findAttUserRecord() {
            if (!vm.rule) {
                return false;
            }
            vm.pageSize += 20;
            return $http.post(basePath + '/findAttUserRecord.htm',
                {
                    pageNumber: vm.pageNumber,
                    pageSize: vm.pageSize,
                    ruleId: vm.rule.id
                }
            ).then(function (response) {
                if (vm.monthList.length === 0) {
                    $scope.dateList = [];
                    vm.signInStatus = 1;
                    angular.forEach(response.data.result, function (month) {
                        angular.forEach(month.signInList, function (sign) {
                            $scope.dateList.push(sign);
                        })
                    });
                    vm.dateList = $scope.dateList;
                } else {
                    $scope.dateList = [];
                    angular.forEach(response.data.result, function (month) {
                        angular.forEach(month.signInList, function (sign) {
                            $scope.dateList.push(sign);
                        })
                    });
                    if (vm.dateList.length === $scope.dateList.length) {
                        vm.signInStatus = 0;
                    } else {
                        vm.signInStatus = 1;
                    }
                    vm.dateList = $scope.dateList;
                }
                $timeout(function () {
                    vm.monthList = angular.copy(response.data.result);
                    angular.forEach(vm.monthList, function (month) {
                        angular.forEach(month.child, function (sign) {
                            if (sign.fastDFSIds) {
                                var fastDFSIds = sign.fastDFSIds.split(',');
                                var photoSrcList = [];
                                angular.forEach(fastDFSIds, function (fastDFSId, index) {
                                    photoSrcList.push({
                                        id: index,
                                        src: stringsConstant.file.downloadServer() + fastDFSId
                                    });
                                });
                                sign.photoSrcList = photoSrcList;
                            }
                        });
                    });
                });
                $scope.$broadcast('scroll.infiniteScrollComplete');
            })
        }


        function getStatusStr(status) {
            var str = "";
            if (status) {
                switch (status) {
                    case 1:
                        str = "正常";
                        break;
                    case 2:
                        str = "迟到";
                        break;
                    case 3:
                        str = "早退";
                        break;
                    case 4:
                        str = "缺卡";
                        break;
                    case 5:
                        str = "旷工";
                        break;
                    case 6:
                        str = "请假";
                        break;
                    case 7:
                        str = "出差";
                        break;
                    case 8:
                        str = "无需打卡";
                        break;
                    default:
                        break;
                }
            }
            return str;
        }


        function getColor(status) {
            var str = "";
            if (status) {
                switch (status) {
                    case 1:
                        str = "";
                        break;
                    case 2:
                        str = '#ca6e03';
                        break;
                    case 3:
                        str = '#ca6e03';
                        break;
                    case 4:
                        str = 'red';
                        break;
                    case 5:
                        str = 'red';
                        break;
                    case 6:
                        str = '#0d8783';
                        break;
                    case 7:
                        str = '#0d8783';
                        break;
                    case 8:
                        str = '#0d8783';
                        break;
                    default:
                        break;
                }
            }
            return str;
        }


        function clickRule(info) {
            vm.rule = angular.copy(info);
            vm.pageSize = 0;
            vm.monthList = [];
            $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
            vm.findAttUserRecord();
        }


        // 预览照片
        $scope.previewPhoto = function (photo) {
            var cordovaFileOpen = cordova.plugins.disusered.open;
            cordovaFileOpen(originBaseUrl + "/file/downloadStream.htm?fastDFSId=" + photo.uri, cordovaFileOpenSuccess, cordovaFileOpenError);

            function cordovaFileOpenSuccess() {
                // 从已安装程序中打开文件完成
            }

            function cordovaFileOpenError(code) {
                if (code === 1) {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '未能在手机已安装APP中找到可预览此文件的程序'
                    });
                } else {
                    $ionicPopup.alert({
                        title: '文件预览提示',
                        template: '预览时发生了未知错误 #' + code
                    });
                }
            }
        };
    }

    //按班次确认结果 列表
    userAttViewController.$inject = ['$http', '$scope', 'ynuiNotification', "$ionicModal", "$timeout", "attStorageService", "$ionicPopup", "$ionicScrollDelegate", "$location", "ynNavigator", "$state"];

    function userAttViewController($http, $scope, ynuiNotification, $ionicModal, $timeout, attStorageService, $ionicPopup,
                                   $ionicScrollDelegate, $location, ynNavigator, $state) {
        var oldSearchInfoData = $location.search();
        if (oldSearchInfoData && oldSearchInfoData.showDate && oldSearchInfoData.searchInfo) {
            $scope.oldData = JSON.parse(oldSearchInfoData.searchInfo);
            $scope.oldDataShowDate = JSON.parse(oldSearchInfoData.showDate);
        }

        var basePath = originBaseUrl + "/third/zbkqAtt";
        var vm = $scope.vm = {
            viewDataModal: null,
            datetimeSettings: {
                buttons: ['set', 'cancel'],
                maxDate: new Date(),
            },
            // 考勤组是排班制且排班表用的是不在系统中排班的才显示这个按钮
            addFlag: false,
            // 是否默认展开第一个
            defaultFirstSpread: false,
            // 搜索
            searchFlag: false,
            // 默认 不显示
            showStatus: null,
            // 加载失败
            errorFlag: false,
            // 需管理的被考勤人员
            manageFlag: false,
            // 列表提示信息
            emptyInfo: null,
            // 考勤组
            ruleList: [],
            // 列表数据
            infoList: [],
            typeList: null,
            statusMapList: null,
            searchInfo: {
                ruleName: null,
                ruleId: null,
                name: null,
                type: null,
                date: null
            },
            // 日期显示
            showDate: {
                today: false,
                todayDate: null,
                week: "",
                showName: null
            },
            // 周
            arr: ["周日", "周一", "周二", "周三", "周四", "周五", "周六"],
            clickStatus: function (type) {
                vm.searchInfo.type = type;
                vm.defaultFirstSpread = false;
                vm.getListInfo(null, null, type != null);
            },
            // 搜索人员数量
            getCount: function () {
                var size = 0;
                angular.forEach(vm.infoList, function (info) {
                    if (info.ids && info.ids.length > 0) {
                        size += info.ids.length;
                    }
                });
                return size;
            },
            // 搜索
            searchUser: function () {
                $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                vm.searchFlag = true;
                vm.searchInfo.name = null;
                vm.defaultFirstSpread = false;
                vm.getListInfo();
            },
            // 取消
            clearSearchName: function () {
                vm.searchFlag = false;
                vm.searchInfo.name = null;
                vm.defaultFirstSpread = false;
                vm.getListInfo();
            },
            changeName: function () {
                vm.defaultFirstSpread = false;
                vm.getListInfo();
            },
            // 班次
            clickShiftClass: function (item) {
                if (item.active) {
                    item.active = false;
                    if (item.teacherVOList && item.teacherVOList.length > 0) {
                        angular.forEach(item.teacherVOList, function (user) {
                            user.active = false;
                        });
                    }
                } else {
                    item.active = true;
                    if (item.teacherVOList && item.teacherVOList.length > 0) {
                        angular.forEach(item.teacherVOList, function (user) {
                            user.active = true;
                        });
                    } else {
                        vm.getAttDetail(item, true);
                    }
                }
            },
            // 人员
            clickUserClass: function (user, item) {
                if (user.active) {
                    user.active = false;
                } else {
                    user.active = true;
                }
                // 处理班次是否选中
                var count = 0;
                angular.forEach(item.teacherVOList, function (info) {
                    if (info.active) {
                        count++;
                    }
                });
                item.active = count == item.teacherVOList.length;
            },
            // 获取所有选中 人员{
            getSelectedCount: function () {
                var count = 0;
                if (vm.infoList && vm.infoList.length > 0) {
                    angular.forEach(vm.infoList, function (item) {
                        if (item.active) {
                            count += item.ids.length;
                        } else {
                            angular.forEach(item.teacherVOList, function (user) {
                                if (user.active) {
                                    count++;
                                }
                            });
                        }

                    });
                }
                return count;
            },
            // 获取列表数据
            getListInfo: function (first, oldValue, tabFlag) {
                vm.teacherVOList = [];
                vm.infoList = [];
                vm.emptyInfo = null;
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    weekDay: vm.searchInfo.date,
                    type: vm.searchInfo.type,
                    first: first,
                    tabFlag: tabFlag,
                    name: vm.searchInfo.name
                };
                if (vm.searchFlag) {
                    param.type = null;
                    param.first = false;
                }
                $http.post(basePath + "/findShiftUser.htm", param).success(function (data) {
                    if (data.status == 0) {
                        if (first || tabFlag) {
                            vm.searchInfo.type = data.result.defaultStatus;
                        }
                        vm.infoList = angular.copy(data.result.voList);
                        $timeout(function () {
                            vm.typeList = angular.copy(data.result.statusMap);
                            vm.notEnd = angular.copy(data.result.notEnd);
                            vm.statusMapList = angular.copy(data.result.statusMapList);
                        });
                        if (vm.infoList && vm.infoList.length > 0) {
                            vm.manageFlag = false;
                            if (oldValue) {
                                angular.forEach(vm.infoList, function (val) {
                                    if (val.id == oldValue.id) {
                                        val.up = false;
                                        vm.getAttDetail(val);
                                    }
                                });
                            } else
                            // 默认展开第一个
                            if (vm.defaultFirstSpread) {
                                vm.getAttDetail(vm.infoList[0]);
                            }

                            vm.defaultFirstSpread = false;
                        } else {
                            if (!vm.searchFlag) {
                                vm.manageFlag = true;
                                vm.emptyInfo = "无考勤结果数据！";
                            }
                        }
                        // 是否确认
                        vm.showStatus = data.result.showStatus;
                    } else if (data.status == 10) {
                        vm.infoList = [];
                        vm.showStatus = null;
                        vm.manageFlag = true;
                        vm.emptyInfo = data.message;
                    } else {
                        vm.infoList = [];
                        vm.showStatus = null;
                        vm.manageFlag = true;
                        vm.emptyInfo = "加载失败！";
                    }
                });
            },
            // 人员打卡记录
            getAttDetail: function (info, flag) {
                info.teacherVOList = [];
                if (info.up) {
                    info.up = false;
                    return false;
                } else {
                    info.up = true;
                }
                var param = {
                    resultIds: info.ids
                };

                $http.post(basePath + "/findShiftUserDetail.htm", param).success(function (data) {
                    if (data.status == 0) {
                        info.teacherVOList = angular.copy(data.result);
                        angular.forEach(info.teacherVOList, function (user) {
                            user.active = info.active;
                        });
                        if (!flag) {
                            info.up = true;
                        }
                    } else {
                        ynuiNotification.error({'msg': "获取数据失败！"});
                    }
                });
            },
            // 获取考勤组
            findRuleByUser: function () {
                $http.post(basePath + "/findRuleByUser.htm").success(function (data) {
                    if (data.status == 0) {
                        vm.ruleList = angular.copy(data.result);
                        if (vm.ruleList && vm.ruleList.length > 0) {
                            if ($scope.oldData) {
                                angular.forEach(vm.ruleList, function (val) {
                                    if (val.id === $scope.oldData.ruleId) {
                                        vm.searchInfo.ruleName = val.name;
                                        vm.searchInfo.ruleId = val.id;
                                        vm.addFlag = val.userNumber == 'true';
                                    }
                                });
                            } else {
                                // 默认第一个
                                vm.searchInfo.ruleName = vm.ruleList[0].name;
                                vm.searchInfo.ruleId = vm.ruleList[0].id;
                                vm.addFlag = vm.ruleList[0].userNumber == 'true';
                            }

                            // 默认不展开
                            vm.getListInfo(false);
                            vm.manageFlag = false;
                            vm.errorFlag = false;
                        } else {
                            vm.errorFlag = true;
                            vm.emptyInfo = "您没有需管理的被考勤人员！";
                        }

                    } else {
                        vm.ruleList = [];
                        vm.errorFlag = true;
                    }
                });
            },
            // 选择考勤组
            clickRule: function (item) {
                vm.searchInfo.ruleName = item.name;
                vm.searchInfo.ruleId = item.id;
                vm.addFlag = item.userNumber == 'true';
                vm.defaultFirstSpread = false;
                // 默认不展开
                vm.getListInfo(false);
            },
            // 修改考勤状态弹出框
            showAttDialog: function (info, value) {
                // 是否结束
                if (!info.endFlag) {
                    ynuiNotification.error({'msg': "该出勤时间的考勤还未结束，请结束后再确认！"});
                    return false;
                }
                var param = {
                    id: info.id
                };
                attStorageService.setItem("show_att_dialog", param);
                $scope.$on("show_att_dialog", function (event, data, flag) {
                    vm.showAttDialogModal.remove();
                    if (data) {
                        // 状态被修改
                        if (flag && value.teacherVOList.length == 1) {
                            // 默认不展开
                            vm.getListInfo(false);
                        } else {
                            vm.getListInfo(false, value);
                        }

                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/affirm_status.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.showAttDialogModal = modal;
                    vm.showAttDialogModal.show();
                });
            },
            // 添加异常结果数据
            addAttDialog: function () {
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    date: vm.searchInfo.date
                };
                attStorageService.setItem("add_att_dialog", param);
                $scope.$on("add_att_dialog", function (event, data) {
                    vm.addAttDialogModal.remove();
                    if (data) {
                        vm.defaultFirstSpread = false;
                        // 默认不展开
                        vm.getListInfo(false);
                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/addAttDialog.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.addAttDialogModal = modal;
                    vm.addAttDialogModal.show();
                });
            },
            delResult: function (item) {
                $http.post(basePath + "/delResult.htm", {id: item.id}).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': "删除成功！"});
                        vm.defaultFirstSpread = false;
                        // 默认不展开
                        vm.getListInfo(false);
                    } else {
                        ynuiNotification.error({'msg': "删除失败！"});
                    }
                });
            },
            // 查看打卡记录
            viewAttDialog: function (info) {
                var param = {
                    ruleId: vm.searchInfo.ruleId,
                    date: vm.searchInfo.date,
                    sysUserId: info.teacherId
                };
                attStorageService.setItem("view_att_dialog", param);
                $scope.$on("view_att_dialog", function (event, data) {
                    vm.viewAttDialogModal.remove();
                    //还原Title
                    if(vm.currentTitle){
                        ynNavigator.setNavTitle(vm.currentTitle);
                    }
                    if (data) {
                        vm.getListInfo();
                    }
                });
                $ionicModal.fromTemplateUrl('templates/zbkq/dialog/clock_record.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.viewAttDialogModal = modal;
                    vm.viewAttDialogModal.show();
                    vm.currentTitle = angular.copy($state.current.data && $state.current.data.title ? $state.current.data.title : null);
                    //修改title
                    ynNavigator.setNavTitle("查看打卡记录");
                    // ynNavigator.registerBackAction(function () {
                    //     vm.viewAttDialogModal.remove();
                    // }, 201);
                });
            },
            // 正式提交效果：存在缺卡状态未处理，无法提交
            showMeg: function () {
                // 提交验证
                if (vm.emptyInfo) {
                    return false;
                } else if (vm.notEnd == false || (vm.typeList && vm.typeList.status_4 && vm.typeList.status_4.length > 0)) {
                    $ionicPopup.alert({
                        title: '提交失败！',
                        template: "存在考勤状态为“缺卡”的被考勤人，还未处理，请处理后再提交！",
                        okText: '关闭',
                    });
                } else if (vm.statusMapList && vm.statusMapList.allIds) {
                    $http.post(basePath + "/batchVerificationUser.htm", {ids: vm.statusMapList.allIds}).success(function (data) {
                        if (data.status == 0) {
                            vm.batchSubmit(vm.statusMapList.allIds);
                        } else if (data.status == 10 || data.status == 11) {
                            $ionicPopup.alert({
                                title: '提示',
                                template: data.message,
                                okText: '关闭',
                            });
                        } else {
                            ynuiNotification.error({'msg': "操作失败！"});
                        }
                    });
                } else {
                    $ionicPopup.alert({
                        title: '提示',
                        template: "无考勤结果数据需要确认！",
                        okText: '关闭',
                    });
                }
            },
            // 一键处理
            batchSubmit: function (ids) {
                var param = {
                    ids: ids,
                    resultFlag: true
                };
                $http.post(basePath + "/batchAddUser.htm", param).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': "确认成功！"});
                        vm.defaultFirstSpread = false;
                        // 默认不展开
                        vm.getListInfo(false);
                    } else {
                        ynuiNotification.error({'msg': "确认失败！"});
                    }
                });

            },
            // 获取当前日期
            getSystemDate: function () {
                $http.post(basePath + "/getSystemDate.htm").success(function (data) {
                    if (data.status == 0) {
                        vm.searchInfo.date = data.result.day;
                        vm.searchInfo.todayDate = data.result.day;
                        vm.showDate.today = true;
                        vm.showDate.week = vm.arr[data.result.week];
                        vm.showDate.showName = "[今天]" + vm.searchInfo.date + " " + vm.showDate.week;
                        vm.findRuleByUser();
                    }
                });
            },
            // 选择日期
            selectDateTime: function (item, inst) {
                var info = inst.getVal().toDateString();
                if (info.indexOf("Wed") > -1) {
                    vm.showDate.week = "周三";
                } else if (info.indexOf("Tue") > -1) {
                    vm.showDate.week = "周二";
                } else if (info.indexOf("Mon") > -1) {
                    vm.showDate.week = "周一";
                } else if (info.indexOf("Sun") > -1) {
                    vm.showDate.week = "周日";
                } else if (info.indexOf("Sat") > -1) {
                    vm.showDate.week = "周六";
                } else if (info.indexOf("Fri") > -1) {
                    vm.showDate.week = "周五";
                } else if (info.indexOf("Thu") > -1) {
                    vm.showDate.week = "周四";
                }
                vm.searchInfo.date = item;
                vm.showDate.showName = vm.searchInfo.date + " " + vm.showDate.week;
                if (item == vm.searchInfo.todayDate) {
                    vm.showDate.showName = "[今天]" + vm.showDate.showName;
                }
                // 强制渲染
                $timeout(function () {
                    vm.showDate.showName;
                });
                vm.defaultFirstSpread = false;
                // 默认不展开
                vm.getListInfo(false);
            },
            // 一键处理
            toDealWith: function () {
                var ids = [], endFlag = true;
                if (vm.infoList && vm.infoList.length > 0) {
                    angular.forEach(vm.infoList, function (item) {
                        angular.forEach(item.teacherVOList, function (user) {
                            if (user.active) {
                                ids.push(user.id);
                                if (!user.endFlag) {
                                    endFlag = false;
                                }
                            }

                        });
                    });
                    if (ids.length == 0) {
                        ynuiNotification.error({'msg': "请至少选择一项！"});
                        return false;
                    }
                    if (endFlag) {
                        // 一键处理
                        var param = {
                            ids: ids
                        };
                        attStorageService.setItem("toDealWith", param);
                        $scope.$on("toDealWith", function (event, data) {
                            vm.viewDataModal.remove();
                            if (data) {
                                vm.defaultFirstSpread = false;
                                // 默认不展开
                                vm.getListInfo(false);
                            }
                        });
                        $ionicModal.fromTemplateUrl('templates/zbkq/dialog/viewData.html', {
                            scope: $scope,
                            animation: 'slide-in-up'
                        }).then(function (modal) {
                            vm.viewDataModal = modal;
                            vm.viewDataModal.show();
                        });
                    } else {
                        ynuiNotification.error({'msg': "您选择的数据中，存在班次出勤时间的考勤还未结束的数据，请重新选择！"});
                        return false;
                    }
                } else {
                    ynuiNotification.error({'msg': "请至少选择一项！"});
                    return false
                }
            },
            // true 上一天 下一天
            goToDay: function (flag) {
                var param = {
                    date: vm.searchInfo.date,
                    flag: flag
                }
                $http.post(basePath + "/getDate.htm", param).success(function (data) {
                    if (data.status == 0) {
                        vm.searchInfo.date = data.result.day;
                        vm.searchInfo.todayDate = data.result.day;
                        vm.showDate.today = false;
                        vm.showDate.week = vm.arr[data.result.week];
                        vm.showDate.showName = (data.result.today ? "[今天]" : "") + vm.searchInfo.date + " " + vm.showDate.week;
                        // 获取数据
                        vm.getListInfo();
                    } else {
                        ynuiNotification.error({'msg': data.message});
                    }
                });
            },
            // 切换
            switchUser: function () {
                $location.path("/attAbnormal").search({
                    "searchInfo": JSON.stringify(vm.searchInfo),
                    "showDate": JSON.stringify(vm.showDate)
                });
            }
        };


        // 初始化
        function init() {
            // 按人员跳转时
            if ($scope.oldData) {
                vm.searchInfo = angular.copy($scope.oldData);
                vm.showDate = angular.copy($scope.oldDataShowDate);
                vm.findRuleByUser();
            } else {
                vm.getSystemDate();
            }


        }

        init();
    }

    //一键处理 明细
    toDealWithDialogController.$inject = ['$http', '$scope', 'ynuiNotification', "attStorageService"];

    function toDealWithDialogController($http, $scope, ynuiNotification, attStorageService) {
        var basePath = originBaseUrl + "/third/zbkqAtt";
        var oldValue = attStorageService.getItem("toDealWith");
        var vm = $scope.vm = {
            detailInfo: {
                status: 1,
                remarks: null
            },
            // 状态选中样式
            getStatusClass: function (type) {
                if (vm.detailInfo && vm.detailInfo.status) {
                    return {'active': type == vm.detailInfo.status};
                }
                return "";
            },
            clickStatus: function (type) {
                vm.detailInfo.status = type;
            },
            // 获取考勤组
            saveInfo: function () {
                var param = {
                    ids: oldValue.ids,
                    status: vm.detailInfo.status,
                    remarks: vm.detailInfo.remarks
                };
                $http.post(basePath + "/batchAddUser.htm", param).success(function (data) {
                    if (data.status == 0) {
                        ynuiNotification.success({'msg': "处理成功！"});
                        vm.clickAttDialog(true);
                    } else {
                        ynuiNotification.error({'msg': "处理失败！"});
                    }
                });
            },
            // 取消
            clickAttDialog: function (flag) {
                $scope.$emit("toDealWith", flag);
            }
        };
    }

    //活动打卡
    signInCtrl.$inject = ['$scope', '$http', '$interval', '$filter', 'ynuiNotification', 'stringsConstant', '$cordovaFileTransfer', '$cordovaFile', '$timeout', '$ionicPopup'];

    function signInCtrl($scope, $http, $interval, $filter, ynuiNotification, stringsConstant, $cordovaFileTransfer, $cordovaFile, $timeout, $ionicPopup) {

        var vm = this;

        vm.findCurrentTimeAndUser = findCurrentTimeAndUser;
        vm.findTaskPointByConditions = findTaskPointByConditions;
        vm.initPageData = initPageData;
        vm.findSignIn = findSignIn;
        vm.submit = submit;

        // 默认tab_1，tab = '2' 为 tab_2
        vm.tab = '1';
        // 默认不显示更多
        vm.showMore = false;
        // 获取数据状态，0失败，1获取中，2获取成功
        vm.dataStatus = '1';
        // 获取时间状态，0失败，1获取中，2获取成功
        vm.timeStatus = '1';
        // 页面显示数据
        vm.pageData = {
            address: ''
        };
        // 保存的打卡点
        vm.dataVO = {
            longAndLat: '',
            gpsIsOpen: '1',
            address: '',
            // 手机号码取不到
            phoneNumber: '',
            errorRange: '',
            fastDFSIds: '',
            remark: ''
        };
        vm.monthList = [];
        vm.dateList = [];
        vm.pageSize = 0;
        vm.pageNumber = 0;
        vm.signInStatus = 1;
        vm.isInitTime = false;

        vm.findSignIn();

        /**
         * 获取系统时间和当前的登陆人员
         */
        function findCurrentTimeAndUser() {
            return $http.get(originBaseUrl + '/third/rydwForMsg/findCurrentTimeAndUser.htm').then(function (response) {
                if (response.status === 200 && response.data.status === 0) {
                    vm.timeStatus = '2';
                } else {
                    vm.timeStatus = '0';
                }
                return response;
            });
        }

        /**
         * 查询GPS全局设置
         */
        $http.get(originBaseUrl + '/third/rydwForMsg/findRYDWLocationSetting.htm').success(function (data) {
            if (data.status === 0 && data.result.id) {
                vm.rydwSetting = data.result;
            }
        });

        /**
         * 根据人员id查询需要打卡的点
         *
         * @param longitudeAndLatitude 经纬度
         */
        function findTaskPointByConditions(longitudeAndLatitude) {
            return $http.get(originBaseUrl + '/third/rydwForMsg/findTaskPointByConditions.htm', {
                params: {
                    longitudeAndLatitude: longitudeAndLatitude
                }
            }).then(function (response) {
                return response;
            }, function (data) {
                console.log(JSON.stringify(data))
            })
        }

        // 获取当前定位
        function getCurrentPosition() {
            navigator.geolocation.getCurrentPosition(function (data) {
                window.clearInterval(gpsTimer);
                if(data.status === 1 && data.result.address){
                    vm.dataVO.gpsIsOpen = '1';
                    vm.dataStatus = '2';
                    var result = data.result;
                    var longAndLat = result.longitude + ',' + result.latitude;
                    vm.dataVO.longAndLat = longAndLat;
                    vm.dataVO.address = vm.pageData.address = result.address;
                    // 取任务打卡点
                    vm.findTaskPointByConditions(longAndLat).then(
                        function (response) {
                            vm.pageData.taskPointVOList = response.data.result;
                        }
                    )
                }else{
                    vm.dataVO.gpsIsOpen = '0';
                    vm.dataStatus = '0';
                    console.log('errorCode: ' + data.result.errorCode + ', errorInfo: ' + data.result.errorInfo);
                }
            }, function (getCurrentPositionError) {
                vm.dataStatus = '0';
                console.log('定位失败:' + JSON.stringify(getCurrentPositionError));
                window.clearInterval(gpsTimer);
                // 取任务打卡点
                vm.findTaskPointByConditions(null).then(
                    function (response) {
                        vm.pageData.taskPointVOList = response.data.result;
                    }
                )
            });
        }

        /**
         * 初始化页面数据
         */
        var gpsTimer;
        var intervalTimer;
        var intervalTimerSet;

        function initPageData() {

            vm.dataStatus = '1';
            vm.pageData.address = '定位中...';
            vm.locationType = 0;  // 定位类型
            var tipsIndex = 0;
            if (gpsTimer) {
                window.clearInterval(gpsTimer);
            }
            gpsTimer = window.setInterval(function () {
                if (tipsIndex > 2) tipsIndex = 2;
                vm.pageData.address = ["正在搜索GPS信号...", "GPS信号较弱，请稍等...", "搜索基站或WI-FI信号..."][tipsIndex];
                tipsIndex++;
            }, 1500);

            // 获取当前时间和打卡人员信息
            vm.findCurrentTimeAndUser()
                .then(function (response) {
                        var currentTime = new Date(response.data.result.currentTime);
                        vm.pageData.currentTime = $filter('date')(currentTime, 'HH:mm:ss');
                        vm.pageData.userName = response.data.result.platformSysUserVO.displayName;
                        if (!vm.isInitTime) {
                            vm.isInitTime = true;
                            intervalTimerSet = $interval(function () {
                                // + 1s
                                currentTime.setTime(currentTime.getTime() + 1000);
                                vm.pageData.currentTime = $filter('date')(currentTime, 'HH:mm:ss');
                                $scope.currentTime = currentTime;
                            }, 1000);
                        }

                        // 获取当前定位
                        getCurrentPosition();
                        intervalTimer = $interval(function () {
                            getCurrentPosition();
                        }, 30000);
                    },
                    function (findCurrentTimeAndUserErr) {
                        // 获取人员、时间失败
                        vm.dataStatus = '0';
                        window.clearInterval(gpsTimer);
                    });
        }

        //初始化人员信息
        vm.findCurrentTimeAndUser().then(function (response) {
            vm.pageData.platformSysUserVO = response.data.result.platformSysUserVO;
        });
        //切换页面
        $scope.$watch("vm.tab", function () {
            if (vm.tab == '2') {
                vm.dateList = [];
                vm.pageSize = 0;
                findSignIn();
            }
        }, true);

        /**
         * 查询一个人的打卡记录
         */
        function findSignIn() {
            vm.pageSize += 20;
            return $http.get(originBaseUrl + '/third/rydwForMsg/findSignIn.htm', {
                params: {
                    pageNumber: vm.pageNumber,
                    pageSize: vm.pageSize
                }
            }).then(function (response) {
                if (vm.monthList.length == 0) {
                    $scope.dateList = [];
                    vm.signInStatus = 1;
                    angular.forEach(response.data.result, function (month) {
                        angular.forEach(month.signInList, function (sign) {
                            $scope.dateList.push(sign);
                        })
                    })
                    vm.dateList = $scope.dateList;
                }

                else {

                    $scope.dateList = [];
                    angular.forEach(response.data.result, function (month) {
                        angular.forEach(month.signInList, function (sign) {
                            $scope.dateList.push(sign);
                        })
                    })
                    if (vm.dateList.length === $scope.dateList.length) {
                        vm.signInStatus = 0;
                    } else {
                        vm.signInStatus = 1;
                    }
                    vm.dateList = $scope.dateList;
                }

                vm.monthList = response.data.result;
                angular.forEach(vm.monthList, function (month) {
                    angular.forEach(month.signInList, function (sign) {
                        if (null !== sign.fastDFSIds) {
                            var fastDFSIds = sign.fastDFSIds.split(',');
                            var photoSrcList = [];
                            angular.forEach(fastDFSIds, function (fastDFSId) {
                                photoSrcList.push(stringsConstant.file.downloadServer() + fastDFSId);
                            });
                            sign.photoSrcList = photoSrcList;
                        }
                    })
                })
                $scope.$broadcast('scroll.infiniteScrollComplete');
            })
        }

        // ====================拍照====================
        /*
         * 照片对象
         * {
         *   uri: ''  // 本地全路径
         *   path: ''    // 本地路径
         *   name: ''    // 文件名
         *   fsId: ''    // 文件服务器id
         *   status: 0  // 状态
         *   progress: 0    // 上传进度
         * }
         * */
        $scope.photos = [];    //照片
        $scope.fillPhotos = [];     //空格子填充

        // 构造空格子
        $scope.buildFillPhotos = function () {
            $scope.fillPhotos = [];
            for (var i = 0; i < 5 - $scope.photos.length; i++) {
                $scope.fillPhotos.push(i);
            }
        };
        $scope.buildFillPhotos();

        // 得到照片字符串
        $scope.getFsIds = function () {
            var photosFsIds = [];
            for (var i = 0; i < $scope.photos.length; i++) {
                if ($scope.photos[i].fsId) {
                    photosFsIds.push($scope.photos[i].fsId);
                }
            }
            vm.dataVO.fastDFSIds = photosFsIds.join(',');
            console.log(JSON.stringify(vm.dataVO.fastDFSIds));
        };

        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            console.log("deviceready");

            vm.initPageData();

            // 初始化打卡标识
            yn.plugin.signkey.getSignKey(function (value) {
                console.debug("打卡标识： " + value);
                vm.dataVO.phoneNumber = value;
            });

            // 拍照上传
            $scope.takePhoto = function () {
                if (vm.timeStatus === '0' || vm.timeStatus === '1') {
                    ynuiNotification.error({'msg': '打卡时间无效，无法拍照'});
                    return;
                }
                //成功拍照 组装photo对象 push到 photos
                var customcamera = yn.plugin.customcamera;
                var opts = [{
                    name: vm.pageData.userName,
                    address: vm.pageData.address,
                    time: $filter('date')($scope.currentTime, 'yyyy/MM/dd 星期' + ['日', '一', '二', '三', '四', '五', '六'][$scope.currentTime.getDay()] + ' HH:mm:ss')
                }];
                customcamera.startCamera(opts, takeSuccess, takeError);
            };

            // 拍照完成
            function takeSuccess(data) {
                var photo = {
                    uri: data,
                    path: data.substr(0, data.lastIndexOf('/') + 1),
                    name: data.substr(data.lastIndexOf('/') + 1),
                    fsId: '',
                    status: 0,
                    progress: 0
                };
                $timeout(function () {
                    // 拍照完成
                    $scope.photos.push(photo);
                    $scope.buildFillPhotos();
                    // 执行上传
                    $scope.upload(photo);
                }, 0)

            }

            // 拍照失败
            function takeError(data) {
                console.error('拍照失败');
                console.error(JSON.stringify(data));
            }

            // 删除照片
            $scope.deletePhoto = function (photo) {
                $ionicPopup.confirm({
                    title: '删除确认',
                    template: '确认要删除当前照片吗?',
                    cancelText: '取消',
                    okText: '删除'
                }).then(function (res) {
                    if (res) {
                        if (photo.fsId) {
                            // 删除服务端文件
                            $http({
                                method: 'GET',
                                url: stringsConstant.file.deleteServer() + photo.fsId
                            })
                                .success(function (deletePhotoRes) {
                                    console.log(JSON.stringify(deletePhotoRes));
                                    if (deletePhotoRes.status == 0) {
                                        // 已从文件服务器删除文件，执行本地删除
                                        $scope.deleteLocalPhoto(photo);
                                    }
                                })
                                .error(function (deletePhotoErr) {
                                    console.error('从文件服务器删除文件失败');
                                    console.error(JSON.stringify(deletePhotoErr));
                                });
                        } else {
                            // 删除本地文件
                            $scope.deleteLocalPhoto(photo);
                        }
                    }
                });

            };
            // 删除本地照片
            $scope.deleteLocalPhoto = function (photo) {
                $cordovaFile
                    .removeFile(photo.path, photo.name)
                    .then(function (removeFileSuccess) {
                        // 已从本地删除文件
                        for (var i = 0; i < $scope.photos.length; i++) {
                            if ($scope.photos[i].uri == photo.uri) {
                                $scope.photos.splice(i, 1);
                                $scope.buildFillPhotos();
                                $scope.getFsIds();
                            }
                        }
                    }, function (removeFileError) {
                        // error
                        console.error('从本地删除文件失败');
                        console.error(JSON.stringify(removeFileError));
                    });
            };
            // 预览照片
            $scope.previewPhoto = function (photo) {
                var cordovaFileOpen = cordova.plugins.disusered.open;
                cordovaFileOpen(photo.uri, cordovaFileOpenSuccess, cordovaFileOpenError);

                function cordovaFileOpenSuccess() {
                    // 从已安装程序中打开文件完成
                }

                function cordovaFileOpenError(code) {
                    if (code === 1) {
                        $ionicPopup.alert({
                            title: '文件预览提示',
                            template: '未能在手机已安装APP中找到可预览此文件的程序'
                        });
                    } else {
                        $ionicPopup.alert({
                            title: '文件预览提示',
                            template: '预览时发生了未知错误 #' + code
                        });
                    }
                }
            };
            // 单个照片失败重试
            $scope.retry = function (photo) {
                console.log('失败文件重试: ' + photo.uri);
                if (photo.status == '-1') {
                    $scope.upload(photo);
                }
            };
            // 单个上传
            $scope.upload = function (photo) {
                photo.status = '0';
                // 参数
                var mac = stringsConstant.utils.uuid();
                var userId = JSON.parse(window.localStorage.getItem('authorizationStr')).userId;
                var options = new FileUploadOptions();
                options.fileName = photo.name;
                options.params = {
                    name: photo.name,
                    userId: userId,
                    mac: mac
                };
                options.headers = {
                    authorization: JSON.parse(window.localStorage.getItem("authorizationStr")).access_token
                };
                $cordovaFileTransfer.upload(stringsConstant.file.uploadServer(), photo.uri, options)
                    .then(function (uploadSuccessData) {
                        console.log(JSON.stringify(uploadSuccessData.response));
                        // 上传完成
                        photo.fsId = JSON.parse(uploadSuccessData.response).result.fileId;
                        if (photo.fsId) {
                            photo.status = '1';
                            // 允许继续拍照
                            $scope.getFsIds();
                        } else {
                            console.error('上传失败,fsId为空');
                            photo.status = '-1';
                        }
                    }, function (uploadError) {
                        console.error('上传失败');
                        console.error(JSON.stringify(uploadError));
                        photo.status = '-1';
                    }, function (progress) {
                        $timeout(function () {
                            photo.progress = parseInt((progress.loaded / progress.total) * 100) + '%';
                            console.log('上传进度: ' + photo.progress);
                        });
                    });
            }
        }

        function submit() {
            // 验证时间是否获取成功
            if (vm.timeStatus === '0') {
                ynuiNotification.error({'msg': '打卡时间无效，请刷新时间'});
                return;
            }
            // 验证定位
            if (vm.dataStatus === '1') {
                ynuiNotification.error({'msg': '正在获取定位信息，请稍后'});
                return;
            }
            // 验证照片
            var photosCount = $scope.photos.length, uploaded = vm.dataVO.fastDFSIds.split(',').length;
            if (photosCount > uploaded) {
                ynuiNotification.error({'msg': '还有' + (photosCount - uploaded) + '张照片没有提交'});
                return;
            }
            /**
             * 增加人脸识别模块
             */
            //recognitionFace == true 需要人脸识别
            if (vm.rydwSetting && vm.rydwSetting.recognitionFace) {
                //调用人脸识别
                faceRecognit();
                return false;
            } else {
                //保存打卡记录
                saveSignIn();
            }
        }

        /**
         * 人脸识别模组
         */
        function faceRecognit() {
            yn.plugin.facerecognition.startFaceRecognition({}, function (data) {
                //转换一下
                data = JSON.parse(data);
                // 0:成功，-1:百度的所有异常，-2:用户取消
                if (data.code == 0) {
                    var faceResult = data.result;
                    /**
                     * 相似度有效
                     */
                    if (faceResult.score >= 80) {
                        if (faceResult.user_id == vm.pageData.platformSysUserVO.id) {
                            //保存打卡记录
                            saveSignIn();
                        } else {
                            /**
                             * 相似度返回id不是本人
                             */
                                //token
                            var access_token = JSON.parse(window.localStorage.getItem("authorizationStr")).access_token;
                            //获取返回人员的信息
                            $.ajax({
                                url: originBaseUrl + '/third/rydwForMsg/findCurrentTimeAndUser.htm?userId=' + faceResult.user_id + '&access_token=' + access_token,
                                cache: false,
                                async: true,
                                type: "GET",
                                dataType: 'json',
                                success: function (data) {
                                    var userVO = data.result.platformSysUserVO;
                                    if (userVO.id) {
                                        var title = "打卡失败，不是本人打卡！";
                                        var template =
                                            "<div class='text-left'>" +
                                            "   <div>" +
                                            "       人脸识别出来是“" + userVO.displayName + "（" + userVO.userNumber + "）”，" +
                                            "       但是当前登录用户是“" + vm.pageData.platformSysUserVO.displayName + "（" + vm.pageData.platformSysUserVO.userNumber + "）”。" +
                                            "   </div>" +
                                            "   <div>这种情况也可能是人脸底库信息有问题，您可以再试一次或者联系信息中心。</div>" +
                                            "</div>";
                                        ionicPopup(title, template);
                                    } else {
                                        //没有人员信息
                                        var title = "操作失败！";
                                        var template =
                                            "<div class='text-left'>" +
                                            "   <div>可能的原因：</div>" +
                                            "   <div>1.未检测到人脸，可能光线太差、您佩戴了帽子、墨镜、面具等遮挡面部的饰品</div>" +
                                            "   <div>2.网络原因，无法进行人脸识别</div>" +
                                            "</div>";
                                        ionicPopup(title, template);
                                    }

                                }
                            });
                        }
                    } else {
                        var title = "打卡失败，不是本人打卡！";
                        var template =
                            "<div class='text-left'>" +
                            "   <div>这种情况可能是人脸底库信息有问题，您可以再试一次或者联系信息中心。</div>" +
                            "</div>";
                        ionicPopup(title, template);
                    }
                } else {
                    // 失败
                    var title = "操作失败！";
                    var template =
                        "<div class='text-left'>" +
                        "   <div>可能的原因：</div>" +
                        "   <div>1.未检测到人脸，可能光线太差、您佩戴了帽子、墨镜、面具等遮挡面部的饰品</div>" +
                        "   <div>2.网络原因，无法进行人脸识别</div>" +
                        "</div>";
                    ionicPopup(title, template);
                }
            }, function (error) {
                // 失败
                var title = "操作失败！";
                var template =
                    "<div class='text-left'>" +
                    "   <div>可能的原因：</div>" +
                    "   <div>1.未检测到人脸，可能光线太差、您佩戴了帽子、墨镜、面具等遮挡面部的饰品</div>" +
                    "   <div>2.网络原因，无法进行人脸识别</div>" +
                    "</div>";
                ionicPopup(title, template);
            })
        }

        /**
         * 弹框提示相关
         */
        function ionicPopup(title, template) {
            $ionicPopup.show({
                title: title,
                template: template,
                buttons: [
                    {
                        text: '返回',
                        type: 'button-theme button-sm button-calm button-local button-outline',
                        onTap: function () {
                            return false;
                        }
                    },
                    {
                        text: "再试一次",
                        type: ' button-theme button-sm button-calm button-local',
                        onTap: function () {
                            faceRecognit();
                        }
                    }
                ]
            });
        }

        /**
         * 提交数据
         */
        function saveSignIn() {
            var dataVO = angular.copy(vm.dataVO);
            $http.post(originBaseUrl + '/third/rydwForMsg/saveSignIn.htm',
                dataVO
            ).then(function (response) {
                if (response.status === 200) {
                    // 后端返回异常
                    if (response.data.status === 1) {
                        ynuiNotification.error({'msg': '打卡失败，' + response.data.message})
                    } else {
                        ynuiNotification.success({'msg': vm.pageData.platformSysUserVO.displayName + '（' + vm.pageData.platformSysUserVO.userNumber + '）,打卡成功！'});
                        vm.tab = '2';
                        vm.findSignIn();
                        // 清空数据
                        $scope.photos = []
                        $scope.getFsIds();
                        $scope.buildFillPhotos();
                        vm.dataVO.remark = '';
                    }
                } else {
                    ynuiNotification.error({'msg': '服务器错误，请稍后再试'});
                }
            }, function () {
                ynuiNotification.error({'msg': '服务器错误，请稍后再试'});
            })
        }


        /**
         * 销毁时终止timer
         */
        $scope.$on("$destroy", function() {
            if (gpsTimer) {
                window.clearInterval(gpsTimer);
                $interval.cancel(intervalTimer);
                $interval.cancel(intervalTimerSet);
                gpsTimer = null;
                intervalTimer = null;
                intervalTimerSet = null;
            }
        });
    }


})();



