(function () {
    'use strict';

    angular
        .module('starter')
        .config(config)
        .controller('indexCtrl', indexCtrl)
        .controller('roomGoodsInfoCtrl', roomGoodsInfoCtrl)
        .controller('billOutCtrl', billOutCtrl)
        .directive('billOutDetail', billOutDetail)
        .controller('billOutEditCtrl', billOutEditCtrl)
        .controller('billReturnCtrl', billReturnCtrl)
        .directive('billReturnDetail', billReturnDetail)
        .controller('billReturnEditCtrl', billReturnEditCtrl)
        .directive('billReturnLostRegister', billReturnLostRegister)
        .directive('goodsInfoSelector', goodsInfoSelector)
        .directive('goodsInfoDetail', goodsInfoDetail)
    ;

    config.$inject = ['$stateProvider'];

    function config($stateProvider) {
        $stateProvider
        // 库房管理员主界面
            .state('rooms', {
                url: '/rooms',
                templateUrl: 'templates/zc/admin/index.html',
                data: {
                    title: '耐用品耗材',
                    prev: null
                },
                controller: 'indexCtrl',
                controllerAs: 'vm'
            })
            // 库房物品列表
            .state('goods', {
                url: '/rooms/goods?roomId&status',
                templateUrl: 'templates/zc/admin/roomGoodsInfo.html',
                data: {
                    title: '物品信息',
                    prev: 'rooms'
                },
                controller: 'roomGoodsInfoCtrl',
                controllerAs: 'vm'
            })
            // 出库单列表
            .state('billOut', {
                url: '/bill/out?status',
                templateUrl: 'templates/zc/admin/billOut.html',
                data: {
                    title: '出库单',
                    prev: 'rooms'
                },
                controller: 'billOutCtrl',
                controllerAs: 'vm'
            })
            // 出库
            .state('billOutEdit', {
                url: '/bill/out/edit?id&goodsInfoId',
                templateUrl: 'templates/zc/admin/billOutEdit.html',
                data: {
                    title: '出库',
                    prev: 'rooms'
                },
                controller: 'billOutEditCtrl',
                controllerAs: 'vm'
            })
            .state('billOutEdit1', {
                url: '/bill/out/edit?id&goodsInfoId',
                templateUrl: 'templates/zc/admin/billOutEdit.html',
                data: {
                    title: '出库',
                    prev: 'goods'
                },
                controller: 'billOutEditCtrl',
                controllerAs: 'vm'
            })
            .state('billOutEdit2', {
                url: '/bill/out/edit?id&goodsInfoId',
                templateUrl: 'templates/zc/admin/billOutEdit.html',
                data: {
                    title: '出库',
                    prev: 'billOut'
                },
                controller: 'billOutEditCtrl',
                controllerAs: 'vm'
            })
            // 退库单列表
            .state('billReturn', {
                url: '/bill/return',
                templateUrl: 'templates/zc/admin/billReturn.html',
                data: {
                    title: '退库单',
                    prev: 'rooms'
                },
                controller: 'billReturnCtrl',
                controllerAs: 'vm'
            })
            // 退库
            .state('billReturnEdit', {
                url: '/bill/return/edit?id&billOutId&goodsInfoId',
                templateUrl: 'templates/zc/admin/billReturnEdit.html',
                data: {
                    title: '退库',
                    prev: 'rooms'
                },
                controller: 'billReturnEditCtrl',
                controllerAs: 'vm'
            })
            .state('billReturnEdit1', {
                url: '/bill/return/edit?id&billOutId&goodsInfoId',
                templateUrl: 'templates/zc/admin/billReturnEdit.html',
                data: {
                    title: '退库',
                    prev: 'goods'
                },
                controller: 'billReturnEditCtrl',
                controllerAs: 'vm'
            })
            .state('billReturnEdit2', {
                url: '/bill/return/edit?id&billOutId&goodsInfoId',
                templateUrl: 'templates/zc/admin/billReturnEdit.html',
                data: {
                    title: '退库',
                    prev: 'billReturn'
                },
                controller: 'billReturnEditCtrl',
                controllerAs: 'vm'
            })
            .state('billReturnEdit3', {
                url: '/bill/return/edit?id&billOutId&goodsInfoId&prev',
                templateUrl: 'templates/zc/admin/billReturnEdit.html',
                data: {
                    title: '退库',
                    prev: 'billOut'
                },
                controller: 'billReturnEditCtrl',
                controllerAs: 'vm'
            })
        ;
    }

    indexCtrl.$inject = ['$scope', '$http', '$rootScope', '$timeout', '$state'];

    function indexCtrl($scope, $http, $rootScope, $timeout, $state) {

        var vm = this;

        vm.gotoGoodsInfoPage = gotoGoodsInfoPage;
        vm.gotoBillOutEditPage = gotoBillOutEditPage;
        vm.gotoBillOutPage = gotoBillOutPage;
        vm.gotoBillReturnEditPage = gotoBillReturnEditPage;
        vm.gotoBillReturnPage = gotoBillReturnPage;

        vm.rooms = null;

        vm.ksSwiper = {
            'effect': 'slide',
            'observer': 'true'
        };

        $timeout(function () {
            findByUserId();
        }, 300);

        function findByUserId() {
            return $http.get(
                originBaseUrl + '/third/zc/room/statistics/' + $rootScope.authorizationStr.userId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.rooms = data.result;
                    // 管理库房数量大于1才显示下面的统计
                    if (1 < vm.rooms.length) {
                        vm.ksSwiper['pagination'] = '.swiper-pagination';
                        // vm.ksSwiper['paginationType'] = 'fraction';
                    }
                }
                return data;
            });
        }

        function gotoGoodsInfoPage(id, status) {
            $state.go('goods', {roomId: id, status: status});
        }

        function gotoBillOutEditPage() {
            $state.go('billOutEdit');
        }

        function gotoBillOutPage() {
            $state.go('billOut');
        }

        function gotoBillReturnEditPage() {
            $state.go('billReturnEdit');
        }

        function gotoBillReturnPage() {
            $state.go('billReturn');
        }
    }

    roomGoodsInfoCtrl.$inject = ['$scope', '$http', '$state', '$stateParams', '$ionicModal', '$filter', '$ionicScrollDelegate', '$timeout', '$ionicPopup', 'scanUtils'];

    //库房物品列表
    function roomGoodsInfoCtrl($scope, $http, $state, $stateParams, $ionicModal, $filter, $ionicScrollDelegate, $timeout, $ionicPopup, scanUtils) {

        var vm = this;

        vm.loadMoreData = loadMoreData;
        vm.onChangeName = onChangeName;
        vm.changeSort = changeSort;
        vm.changeTotalStatus = changeTotalStatus;
        vm.selectContainer = selectContainer;
        vm.selectCategory = selectCategory;
        vm.reInitConditions = reInitConditions;
        vm.confirmConditions = confirmConditions;
        vm.showGoodsInfoModal = showGoodsInfoModal;
        vm.hideGoodsInfoModal = hideGoodsInfoModal;
        vm.showGoodsInfoOperationModal = showGoodsInfoOperationModal;
        vm.goOut = goOut;
        vm.goReturn = goReturn;
        vm.scan = scan;

        vm.containerIds = [];

        vm.categoryIds = [];

        vm.conditions = {
            roomId: $stateParams.roomId,
            name: null,
            number: null,
            totalStatus: $stateParams.status,
            locationNumber: null,
            categoryName: null,
            specification: null,
            tradeMark: null,
            containerName: null,
            type: 0,
            asc: true,
            pageSize: 10,
            pageNumber: -1
        };

        // 更多条件
        $ionicModal.fromTemplateUrl('more-conditions.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.moreConditionsModal = modal;
        });

        $timeout(function () {
            findContainerByRoomId().success(function () {
                findAllCategory().success(function () {
                    // 第一次进入页面 ion-infinite-scroll 去加载数据
                    $timeout(function () {
                        vm.moreDataCanBeLoaded = true;
                    }, 150);
                });
            });
        }, 500);

        function findGoodsByStorageRoom(obj) {
            return $http.post(
                originBaseUrl + '/third/zc/goods/room.htm', obj
            ).success(function (data) {
                if (0 === data.status) {
                    vm.goodsInfoPage = data.result;
                    // 判断是否最后一页数据，最后一页隐藏 ion-infinite-scroll
                    vm.moreDataCanBeLoaded = !vm.goodsInfoPage.lastPage;
                }
                return data;
            });
        }

        /**
         * 加载数据
         * @param init true从第一页重新加载数据
         */
        function loadMoreData(init) {
            // 页码
            if (init) {
                vm.conditions.pageNumber = -1;
            }
            vm.conditions.pageNumber += 1;
            // 查询条件处理
            if (0 < vm.containerIds.length) {
                vm.conditions.containerName = vm.containerIds.join(',');
            } else {
                vm.conditions.containerName = null;
            }
            if (0 < vm.categoryIds.length) {
                vm.conditions.categoryName = vm.categoryIds.join(',')
            } else {
                vm.conditions.categoryName = null;
            }
            findGoodsByStorageRoom(vm.conditions).success(function (data) {
                if (0 === data.status) {
                    if (init || null == vm.goodsInfos) {
                        vm.goodsInfos = data.result.content;
                        $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                    } else {
                        vm.goodsInfos = vm.goodsInfos.concat(data.result.content);
                    }
                }
            }).finally(function () {
                $scope.$broadcast('scroll.refreshComplete');
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        }

        function onChangeName(name) {
            if (null == name) {
                vm.conditions.name = null;
                loadMoreData(true);
            } else {
                if (vm.timer) {
                    $timeout.cancel(vm.timer);
                }
                vm.timer = $timeout(function () {
                    loadMoreData(true);
                }, 1000);
            }
        }

        function changeSort(type, asc) {
            vm.conditions.type = type;
            vm.conditions.asc = asc;
            // 刷新
            loadMoreData(true);
        }

        function changeTotalStatus(status) {
            vm.conditions.totalStatus = status;
            // 刷新
            loadMoreData(true);
        }

        function findContainerByRoomId() {
            return $http.get(
                originBaseUrl + '/third/zc/room/container/' + vm.conditions.roomId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.containers = data.result;
                }
            });
        }

        function selectContainer(id) {
            if (id) {
                var i = vm.containerIds.indexOf(id);
                if (0 <= i) {
                    vm.containerIds.splice(i, 1);
                } else {
                    vm.containerIds.push(id);
                }
            } else {
                vm.containerIds = [];
            }
        }

        function findAllCategory() {
            return $http.get(originBaseUrl + '/third/zc/goods/category.htm').success(function (data) {
                if (0 === data.status) {
                    vm.categorys = data.result;
                    vm.categorys_1 = $filter('filter')(data.result, {userNumber: '1'});
                    vm.categorys_2 = $filter('filter')(data.result, {userNumber: '2'});
                }
            });
        }

        function selectCategory(id) {
            if (id) {
                var i = vm.categoryIds.indexOf(id);
                if (i !== -1) {
                    vm.categoryIds.splice(i, 1);
                } else {
                    vm.categoryIds.push(id);
                }
            } else {
                vm.categoryIds = [];
            }
        }

        function reInitConditions() {
            vm.containerIds = [];
            vm.categoryIds = [];
            vm.conditions.containerName = null;
            vm.conditions.locationNumber = null;
            vm.conditions.categoryName = null;
            vm.conditions.specification = null;
            vm.conditions.tradeMark = null;
            loadMoreData(true);
        }

        function confirmConditions() {
            vm.moreConditionsModal.hide().then(function () {
                loadMoreData(true);
            });
        }

        function showGoodsInfoModal(id) {
            vm.conditions.goodsId = id;
            // 点击单个物品的弹框
            $ionicModal.fromTemplateUrl('goods-info-detail.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                modal.show();
                vm.goodsInfoModal = modal;
            });
        }

        function hideGoodsInfoModal() {
            vm.goodsInfoModal.remove();
        }

        function showGoodsInfoOperationModal(g) {
            vm.operationGoodsInfo = g;
            // 点击单个物品操作的弹框
            $ionicModal.fromTemplateUrl('goods-info-operation.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                vm.goodsInfoOperationModal = modal;
                vm.goodsInfoOperationModal.show();
            });
        }

        function goOut() {
            if (vm.operationGoodsInfo.id) {
                if (0 === vm.operationGoodsInfo.total) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: vm.operationGoodsInfo.name + '库存为0，无法出库',
                        okText: '确定'
                    }).then(function () {
                    });
                    return false;
                }
                vm.goodsInfoOperationModal.remove().then(function () {
                    $state.go('billOutEdit1', {goodsInfoId: vm.operationGoodsInfo.id});
                });
            }
        }

        function goReturn() {
            if (vm.operationGoodsInfo.id) {
                vm.goodsInfoOperationModal.remove().then(function () {
                    $state.go('billReturnEdit1', {goodsInfoId: vm.operationGoodsInfo.id});
                });
            }
        }

        function scan() {
            scanUtils.scanGoodsInfoQRCode().then(function (data) {
                if (null != data) {
                    vm.conditions.name = data;
                    loadMoreData(true);
                } else if (!angular.isUndefined(data)) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '未查询到物品信息',
                        okText: '确定'
                    });
                }
            });
        }
    }

    //出库单
    billOutCtrl.$inject = ['$scope', '$rootScope', '$http', '$ionicModal', '$ionicScrollDelegate', '$state', '$ionicPopup', 'modalManager', 'selectOrgService', '$timeout', '$stateParams', 'scanUtils', 'ynNavigator'];

    function billOutCtrl($scope, $rootScope, $http, $ionicModal, $ionicScrollDelegate, $state, $ionicPopup, modalManager, selectOrgService, $timeout, $stateParams, scanUtils, ynNavigator) {
        var vm = this;
        vm.changeNumber = changeNumber;
        vm.changeSort = changeSort;
        vm.changeStatus = changeStatus;
        vm.changeDealDate = changeDealDate;
        vm.loadMoreData = loadMoreData;
        vm.selectStorageRoom = selectStorageRoom;
        vm.chooseTeacher = chooseTeacher;
        vm.chooseOrg = chooseOrg;
        vm.reInitConditions = reInitConditions;
        vm.showMoreConditions = showMoreConditions;
        vm.confirmConditions = confirmConditions;
        vm.gotoBillOutEdit = gotoBillOutEdit;
        vm.doDelete = doDelete;
        vm.doRevertStatus = doRevertStatus;
        vm.showBillOutDetail = showBillOutDetail;
        vm.hideBillOutDetail = hideBillOutDetail;
        vm.gotoBillReturnEdit = gotoBillReturnEdit;
        vm.showLostRegister = showLostRegister;
        vm.hideLostRegister = hideLostRegister;
        vm.showSignaturePad = showSignaturePad;
        vm.padCallback = padCallback;
        vm.scan = scan;

        vm.conditions = {
            type: 0,
            asc: false,
            number: null,
            status: $stateParams.status ? $stateParams.status : null,
            // 默认近7天
            dealDays: '7',
            roomNames: null,
            requestUserId: null,
            requestUserName: null,
            requestOrgNo: null,
            requestOrgName: null,
            requestType: null,
            goodsInfoNumber: null,
            goodsInfoName: null,
            requestDate: null,
            dealOperatorId: null,
            dealDate: null,
            pageNumber: -1,
            pageSize: 10
        };

        vm.storageRoomIds = [];

        vm.selectBillOutId = '';
        vm.billOutDetailModal = null;

        vm.fromReturn = !!$stateParams.status;

        // 更多条件
        function showMoreConditions() {
            if (null == vm.moreConditionsModal) {
                $ionicModal.fromTemplateUrl('more-conditions.html', {
                    scope: $scope,
                    animation: 'slide-in-left'
                }).then(function (modal) {
                    vm.moreConditionsModal = modal;
                    modal.show();
                });
            } else {
                vm.moreConditionsModal.show();
            }
        }
        function confirmConditions() {
            vm.moreConditionsModal.hide().then(function () {
                loadMoreData(true);
            });
        }
        $timeout(function () {
            findRoom().success(function (data) {
                if (0 === data.status) {
                    // 第一次进入页面 ion-infinite-scroll 去加载数据
                    $timeout(function () {
                        vm.moreDataCanBeLoaded = true;
                    }, 100);
                }
            });
        }, 500);

        function changeNumber() {
            if (vm.timer) {
                $timeout.cancel(vm.timer);
            }
            vm.timer = $timeout(function () {
                loadMoreData(true);
            }, 1000);
        }

        function changeSort(type, asc) {
            vm.conditions.type = type;
            vm.conditions.asc = asc;
            loadMoreData(true);
        }

        function changeStatus(status) {
            vm.conditions.status = status;
            loadMoreData(true);
        }

        function changeDealDate(dealDays) {
            vm.conditions.dealDays = dealDays;
            loadMoreData(true);
        }

        function findByConditions(obj) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/out/page.htm', obj
            ).success(function (data) {
                if (0 === data.status) {
                    vm.billOutPage = data.result;
                    // 判断是否最后一页数据，最后一页隐藏 ion-infinite-scroll
                    vm.moreDataCanBeLoaded = !vm.billOutPage.lastPage;
                }
                return data;
            });
        }

        function loadMoreData(init) {
            // 页码
            if (init) {
                vm.conditions.pageNumber = -1;
            }
            vm.conditions.pageNumber += 1;
            // 库房
            if (0 < vm.storageRoomIds.length) {
                vm.conditions.roomNames = vm.storageRoomIds.join(',');
            } else {
                var roomIds = [];
                angular.forEach(vm.storageRooms, function (r) {
                    roomIds.push(r.id);
                });
                vm.conditions.roomNames = roomIds.join(',');
            }
            // 查询
            findByConditions(vm.conditions).success(function (data) {
                if (0 === data.status) {
                    if (init || null == vm.billOuts) {
                        vm.billOuts = data.result.content;
                        $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop(true);
                    } else {
                        vm.billOuts = vm.billOuts.concat(data.result.content);
                    }
                }
            }).finally(function () {
                $scope.$broadcast('scroll.refreshComplete');
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        }

        function findRoom() {
            return $http.get(
                originBaseUrl + '/third/zc/room/' + $rootScope.authorizationStr.userId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.storageRooms = data.result;
                }
            });
        }

        function selectStorageRoom(id) {
            if (id) {
                var i = vm.storageRoomIds.indexOf(id);
                if (0 <= i) {
                    vm.storageRoomIds.splice(i, 1);
                } else {
                    vm.storageRoomIds.push(id);
                }
            } else {
                vm.storageRoomIds = [];
            }
        }

        function chooseTeacher(type) {
            if ('request' === type) {
                vm.chooseTeacherCallback = function (teacher) {
                    if (teacher) {
                        vm.conditions.requestUserId = teacher.userId;
                        vm.conditions.requestUserName = teacher.name;
                    }
                }
            } else {
                vm.chooseTeacherCallback = function (teacher) {
                    if (teacher) {
                        vm.conditions.dealOperatorId = teacher.userId;
                        vm.conditions.dealOperatorName = teacher.name;
                    }
                }
            }
            if (!modalManager.exist('chooseAllTeacher')) {
                $ionicModal.fromTemplateUrl('teacher-selector.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    modalManager.put('chooseAllTeacher', modal);
                    modal.show();
                    ynNavigator.registerBackAction(function () {
                        modalManager.remove('chooseAllTeacher');
                        ynNavigator.cancelBackAction(201);
                    }, 201);
                });
            } else {
                modalManager.show('chooseAllTeacher');
                ynNavigator.registerBackAction(function () {
                    modalManager.remove('chooseAllTeacher');
                    ynNavigator.cancelBackAction(201);
                }, 201);
            }
        }

        function chooseOrg() {
            if (vm.moreConditionsModal.isShown()) {
                vm.moreConditionsModal.hide().then(function () {
                    selectOrgService.singleSelect(function (item) {
                        vm.conditions.requestOrgNo = item.id;
                        vm.conditions.requestOrgName = item.name;
                        vm.moreConditionsModal.show();
                    });
                });
            } else {
                vm.moreConditionsModal.show();
            }
        }

        function reInitConditions() {
            vm.storageRoomIds = [];
            vm.conditions.roomNames = null;
            vm.conditions.requestUserId = null;
            vm.conditions.requestUserName = null;
            vm.conditions.requestOrgNo = null;
            vm.conditions.requestOrgName = null;
            vm.conditions.requestType = null;
            vm.conditions.goodsInfoNumber = null;
            vm.conditions.goodsInfoName = null;
            vm.conditions.requestDate = null;
            vm.conditions.dealOperatorId = null;
            vm.conditions.dealOperatorName = null;
            vm.conditions.dealDate = null;
            loadMoreData(true);
        }


        function gotoBillOutEdit(id) {
            if (id) {
                $state.go('billOutEdit2', {id: id});
            } else {
                $state.go('billOutEdit2');
            }
        }

        function deleteById(id) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/out/' + id + '.htm'
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '删除成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                }
                return data;
            });
        }

        function doDelete(id) {
            $ionicPopup.confirm({
                title: '提示',
                template: '您确认要删除该出库单吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    deleteById(id);
                }
            });
        }

        function revertStatus(id) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/out/revert/' + id + '.htm'
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '撤回成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                }
                return data;
            });
        }

        function doRevertStatus(id) {
            $ionicPopup.confirm({
                title: '提示',
                template: '您确认将该出库单撤回为草稿状态吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    revertStatus(id);
                }
            });
        }

        function showBillOutDetail(id) {
            vm.selectBillOutId = id;
            if (null == vm.billOutDetailModal) {
                $ionicModal.fromTemplateUrl('bill-out-selector.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.billOutDetailModal = modal;
                    modal.show();
                });
            } else {
                vm.billOutDetailModal.show();
            }
        }

        function hideBillOutDetail() {
            if (null != vm.billOutDetailModal) {
                vm.billOutDetailModal.remove().then(function () {
                    vm.billOutDetailModal = null;
                });
            }
        }

        function gotoBillReturnEdit(id) {
            if (id) {
                $state.go('billReturnEdit3', {billOutId: id});
            } else {
                $state.go('billReturnEdit3', {prev: $state.$current.name});
            }
        }

        function showLostRegister(id) {
            vm.selectBillOutId = id;
            if (null == vm.lostRegisterModal) {
                $ionicModal.fromTemplateUrl('lost-register.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    vm.lostRegisterModal = modal;
                    ynNavigator.registerBackAction(function () {
                        hideLostRegister();
                    }, 201);
                    modal.show();
                });
            } else {
                vm.lostRegisterModal.show();
                ynNavigator.registerBackAction(function () {
                    hideLostRegister();
                }, 201);
            }
        }

        function hideLostRegister(option) {
            if (null != vm.lostRegisterModal) {
                vm.lostRegisterModal.remove().then(function () {
                    vm.lostRegisterModal = null;
                    if ('confirm' === option) {
                        loadMoreData(true);
                    }
                });
                ynNavigator.cancelBackAction(201);
            }
        }

        function signatureConfirm(fsId) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/out/signature/' + vm.selectBillOutId + '.htm', {}, {
                    params: {
                        fsId: fsId
                    }
                }
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '操作成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                } else if (0 === data.status && null != data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.result,
                        okText: '确定'
                    });
                }
            });
        }

        function showSignaturePad(id, o) {
            vm.selectBillOutId = id;
            // 判断库房权限
            var passed = true;
            var roomIds = o.roomIds.split(',');
            var roomNames = o.roomNames.split('、');
            var authRoomIds = [];
            vm.storageRooms.forEach(function (room) {
                authRoomIds.push(room.id);
            });
            roomIds.forEach(function (value, index) {
                if (-1 === authRoomIds.indexOf(value) && passed) {
                    passed = false;
                    $ionicPopup.alert({
                        title: '提示',
                        template: '您不能出库“' + roomNames[index] + '”的物品，请撤回草稿，重新选择物品！',
                        okText: '确定'
                    });
                }
            });
            if (!passed) {
                return false;
            }
            $ionicModal.fromTemplateUrl('signature-pad.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                modal.show();
                modalManager.put('signaturePadModal', modal);
            });
        }

        function padCallback(fsId) {
            // 保存
            if (fsId) {
                signatureConfirm(fsId);
            }
        }

        function scan() {
            scanUtils.scanTeacherQRCode().then(function (res) {
                if (null != res && 200 === res.status && 0 === res.data.status) {
                    if (res.data.result) {
                        vm.conditions.number = res.data.result.name;
                        loadMoreData(true);
                    } else {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '未查询到教职工信息',
                            okText: '确定'
                        });
                    }
                }
            });
        }

    }

    //出库单明细
    function billOutDetail() {
        return {
            restrict: 'E',
            templateUrl: 'templates/zc/admin/billOutDetail.html',
            scope: {
                billOutId: '=',
                clickCloseFun: '='
            },
            link: link,
            controller: billOutDetailCtrl,
            controllerAs: 'vm',
            bindToController: true
        }

        function link() {

        }

        billOutDetailCtrl.$inject = ['$scope', '$http', '$timeout']

        function billOutDetailCtrl($scope, $http, $timeout) {

            var vm = this;

            vm.originBaseUrl = originBaseUrl;
            vm.detail = null;

            $timeout(function () {
                findOne();
            }, 500);

            function findOne() {
                return $http.get(
                    originBaseUrl + '/third/zc/bill/out/' + vm.billOutId + '.htm'
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.detail = data.result;
                    }
                    return data;
                });
            }
        }
    }


    //出库
    billOutEditCtrl.$inject = ['$scope', '$http', '$rootScope', '$ionicModal', 'modalManager', '$ionicPopup',
        '$state', '$stateParams', 'selectOrgService', 'scanUtils', '$timeout', 'ynuiNotification', 'ynNavigator'];

    function billOutEditCtrl(
        $scope, $http, $rootScope, $ionicModal, modalManager, $ionicPopup, $state, $stateParams, selectOrgService,
        scanUtils, $timeout, ynuiNotification, ynNavigator) {
        var vm = this;

        vm.chooseTeacher = chooseTeacher;
        vm.chooseTeacherCallback = chooseTeacherCallback;
        vm.chooseOrg = chooseOrg;
        vm.showGoodsInfoSelectorModal = showGoodsInfoSelectorModal;
        vm.goodInfoSelectorCallback = goodInfoSelectorCallback;
        vm.removeSelectGoodsInfo = removeSelectGoodsInfo;
        vm.changeSelectCount = changeSelectCount;
        vm.onChangeSelectCount = onChangeSelectCount;
        vm.getSelectCount = getSelectCount;
        vm.doSave = doSave;
        vm.padCallback = padCallback;
        vm.scan = scan;

        vm.requestTypeArr = [
            {id: 0, name: '个人领用'},
            {id: 1, name: '部门领用'}
        ];

        vm.usedTypeArr = [
            {id: 0, name: '办公耗材'}
        ];

        vm.outReasonArr = [
            {id: 1, name: '领用/借用'},
            {id: 2, name: '物品损坏'},
            {id: 3, name: '物品遗失'},
            {id: 4, name: '物品过期'},
            {id: 0, name: '其他'}
        ];

        vm.signature = false;

        vm.editObj = {
            id: $stateParams.id,
            requestType: 0,
            usedType: 0,
            requestUserId: null,
            requestOrgNo: null,
            requestDate: null,
            outReason: 1,
            remarks: null,
            dealOperatorId: null,
            dealOperatorName: null,
            dealDate: null,
            goodsInfoVOS: []
        };

        vm.roomIds = [];

        vm.goodsInfoSelectorModal = null;

        vm.selectedObj = [];

        $timeout(function () {
            if (vm.editObj.id) {
                findRoomsByUserId().success(function () {
                    findOne().success(function () {
                        findUserByUserId($rootScope.authorizationStr.userId, true);
                    });
                });
            } else {
                findRoomsByUserId().success(function () {
                    // 从物品过来的，直接加载物品
                    if ($stateParams.goodsInfoId) {
                        var obj = {zcGoodsInfoId: $stateParams.goodsInfoId, total: 0};
                        goodInfoSelectorCallback([obj]);
                    }
                });
                findUserByUserId($rootScope.authorizationStr.userId, true);
            }
            getSignatureSetting();
        }, 500);

        function findOne() {
            return $http.get(
                originBaseUrl + '/third/zc/bill/out/' + vm.editObj.id + '.htm', {
                    params: {
                        roomIds: vm.roomIds
                    }
                }
            ).success(function (data) {
                if (0 === data.status) {
                    vm.editObj = data.result;
                    if (null == vm.editObj.requestType) {
                        vm.editObj.requestType = 0;
                    }
                    // 处理已选物品
                    angular.forEach(vm.editObj.goodsInfoVOS, function (goodsInfo) {
                        var total = 0;
                        var ableTotal = 0;
                        angular.forEach(goodsInfo.countList, function (count) {
                            total += count.selectCount;
                            ableTotal += count.ableTotal;
                        });
                        vm.selectedObj.push({
                            zcGoodsInfoId: goodsInfo.zcGoodsInfoId
                            , total: total
                            , unit: goodsInfo.unit
                            , number: goodsInfo.zcGoodsInfoNumber
                            , name: goodsInfo.zcGoodsInfoName
                            , ableTotal: ableTotal
                            , specification: goodsInfo.specification
                        });
                    });
                }
            });
        }

        function findUserByUserId(userId, isDeal) {
            return $http.get(
                originBaseUrl + '/third/zc/bill/out/user/' + userId + '.htm'
            ).success(function (data) {
                if (0 === data.status && isDeal) {
                    vm.editObj.dealOperatorId = data.result.id;
                    vm.editObj.dealOperatorName = data.result.name;
                    vm.editObj.dealDate = data.result.date;
                    if (null == vm.editObj.requestDate) {
                        vm.editObj.requestDate = data.result.date;
                    }
                }
                return data;
            });
        }

        function findRoomsByUserId() {
            return $http.get(
                originBaseUrl + '/third/zc/room/' + $rootScope.authorizationStr.userId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    angular.forEach(data.result, function (r) {
                        vm.roomIds.push(r.id);
                    });
                }
                return data;
            });
        }

        function getSignatureSetting() {
            return $http.get(
                originBaseUrl + '/third/zc/bill/out/signature/setting/JZGLJY.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.signature = 1 === data.result;
                }
                return data;
            });
        }

        function chooseTeacher() {
            if (!modalManager.exist('chooseAllTeacher')) {
                $ionicModal.fromTemplateUrl('teacher-selector.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    modalManager.put('chooseAllTeacher', modal);
                    modal.show();
                    ynNavigator.registerBackAction(function () {
                        modalManager.remove('chooseAllTeacher');
                        ynNavigator.cancelBackAction(201);
                    }, 201);
                });
            } else {
                modalManager.show('chooseAllTeacher');
                ynNavigator.registerBackAction(function () {
                    modalManager.remove('chooseAllTeacher');
                    ynNavigator.cancelBackAction(201);
                }, 201);
            }
        }

        function chooseTeacherCallback(teacher) {
            if (teacher) {
                findUserByUserId(teacher.userId).success(function (data) {
                    if (0 === data.status) {
                        vm.editObj.requestUserId = data.result.id;
                        vm.editObj.requestUserName = data.result.name;
                        vm.editObj.requestOrgNo = data.result.orgNo;
                        vm.editObj.requestOrgName = data.result.orgName;
                    }
                });
            }
        }

        function chooseOrg() {
            selectOrgService.singleSelect(function (item) {
                vm.editObj.requestOrgNo = item.id;
                vm.editObj.requestOrgName = item.name;
            });
        }


        function dealStorageRoomCount(voList) {
            var saveData = [];
            angular.forEach(voList, function (data) {
                saveData.push({zcGoodsInfoId: data.zcGoodsInfoId, total: data.total});
            });
            return saveData;
        }

        function getByStorageRoomCount(voList) {
            var saveData = dealStorageRoomCount(voList);
            var config = {
                url: originBaseUrl + '/third/zc/bill/out/room/storage.htm',
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                params: {
                    roomIds: vm.roomIds.join(','),
                    type: 1,
                    access_token: $rootScope.authorizationStr.access_token
                },
                dataType: 'JSON',
                data: JSON.stringify(saveData)
            }
            return $http(config).success(function (data) {
                return data;
            });
        }

        // 点击添加物品的弹框
        function showGoodsInfoSelectorModal() {
            $ionicModal.fromTemplateUrl('goods-info-selector.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                vm.goodsInfoSelectorModal = modal;
                modal.show();
                //框架返回拦截注册模态框 qiucheng Lu 2021年4月23日
                ynNavigator.registerBackAction(function () {
                    goodInfoSelectorCallback();
                }, 201);
            });
        }

        function goodInfoSelectorCallback(selectObjArr) {
            if (null != vm.goodsInfoSelectorModal) {
                vm.goodsInfoSelectorModal.remove();
            }
            // 请求获取各库房数据
            if (selectObjArr && 0 < selectObjArr.length) {
                getByStorageRoomCount(selectObjArr).success(function (data) {
                    if (0 === data.status) {
                        vm.editObj.goodsInfoVOS = data.result;
                    }
                });
            }
            //框架返回拦截模态框取消注册 qiucheng Lu 2021年4月23日
            ynNavigator.cancelBackAction(201);
        }

        function removeSelectGoodsInfo(index, obj) {
            if (0 === vm.editObj.goodsInfoVOS.length) {
                return false;
            }
            $ionicPopup.confirm({
                title: '提示',
                template: null == obj ? '确定要清空所有吗？' : '确定要移除“' + obj.zcGoodsInfoName + '”吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    if (null != obj) {
                        vm.editObj.goodsInfoVOS.splice(index, 1);
                        vm.selectedObj.splice(index, 1);
                    } else {
                        vm.editObj.goodsInfoVOS = [];
                        vm.selectedObj = [];
                    }
                }
            });
        }

        function changeSelectCount(c, step, g) {
            if (c.selectCount) {
                var numbers = (c.selectCount + '').split('.');
                var number = parseInt(numbers[0]) + step;
                c.selectCount = parseFloat(number + '.' + numbers[1]);
            } else {
                c.selectCount = step;
            }
            if (0 > c.selectCount) {
                c.selectCount = 0;
            } else if (c.selectCount > c.ableTotal) {
                c.selectCount = c.ableTotal;
            }
            changeSelectedObj(g);
        }

        function onChangeSelectCount(c, g) {
            if ((c.selectCount && c.selectCount > c.ableTotal) || angular.isUndefined(c.selectCount)) {
                if (c.ableTotal) {
                    ynuiNotification.error({msg: '超过库存了，最多只能选择' + c.ableTotal + g.unit});
                    c.selectCount = c.ableTotal;
                } else {
                    c.selectCount = 0;
                }
            } else if (null == c.selectCount) {
                c.selectCount = 0;
            }
            var numbers = (c.selectCount + '').split('.');
            if (2 === numbers.length && 2 < numbers[1].length) {
                ynuiNotification.error({msg: '只能输入两位小数'});
                numbers[1] = numbers[1].substr(0, 2);
            }
            c.selectCount = parseFloat(numbers.join('.'));
            changeSelectedObj(g);
        }

        function getSelectCount(g) {
            var result = 0;
            angular.forEach(g.countList, function (c) {
                result += Math.round(c.selectCount * 100);
            });
            return result / 100 + ' ' + g.unit;
        }

        function changeSelectedObj(g) {
            angular.forEach(vm.selectedObj, function (obj) {
                if (obj.zcGoodsInfoId === g.zcGoodsInfoId) {
                    obj.total = 0;
                    angular.forEach(g.countList, function (countVO) {
                        obj.total += Math.round(countVO.selectCount * 100);
                    });
                    obj.total = obj.total / 100;
                }
            });
        }

        function save(obj) {
            var config = {
                url: originBaseUrl + '/third/zc/bill/out/create.htm',
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                params: {
                    userId: $rootScope.authorizationStr.userId,
                    access_token: $rootScope.authorizationStr.access_token
                },
                dateType: 'JSON',
                data: JSON.stringify(obj)
            };
            return $http(config).success(function (data) {
                if (0 === data.status && 0 === data.result.length) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: 0 === obj.status ? '保存成功' : '提交成功',
                        okText: '确定'
                    }).then(function () {
                        $state.go('billOut', {}, {location: 'replace'});
                    });
                } else if (0 === data.status && 0 < data.result.length) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.result[0].failedReason,
                        okText: '确定'
                    }).then(function () {
                    });
                }
            });
        }

        function doSave(status) {
            if (1 === vm.editObj.outReason) {
                if (null == vm.editObj.requestUserId) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '请选择领用人',
                        okText: '确定'
                    });
                    return false;
                }
                if (null == vm.editObj.requestOrgNo && 1 === vm.editObj.requestType) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '请选择领用部门',
                        okText: '确定'
                    });
                    return false;
                }
            } else {
                vm.editObj.requestUserId = null;
                vm.editObj.requestUserName = null;
                vm.editObj.requestOrgNo = null;
                vm.editObj.requestOrgName = null;
                vm.editObj.requestType = null;
            }
            if (0 === vm.editObj.goodsInfoVOS.length) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '您还没有添加任何物品',
                    okText: '确定'
                });
                return false;
            } else {
                var result = false;
                angular.forEach(vm.editObj.goodsInfoVOS, function (vo) {
                    var count = 0;
                    var noAuth = "";
                    angular.forEach(vo.countList, function (c) {
                        count += c.selectCount;
                        if (-1 === vm.roomIds.indexOf(c.zcStoreRoomId) && '' === noAuth) {
                            noAuth = c.zcStoreRoomName;
                        }
                    });
                    if (0 === count && !result) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '“' + vo.zcGoodsInfoName + '”的合计所选数量不能为0',
                            okText: '确定'
                        });
                        result = true;
                    }
                    if (noAuth && !result) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '“' + noAuth + '”库房的物品已不是你管理，请把该库房的物品移除再提交',
                            okText: '确定'
                        });
                        result = true;
                    }
                });
                if (result) {
                    return false;
                }
            }
            vm.editObj.status = status;
            // 需要签字
            if (1 === status && vm.signature && 1 === vm.editObj.outReason) {
                showSignaturePad();
            } else {
                save(vm.editObj);
            }
        }

        function showSignaturePad() {
            $ionicModal.fromTemplateUrl('signature-pad.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                modal.show();
                modalManager.put('signaturePadModal', modal);
            });
        }

        function padCallback(fsId) {
            vm.editObj.fsId = fsId
            save(vm.editObj);
        }

        function scan() {
            scanUtils.scanTeacherQRCode().then(function (res) {
                if (null != res && 200 === res.status && 0 === res.data.status) {
                    if (res.data.result) {
                        vm.editObj.requestUserId = res.data.result.id;
                        vm.editObj.requestUserName = res.data.result.name;
                    } else {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '未查询到教职工信息',
                            okText: '确定'
                        });
                    }
                }
            });
        }
    }

    //退库单
    billReturnCtrl.$inject = ['$scope', '$http', '$rootScope', '$ionicModal', '$timeout', '$ionicScrollDelegate',
        'modalManager', 'selectOrgService', '$state', '$ionicPopup', 'scanUtils','ynNavigator'];

    function billReturnCtrl(
        $scope, $http, $rootScope, $ionicModal, $timeout, $ionicScrollDelegate, modalManager, selectOrgService, $state,
        $ionicPopup, scanUtils,ynNavigator) {

        var vm = this;

        vm.changeNumber = changeNumber;
        vm.changeSort = changeSort;
        vm.changeStatus = changeStatus;
        vm.changeDealDate = changeDealDate;
        vm.loadMoreData = loadMoreData;
        vm.selectStorageRoom = selectStorageRoom;
        vm.chooseTeacher = chooseTeacher;
        vm.chooseOrg = chooseOrg;
        vm.reInitConditions = reInitConditions;
        vm.confirmConditions = confirmConditions;
        vm.gotoBillReturnEdit = gotoBillReturnEdit;
        vm.gotoBillOut = gotoBillOut;
        vm.doDelete = doDelete;
        vm.doRevertStatus = doRevertStatus;
        vm.showBillReturnDetail = showBillReturnDetail;
        vm.hideBillReturnDetail = hideBillReturnDetail;
        vm.showSignaturePad = showSignaturePad;
        vm.padCallback = padCallback;
        vm.scan = scan;

        vm.conditions = {
            type: 0,
            asc: false,
            number: null,
            status: null,
            // 默认近7天
            dealDays: '7',
            zcStoreRoomId: null,
            returnUserId: null,
            returnUserName: null,
            returnOrgNo: null,
            returnOrgName: null,
            returnType: null,
            returnDate: null,
            zcGoodsInfoNumber: null,
            zcGoodsInfoName: null,
            dealOperatorId: null,
            dealDate: null,
            pageNumber: -1,
            pageSize: 10
        };

        vm.storageRoomIds = [];

        vm.selectBillReturnId = null;
        vm.billReturnDetailModal = null;

        // 更多条件
        $ionicModal.fromTemplateUrl('more-conditions.html', {
            scope: $scope,
            animation: 'slide-in-left'
        }).then(function (modal) {
            vm.moreConditionsModal = modal;
        });

        $timeout(function () {
            findRoom().success(function (data) {
                if (0 === data.status) {
                    // 第一次进入页面 ion-infinite-scroll 去加载数据
                    $timeout(function () {
                        vm.moreDataCanBeLoaded = true;
                    }, 100);
                }
            });
        }, 500);

        function changeNumber() {
            if (vm.timer) {
                $timeout.cancel(vm.timer);
            }
            vm.timer = $timeout(function () {
                loadMoreData(true);
            }, 1000);
        }

        function changeSort(type, asc) {
            vm.conditions.type = type;
            vm.conditions.asc = asc;
            loadMoreData(true);
        }

        function changeStatus(status) {
            vm.conditions.status = status;
            loadMoreData(true);
        }

        function changeDealDate(dealDays) {
            vm.conditions.dealDays = dealDays;
            loadMoreData(true);
        }

        function findByConditions(obj) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/return/page.htm', obj
            ).success(function (data) {
                if (0 === data.status) {
                    vm.billReturnPage = data.result;
                    // 判断是否最后一页数据，最后一页隐藏 ion-infinite-scroll
                    vm.moreDataCanBeLoaded = !vm.billReturnPage.lastPage;
                }
                return data;
            });
        }

        function loadMoreData(init) {
            // 页码
            if (init) {
                vm.conditions.pageNumber = -1;
            }
            vm.conditions.pageNumber += 1;
            // 库房
            if (0 < vm.storageRoomIds.length) {
                vm.conditions.zcStoreRoomId = vm.storageRoomIds.join(',');
            } else {
                var roomIds = [];
                angular.forEach(vm.storageRooms, function (r) {
                    roomIds.push(r.id);
                });
                vm.conditions.zcStoreRoomId = roomIds.join(',');
            }
            // 查询
            findByConditions(vm.conditions).success(function (data) {
                if (0 === data.status) {
                    if (init || null == vm.billReturns) {
                        vm.billReturns = data.result.content;
                        $ionicScrollDelegate.$getByHandle('bill-return').scrollTop(true);
                    } else {
                        vm.billReturns = vm.billReturns.concat(data.result.content);
                    }
                }
            }).finally(function () {
                $scope.$broadcast('scroll.refreshComplete');
                $scope.$broadcast('scroll.infiniteScrollComplete');
            });
        }

        function findRoom() {
            return $http.get(
                originBaseUrl + '/third/zc/room/' + $rootScope.authorizationStr.userId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.storageRooms = data.result;
                }
            });
        }

        function selectStorageRoom(id) {
            if (id) {
                var i = vm.storageRoomIds.indexOf(id);
                if (0 <= i) {
                    vm.storageRoomIds.splice(i, 1);
                } else {
                    vm.storageRoomIds.push(id);
                }
            } else {
                vm.storageRoomIds = [];
            }
        }

        function chooseTeacher(type) {
            if ('return' === type) {
                vm.chooseTeacherCallback = function (teacher) {
                    if (teacher) {
                        vm.conditions.returnUserId = teacher.userId;
                        vm.conditions.returnUserName = teacher.name;
                    }
                }
            } else {
                vm.chooseTeacherCallback = function (teacher) {
                    if (teacher) {
                        vm.conditions.dealOperatorId = teacher.userId;
                        vm.conditions.dealOperatorName = teacher.name;
                    }
                }
            }
            if (!modalManager.exist('chooseAllTeacher')) {
                $ionicModal.fromTemplateUrl('teacher-selector.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    modalManager.put('chooseAllTeacher', modal);
                    modal.show();
                    ynNavigator.registerBackAction(function () {
                        modalManager.remove('chooseAllTeacher');
                        ynNavigator.cancelBackAction(201);
                    }, 201);
                });
            } else {
                modalManager.show('chooseAllTeacher');
                ynNavigator.registerBackAction(function () {
                    modalManager.remove('chooseAllTeacher');
                    ynNavigator.cancelBackAction(201);
                }, 201);
            }
        }

        function chooseOrg() {
            if (vm.moreConditionsModal.isShown()) {
                vm.moreConditionsModal.hide().then(function () {
                    selectOrgService.singleSelect(function (item) {
                        vm.conditions.returnOrgNo = item.id;
                        vm.conditions.returnOrgName = item.name;
                        vm.moreConditionsModal.show();
                    });
                });
            } else {
                vm.moreConditionsModal.show();
            }
        }

        function reInitConditions() {
            vm.storageRoomIds = [];
            vm.conditions.zcStoreRoomId = null;
            vm.conditions.returnUserId = null;
            vm.conditions.returnUserName = null;
            vm.conditions.returnOrgNo = null;
            vm.conditions.returnOrgName = null;
            vm.conditions.returnType = null;
            vm.conditions.returnDate = null;
            vm.conditions.zcGoodsInfoNumber = null;
            vm.conditions.zcGoodsInfoName = null;
            vm.conditions.dealOperatorId = null;
            vm.conditions.dealOperatorName = null;
            vm.conditions.dealDate = null;
            loadMoreData(true);
        }

        function confirmConditions() {
            vm.moreConditionsModal.hide().then(function () {
                loadMoreData(true);
            });
        }

        function gotoBillReturnEdit(id) {
            if (id) {
                $state.go('billReturnEdit2', {id: id});
            } else {
                $state.go('billReturnEdit2');
            }
        }

        function gotoBillOut() {
            $state.go('billOut', {status: 2});
        }

        function deleteById(id) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/return/delete/' + id + '.htm'
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '删除成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                }
                return data;
            });
        }

        function doDelete(id) {
            $ionicPopup.confirm({
                title: '提示',
                template: '您确认要删除该退库单吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    deleteById(id);
                }
            });
        }

        function revertStatus(id) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/return/revert/' + id + '.htm'
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '撤回成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                }
                return data;
            });
        }

        function doRevertStatus(id) {
            $ionicPopup.confirm({
                title: '提示',
                template: '您确认将该退库单撤回为草稿状态吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    revertStatus(id);
                }
            });
        }

        function showBillReturnDetail(id) {
            vm.selectBillReturnId = id;
            if (null == vm.billReturnDetailModal) {
                $ionicModal.fromTemplateUrl('bill-return-detail.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    vm.billReturnDetailModal = modal;
                    modal.show();
                });
            } else {
                vm.billReturnDetailModal.show();
            }
        }

        function hideBillReturnDetail() {
            if (null != vm.billReturnDetailModal) {
                vm.billReturnDetailModal.remove().then(function () {
                    vm.billReturnDetailModal = null;
                });
            }
        }

        function signatureConfirm(fsId) {
            return $http.post(
                originBaseUrl + '/third/zc/bill/return/signature/' + vm.selectBillReturnId + '.htm', {}, {
                    params: {
                        fsId: fsId
                    }
                }
            ).success(function (data) {
                if (0 === data.status && null == data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '操作成功',
                        okText: '确定'
                    });
                    loadMoreData(true);
                } else if (0 === data.status && null != data.result) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.result,
                        okText: '确定'
                    });
                }
            });
        }

        function showSignaturePad(id) {
            vm.selectBillReturnId = id;
            $ionicModal.fromTemplateUrl('signature-pad.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                modal.show();
                modalManager.put('signaturePadModal', modal);
            });
        }

        function padCallback(fsId) {
            // 保存
            if (fsId) {
                signatureConfirm(fsId);
            }
        }

        function scan() {
            scanUtils.scanTeacherQRCode().then(function (res) {
                if (null != res && 200 === res.status && 0 === res.data.status) {
                    if (res.data.result) {
                        vm.conditions.number = res.data.result.name;
                        loadMoreData(true);
                    } else {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '未查询到教职工信息',
                            okText: '确定'
                        });
                    }
                }
            });
        }

    }

    //退库单明细
    function billReturnDetail() {
        return {
            restrict: 'E',
            templateUrl: 'templates/zc/admin/billReturnDetail.html',
            scope: {
                billReturnId: '=',
                clickCloseFun: '='
            },
            link: link,
            controller: ctrl,
            controllerAs: 'vm',
            bindToController: true
        }

        function link() {

        }

        ctrl.$inject = ['$scope', '$http', '$timeout']

        function ctrl($scope, $http, $timeout) {

            var vm = this;

            vm.originBaseUrl = originBaseUrl;
            vm.detail = null;

            $timeout(function () {
                findOne();
            }, 500);

            function findOne() {
                return $http.get(
                    originBaseUrl + '/third/zc/bill/return/' + vm.billReturnId + '.htm'
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.detail = data.result;
                    }
                    return data;
                });
            }
        }
    }

    //退库
    billReturnEditCtrl.$inject = ['$scope', '$http', '$state', '$stateParams', 'modalManager', '$ionicModal',
        'selectOrgService', '$rootScope', '$ionicPopup', 'scanUtils', '$timeout', 'ynuiNotification', 'ynNavigator'];

    function billReturnEditCtrl(
        $scope, $http, $state, $stateParams, modalManager, $ionicModal, selectOrgService, $rootScope, $ionicPopup,
        scanUtils, $timeout, ynuiNotification, ynNavigator) {
        var vm = this;
        vm.chooseTeacher = chooseTeacher;
        vm.chooseTeacherCallback = chooseTeacherCallback;
        vm.chooseOrg = chooseOrg;
        vm.showGoodsInfoSelectorModal = showGoodsInfoSelectorModal;
        vm.goodInfoSelectorCallback = goodInfoSelectorCallback;
        vm.removeSelectGoodsInfo = removeSelectGoodsInfo;
        vm.getSelectCount = getSelectCount;
        vm.getNotReturnedTotal = getNotReturnedTotal;
        vm.changeSelectCount = changeSelectCount;
        vm.onChangeSelectCount = onChangeSelectCount;
        vm.changeNotReturnedReason = changeNotReturnedReason;
        vm.doSave = doSave;
        vm.showLostRegister = showLostRegister;
        vm.hideLostRegister = hideLostRegister;
        vm.padCallback = padCallback;
        vm.scan = scan;

        ynNavigator.registerBackAction(function () {
            if ($stateParams.billOutId || $stateParams.prev) {
                $state.go('billOut', {status: 2});
            } else {
                ynNavigator.pop(true);
            }
        }, 101);

        vm.requestTypeArr = [
            {id: 0, name: '个人领用退库'},
            {id: 1, name: '部门领用退库'}
        ];

        vm.usedTypeArr = [
            {id: 0, name: '办公耗材'}
        ];
        vm.editObj = {
            id: $stateParams.id,
            zcStorageBillOutId: $stateParams.billOutId,
            returnType: 0,
            usedType: 0,
            returnUserId: null,
            returnOrgNo: null,
            returnDate: null,
            remarks: null,
            dealOperatorId: null,
            dealOperatorName: null,
            dealDate: null,
            infoVOList: []
        };

        vm.selectorType = $stateParams.billOutId ? 3 : 2;

        vm.signature = false;

        vm.roomIds = [];

        vm.selectedObj = [];

        $timeout(function () {
            if (vm.editObj.id || vm.editObj.zcStorageBillOutId) {
                findRoomsByUserId().success(function () {
                    findOne().success(function () {
                        findUserByUserId($rootScope.authorizationStr.userId, true);
                    });
                });
            } else {
                findRoomsByUserId().success(function () {
                    findUserByUserId($rootScope.authorizationStr.userId, true);
                    if ($stateParams.goodsInfoId) {
                        var obj = {zcGoodsInfoId: $stateParams.goodsInfoId, total: 0};
                        goodInfoSelectorCallback([obj]);
                    }
                });
            }
            getSignatureSetting();
        }, 500);

        function findOne() {
            var url = originBaseUrl + '/third/zc/bill/return/' + vm.editObj.id + '.htm';
            if (vm.editObj.zcStorageBillOutId) {
                url = originBaseUrl + '/third/zc/bill/return/bill/out/' + vm.editObj.zcStorageBillOutId + '.htm';
            }
            return $http.post(url, {roomIds: vm.roomIds}, {
                params: {
                    access_token: $rootScope.authorizationStr.access_token
                }
            }).success(function (data) {
                if (0 === data.status) {
                    vm.editObj = data.result;
                    if ($stateParams.billOutId &&
                        vm.editObj.id && (null == vm.editObj.infoVOList || 0 === vm.editObj.infoVOList)) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: vm.editObj.id,
                            okText: '确定'
                        }).then(function () {
                            window.history.back();
                        });
                    } else {
                        // 处理已选物品
                        angular.forEach(vm.editObj.infoVOList, function (infoVO) {
                            var total = 0;
                            var needTotal = 0;
                            angular.forEach(infoVO.countVOList, function (count) {
                                total += count.total;
                                needTotal += count.needTotal;
                            });
                            vm.selectedObj.push({
                                zcGoodsInfoId: infoVO.zcGoodsInfoId
                                , total: total
                                , unit: infoVO.unit
                                , number: infoVO.zcGoodsInfoNumber
                                , name: infoVO.zcGoodsInfoName
                                , ableTotal: needTotal
                                , specification: infoVO.specification
                            });
                        });
                    }
                }
            });
        }

        function findUserByUserId(userId, isDeal) {
            return $http.get(
                originBaseUrl + '/third/zc/bill/out/user/' + userId + '.htm'
            ).success(function (data) {
                if (0 === data.status && isDeal) {
                    vm.editObj.dealOperatorId = data.result.id;
                    vm.editObj.dealOperatorName = data.result.name;
                    vm.editObj.dealDate = data.result.date;
                    if (null == vm.editObj.returnDate) {
                        vm.editObj.returnDate = data.result.date;
                    }
                }
                return data;
            });
        }

        function findRoomsByUserId() {
            return $http.get(
                originBaseUrl + '/third/zc/room/' + $rootScope.authorizationStr.userId + '.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    angular.forEach(data.result, function (r) {
                        vm.roomIds.push(r.id);
                    });
                }
                return data;
            });
        }

        function getSignatureSetting() {
            return $http.get(
                originBaseUrl + '/third/zc/bill/out/signature/setting/JZGGH.htm'
            ).success(function (data) {
                if (0 === data.status) {
                    vm.signature = 3 === data.result;
                }
                return data;
            });
        }

        function chooseTeacher() {
            if (!modalManager.exist('chooseAllTeacher')) {
                $ionicModal.fromTemplateUrl('teacher-selector.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    modalManager.put('chooseAllTeacher', modal);
                    modal.show();
                    ynNavigator.registerBackAction(function () {
                        modalManager.remove('chooseAllTeacher');
                        ynNavigator.cancelBackAction(201);
                    }, 201);
                });
            } else {
                modalManager.show('chooseAllTeacher');
                ynNavigator.registerBackAction(function () {
                    modalManager.remove('chooseAllTeacher');
                    ynNavigator.cancelBackAction(201);
                }, 201);
            }
        }

        function chooseTeacherCallback(teacher) {
            if (teacher) {
                findUserByUserId(teacher.userId).success(function (data) {
                    if (0 === data.status) {
                        vm.editObj.returnUserId = data.result.id;
                        vm.editObj.returnUserName = data.result.name;
                        vm.editObj.returnOrgNo = data.result.orgNo;
                        vm.editObj.returnOrgName = data.result.orgName;
                    }
                });
            }
        }

        function chooseOrg() {
            selectOrgService.singleSelect(function (item) {
                vm.editObj.returnOrgNo = item.id;
                vm.editObj.returnOrgName = item.name;
            });
        }

        function dealStorageRoomCount(voList) {
            var saveData = [];
            angular.forEach(voList, function (data) {
                saveData.push({zcGoodsInfoId: data.zcGoodsInfoId, total: data.total});
            });
            return saveData;
        }

        function getByStorageRoomCount(voList) {
            var saveData = dealStorageRoomCount(voList);
            var config = {
                url: originBaseUrl + '/third/zc/bill/out/room/storage.htm',
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                params: {
                    roomIds: vm.roomIds.join(','),
                    type: 2,
                    billOutId: vm.editObj.zcStorageBillOutId,
                    billReturnId: vm.editObj.id,
                    access_token: $rootScope.authorizationStr.access_token
                },
                dataType: 'JSON',
                data: JSON.stringify(saveData)
            }
            return $http(config).success(function (data) {
                return data;
            });
        }

        // 点击添加物品的弹框
        function showGoodsInfoSelectorModal() {
            $ionicModal.fromTemplateUrl('goods-info-selector.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                vm.goodsInfoSelectorModal = modal;
                modal.show();
                ynNavigator.registerBackAction(function () {
                    goodInfoSelectorCallback();
                }, 201);
            });
        }

        function goodInfoSelectorCallback(selectObjArr) {
            if (vm.goodsInfoSelectorModal) {
                vm.goodsInfoSelectorModal.remove();
            }
            // 请求获取各库房数据
            if (selectObjArr && 0 < selectObjArr.length) {
                getByStorageRoomCount(selectObjArr).success(function (data) {
                    if (0 === data.status) {
                        vm.editObj.infoVOList = [];
                        angular.forEach(data.result, function (g) {
                            var obj = {
                                zcGoodsInfoId: g.zcGoodsInfoId,
                                zcGoodsInfoName: g.zcGoodsInfoName,
                                tradeMark: g.tradeMark,
                                specification: g.specification,
                                unit: g.unit,
                                countVOList: []
                            }
                            angular.forEach(g.countList, function (c) {
                                var countObj = {
                                    zcStoreRoomId: c.zcStoreRoomId,
                                    zcStoreRoomName: c.zcStoreRoomName,
                                    zcGoodsInfoId: c.zcGoodsInfoId,
                                    total: c.selectCount,
                                    needTotal: c.ableTotal,
                                    notReturnedTotal: 0,
                                    price: c.price
                                }
                                obj.countVOList.push(countObj);
                            });
                            vm.editObj.infoVOList.push(obj);
                            setNotReturnedReason(obj);
                        });
                    }
                });
            }
            ynNavigator.cancelBackAction(201);
        }

        function removeSelectGoodsInfo(index, obj) {
            if (0 === vm.editObj.infoVOList.length) {
                return false;
            }
            $ionicPopup.confirm({
                title: '提示',
                template: null == obj ? '确定要清空所有吗？' : '确定要移除“' + obj.zcGoodsInfoName + '”吗？',
                cancelText: '取消',
                okText: '确定'
            }).then(function (res) {
                if (res) {
                    if (null != obj) {
                        vm.editObj.infoVOList.splice(index, 1);
                        vm.selectedObj.splice(index, 1);
                    } else {
                        vm.editObj.infoVOList = [];
                        vm.selectedObj = [];
                    }
                }
            });
        }

        function changeSelectCount(c, step, g) {
            if (c.total) {
                var numbers = (c.total + '').split('.');
                var number = parseInt(numbers[0]) + step;
                c.total = parseFloat(number + '.' + numbers[1]);
            } else {
                c.total = step;
            }
            if (0 > c.total) {
                c.total = 0;
            } else if (vm.editObj.zcStorageBillOutId && c.total > c.needTotal) {
                c.total = c.needTotal;
            }
            changeSelectedObj(g);
            setNotReturnedReason(g);
        }

        function onChangeSelectCount(c, g) {
            if (angular.isUndefined(c.total)) {
                if (vm.editObj.zcStorageBillOutId) {
                    ynuiNotification.error({msg: '超过最大值了，最多只能选择' + c.needTotal + g.unit});
                    c.total = c.needTotal;
                } else {
                    c.total = 0;
                }
            } else if (null == c.total) {
                c.total = 0;
            }
            var numbers = (c.total + '').split('.');
            if (2 === numbers.length && 2 < numbers[1].length) {
                ynuiNotification.error({msg: '只能输入两位小数'});
                numbers[1] = numbers[1].substr(0, 2);
            }
            c.total = parseFloat(numbers.join('.'));
            changeSelectedObj(g);
            setNotReturnedReason(g);
        }

        function getSelectCount(g) {
            var result = 0;
            angular.forEach(g.countVOList, function (c) {
                result += Math.round(c.total);
            });
            return result + ' ' + g.unit;
        }

        function getNotReturnedTotal(g) {
            var result = 0;
            angular.forEach(g.countVOList, function (c) {
                result += Math.round(c.needTotal * 100) - Math.round(c.total * 100);
            });
            return result / 100;
        }

        function changeSelectedObj(g) {
            angular.forEach(vm.selectedObj, function (obj) {
                if (obj.zcGoodsInfoId === g.zcGoodsInfoId) {
                    obj.total = 0;
                    angular.forEach(g.countVOList, function (countVO) {
                        obj.total += countVO.total;
                    });
                }
            });
        }

        function setNotReturnedReason(g) {
            var result = getNotReturnedTotal(g);
            g.notReturnedTotal = result;
            if (0 === result) {
                g.notReturnedReason = null;
            } else if (0 < result && null == g.notReturnedReason) {
                g.notReturnedReason = 0;
            }
        }

        function changeNotReturnedReason(g, reason) {
            g.notReturnedReason = reason;
        }

        function save(obj, showTip) {
            var config = {
                url: originBaseUrl + '/third/zc/bill/return/create.htm',
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                params: {
                    userId: $rootScope.authorizationStr.userId,
                    access_token: $rootScope.authorizationStr.access_token
                },
                dateType: 'JSON',
                data: JSON.stringify(obj)
            };
            return $http(config).success(function (data) {
                if (0 === data.status && 0 === data.result.length) {
                    if (showTip) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: 0 === obj.status ? '保存成功' : '提交成功',
                            okText: '确定'
                        }).then(function (r) {
                            if (r) {
                                $state.go('billReturn', {}, {location: 'replace'});
                            }
                        });
                    }
                } else if (0 === data.status && 0 < data.result.length) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.result[0].failedReason,
                        okText: '确定'
                    }).then(function () {
                    });
                }
                return data;
            });
        }

        function doSave(status) {
            if (null == vm.editObj.returnUserId) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请选择归还人',
                    okText: '确定'
                });
                return false;
            }
            if (null == vm.editObj.returnOrgNo && 1 === vm.editObj.returnType) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '请选择归还部门',
                    okText: '确定'
                });
                return false;
            }
            if (0 === vm.editObj.infoVOList.length) {
                $ionicPopup.alert({
                    title: '提示',
                    template: '您还没有添加任何物品',
                    okText: '确定'
                });
                return false;
            } else {
                var result = false;
                angular.forEach(vm.editObj.infoVOList, function (vo) {
                    var count = 0;
                    var noAuth = "";
                    angular.forEach(vo.countVOList, function (c) {
                        count += c.total;
                        if (-1 === vm.roomIds.indexOf(c.zcStoreRoomId) && '' === noAuth) {
                            noAuth = c.zcStoreRoomName;
                        }
                    });
                    if (0 === count && !result) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '“' + vo.zcGoodsInfoName + '”的合计所选数量不能为0',
                            okText: '确定'
                        });
                        result = true;
                    }
                    if (noAuth && !result) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '“' + noAuth + '”库房的物品已不是你管理，请把该库房的物品移除再提交',
                            okText: '确定'
                        });
                        result = true;
                    }
                });
                if (result) {
                    return false;
                }
            }
            vm.editObj.status = status;
            if (0 === status) {
                save(vm.editObj, true);
            } else {
                if (vm.signature) {
                    showSignaturePad();
                } else {
                    padCallback(null);
                }
            }
        }

        function showLostRegister(lostGoodInfoIds) {
            vm.lostGoodsInfoIds = lostGoodInfoIds;
            if (null == vm.lostRegisterModal) {
                $ionicModal.fromTemplateUrl('lost-register.html', {
                    scope: $scope,
                    animation: 'slide-in-up',
                    backdropClickToClose: false,
                    hardwareBackButtonClose: false
                }).then(function (modal) {
                    vm.lostRegisterModal = modal;
                    modal.show();
                    ynNavigator.registerBackAction(function () {
                        hideLostRegister();
                    }, 201);
                });
            } else {
                vm.lostRegisterModal.show();
                ynNavigator.registerBackAction(function () {
                    hideLostRegister();
                }, 201);
            }
        }

        function hideLostRegister() {
            if (null != vm.lostRegisterModal) {
                vm.lostRegisterModal.remove().then(function () {
                    vm.lostRegisterModal = null;
                    $state.go('billReturn', {}, {location: 'replace'});
                    ynNavigator.cancelBackAction(201);
                });
            }
        }

        function showSignaturePad() {
            $ionicModal.fromTemplateUrl('signature-pad.html', {
                scope: $scope,
                animation: 'slide-in-up',
                backdropClickToClose: false,
                hardwareBackButtonClose: false
            }).then(function (modal) {
                modal.show();
                modalManager.put('signaturePadModal', modal);
            });
        }

        function padCallback(fsId) {
            vm.editObj.fsId = fsId
            // 判断是否有需要登记损坏的
            var lostGoodsInfoIds = [];
            angular.forEach(vm.editObj.infoVOList, function (g) {
                if (1 === g.notReturnedReason) {
                    lostGoodsInfoIds.push(g.zcGoodsInfoId);
                }
            });
            if (0 < lostGoodsInfoIds.length) {
                save(vm.editObj, false).success(function (data) {
                    if (data && 0 === data.status && 0 === data.result.length) {
                        showLostRegister(lostGoodsInfoIds);
                    }
                });
            } else {
                save(vm.editObj, true);
            }
        }

        function scan() {
            scanUtils.scanTeacherQRCode().then(function (res) {
                if (null != res && 200 === res.status && 0 === res.data.status) {
                    if (res.data.result) {
                        vm.editObj.returnUserId = res.data.result.id;
                        vm.editObj.returnUserName = res.data.result.name;
                    } else {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '未查询到教职工信息',
                            okText: '确定'
                        });
                    }
                }
            });
        }
    }

    //报损报失
    function billReturnLostRegister() {
        return {
            restrict: 'E',
            templateUrl: 'templates/zc/admin/billReturnLostRegister.html',
            scope: {
                billOutId: '=',
                lostGoodsInfoIds: '=',
                callback: '='
            },
            link: link,
            controller: billReturnLostRegisterCtrl,
            controllerAs: 'vm',
            bindToController: true
        }

        function link() {

        }

        billReturnLostRegisterCtrl.$inject = ['$scope', '$http', '$rootScope', '$ionicPopup', '$filter', '$timeout', 'ynuiNotification'];

        function billReturnLostRegisterCtrl($scope, $http, $rootScope, $ionicPopup, $filter, $timeout, ynuiNotification) {

            var vm = this;

            vm.changeNotReturnedReason = changeNotReturnedReason;
            vm.changeSelectCount = changeSelectCount;
            vm.onChangeSelectCount = onChangeSelectCount;
            vm.close = close;
            vm.doSave = doSave;

            $timeout(function () {
                findRoomsByUserId().then(function () {
                    findOne();
                });
            }, 500);

            function findRoomsByUserId() {
                return $http.post(
                    originBaseUrl + '/third/zc/room/' + $rootScope.authorizationStr.userId + '.htm', {roomIds: vm.roomIds}
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.roomIds = [];
                        angular.forEach(data.result, function (r) {
                            vm.roomIds.push(r.id);
                        });
                    }
                    return data;
                });
            }

            function findOne() {
                return $http.post(
                    originBaseUrl + '/third/zc/bill/return/bill/out/' + vm.billOutId + '.htm', {
                        roomIds: vm.roomIds
                    }
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.editObj = data.result;
                        if (vm.editObj.id && (null == vm.editObj.infoVOList || 0 === vm.editObj.infoVOList)) {
                            $ionicPopup.alert({
                                title: '提示',
                                template: vm.editObj.id,
                                okText: '确定'
                            }).then(function () {
                                close();
                            });
                        } else {
                            if (vm.lostGoodsInfoIds && 0 < vm.lostGoodsInfoIds.length) {
                                data.result.infoVOList = $filter('filter')(data.result.infoVOList, function (value) {
                                    return 0 <= vm.lostGoodsInfoIds.indexOf(value.zcGoodsInfoId);
                                });
                            }
                            vm.editObj = data.result;
                            angular.forEach(vm.editObj.infoVOList, function (infoVO) {
                                infoVO.notReturnedReason = 1;
                            });
                        }
                    }
                });
            }

            function changeSelectCount(c, step) {
                if (c.total) {
                    var numbers = (c.total + '').split('.');
                    var number = parseInt(numbers[0]) + step;
                    c.total = parseFloat(number + '.' + numbers[1]);
                } else {
                    c.total = step;
                }
                if (0 > c.total) {
                    c.total = 0;
                } else if (vm.editObj.zcStorageBillOutId && c.total > c.needTotal) {
                    c.total = c.needTotal;
                }
            }

            function onChangeSelectCount(c) {
                if (angular.isUndefined(c.total)) {
                    if (vm.editObj.zcStorageBillOutId) {
                        ynuiNotification.error({msg: '最多只能输入' + c.needTotal + c.unit});
                        c.total = c.needTotal;
                    } else {
                        c.total = 0;
                    }
                } else if (null == c.total) {
                    c.total = 0;
                }
                var numbers = (c.total + '').split('.');
                if (2 === numbers.length && 2 < numbers[1].length) {
                    ynuiNotification.error({msg: '只能输入两位小数'});
                    numbers[1] = numbers[1].substr(0, 2);
                }
                c.total = parseFloat(numbers.join('.'));
            }

            function changeNotReturnedReason(g, reason) {
                g.notReturnedReason = reason;
            }

            function close() {
                if (angular.isFunction(vm.callback)) vm.callback('close');
            }

            function lostRegister() {
                var config = {
                    url: originBaseUrl + '/third/zc/bill/return/lost.htm',
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    params: {
                        userId: $rootScope.authorizationStr.userId,
                        access_token: $rootScope.authorizationStr.access_token
                    },
                    dateType: 'JSON',
                    data: JSON.stringify(vm.editObj)
                };
                return $http(config).success(function (data) {
                    return data;
                });
            }

            function doSave() {
                // 判断有为空的情况，不允许提交
                var count = 0;
                // 把已选的值赋给未还
                angular.forEach(vm.editObj.infoVOList, function (g) {
                    angular.forEach(g.countVOList, function (c) {
                        c.notReturnedTotal = c.total;
                        count += c.total;
                    });
                });
                if (0 === count) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: '登记物品总数量为0，不能提交',
                        okText: '确定'
                    });
                    return false;
                }
                lostRegister().success(function (data) {
                    if (0 === data.status && 0 === data.result.length) {
                        $ionicPopup.alert({
                            title: '提示',
                            template: '保存成功',
                            okText: '确定'
                        }).then(function (r) {
                            if (r && angular.isFunction(vm.callback)) {
                                vm.callback('confirm');
                            }
                        });
                    }
                });
            }
        }
    }

    //物品选择器
    function goodsInfoSelector() {
        return {
            restrict: 'E',
            templateUrl: 'templates/zc/admin/goodsInfoSelector.html',
            scope: {
                roomIds: '=',
                selectedObj: '=',
                // 选择器类型：1出库，2退库，3出库单退库
                selectorType: '=',
                billOutId: '=',
                callback: '='
            },
            link: link,
            controller: goodsInfoSelectorCtrl,
            controllerAs: 'vm',
            bindToController: true
        };

        function link() {

        }

        goodsInfoSelectorCtrl.$inject = ['$scope', '$http', '$ionicScrollDelegate', '$timeout', 'scanUtils', '$ionicPopup',
            'ynuiNotification', '$ionicModal'];

        function goodsInfoSelectorCtrl($scope, $http, $ionicScrollDelegate, $timeout, scanUtils, $ionicPopup, ynuiNotification, $ionicModal) {

            var vm = this;

            vm.changeTotalStatus = changeTotalStatus;
            vm.changeNeedReturn = changeNeedReturn;
            vm.nextLevelCategory = nextLevelCategory;
            vm.backLevelCategory = backLevelCategory;
            vm.changeCategory = changeCategory;
            vm.loadMoreData = loadMoreData;
            vm.onChangeSearch = onChangeSearch;
            vm.changeSelectCount = changeSelectCount;
            vm.onChangeSelectCount = onChangeSelectCount;
            vm.editSelectCount = editSelectCount;
            vm.countAll = countAll;
            vm.cancel = cancel;
            vm.confirm = confirm;
            vm.scan = scan;
            vm.showSelectedDialog = showSelectedDialog;
            vm.calculateHeight = calculateHeight;
            vm.changeGoodsNumberCheck = changeGoodsNumberCheck;

            vm.conditions = {
                type: 0,
                asc: true,
                pageNumber: -1,
                pageSize: 10,
                totalStatus: null,
                needReturn: null,
                categoryName: '1',
                roomId: vm.roomIds.join(','),
                billOutId: vm.billOutId
            };

            vm.categoryArr = [];
            vm.categoryParentArr = [];

            vm.goodsInfoPage = null;

            if (null == vm.selectedObj) {
                vm.selectedObj = [];
            }

            $timeout(function () {
                findCategoryByParentId('null').success(function () {
                    // 第一次进入页面 ion-infinite-scroll 去加载数据
                    $timeout(function () {
                        vm.moreDataCanBeLoaded = true;
                    }, 100);
                });
            }, 500);

            $ionicModal.fromTemplateUrl('goods-detail.html', {
                scope: $scope,
                animation: 'slide-in-up'
            }).then(function (modal) {
                $scope.modal2 = modal;
            });

            function showSelectedDialog() {
                if (!vm.selectedObj || vm.selectedObj.length == 0) {
                    return;
                }
                $scope.modal2.show();
                $timeout(function () {
                    calculateHeightSelectedDialog();
                });
            }

            //计算高度
            function calculateHeightSelectedDialog() {
                var height = $(".loading-container").outerHeight();
                var htemp = height * 0.8;
                var out = 0;
                angular.forEach($("#listTest ion-item"), function (item) {
                    out += $(item).outerHeight() + 10;
                });
                if (htemp > out) {
                    vm.itemHeight = {
                        "height": out
                    };
                } else {
                    vm.itemHeight = {
                        "height": htemp
                    };
                }
            }

            function changeTotalStatus(totalStatus) {
                vm.conditions.totalStatus = totalStatus;
                loadMoreData(true);
            }

            function changeNeedReturn(needReturn) {
                vm.conditions.needReturn = needReturn;
                loadMoreData(true);
            }

            function findCategoryByParentId(parentId) {
                vm.categoryArr = [];
                return $http.get(
                    originBaseUrl + '/third/zc/goods/category/' + parentId + '.htm'
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.categoryArr = data.result;
                    }
                    return data;
                });
            }

            function nextLevelCategory(category) {
                vm.categoryParentArr.push(category);
                findCategoryByParentId(category.id);
            }

            function backLevelCategory() {
                var id = 'null';
                if (0 < vm.categoryParentArr.length) {
                    vm.categoryParentArr.splice(vm.categoryParentArr.length - 1, 1);
                    var lastIndex = vm.categoryParentArr.length - 1;
                    if (0 < vm.categoryParentArr.length) {
                        id = vm.categoryParentArr[lastIndex].id;
                    }
                }
                findCategoryByParentId(id);
            }

            function changeCategory(category) {
                vm.conditions.categoryName = category.id;
                loadMoreData(true);
            }

            function findGoodsByStorageRoom(obj) {
                return $http.post(
                    originBaseUrl + '/third/zc/goods/room.htm', obj
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.goodsInfoPage = data.result;
                        // 判断是否最后一页数据，最后一页隐藏 ion-infinite-scroll
                        vm.moreDataCanBeLoaded = !vm.goodsInfoPage.lastPage;
                    }
                    return data;
                });
            }

            function initSelectCount(array) {
                angular.forEach(array, function (c) {
                    angular.forEach(vm.selectedObj, function (obj) {
                        if (obj.zcGoodsInfoId === c.id) {
                            c.selectCount = obj.total;
                        }
                    });
                    if (null == c.selectCount) {
                        c.selectCount = 0;
                    }
                });
            }

            function loadMoreData(init) {
                // 页码
                if (init) {
                    vm.conditions.pageNumber = -1;
                    $ionicScrollDelegate.$getByHandle('goods-info-selector-scroll').scrollTop(true);
                }
                vm.conditions.pageNumber += 1;
                findGoodsByStorageRoom(vm.conditions).success(function (data) {
                    if (0 === data.status) {
                        initSelectCount(data.result.content);
                        if (init || null == vm.goodsInfos) {
                            vm.goodsInfos = data.result.content;
                        } else {
                            vm.goodsInfos = vm.goodsInfos.concat(data.result.content);
                        }
                    }

                }).finally(function () {
                    $scope.$broadcast('scroll.refreshComplete');
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                });
            }

            function onChangeSearch() {
                if (vm.timer) {
                    $timeout.cancel(vm.timer);
                }
                vm.timer = $timeout(function () {
                    loadMoreData(true);
                }, 500);
            }

            //编辑选中的产品
            function editSelectCount(c, step, index) {
                var numbers = (c.total + '').split('.');
                var number = parseInt(numbers[0]) + step;
                c.total = parseFloat(number + '.' + numbers[1]);
                if (0 > c.total) {
                    c.total = 0;
                } else if (2 !== vm.selectorType && c.total > c.ableTotal) {
                    c.total = c.ableTotal;
                }
                calculateHeight(c, index);
            }


            function changeGoodsNumberCheck(c) {
                if (2 !== vm.selectorType
                    && ((c.total && c.total > c.ableTotal) || angular.isUndefined(c.total))) {
                    ynuiNotification.error({msg: '最多只能输入' + c.ableTotal + c.unit});
                    c.total = c.ableTotal;
                } else if (null == c.total) {
                    c.total = 0;
                }
                var numbers = (c.total + '').split('.');
                if (2 === numbers.length && 2 < numbers[1].length) {
                    ynuiNotification.error({msg: '只能输入两位小数'});
                    numbers[1] = numbers[1].substr(0, 2);
                }
                c.total = parseFloat(numbers.join('.'));
            }

            //计算高度
            function calculateHeight(c, index) {
                if (!c.total) {
                    vm.selectedObj.splice(index, 1);
                    if (!vm.selectedObj || vm.selectedObj.length == 0) {
                        $scope.modal2.hide();
                    }
                    $timeout(function () {
                        calculateHeightSelectedDialog();
                    });
                }
                editGoodsNumber(c.zcGoodsInfoId, c.total);
            }

            function editGoodsNumber(goodsId, number) {
                for (var i = 0; i < vm.goodsInfos.length; i++) {
                    var goodsInfo = vm.goodsInfos[i];
                    if (goodsId == goodsInfo.id) {
                        goodsInfo.selectCount = number;
                        return;
                    }
                }
            }

            function changeSelectCount(c, step, isCount) {
                if (c.selectCount) {
                    var numbers = (c.selectCount + '').split('.');
                    var number = parseInt(numbers[0]) + step;
                    c.selectCount = parseFloat(number + '.' + numbers[1]);
                } else {
                    c.selectCount = step;
                }
                if (0 > c.selectCount) {
                    c.selectCount = 0;
                } else if (2 !== vm.selectorType && c.selectCount > c.ableTotal) {
                    c.selectCount = c.ableTotal;
                }
                if (isCount) {
                    countSelected(vm.goodsInfos);
                }
            }

            function onChangeSelectCount(c, isCount) {
                if (2 !== vm.selectorType
                    && ((c.selectCount && c.selectCount > c.ableTotal) || angular.isUndefined(c.selectCount))) {
                    ynuiNotification.error({msg: '最多只能输入' + c.ableTotal + c.unit});
                    c.selectCount = c.ableTotal;
                } else if (null == c.selectCount) {
                    c.selectCount = 0;
                }
                var numbers = (c.selectCount + '').split('.');
                if (2 === numbers.length && 2 < numbers[1].length) {
                    ynuiNotification.error({msg: '只能输入两位小数'});
                    numbers[1] = numbers[1].substr(0, 2);
                }
                c.selectCount = parseFloat(numbers.join('.'));
                if (isCount) {
                    countSelected(vm.goodsInfos);
                }
            }

            function countSelected(arr) {
                angular.forEach(arr, function (info) {
                    var index = -1;
                    angular.forEach(vm.selectedObj, function (obj, i) {
                        if (obj.zcGoodsInfoId === info.id) {
                            index = i;
                        }
                    });
                    if (-1 === index && 0 < info.selectCount) {
                        vm.selectedObj.push({
                            zcGoodsInfoId: info.id
                            , total: info.selectCount
                            , specification: info.specification
                            , ableTotal: info.ableTotal
                            , number: info.number, name: info.name, unit: info.unit
                        });
                    } else if (-1 < index && 0 === info.selectCount) {
                        vm.selectedObj.splice(index, 1);
                    } else if (-1 < index && 0 < info.selectCount) {
                        vm.selectedObj[index].total = info.selectCount;
                    }
                });
            }

            function countAll() {
                var count = 0;
                angular.forEach(vm.selectedObj, function (obj) {
                    count += Math.round(obj.total * 100);
                });
                return count / 100;
            }

            function cancel() {
                vm.callback();
            }

            function confirm() {
                if (0 === vm.selectedObj.length) {
                    // ynuiNotification.error({msg: '您没有选择任何物品！'});
                    // return false;
                }
                vm.callback(vm.selectedObj);
            }

            function findByNumberAndRoomIds(number) {
                return $http.get(originBaseUrl + '/third/zc/goods/' + number + '.htm', {
                    params: {
                        roomIds: vm.roomIds.join(',')
                    }
                }).success(function (data) {
                    return data;
                });
            }

            function scan() {
                scanUtils.scanGoodsInfoQRCode().then(function (data) {
                    if (angular.isUndefined(data) || null == data) {
                        return;
                    }
                    // 查询 '2858359780427250232'
                    findByNumberAndRoomIds(data).success(function (data) {
                        if (0 === data.status && data.result) {
                            // 查询到了
                            vm.scanObj = data.result;
                            vm.scanObj.selectCount = 0;
                            // 之前有选择，默认赋值
                            angular.forEach(vm.selectedObj, function (obj) {
                                if (obj.zcGoodsInfoId === vm.scanObj.id) {
                                    vm.scanObj.selectCount = obj.total;
                                }
                            });
                            $ionicPopup.show({
                                title: vm.scanObj.name,
                                templateUrl: 'scan-detail.html',
                                scope: $scope,
                                buttons: [{
                                    text: '取消',
                                    type: 'button-default',
                                    onTap: function () {
                                        initSelectCount(vm.goodsInfos);
                                    }
                                }, {
                                    text: '确定',
                                    type: 'button-positive',
                                    onTap: function (e) {
                                        if (0 === vm.scanObj.selectCount) {
                                            ynuiNotification.error({'msg': '物品数量必须大于0'});
                                            e.preventDefault();
                                        }
                                        countSelected([vm.scanObj]);
                                    }
                                }],
                                cancelText: '取消',
                                okText: '确定'
                            });
                        } else {
                            // 没有查询到
                            $ionicPopup.alert({
                                title: '提示',
                                template: '未查询到物品信息',
                                okText: '确定'
                            });
                        }
                    });
                });
            }
        }
    }

    //物品信息
    function goodsInfoDetail() {
        return {
            restrict: 'E',
            templateUrl: 'templates/zc/admin/goodsInfoDetail.html',
            scope: {
                roomId: '=',
                goodsId: '=',
                clickCloseFun: '='
            },
            link: link,
            controller: goodsInfoDetailCtrl,
            controllerAs: 'vm',
            bindToController: true
        }

        function link() {

        }

        goodsInfoDetailCtrl.$inject = ['$http', '$timeout'];

        function goodsInfoDetailCtrl($http, $timeout) {

            var vm = this;

            vm.goodsInfo = null;

            $timeout(function () {
                findGoodsInfo();
            }, 500);

            function findGoodsInfo() {
                return $http.get(
                    originBaseUrl + '/third/zc/goods/' + vm.roomId + '/' + vm.goodsId + '.htm'
                ).success(function (data) {
                    if (0 === data.status) {
                        vm.goodsInfo = data.result;
                    }
                    return data;
                });
            }
        }
    }


})();
