package com.yineng.ynbridge

import android.util.Log

/**
 * ClassName CallbackContext
 * User: zuoweichen
 * Date: 2022/3/16 10:47
 * Description: 描述
 */
class CallbackContext {
    private val LOG_TAG = "YnBridgePlugin"
    private val callbackId: String?
    private val webView: YnBridgeWebView
    protected var finished = false

    constructor(callbackId: String?, webView: YnBridgeWebView) {
        this.callbackId = callbackId
        this.webView = webView
    }

    fun success() {
        sendPluginResult(PluginResult(PluginResult.Status.OK))
    }

    fun success(message: String) {
        sendPluginResult(PluginResult(PluginResult.Status.OK, message))
    }
    fun error(message: String) {
        sendPluginResult(PluginResult(PluginResult.Status.ERROR, message))
    }
    @Synchronized
    fun sendPluginResult(pluginResult: PluginResult) {
        if (callbackId.isNullOrEmpty()) {
            Log.w(
                LOG_TAG,
                "The callbackId is empty, either because there is an error or because the JS does not need a callback"
            )
            return
        }
        Log.w(
            LOG_TAG,
            " Attempted to send a second callback for ID: $callbackId Result was: ${pluginResult.getMessage()}".trimIndent()
        )
        synchronized(this) {
            if (finished) {
                return
            } else {
                finished = !pluginResult.getKeepCallback()
            }
        }

        webView.sendPluginResult(pluginResult, callbackId)
    }
}