package com.yineng.ynbridge

import android.content.Context
import android.util.Log
import org.xmlpull.v1.XmlPullParser
import org.xmlpull.v1.XmlPullParserException
import java.io.IOException
import java.util.*
import kotlin.collections.ArrayList

/**
 * ClassName ConfigXmlParser
 * User: zuoweichen
 * Date: 2022/3/17 15:46
 * Description: 描述
 */
class ConfigXmlParser {
    private val pluginEntries = arrayListOf<PluginEntry>()

    companion object {
        val TAG = "ConfigXmlParser"
    }

    fun getPluginEntries(): ArrayList<PluginEntry> {
        return pluginEntries
    }

    fun parse(context: Context) {
        var id = context.resources.getIdentifier("config", "xml", context.javaClass.`package`?.name)
        if (id == 0) {
            id = context.resources.getIdentifier("config", "xml", context.packageName)
            if (id == 0) {
                Log.e(TAG, "res/xml/config.xml is missing!")
                return
            }
        }
        parse(context.resources.getXml(id))
    }

    var insideFeature = false
    var service = ""
    var pluginClass = ""
    var paramType = ""
    var onload = false
    fun parse(xml: XmlPullParser) {
        var eventType = -1

        while (eventType != XmlPullParser.END_DOCUMENT) {
            if (eventType == XmlPullParser.START_TAG) {
                handleStartTag(xml)
            } else if (eventType == XmlPullParser.END_TAG) {
                handleEndTag(xml)
            }
            try {
                eventType = xml.next()
            } catch (e: XmlPullParserException) {
                e.printStackTrace()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }
    }

    fun handleStartTag(xml: XmlPullParser) {
        val strNode = xml.name
        if (strNode == "feature") {
            insideFeature = true
            service = xml.getAttributeValue(null, "name")
        } else if (insideFeature && strNode == "param") {
            paramType = xml.getAttributeValue(null, "name")
            if (paramType == "service") // check if it is using the older service param
                service = xml.getAttributeValue(
                    null,
                    "value"
                ) else if (paramType == "package" || paramType == "android-package") pluginClass =
                xml.getAttributeValue(null, "value") else if (paramType == "onload") onload =
                "true" == xml.getAttributeValue(null, "value")
        }
    }

    fun handleEndTag(xml: XmlPullParser) {
        val strNode = xml.name
        if (strNode == "feature") {
            pluginEntries.add(PluginEntry(service, pluginClass, onload))
            service = ""
            pluginClass = ""
            insideFeature = false
            onload = false
        }
    }

}