package com.yineng.ynbridge

import android.util.Log
import org.json.JSONException
import org.json.JSONObject

/**
 * ClassName CoreAndroid
 * User: zuoweichen
 * Date: 2022/3/22 14:36
 * Description: 基础核心插件
 */
class CoreAndroid : YnWebPlugin() {
    private val messageChannelLock = Any()
    private var messageChannel: CallbackContext? = null

    companion object {
        const val PLUGIN_NAME: String = "Core"
        const val TAG = "CoreAndroid"
    }

    override fun execute(
        action: String,
        rawArgs: String,
        callbackContext: CallbackContext
    ): Boolean {
        try {
            when (action) {
                //关闭
                "close" -> {
                    this.close()
                }
                "messageChannel" -> {
                    synchronized(messageChannelLock) {
                        messageChannel = callbackContext
                    }

                }
            }
            return true
        } catch (e: Exception) {
            callbackContext.sendPluginResult(
                PluginResult(
                    PluginResult.Status.ERROR,
                    e.message ?: ""
                )
            )
            return false
        }

    }

    fun fireJavascriptEvent(action: String) {
        sendEventMessage(action)
    }

    private fun sendEventMessage(action: String) {
        val obj = JSONObject()
        try {
            obj.put("eventName", action)
        } catch (e: JSONException) {
            Log.e(TAG, "Failed to create event message", e)
        }
        sendEventMessage(PluginResult(PluginResult.Status.OK, obj))
    }

    private fun sendEventMessage(payload: PluginResult) {
        payload.setKeepCallback(true)
        messageChannel?.sendPluginResult(payload)
    }

    private fun close() {
        webView?.getPluginManager()?.postMessage("close",null)
    }
}