package com.yineng.ynbridge

import android.text.TextUtils
import java.security.SecureRandom

/**
 * ClassName YnBridge
 * User: zuoweichen
 * Date: 2022/3/16 11:31
 * Description: 描述
 */
class YnBridge {
    private var pluginManager: PluginManager

    @Volatile
    private var expectedBridgeSecret = -1 // written by UI thread, read by JS thread.

    constructor(pluginManager: PluginManager) {
        this.pluginManager = pluginManager
    }

    fun jsExec(
        bridgeSecret: Int,
        service: String?,
        action: String?,
        callbackId: String?,
        arguments: String?
    ): String? {
        if (!verifySecret(bridgeSecret)) {
            return null
        }
        // If the arguments weren't received, send a message back to JS.  It will switch bridge modes and try again.  See CB-2666.
        // We send a message meant specifically for this case.  It starts with "@" so no other message can be encoded into the same string.
        if (arguments == null) {
            return "@Null arguments."
        }
        if (!TextUtils.isEmpty(service)
            && !TextUtils.isEmpty(action)
        ) {
            pluginManager.exec(service!!, action!!, callbackId, arguments)
        }
        return ""
    }


    fun promptOnJsPrompt(
        url: String?,
        message: String?,
        defaultValue: String?
    ): String? {
        if (defaultValue?.startsWith("base_init") == true) {
            val secret = generateBridgeSecret()
            return secret.toString()
        }
        return null
    }

    private fun generateBridgeSecret(): Int {
        val randGen = SecureRandom()
        expectedBridgeSecret = randGen.nextInt(Int.MAX_VALUE)
        return expectedBridgeSecret
    }

    private fun verifySecret(bridgeSecret: Int): Boolean {
        if (expectedBridgeSecret < 0 || expectedBridgeSecret != bridgeSecret) {
            return false
        }
        return true
    }
}
