package com.yineng.ynbridge

import android.os.Handler
import android.os.Looper
import android.view.KeyEvent

/**
 * ClassName YnBridgeWebViewImpl
 * User: zuoweichen
 * Date: 2022/3/16 14:25
 * Description: 描述
 */
class YnBridgeWebViewImpl : YnBridgeWebView {
    protected val webViewEngine: YnBridgeWebViewEngine
    private lateinit var pluginManager: PluginManager
    private val engineClient = EngineClient()
    private var appPlugin: CoreAndroid? = null
    private var bridgeInterface: YnBridgeInterface? = null

    constructor(engine: YnBridgeWebViewEngine) {
        this.webViewEngine = engine
    }

    override fun init(bridgeInterface: YnBridgeInterface, pluginEntries: MutableList<PluginEntry>) {
        this.bridgeInterface = bridgeInterface
        pluginManager = PluginManager(this, bridgeInterface, pluginEntries)
        webViewEngine.init(engineClient, pluginManager)

        pluginManager.addService(CoreAndroid.PLUGIN_NAME, CoreAndroid::class.java.name)
        pluginManager.init()
    }

    override fun loadUrl(url: String) {
        webViewEngine.loadUrl(url)
    }

    override fun sendPluginResult(result: PluginResult, callbackId: String) {
        runOnMainThread {
            getEngine().evaluateJavascript(buildJsMessage(result, callbackId), null);
        }
    }

    override fun getEngine(): YnBridgeWebViewEngine {
        return webViewEngine
    }

    override fun getPluginManager(): PluginManager {
        return pluginManager
    }

    private fun buildJsMessage(result: PluginResult, callbackId: String): String {
        val sb = StringBuilder()
        val status = result.getStatus()
        val success =
            (status == PluginResult.Status.OK.ordinal)
        sb.append("YNBridge.nativeCallback('")
            .append(callbackId)
            .append("',")
           /* .append(success)
            .append(",")*/
            .append(status)
            .append(",")
            .append(result.getMessage())
            .append(",")
            .append(result.getKeepCallback())
            .append(");")
        return sb.toString()
    }

    private fun sendJavascriptEvent(event: String) {
        if (appPlugin == null) {
            val plugin = pluginManager.getPlugin(CoreAndroid.PLUGIN_NAME)
            if (plugin != null) {
                appPlugin = plugin as CoreAndroid
            }
        }
        if (appPlugin == null) {
            return
        }
        appPlugin?.fireJavascriptEvent(event)
    }

    private fun runOnMainThread(runnable: Runnable) {
        if (Looper.getMainLooper() == Looper.myLooper()) {
            runnable.run()
            return
        }
        Handler(Looper.getMainLooper()).post(runnable)
    }

    inner class EngineClient : YnBridgeWebViewEngine.Client {
        override fun onDispatchKeyEvent(event: KeyEvent): Boolean? {
            val keyCode = event.keyCode
            if (event.action == KeyEvent.ACTION_DOWN) {

            } else if (event.action == KeyEvent.ACTION_UP) {
                when (keyCode) {
                    KeyEvent.KEYCODE_BACK -> {
                        sendJavascriptEvent("back")
                        return true
                    }
                }
            }
            return null
        }

    }
}